#
# spec file for package kiwi
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
#
# Please submit bugfixes or comments via:
#
#       https://github.com/openSUSE/kiwi/issues
#
#
#perl_verion is not defined in centos/RHEL yet
%if 0%{?rhel_version} || 0%{?centos_version}
%define perl_version    %(eval "`%{__perl} -V:version`"; echo $version)
%endif

Summary:        KIWI - Appliance Builder
Url:            http://github.com/openSUSE/kiwi
Name:           kiwi
License:        GPL-2.0
Group:          System/Management
Version:        7.04.8
Provides:       kiwi-schema = 6.2
Provides:       kiwi-image:aci
Provides:       kiwi-image:lxc
Provides:       kiwi-image:tbz
Provides:       kiwi:%{_mandir}/man1/kiwi.1.gz
Provides:       kiwi:%{_mandir}/man1/KIWI::images.sh.1.gz
Provides:       kiwi:%{_mandir}/man1/KIWI::config.sh.1.gz
Provides:       kiwi:%{_mandir}/man1/KIWI::kiwirc.1.gz
Conflicts:      kiwi-doc < 5
Release:        1.1
# requirements to build packages
BuildRequires:  genisoimage
BuildRequires:  diffutils
BuildRequires:  e2fsprogs
BuildRequires:  gcc-c++
BuildRequires:  libxslt
BuildRequires:  lvm2
BuildRequires:  module-init-tools
BuildRequires:  rsync
BuildRequires:  screen
BuildRequires:  zlib-devel
BuildRequires:  perl-Class-Singleton
BuildRequires:  perl-Config-IniFiles
BuildRequires:  perl-Digest-SHA1
BuildRequires:  perl-File-Slurp
BuildRequires:  perl-JSON
BuildRequires:  perl-Readonly
BuildRequires:  perl-XML-LibXML
BuildRequires:  perl-XML-LibXML-Common
BuildRequires:  perl-XML-SAX
BuildRequires:  perl-libwww-perl
BuildRequires:  perl-Test-Unit-Lite
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
%ifarch %ix86 x86_64
BuildRequires:  syslinux
%endif
%if 0%{?suse_version} > 1140
BuildRequires:  btrfsprogs
BuildRequires:  genisoimage
BuildRequires:  squashfs
BuildRequires:  zypper
%endif
# requirements to run kiwi
Requires:       perl >= %{perl_version}
Requires:       checkmedia
Requires:       coreutils
Requires:       kiwi-tools >= %{version}
Requires:       libxslt
Requires:       perl-Class-Singleton
Requires:       perl-Config-IniFiles >= 2.49
Requires:       perl-Digest-SHA1
Requires:       perl-File-Slurp
Requires:       perl-JSON
Requires:       perl-Readonly
Requires:       perl-XML-LibXML
Requires:       perl-XML-LibXML-Common
Requires:       perl-XML-SAX
Requires:       perl-libwww-perl
Requires:       rsync
Requires:       screen
Requires:       tar >= 1.2.7
Requires:       psmisc
Requires:       util-linux
%if 0%{?suse_version} == 1110
Requires:       sysvinit
%else
Requires:       sysvinit-tools
%endif
%if 0%{?suse_version}
# SUSE specific requires
%if 0%{?suse_version} >= 1210
Requires:       gptfdisk
Requires:       libsolv-tools
Requires:       perl-solv
%else
Requires:       satsolver-tools
Requires:       perl-satsolver >= 0.42
%endif
%if 0%{?suse_version} == 1110
Requires:       virt-utils
%else
Requires:       qemu-tools
%endif
%endif
%if 0%{?rhel_version} || 0%{?fedora} || 0%{?centos}
# RHEL specific requires
Requires:       qemu-img
%endif
# recommended to run kiwi
%if 0%{?suse_version}
Recommends:     db45-utils
Recommends:     db48-utils
%endif
# obsoletes
Obsoletes:      kiwi-desc-usbboot <= 4.81
Obsoletes:      kiwi-desc-xenboot <= 4.81
# sources
Source:         %{name}.tar.bz2
Source1:        %{name}-rpmlintrc
Source2:        %{name}-docu.tar.bz2
Source3:        %{name}-repo.tar.bz2
Source4:        %{name}-find-boot-requires.sh
# build root path
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

# find out about the name scheme of the local system for
# the buildservice needed -requires packages. In terms of
# problems with this magic ask adrian@suse.de for details

%if 0%{?suse_version}
%define mysystems %(echo `export VER=%{suse_version}; echo "suse-${VER:0:2}.${VER:2:1}"`)
# redefine for the SLES case if no sles_version exists
# SLE12:
%if 0%{?suse_version} == 1315 && !0%{?is_opensuse}
%define mysystems suse-SLES12
%endif
# Leap 42.1:
%if 0%{?suse_version} == 1315 && 0%{?is_opensuse}
%define mysystems suse-leap42.1
%endif
# Tumbleweed:
# Current Tumbleweed version, moving target
%if 0%{?suse_version} == 1330
%define mysystems suse-tumbleweed
%endif
# redefine for the SLE11 case if no sles_version exists
# SLE11: NOTE: this works only because openSUSE 11.1 is out of scope
%if 0%{?suse_version} == 1110
%define mysystems suse-SLES11
%endif
%endif

# SLES with sles_version macro
%if 0%{?sles_version}
%define mysystems suse-SLES%{sles_version}
%endif

# RHEL // CentOS
# use the rhel templates for CentOS, too
%if 0%{?rhel_version} == 600 || 0%{?centos_version} == 600
%define mysystems rhel-06.0
%endif
%if 0%{?rhel_version} == 700 || 0%{?centos_version} == 700
%define mysystems rhel-07.0
%endif

# find out about my arch name, could be done also via symlinks
%define myarch %{_target_cpu}
%ifarch armv7l armv7hl
%define myarch armv7l
%endif
%ifarch armv6l armv6hl
%define myarch armv6l
%endif
%ifarch %ix86
%define myarch ix86
%endif

%description
The KIWI Image System provides an operating system image builder
for Linux supported hardware platforms as well as for virtualization
and cloud systems like Xen, KVM, VMware, EC2 and more. The online
documentation can be found here: http://doc.opensuse.org

Authors:
--------
        Marcus Schaefer <ms@suse.com>
        Robert Schweikert <rjschwei@suse.com>

%package -n kiwi-requires
Summary:        KIWI - buildservice package requirements
Provides:       kiwi-filesystem:btrfs
Provides:       kiwi-filesystem:xfs
Provides:       kiwi-filesystem:ext3
Provides:       kiwi-filesystem:ext4
Provides:       kiwi-filesystem:squashfs
Provides:       kiwi-image:docker
Requires:       btrfsprogs
Requires:       e2fsprogs
Requires:       kiwi = %{version}
License:        GPL-2.0
Group:          System/Management
%if 0%{?rhel_version} || 0%{?centos_version}
Provides:       kiwi-packagemanager:yum
Requires:       yum
Requires:       squashfs-tools
%endif
%if 0%{?suse_version}
Provides:       kiwi-packagemanager:zypper
Requires:       zypper
Requires:       squashfs
%endif
%if 0%{?suse_version} > 1120
BuildArch:      noarch
%endif

%description -n kiwi-requires
Meta-package to pull in all requires to prepare a new root system.
It is used by Open Build Service (OBS) to provide and install the
needed packages automatically.

%package -n kiwi-instsource
Provides:       kiwi-packagemanager:instsource
Summary:        KIWI - Product media creator
Requires:       build
Requires:       createrepo
Requires:       inst-source-utils
Requires:       kiwi-instsource-plugin
Requires:       kiwi = %{version}
Requires:       genisoimage
%ifarch %ix86 x86_64
Requires:       syslinux
%endif
License:        GPL-2.0
Group:          System/Management

%description -n kiwi-instsource
This package contains modules used for installation source creation.
With those it is possible to create a valid installation repository
from blank RPM file trees. The created tree can be used directly for
the image creation process afterwards. This package allows using the
--create-instsource <path-to-config.xml> switch.

Authors:
--------
    Adrian Schroeter <adrian@suse.com>
    Stephan Kulow <coolo@suse.com>

%package -n kiwi-doc
Summary:        KIWI - Appliance Builder Documentation
License:        LGPL-2.0+
Group:          Documentation/Howto
%if 0%{?suse_version} > 1120
BuildArch:      noarch
%endif

%description -n kiwi-doc
This package contains the documentation and manual pages for
the KIWI image builder.

Authors:
--------
        Thomas Schraitle <toms@suse.com>
        Marcus Schaefer <ms@suse.com>

%package -n kiwi-tools
Summary:        KIWI - Collection of Boot Helper Tools
License:        GPL-2.0+
Group:          System/Management

%description -n kiwi-tools
This package contains a small set of helper tools used for the
kiwi created initial ramdisk which is used to control the very
first boot of an appliance. The tools are not meant to be used
outside of the scope of kiwi appliance building.

Authors:
--------
        Marcus Schaefer <ms@suse.com>

%ifarch %ix86 x86_64

%package -n kiwi-pxeboot
Summary:        KIWI - PXE boot structure
PreReq:         coreutils
%if 0%{?rhel_version} || 0%{?centos_version}
PreReq:         shadow-utils
%else
%if 0%{?suse_version} > 1220
PreReq:         shadow
%else
PreReq:         pwdutils
%endif
%endif
%ifarch %ix86 x86_64
Requires:       syslinux
%endif
License:        GPL-2.0+
Group:          System/Management

%description -n kiwi-pxeboot
This package contains the basic PXE directory structure which is
needed to serve kiwi built images via PXE.

Authors:
--------
        Marcus Schaefer <ms@suse.com>
%endif

%ifarch %ix86 x86_64

%package -n kiwi-desc-isoboot
Summary:        KIWI - Live ISO boot templates
Requires:       e2fsprogs
Requires:       kiwi = %{version}
%ifarch %ix86 x86_64
Requires:       syslinux
%endif
Requires:       dosfstools
%if 0%{?suse_version}
Requires:       genisoimage
%endif
License:        GPL-2.0+
Group:          System/Management

%description -n kiwi-desc-isoboot
This package contains kiwi boot (initrd) descriptions for booting
live ISO images.

Authors:
--------
        Marcus Schaefer <ms@suse.com>

%package -n kiwi-desc-isoboot-requires
Provides:       kiwi-image:iso
Provides:       kiwi-boot:isoboot
%if 0%{?suse_version}
Requires:       genisoimage
%endif
Requires:       kiwi-desc-isoboot = %{version}
Requires:       %(echo `bash %{S:4} %{S:0} isoboot %{myarch} %{mysystems}`)
%ifarch ppc ppc64 ppc64le
%if 0%{?suse_version} >= 1315
Requires:       grub2-powerpc-ieee1275
%else
Requires:       yaboot
%endif
%endif
%ifarch s390 s390x
Requires:       s390-tools
%endif
%ifarch %ix86 x86_64
# rhel7 has no grub, only grub2
%if 0%{?suse_version} < 1315 && 0%{?rhel_version} < 700 && 0%{?centos_version} < 700
Requires:       grub
%endif
%endif
Summary:        KIWI - buildservice package requirements for isoboot
License:        GPL-2.0+
Group:          System/Management

%description -n kiwi-desc-isoboot-requires
Meta-package to pull in all requires to build an isoboot media.
It is used by Open Build Service (OBS) to provide and install the
needed packages automatically.

%endif

%ifarch %ix86 x86_64 ppc ppc64 ppc64le s390 s390x %arm aarch64

%package -n kiwi-desc-vmxboot
Summary:        KIWI - Virtual Machine boot templates
Requires:       lvm2
Requires:       dosfstools
Requires:       e2fsprogs
Requires:       kiwi = %{version}
Requires:       parted
%if 0%{?suse_version}
Requires:       multipath-tools
Requires:       squashfs
%endif
%if 0%{?rhel_version} || 0%{?centos_version}
Requires:       device-mapper-multipath
Requires:       squashfs-tools
%endif
%ifarch %ix86 x86_64
Requires:       syslinux
%if 0%{?suse_version} >= 1220 || 0%{?rhel_version} >= 700 || 0%{?centos_version} >= 700
Requires:       grub2
%else
Requires:       grub
%endif
%endif
License:        GPL-2.0+
Group:          System/Management

%description -n kiwi-desc-vmxboot
This package contains kiwi boot (initrd) descriptions for booting
virtual disk images.

Authors:
--------
        Marcus Schaefer <ms@suse.com>

%package -n kiwi-desc-vmxboot-requires
Summary:        KIWI - buildservice package requirements for vmxboot
Provides:       kiwi-image:vmx
Provides:       kiwi-boot:vmxboot
%if 0%{?suse_version}
Requires:       genisoimage
%endif
Requires:       kiwi-desc-vmxboot = %{version}
Requires:       %(echo `bash %{S:4} %{S:0} vmxboot %{myarch} %{mysystems}`)
%ifarch ppc ppc64 ppc64le
%if 0%{?suse_version} >= 1315
Requires:       grub2-powerpc-ieee1275
%else
Requires:       yaboot
%endif
%endif
%ifarch s390 s390x
Requires:       s390-tools
%endif
%ifarch %ix86 x86_64 %arm aarch64
%if 0%{?suse_version} < 1315 && 0%{?rhel_version} < 700 && 0%{?centos_version} < 700
Requires:       grub
%endif
%if 0%{?suse_version} >= 1220 || 0%{?rhel_version} >= 700 || 0%{?centos_version} >= 700
Requires:       grub2
%endif
%ifarch x86_64
Requires:       grub2-x86_64-efi
%endif
%ifarch %ix86
Requires:       grub2-i386-efi
%endif
%ifarch aarch64
Requires:       grub2-arm64-efi
%endif
%ifarch %arm
Requires:       grub2-arm-efi
%endif
%endif
License:        GPL-2.0+
Group:          System/Management

%description -n kiwi-desc-vmxboot-requires
Meta-package to pull in all requires to build a vmxboot media.
It is used by Open Build Service (OBS) to provide and install the
needed packages automatically.

%endif

%ifarch %ix86 x86_64 ppc ppc64 ppc64le s390 s390x

%package -n kiwi-desc-netboot
Summary:        KIWI - PXE network boot templates
Requires:       kiwi = %{version}
License:        GPL-2.0+
Group:          System/Management

%description -n kiwi-desc-netboot
kiwi boot (initrd) image for booting PXE images.

Authors:
--------
        Marcus Schaefer <ms@suse.com>

%package -n kiwi-desc-netboot-requires
Provides:       kiwi-image:pxe
Provides:       kiwi-boot:netboot
Summary:        KIWI - buildservice package requirements for netboot
Requires:       kiwi-desc-netboot = %{version}
Requires:       %(echo `bash %{S:4} %{S:0} netboot %{myarch} %{mysystems}`)
License:        GPL-2.0+
Group:          System/Management

%description -n kiwi-desc-netboot-requires
Meta-package to pull in all requires to build a netboot media.
It is used by Open Build Service (OBS) to provide and install the
needed packages automatically.

%endif

%ifarch %ix86 x86_64 ppc ppc64 ppc64le s390 s390x %arm aarch64

%package -n kiwi-desc-oemboot
Summary:        KIWI - Expandable Virtual Machine boot templates
Requires:       lvm2
Requires:       dosfstools
Requires:       e2fsprogs
Requires:       kiwi = %{version}
Requires:       parted
%if 0%{?suse_version}
Requires:       genisoimage
Requires:       multipath-tools
Requires:       mtools
Requires:       squashfs
%endif
%if 0%{?rhel_version} || 0%{?centos_version}
Requires:       device-mapper-multipath
Requires:       squashfs-tools
%endif
%ifarch %ix86 x86_64
Requires:       syslinux
%if 0%{?suse_version} >= 1220 || 0%{?rhel_version} >= 700 || 0%{?centos_version} >= 700
Requires:       grub2
%else
Requires:       grub
%endif
%endif
%ifarch %arm aarch64
Requires:       u-boot-tools
%endif
License:        GPL-2.0
Group:          System/Management

%description -n kiwi-desc-oemboot
This package contains kiwi boot (initrd) descriptions for booting
expandable virtual disk images.

Authors:
--------
        Marcus Schaefer <ms@suse.com>

%package -n kiwi-desc-oemboot-requires
Provides:       kiwi-image:oem
Provides:       kiwi-boot:oemboot
Provides:       kiwi-boot:tbz
%if 0%{?suse_version}
Requires:       genisoimage
%endif
Requires:       kiwi-desc-oemboot = %{version}
Requires:       %(echo `bash %{S:4} %{S:0} oemboot %{myarch} %{mysystems}`)
%ifarch ppc ppc64 ppc64le
%if 0%{?suse_version} >= 1315
Requires:       grub2-powerpc-ieee1275
%else
Requires:       yaboot
%endif
%endif
%ifarch s390 s390x
Requires:       s390-tools
%endif
%ifarch %ix86 x86_64 %arm aarch64
%if 0%{?suse_version} < 1315 && 0%{?rhel_version} < 700 && 0%{?centos_version} < 700
Requires:       grub
%endif
%if 0%{?suse_version} >= 1220 || 0%{?rhel_version} >= 700 || 0%{?centos_version} >= 700
Requires:       grub2
%endif
%ifarch x86_64
Requires:       grub2-x86_64-efi
%endif
%ifarch %ix86
Requires:       grub2-i386-efi
%endif
%ifarch aarch64
Requires:       grub2-arm64-efi
%endif
%ifarch %arm
Requires:       grub2-arm-efi
%endif
%endif

Summary:        KIWI - buildservice package requirements for oemboot
License:        GPL-2.0+
Group:          System/Management

%description -n kiwi-desc-oemboot-requires
Meta-package to pull in all requires to build a oemboot media.
It is used by Open Build Service (OBS) to provide and install the
needed packages automatically.

%endif

%ifarch %ix86 x86_64 ppc ppc64 ppc64le s390 s390x %arm aarch64

%package -n kiwi-templates
Summary:        KIWI - JeOS system image templates
PreReq:         coreutils
Requires:       kiwi-desc-vmxboot = %{version}
License:        GPL-2.0+
Group:          System/Management

%description -n kiwi-templates
This package contains system image templates to easily build
a JeOS based operating system image with kiwi 

Authors:
--------
        Marcus Schaefer <ms@suse.com>
%endif

%ifarch %ix86 x86_64 ppc ppc64 ppc64le s390 s390x %arm aarch64

%package -n kiwi-media-requires
Summary:        Packages which should be part of the DVD media
License:        GPL-2.0+
Group:          System/Management
%if 0%{?suse_version}
Recommends:     busybox
Recommends:     atftp
Recommends:     gfxboot
Recommends:     memtest86+
Recommends:     kiwi
Recommends:     kiwi-desc-oemboot
Recommends:     kiwi-desc-vmxboot
Recommends:     kiwi-desc-isoboot
Recommends:     kiwi-desc-netboot
Recommends:     kiwi-templates
Recommends:     fribidi
Recommends:     fbiterm
%ifarch x86_64
%if 0%{?suse_version} > 1220
Recommends:     shim
%endif
%endif
%endif
%if 0%{?suse_version} > 1120
BuildArch:      noarch
%endif

%description -n kiwi-media-requires
This package recommends a set of packages which should be part of
the DVD distribution. Some kiwi system/boot templates references
those packages and it is assumed that they are part of the 
distributed source media (DVD)

Authors:
--------
        Marcus Schaefer <ms@suse.com>
%endif

%package -n kiwi-test
Requires:       kiwi = %{version}
Requires:       perl-Test-Unit-Lite
Summary:        Unit tests for kiwi
License:        GPL-2.0
Group:          System/Management
%if 0%{?suse_version} > 1120
BuildArch:      noarch
%endif

%description -n kiwi-test
This package contains the unit tests executed during package build and
used for development testing.

Authors:
--------
        Robert Schweikert <rjschwei@suse.com>
        Marcus Schaefer <ms@suse.com>

%prep
%setup -q -n %name -a2 -a3

%build
echo "mysystems set to: %{mysystems}"
# empty because of rpmlint warning rpm-buildroot-usage

%if 0%{?suse_version} > 1140
%check
make KIWIVERBTEST=1 KIWI_NO_NET=1 test
%endif

%install
# build
test -e /.buildenv && . /.buildenv
make buildroot=$RPM_BUILD_ROOT CFLAGS="$RPM_OPT_FLAGS"

#install
cd $RPM_BUILD_DIR/kiwi
make buildroot=$RPM_BUILD_ROOT \
         doc_prefix=$RPM_BUILD_ROOT/%{_defaultdocdir} \
         man_prefix=$RPM_BUILD_ROOT/%{_mandir} \
         install
touch kiwi.loader

%ifarch %ix86 x86_64
    install -m 644 pxeboot/pxelinux.0.config \
        $RPM_BUILD_ROOT/srv/tftpboot/pxelinux.cfg/default.default
%else
    # no PXE boot setup for non x86 archs
    rm -rf $RPM_BUILD_ROOT/srv/tftpboot
    rm -rf $RPM_BUILD_ROOT/etc/permissions.d/kiwi
%endif

mkdir -p $RPM_BUILD_ROOT/var/cache/kiwi
mkdir -p $RPM_BUILD_ROOT/var/cache/kiwi/packages
mkdir -p $RPM_BUILD_ROOT/var/cache/kiwi-images

test -f $RPM_BUILD_ROOT/srv/tftpboot/pxelinux.0 && \
    echo /srv/tftpboot/pxelinux.0 > kiwi.loader
test -f $RPM_BUILD_ROOT/srv/tftpboot/mboot.c32 && \
    echo /srv/tftpboot/mboot.c32 >> kiwi.loader
./.links
%if 0%{?suse_version} > 1020
%fdupes $RPM_BUILD_ROOT/srv/tftpboot
%fdupes $RPM_BUILD_ROOT/usr/share/kiwi/image
%fdupes $RPM_BUILD_ROOT/usr/share/doc/packages/kiwi/examples
%fdupes $RPM_BUILD_ROOT/usr/share/doc/packages/kiwi/schema
%fdupes $RPM_BUILD_ROOT/usr/share/kiwi/tests/unit/data
%endif
cat kiwi.loader

%if 0%{?suse_version}
# suse provides this tool in an extra package, others don't
rm -f $RPM_BUILD_ROOT/usr/bin/setctsid
%endif

for i in isoboot vmxboot netboot oemboot ; do
    if [ -d  $RPM_BUILD_ROOT/%{_datadir}/kiwi/image/$i ]; then
        cat > $RPM_BUILD_ROOT/%{_datadir}/kiwi/image/$i/README.requires <<EOF
This is a meta package to pull in all dependencies required for $i kiwi
images. This is supposed to be used in Open Build Service in first place
to track the dependencies.
EOF
    fi
done
cat > $RPM_BUILD_ROOT/%{_datadir}/kiwi/README.requires <<EOF
This is a meta package to pull in all base dependencies required for kiwi
images. This is supposed to be used in Open Build Service in first place
to track the dependencies.
EOF

%ifarch %ix86 x86_64
%pre -n kiwi-pxeboot
#============================================================
# create user and group tftp if they does not exist
if ! /usr/bin/getent group tftp >/dev/null; then
    %{_sbindir}/groupadd -r tftp 2>/dev/null || :
fi
if ! /usr/bin/getent passwd tftp >/dev/null; then
    %{_sbindir}/useradd -c "TFTP account" -d /srv/tftpboot -G tftp -g tftp \
        -r -s /bin/false tftp 2>/dev/null || :
fi

%post -n kiwi-pxeboot
#============================================================
# create /srv/tftpboot/pxelinux.cfg/default only if not exist
if ( [ ! -e srv/tftpboot/pxelinux.cfg/default  ] ) ; then
    cp /srv/tftpboot/pxelinux.cfg/default.default \
        /srv/tftpboot/pxelinux.cfg/default
fi
%endif

%ifarch %ix86 x86_64 ppc ppc64 ppc64le s390 s390x %arm aarch64

%post -n kiwi-templates
#============================================================
# Clean up old old template directories if present
for dist in 10.1 10.2 10.3 11.0 11.1 11.2 11.3 12.1 12.2 12.3 SLE10 SLED10; do
    if ( [ -d /usr/share/kiwi/image/suse-$dist-JeOS ] ) ; then
        rm -rf /usr/share/kiwi/image/suse-$dist-JeOS
    fi
done
%endif

%post -n kiwi
# make sure kiwi can create this file from scratch with the
# permissions it needs and is not in trouble if it exists
# already with permissions which doesn't allow kiwi to create
# or use this file if kiwi is called as non root user
rm -f /dev/shm/lwp-download

%clean
rm -rf $RPM_BUILD_ROOT
#=================================================
# KIWI files...      
#-------------------------------------------------

%files
%defattr(-, root, root)
%dir %{_datadir}/kiwi
%dir %{_datadir}/kiwi/image
%dir /var/cache/kiwi
%dir /var/cache/kiwi-images
%dir /var/cache/kiwi/packages
%doc %{_mandir}/man1/kiwi.1.gz
%doc %{_mandir}/man1/KIWI::images.sh.1.gz
%doc %{_mandir}/man1/KIWI::config.sh.1.gz
%doc %{_mandir}/man1/KIWI::kiwirc.1.gz
%ifarch %ix86 x86_64
%exclude %{_datadir}/kiwi/image/suse-13.1-JeOS
%exclude %{_datadir}/kiwi/image/suse-13.2-JeOS
%exclude %{_datadir}/kiwi/image/suse-SLE11-community-JeOS
%exclude %{_datadir}/kiwi/image/suse-SLE12-community-JeOS
%exclude %{_datadir}/kiwi/image/suse-leap-42.1-JeOS
%exclude %{_datadir}/kiwi/image/rhel-06.6-JeOS
%exclude %{_datadir}/kiwi/image/rhel-07.0-JeOS
%endif
%ifarch s390 s390x
%exclude %{_datadir}/kiwi/image/suse-SLE11-community-JeOS
%exclude %{_datadir}/kiwi/image/suse-SLE12-community-JeOS
%endif
%ifarch %arm aarch64
%exclude %{_datadir}/kiwi/image/suse-SLE12-community-JeOS
%endif
%{_datadir}/kiwi/.revision
%{_datadir}/kiwi/modules
%{_datadir}/kiwi/metadata
%{_datadir}/kiwi/livestick
%{_datadir}/kiwi/editing
%{_datadir}/kiwi/locale
%{_datadir}/kiwi/repo
%{_datadir}/emacs/site-lisp
%config /etc/bash_completion.d/kiwi.sh
%exclude %{_datadir}/kiwi/metadata/KIWIIsoLinux-AppleFileMapping.map
%exclude %{_datadir}/kiwi/modules/KIWICollect.pm
%exclude %{_datadir}/kiwi/modules/KIWIRepoMetaHandler.pm
%exclude %{_datadir}/kiwi/modules/KIWIUtil.pm
%{_datadir}/kiwi/xsl
%{_sbindir}/kiwi
/usr/bin/livestick

%files -n kiwi-requires
%defattr(-, root, root)
%doc %{_datadir}/kiwi/README.requires
#=================================================
# KIWI doc...      
#-------------------------------------------------

%files -n kiwi-doc
%defattr(-, root, root)
%dir %{_defaultdocdir}/kiwi
%{_defaultdocdir}/kiwi/COPYING
%{_defaultdocdir}/kiwi/examples
%{_defaultdocdir}/kiwi/html
%{_defaultdocdir}/kiwi/pdf
%{_defaultdocdir}/kiwi/schema
#=================================================
# KIWI instsource...      
#-------------------------------------------------

%files -n kiwi-instsource
%defattr(-, root, root)
%{_datadir}/kiwi/metadata/KIWIIsoLinux-AppleFileMapping.map
%{_datadir}/kiwi/modules/KIWICollect.pm
%{_datadir}/kiwi/modules/KIWIUtil.pm
%{_datadir}/kiwi/modules/KIWIRepoMetaHandler.pm

#=================================================
# KIWI-pxeboot files...  
# ------------------------------------------------
%ifarch %ix86 x86_64

%files -n kiwi-pxeboot -f kiwi.loader
%defattr(-, root, root)
%dir %attr(0750,tftp,tftp) /srv/tftpboot
%doc /srv/tftpboot/README
%dir /srv/tftpboot/KIWI
%dir /srv/tftpboot/pxelinux.cfg
%dir /srv/tftpboot/image
%dir /srv/tftpboot/upload
%dir /srv/tftpboot/boot
/srv/tftpboot/pxelinux.cfg/default.default
%endif
#=================================================
# KIWI-tools files...  
# ------------------------------------------------

%files -n kiwi-tools
%defattr(-, root, root)
%dir %{_defaultdocdir}/kiwi
%doc %{_defaultdocdir}/kiwi/README.tools
%exclude /usr/bin/livestick
/usr/bin/*
#=================================================
# KIWI-desc-* and templates...
# ------------------------------------------------
%ifarch %ix86 x86_64

%files -n kiwi-desc-isoboot
%defattr(-, root, root)
%dir %{_datadir}/kiwi/image/isoboot
%doc %{_datadir}/kiwi/image/isoboot/README
%{_datadir}/kiwi/image/isoboot/suse*
%{_datadir}/kiwi/image/isoboot/rhel*

%files -n kiwi-desc-isoboot-requires
%defattr(-, root, root)
%doc %{_datadir}/kiwi/image/isoboot/README.requires
%endif

%ifarch %ix86 x86_64 ppc ppc64 ppc64le s390 s390x %arm aarch64

%files -n kiwi-desc-vmxboot
%defattr(-, root, root)
%dir %{_datadir}/kiwi/image/vmxboot
%doc %{_datadir}/kiwi/image/vmxboot/README
%{_datadir}/kiwi/image/vmxboot/suse*
%ifarch %ix86 x86_64
%{_datadir}/kiwi/image/vmxboot/rhel*
%endif

%files -n kiwi-desc-vmxboot-requires
%defattr(-, root, root)
%doc %{_datadir}/kiwi/image/vmxboot/README.requires
%endif

%ifarch %ix86 x86_64 ppc ppc64 ppc64le s390 s390x

%files -n kiwi-desc-netboot
%defattr(-, root, root)
%dir %{_datadir}/kiwi/image/netboot
%doc %{_datadir}/kiwi/image/netboot/README
%{_datadir}/kiwi/image/netboot/suse*
%ifarch %ix86 x86_64
%{_datadir}/kiwi/image/netboot/rhel*
%endif

%files -n kiwi-desc-netboot-requires
%defattr(-, root, root)
%doc %{_datadir}/kiwi/image/netboot/README.requires
%endif

%ifarch %ix86 x86_64 ppc ppc64 ppc64le s390 s390x %arm aarch64

%files -n kiwi-desc-oemboot
%defattr(-, root, root)
%dir %{_datadir}/kiwi/image/oemboot
%doc %{_datadir}/kiwi/image/oemboot/README
%{_datadir}/kiwi/image/oemboot/suse*
%ifarch %ix86 x86_64
%{_datadir}/kiwi/image/oemboot/rhel*
%endif

%files -n kiwi-desc-oemboot-requires
%defattr(-, root, root)
%doc %{_datadir}/kiwi/image/oemboot/README.requires
%endif

%ifarch %ix86 x86_64 ppc ppc64 ppc64le s390 s390x %arm aarch64

%files -n kiwi-templates
%defattr(-, root, root)
%ifarch %ix86 x86_64
%{_datadir}/kiwi/image/suse-13.1-JeOS
%{_datadir}/kiwi/image/suse-13.2-JeOS
%{_datadir}/kiwi/image/suse-SLE11-community-JeOS
%{_datadir}/kiwi/image/suse-SLE12-community-JeOS
%{_datadir}/kiwi/image/suse-leap-42.1-JeOS
%{_datadir}/kiwi/image/rhel-06.6-JeOS
%{_datadir}/kiwi/image/rhel-07.0-JeOS
%endif
%ifarch s390 s390x
%{_datadir}/kiwi/image/suse-SLE11-community-JeOS
%{_datadir}/kiwi/image/suse-SLE12-community-JeOS
%endif
%ifarch %arm aarch64
%{_datadir}/kiwi/image/suse-SLE12-community-JeOS
%endif
%ifarch ppc ppc64 ppc64le
%{_datadir}/kiwi/image/suse-SLE11-community-JeOS
%{_datadir}/kiwi/image/suse-SLE12-community-JeOS
%endif

%endif

%ifarch %ix86 x86_64 ppc ppc64 ppc64le s390 s390x %arm aarch64

%files -n kiwi-media-requires
%defattr(-, root, root)
%dir %{_defaultdocdir}/kiwi

%endif

%files -n kiwi-test
%defattr(-, root, root)
%{_datadir}/kiwi/tests

%changelog
* Tue Oct 25 2016 ms@suse.de
- v7.04.8 released
* Tue Oct 25 2016 ms@suse.de
- Only one changelog section is allowed
* Tue Oct 25 2016 ms@suse.de
- Make sure an empty %%changelog tag exists
* Tue Oct 25 2016 ms@suse.de
- No longer write a %%changelog section in the spec
  For some reason the packaging concept no longer needs a changelog
  section in the spec file. Most likely the build service scripts
  now generates those information from the .changes file which lead
  to duplicate changelog information in the package
* Fri Oct 21 2016 ms@suse.de
- v7.04.7 released
* Wed Oct 19 2016 andrew.chace@gmail.com
- Fixed a rounding error in partedMBToCylinder():
  bc truncates number of cylinders to zero decimal places, which results in a
  partition that is slightly smaller than the requested size. Add one cylinder
  to compensate.
* Wed Oct 19 2016 adrian@suse.de
- drop kiwi-instsource-plugins
  It got moved to
  https://github.com/openSUSE/kiwi-instsource-plugins
* Wed Oct 12 2016 ms@suse.de
- v7.04.6 released
* Tue Oct 11 2016 dcassany@suse.com
- Fixing wrong spaces
* Tue Oct 11 2016 dcassany@suse.com
- Make sure there is no splash present when download dialogs appear
* Tue Oct 11 2016 ms@suse.de
- Fixed creation of etc/crypttab
  The method setupCryptTab creates etc/crypttab from the given
  storage device. However in a raid setup the correct /dev/mdX
  device needs to be used and not one of the storage devices in
  the raid array. Fixes bnc#1003595
* Tue Oct 11 2016 dcassany@suse.com
- Solving some broken dialogs
  HideSplash method used to hide the splash only if there was an active
  console, however the dialogs appear broken if the splash isn't hidden
  and in some cases is hard to check if there is an active consoles
  (i.e. after umount /sys or mount --move /dev /mnt/dev).\
  This commit fixes bnc#997085
* Mon Oct 10 2016 ms@suse.de
- v7.04.5 released
* Mon Oct 10 2016 ms@suse.de
- Don't lookup a tool if it is not necessary
  Fixup runtime check for iso tool check
* Mon Oct 10 2016 ms@suse.de
- v7.04.4 released
* Mon Oct 10 2016 ms@suse.de
- Don't lookup a tool if it is not necessary
* Mon Oct 10 2016 ms@suse.de
- v7.04.3 released
* Mon Oct 10 2016 ms@suse.de
- Build require an iso creation tool to pass checks
* Mon Oct 10 2016 ms@suse.de
- Fixup wicked DNS data validation
  wicked provides DNS info in DNSSERVERS with a space as
  separator and not with a ',' as it was the case in dhcpcd
* Mon Oct 10 2016 ms@suse.de
- v7.04.2 released
* Mon Oct 10 2016 dcassany@suse.com
- Remove cdrkit-cdrtools-compat from requirements
* Thu Oct  6 2016 ms@suse.de
- v7.04.01 released
* Mon Oct  3 2016 dcassany@suse.com
- Added support for mkisofs in addition to genisoimage
  * Removed 'allow-limited-size' which is not supported by mkisofs
  * fixCatalog was returning null even if is was not failing
  * regex for parsing isoinfo output has been improved to support
    mkisofs format
* Sat Oct  1 2016 cyberorg@opensuse.org
- do not use ramdisk for rw, using tmpfs is more efficient
* Tue Sep 27 2016 elchevive68@gmail.com
- Translated using Weblate (Portuguese (Brazil))
  Currently translated at 100.0%% (28 of 28 strings)
* Tue Sep 27 2016 ms@suse.de
- v7.03.96 released
* Tue Sep 27 2016 ms@suse.de
- Make sure netboot code populates kiwi_RootPart
  For disk based images the file config.partids is written and
  imported. However, for netboot stations a disk is optional
  and no partids information exists. In order to provide at
  least the partition number for the root partition on netboot
  stations with a disk, the kiwi_RootPart is exported from
  the provided client configuration file. Fixes bnc#1000194
* Thu Sep 22 2016 dcassany@suse.com
- Custom device timeout variable added
  This commit patches the issue bnc#992992. Now DEVICE_TIMEOUT
  variable can be used in order to set the device waiting timeout
  in watForStorageDevice function. Must be a numeric value expressed
  in seconds.
* Mon Sep 19 2016 ms@suse.de
- v7.03.95 released
* Mon Sep 19 2016 ms@suse.de
- v7.03.94 released
* Sun Sep 18 2016 cyberorg@opensuse.org
- tab to spaces
* Sun Sep 18 2016 cyberorg@opensuse.org
- ip link ls output is unreliable on some interfaces, when available use ifplugstatus instead
* Thu Sep 15 2016 ms@suse.de
- v7.03.93 released
* Thu Sep 15 2016 ms@suse.de
- Revert "waitForStorageDevice patch"
  The logic to setup a wait timeout by asking a device property
  from a device which does not yet exist raises a chicken and egg
  problem. This reverts commit 9654d53e3c4a500a4e3a7e5cc8d40a56e0da6525.
* Thu Sep 15 2016 ms@suse.de
- Follow up fix for setupNetworkWicked
  IP address information from wicked is imported twice.
  However the plain IPv4 address validation happened only
  on the first import. Fixes bnc#992989
* Sun Sep 11 2016 ms@suse.de
- Fixed message typo (bnc#996255)
* Thu Aug 25 2016 ms@suse.de
- v7.03.92 released
* Thu Aug 25 2016 pnhoang96@gmail.com
- Translated using Weblate (Vietnamese)
  Currently translated at 100.0%% (28 of 28 strings)
* Wed Aug 24 2016 ms@suse.de
- Fixup elilo.conf append setup
  append parameter was filled with an undefined variable
  It should contain the information from $cmdline
* Tue Aug 23 2016 ms@suse.de
- v7.03.91 released
* Tue Aug 23 2016 ms@suse.de
- Fixed bootloader configuration
  custom kernel parameters should be added to
  GRUB_CMDLINE_LINUX and not GRUB_CMDLINE_LINUX_DEFAULT
  Fixes bnc#994910
* Mon Aug 22 2016 dcassany@suse.com
- waitForStorageDevice patch
  This solves the issue bnc#992992. Now waitForStorageDevice method
  has set a timeout of 4 seconds instead of 60 if the device is a usb.
  GetDeviceTransportType method has been added in order to determine
  device type (usb, sata, etc.)
* Tue Aug 16 2016 ms@suse.de
- v7.03.90 released
* Tue Aug 16 2016 ms@suse.de
- Preserve timestamp on grub2-install copy
  In order to workaround the bug in shim-install which
  unnecessarily calls grub2-install we replace the binary
  by a noop before calling shim-install. However all file
  attributes of the grub2-install binary, timestamp, modes,
  etc should stay untouched (bnc#993825)
* Thu Aug 11 2016 ms@suse.de
- v7.03.89 released
* Thu Aug 11 2016 ms@suse.de
- Fixed setupNetworkWicked
  IP address information from wicked dhcp reply consists out of
  two parts but we are only interested in the plain IPv4 address
  information at this point. Fixes bnc#992989
* Thu Aug 11 2016 ms@suse.de
- Make sure DHCPCHADDR is uppercase
  Fixes bnc#992988
* Thu Aug  4 2016 ms@suse.de
- v7.03.88 released
* Thu Aug  4 2016 ms@suse.de
- Fixed device setup for initrd only disk images
* Wed Aug  3 2016 ms@suse.de
- v7.03.87 released
* Wed Aug  3 2016 ms@suse.de
- Fixed use of undefined firmware value
* Wed Aug  3 2016 ms@suse.de
- Fixed setupBootLoaderConfiguration
  Theme setup should be optional. The bootloader setup should
  allow for working without a graphics boot theme setup
* Wed Aug  3 2016 ms@suse.de
- Fixed use of uninitialized value in string eq
* Mon Aug  1 2016 ms@suse.de
- v7.03.86 released
* Mon Aug  1 2016 ms@suse.de
- netboot code for rhel only added on x86 atm
* Mon Aug  1 2016 ms@suse.de
- v7.03.85 released
* Mon Aug  1 2016 ms@suse.de
- Package rhel netboot descriptions
* Wed Jul 27 2016 dimstar@opensuse.org
- mini iso: Pass kexec=1 to linuxrc (boo#990374)
* Wed Jul 27 2016 dimstar@opensuse.org
- Duplicate openSUSE-13.2 to openSUSE-Tumbleweed
* Mon Jul 25 2016 ms@suse.de
- v7.03.84 released
* Mon Jul 25 2016 ms@suse.de
- insserv please just do what I want from you
  force remove of service
* Mon Jul 25 2016 ms@suse.de
- v7.03.83 released
* Mon Jul 25 2016 ms@suse.de
- Follow up fix for insserv is not a chkconfig
  When changing the call from chkconfig to insserv also
  the caller syntax changes.
* Mon Jul 25 2016 dimstar@opensuse.org
- Trivial: Fix spelling of openSUSE
* Mon Jul 18 2016 ms@suse.de
- v7.03.82 released
* Mon Jul 18 2016 ms@suse.de
- Fixed changelog generator
* Mon Jul 18 2016 ms@suse.de
- v7.03.81 released
* Mon Jul 18 2016 ms@suse.de
- Don't ask to start recovery in unattended mode
* Mon Jul 18 2016 k0da@opensuse.org
- Support GPT for pxedeploy
  Signed-off-by: Dinar Valeev <k0da@opensuse.org>
* Sun Jul 17 2016 ms@suse.de
- Fixed __checkSelectedBootLoaderIncluded check
  When explicitly specifying in config.xml the version of
  grub to be used, the  __checkSelectedBootLoaderIncluded()
  function in KIWIRuntimeChecker.pm doesn't work properly.
  This issue is that the comparison is done against
  "grub=<version>" which will never match "grub"
* Wed Jul 13 2016 andrey.arapov@nixaid.com
- insserv is not a chkconfig
* Mon Jul 11 2016 ms@suse.de
- v7.03.80 released
* Sun Jul 10 2016 cyberorg@opensuse.org
- prefer newer overlayfs, otherwise mount succeeds in compat mode but live image fail to boot/exhibit weird symptoms
* Sat Jul  9 2016 cyberorg@opensuse.org
- prefer newer overlayfs, otherwise mount succeeds in compat mode but live image fail to boot/exhibit weird symptoms
* Fri Jul  8 2016 ms@suse.de
- v7.03.79 released
* Fri Jul  8 2016 ms@suse.de
- Message commit for bug reference
  Fixup of VMware disk tag references (bnc#988087)
* Fri Jul  8 2016 ms@suse.de
- v7.03.78 released
* Wed Jul  6 2016 jmason@suse.com
- Conditionally prefix encoding to vmware disk tag
  Prior code was always adding the encoding statement to vmware disk tag;
  in the event it is already present there's no need to add it a second time.
* Wed Jul  6 2016 jmason@suse.com
- Remove null padding on the vmware disk tag
  The block of data read via dd is null padded; adding the tools data after
  the padding breaks detection of the data. We need to remove the nulls (0x0)
  so appends can occur adjacent to the block of strings.
* Wed Jul  6 2016 ms@suse.de
- v7.03.77 released
* Wed Jul  6 2016 ms@suse.de
- Fix potential timing issue after vgchange
  After activation of the volume group with vgchange an
  udev wait until the volume device nodes exists should
  be performed
* Tue Jun 28 2016 ms@suse.de
- v7.03.76 released
* Tue Jun 28 2016 ms@suse.de
- Fixed zipl installation
  prior to the zipl installation some parameters are read from the
  disk file. kiwi ran another loopsetup call on the raw disk file
  to get those values. However while the raw disk is already loop
  setup by another loop device this causes problems when calling
  fdasd on the new loop. This patch prevents another loopsetup call
  and operates on the given block device
* Mon Jun 27 2016 k0da@opensuse.org
- Add RHEL7 netboot descriptions
  Signed-off-by: Dinar Valeev <k0da@opensuse.org>
* Tue Jun 21 2016 ms@suse.de
- v7.03.75 released
* Fri Jun 17 2016 k0da@opensuse.org
- Don't run updateMTAB on RHEL6 systems
  RHEL6 doesn't have /etc/mtab as a link. Let's keep original behaviour
  Signed-off-by: Dinar Valeev <k0da@opensuse.org>
* Fri Jun 17 2016 k0da@opensuse.org
- Fix RHEL6 bootloader install
  RHEL expects /etc/grub.conf to be a symlink to /boot/grub/grub.conf,
  lets fix a condition where we enter that specific path.
  Signed-off-by: Dinar Valeev <k0da@opensuse.org>
* Tue Jun 14 2016 ms@suse.de
- v7.03.74 released
* Tue Jun 14 2016 ms@suse.de
- Fixed creation of install stick
  The bind mountpoint boot directory needs to be created
  It's not enough to assume the boot mount point exists in
  any case.
* Tue Jun 14 2016 ms@suse.de
- Fixed setup of container configuration
  An empty fstab file is created, the former deletion of a
  potentially existing fstab failed if no such file existed
* Sun Jun 12 2016 ms@suse.de
- v7.03.73 released
* Sun Jun 12 2016 ms@suse.de
- Make sure package cache dir is managed
  Fix spec file to create and manage /var/cache/kiwi/packages
* Mon Jun  6 2016 i@marguerite.su
- Translated using Weblate (Chinese (China))
  Currently translated at 100.0%% (28 of 28 strings)
* Mon Jun  6 2016 i@marguerite.su
- Translated using Weblate (Chinese (China))
  Currently translated at 100.0%% (28 of 28 strings)
* Mon May 30 2016 ms@suse.de
- v7.03.72 released
* Mon May 30 2016 adrian@suse.de
- fix hash key handling for perl 5.24 (boo#981080)
* Sun May 29 2016 ms@suse.de
- v7.03.71 released
* Sun May 29 2016 ms@suse.de
- Delete vmxboot dracut optimization
  For vmx type images, dracut was called in background to speedup
  the boot process. However this could cause a race condition
  together with grub2-mkconfig. If grub2-mkconfig is called but
  dracut has not yet created the initrd, grub2 creates a configuration
  file without an initrd. The result boot setup is not able to
  reboot the system because the initrd is not loaded.
  This fixes (bnc#982092)
* Wed May 25 2016 ms@suse.de
- v7.03.70 released
* Wed May 25 2016 ms@suse.de
- v7.03.69 released
* Wed May 25 2016 ms@suse.de
- Added readonly check for persistent data
  When creating a partition for persistent data, check
  if the device class has the readonly flag set before
  trying to write anything there. Fixes #576
* Tue May 24 2016 adrian@suse.de
- tag debug and source medias in rpm-md meta data (bnc#980871)
* Mon May  9 2016 ms@suse.de
- v7.03.68 released
* Mon May  9 2016 schwab@suse.de
- Add aarch64_ilp32 to the list of known architectures
* Thu May  5 2016 dmueller@suse.com
- Add aarch64_ilp32 support
  This is the -32bit variant of aarch64. Right now only needed for
  install medias.
* Tue May  3 2016 adrian@suse.de
- new sle12-sp2 media style
  default patterns are now provides and not recommends
* Mon May  2 2016 dvaleev@suse.com
- implement experimental headersonly build
* Wed Apr 27 2016 ms@suse.de
- Don't create default fstab file
  Follow up fix for bnc#964472. A kiwi generated fstab file
  is not required to build the image
* Tue Apr 26 2016 ms@suse.de
- DB: rebuild documentation
* Tue Apr 26 2016 ms@suse.de
- Fixed documentation style
  indexterms must be in para element. Fixes #568
* Mon Apr 25 2016 xein@naver.com
- Translated using Weblate (Korean)
  Currently translated at 100.0%% (28 of 28 strings)
* Thu Apr 21 2016 ms@suse.de
- Update README
* Mon Apr 18 2016 ms@suse.de
- v7.03.67 released
* Mon Apr 18 2016 ms@suse.de
- Add part_msdos module for self build EFI image
  On ARM we have a few hooks in kiwi that allow us to adapt the
  resulting image to target boards. On some systems, we need to
  install the firmware to hardware specified sector offsets on
  the image target (sd card).
  Unfortunately some systems demand firmware at sector 1 which is
  where the GPT would usually reside. So we need to use an MBR partition
  layout.
  We can convert the GPT into an MBR using gdisk in our ARM scripts,
  but at that point grub2 would have to be able to interpret the MBR
  as well. So we need the "msdos_part" module included (bnc#975898)
* Mon Apr 18 2016 ms@suse.de
- Follow up fix for not writing grub.cfg to EFI dir
  With the move to grub2-install and also shim-install
  the static copy of the grub configuration into the
  EFI boot directory became obsolete (bnc#968270)
* Mon Apr 11 2016 ms@suse.de
- v7.03.66 released
* Mon Apr 11 2016 ms@suse.de
- Fixed kiwi-pxeboot package setup
  The package was marked noarch but has architecture dependant
  requirements. Therefore it can't be marked noarch (bnc#974651)
* Mon Apr 11 2016 ms@suse.de
- Fixed oem and vmx buildservice boot requires
  The packages kiwi-desc-oemboot-requires and kiwi-desc-vmxboot-requires
  did not explicitly require grub2 or the architecture specific efi module
  packages for the arm architectures. The requirement was added by the
  contents of the arm boot image descriptions. However those packages
  will not be part of the boot image descriptions in the near future
  and thus the buildservice needs them to be referenced explicitly
  in the spec file
* Mon Apr 11 2016 alexandros.venn@gmail.com
- Translated using Weblate (Greek)
  Currently translated at 89.2%% (25 of 28 strings)
* Wed Apr  6 2016 ms@suse.de
- v7.03.65 released
* Wed Apr  6 2016 ms@suse.de
- Fixed ppc setup of etc/default/grub_installdevice
  On power grub must be installed into the Prep partition into
  the master boot record of the disk
* Mon Apr  4 2016 schreiner@suse.de
- plugin for new createrepo_c in kiwi
* Thu Mar 31 2016 xein@naver.com
- Translated using Weblate (Korean)
  Currently translated at 100.0%% (28 of 28 strings)
* Thu Mar 31 2016 malham1@gmail.com
- Translated using Weblate (Arabic)
  Currently translated at 100.0%% (28 of 28 strings)
* Wed Mar 30 2016 nthn@unseen.is
- Translated using Weblate (Dutch)
  Currently translated at 100.0%% (28 of 28 strings)
* Sun Mar 27 2016 eiosifidis@gmail.com
- Translated using Weblate (Greek)
  Currently translated at 85.7%% (24 of 28 strings)
* Wed Mar 23 2016 ms@suse.de
- Update SLE12-community-JeOS to SP1 repos
* Mon Mar 21 2016 christian.brauner@mailbox.org
- have tar preserve all xattrs
  By default tar will only preserve a subset of the capabilities with --xattrs.
  Adding --xattrs-include=* should preserve all capabilities (e.g. user.*,
  security.capability etc.).
  Signed-off-by: Christian Brauner <christian.brauner@mailbox.org>
* Fri Mar 18 2016 rsassu@suse.de
- bootImage: don't copy initial ram disk content to /run/initramfs
  We should avoid copying the initial ram disk content to a tmpfs filesystem,
  especially on low memory systems (bsc#963276).
  Signed-off-by: Roberto Sassu <rsassu@suse.de>
* Fri Mar 18 2016 ms@suse.de
- Refactor case statement in udevStart
  two case blocks with one condition each makes a case
  selection obsolete
* Wed Mar 16 2016 ms@suse.de
- Delete obsolete shim code from kiwi
  This has been replaced by the use of shim-install
* Mon Mar 14 2016 ms@suse.de
- v7.03.64 released
* Mon Mar 14 2016 ms@suse.de
- Revert "Added pv kernel profile"
  There is no kernel-pv
  This reverts commit 8ca75eeee4bd7999a20ed050d9ebe4ba75607c5d.
* Sun Mar 13 2016 ms@suse.de
- v7.03.63 released
* Sun Mar 13 2016 ms@suse.de
- Use shim-install to setup EFI secure boot
  This fixes (bnc#968475)
* Fri Mar 11 2016 ms@suse.de
- Added pv kernel profile
* Wed Mar  9 2016 rsassu@suse.de
- Execute haveged in udevStart
  This ensure there is at least a source of entropy for /dev/random when
  the fips mode is enabled. Without it, VMware virtual machines hang at boot
  (bsc#964204).
  Signed-off-by: Roberto Sassu <rsassu@suse.de>
* Fri Mar  4 2016 asarai@suse.com
- rpm: require tar>=1.2.7 for --xattrs support
  tar 1.2.6 and earlier doesn't have support for the --xattrs options
  (which is necessary in order to build valid Docker image root
  filesystems).
  Signed-off-by: Aleksa Sarai <asarai@suse.com>
* Fri Mar  4 2016 asarai@suse.com
- travis: install newest version of GNU tar from trusty source
--xattrs support was added quite some time ago, but Travis doesn't seem
  to have a recent enough version of GNU tar. Realistically, most
  up-to-date systems do, so we can just install the latest version here.
  In order to install the latest version, we have to build it from the
  Ubuntu 14.04 source repo.
  Signed-off-by: Aleksa Sarai <asarai@suse.com>
* Fri Mar  4 2016 asarai@suse.com
- modules: KIWIContainerBuilder: preserve xattrs
  tar doesn't preserve extended attributes by default, causing Docker
  images to not have any correct set-capabilities bits set on binaries
  such as ping. Fix this by adding the --xattrs flag to the tar command
  run to generate the root filesystem image.
  Signed-off-by: Aleksa Sarai <asarai@suse.com>
* Fri Mar  4 2016 ms@suse.de
- v7.03.62 released
* Thu Mar  3 2016 ms@suse.de
- v7.03.61 released
* Thu Mar  3 2016 ms@suse.de
- Fixed gce disk format
  The order of the files in the tarball is important. The first
  entry must be the manifest.json followed by disk.raw. In addition
  the style of the manifest.json has been adapted too. A space after
  colon seems to be required for gce to accept the data
* Tue Mar  1 2016 ms@suse.de
- v7.03.60 released
* Tue Mar  1 2016 ms@suse.de
- Fixed global mount method
  There could be a max of four partitions in the image setup
  bios_grub/prep | EFI | boot | root. Thus the search should
  expect the layout correctly. Fixes #554
* Tue Mar  1 2016 ms@suse.de
- v7.03.59 released
* Tue Mar  1 2016 ms@suse.de
- Quote repository alias
  Fixes #545
* Tue Mar  1 2016 ms@suse.de
- Keep yum package package
  Fixes #553
* Tue Mar  1 2016 aplanas@suse.com
- Translated using Weblate (Spanish)
  Currently translated at 100.0%% (28 of 28 strings)
* Tue Mar  1 2016 aplanas@suse.com
- Translated using Weblate (English (United States))
  Currently translated at 100.0%% (28 of 28 strings)
* Tue Mar  1 2016 ms@suse.de
- Don't write grub.cfg to EFI directory
  Originally the file was written there as reference, but nothing
  will ever update that file if the real grub configuration changes.
  Thus it doesn't make sense to provide this information (bnc#968270)
* Tue Mar  1 2016 ms@suse.de
- Avoid lvcreate to ask for wiping swap signature
  When kiwi creates the logical volume for the swap space
  and there is already a swap signature at the place on
  disk, lvm stops and asks what to do with it. This should
  be generally avoided at that stage in the boot process
  Fixes (bnc#968601)
* Thu Feb 25 2016 guillaume.gardet@opensuse.org
- Translated using Weblate (French)
  Currently translated at 100.0%% (28 of 28 strings)
* Tue Feb 23 2016 cyberorg@opensuse.org
- quiet umount /proc error of missing mtab
* Tue Feb 23 2016 cyberorg@opensuse.org
- run exec >/dev/null after screen clears in quiet mode
* Tue Feb 23 2016 ms@suse.de
- v7.03.58 released
* Tue Feb 23 2016 ms@suse.de
- Fixed shell syntax in grub2 template
  Fixes (bnc#961334)
* Mon Feb 22 2016 ms@suse.de
- v7.03.57 released
* Mon Feb 22 2016 ms@suse.de
- Refactor suseStripKernel
  The way the method downsizes the kernel tree is wrong in
  several places and very hard to read. Therefore the code
  has been refactored and splitted into task methods which
  can run independently from each other. As one result the
  kernel tree is not missing any metadata and/or update
  weak-updates paths anymore. Fixes (bnc#965830)
* Mon Feb 22 2016 ms@suse.de
- v7.03.56 released
* Sun Feb 21 2016 dmueller@suse.com
- Fix filesystem check on boot
  In the refactoring fc363cc06, the parameters of checkFileSystem got
  changed to expect the device name, but one of the invocations didn't
  pass down the device name due to a typo.
* Sat Feb 20 2016 dmueller@suse.com
- Remove grub2 from the armv6/v7 initrd
  Grub2 adds 35MB to the initrd for no reason on armv6/v7, as
  those images use u-boot scripts for booting.
* Sat Feb 20 2016 dmueller@suse.com
- Remove flush before resize filesystem
  According to the manpage, -F is flushing the fileystem buffer
  caches. which is only really useful for doing resize2fs time trials.
  With current Tumbleweed installed on MMC, -F triggers a Inappropriate ioctl for device
  while trying to flush error, and then fails to resize.
* Thu Feb 18 2016 ms@suse.de
- DB: rebuild documentation
* Wed Feb 17 2016 robert.paschedag@web.de
- Do not activate dmraid paritions
  This only activates the device itself, not the partitions, that may also exist. If partitions exist, the UDEV rules will create the corresponding "_partX" symlinks for each partition within "/dev/mapper, which are totally sufficient.
* Mon Feb 15 2016 ms@suse.de
- v7.03.55 released
* Mon Feb 15 2016 ms@suse.de
- s390: Don't strip ctc_configure from initrd
* Sat Feb 13 2016 atalanttore@googlemail.com
- Translated using Weblate (German)
  Currently translated at 100.0%% (28 of 28 strings)
  Author: Bernhard M. Wiedemann <bernhard+kiwigit lsmod.de>
* Thu Feb 11 2016 atalanttore@googlemail.com
- doc: fix typo
  Author: Bernhard M. Wiedemann <bernhard+kiwigit lsmod.de>
* Thu Feb 11 2016 atalanttore@googlemail.com
- make xml example valid
  the <strip> tag needs to remain open here.
* Thu Feb 11 2016 ms@suse.de
- v7.03.54 released
* Thu Feb 11 2016 ms@suse.de
- Fixed validation of custom root cmdline variable
  A variable of the format root=LABEL=x was not correctly validated
* Wed Feb 10 2016 rjschwei@suse.com
- Enable pvops builds for EC2
* Fri Feb  5 2016 ms@suse.de
- v7.03.53 released
* Fri Feb  5 2016 ms@suse.de
- Fixed disk bundler for install stick target
  The bundler looked up the wrong extension. This fixes #542
* Fri Feb  5 2016 ms@suse.de
- Preserve package cache only if it exists
* Fri Feb  5 2016 ms@suse.de
- v7.03.52 released
* Fri Feb  5 2016 ms@suse.de
- Fixed use of noglob shell option
* Wed Feb  3 2016 ludwig.nussel@suse.de
- output correct sha256 file
  whether or not the argument to $sha->addfile is absolute doesn't
  actually matter as $sha->hexdigest never outputs any file name. We
  have to add the file name ourselves.
  Reason for the confusion is code in OBS's build script that under
  certain conditions computes the sha256sum file itself. So this code here
  was never used where it actually matters.
  This reverts commit 97b92d0e0a58cdd237b109efbf843b6057172164.
* Wed Feb  3 2016 ms@suse.de
- v7.03.51 released
* Wed Feb  3 2016 ludwig.nussel@suse.de
- always sign bundled result
  no matter what the output format is we want OBS to add a gpg
  signature on the result. Therefore always also produce a .sha256
  sums file for that purpose.
* Wed Feb  3 2016 ms@suse.de
- Fixed updateRootDeviceFstab
  Support by-label mount entries for btrfs subvolumes
  This fixes bnc#964474
* Tue Feb  2 2016 ms@suse.de
- Don't add kernel filesystems to fstab
  Systems with systemd which this kiwi version aims for, doesn't
  need proc, sysfs, debugfs and friends to be part of the fstab
  This fixes bnc#964472
* Mon Feb  1 2016 ms@suse.de
- Update rhel6 template
  Added Vagrantfile to build via dice
* Mon Feb  1 2016 ms@suse.de
- Update rhel6 template
  delete unused oracle linux build target
* Fri Jan 29 2016 ms@suse.de
- v7.03.50 released
* Wed Jan 27 2016 ms@suse.de
- Allow system to be installed on btrfs snapshot
  This fixes (bnc#946648)
* Wed Jan 27 2016 ms@suse.de
- Put kiwi_btrfs_root_is_snapshot to boot profile
  This is related to (bnc#946648)
* Wed Jan 27 2016 ms@suse.de
- Evaluate kiwi_btrfs_root_is_snapshot in boot code
  If set it's required to mount the subvolumes like it is
  done with lvm volumes. In addition this patch fixes the
  update of the fstab file which has to contain an entry
  for each subvolume excluding snapshots and the toplevel
  This is related to (bnc#946648)
* Wed Jan 27 2016 ms@suse.de
- Added get/set(er) for btrfs_root_is_snapshot attr
  This is related to (bnc#946648)
* Wed Jan 27 2016 ms@suse.de
- Added btrfs_root_is_snapshot attribute
  This is related to (bnc#946648)
* Wed Jan 20 2016 ms@suse.de
- Fixed pxe type setup for s390 SLE12-community-JeOS
* Wed Jan 20 2016 ms@suse.de
- Added util-linux to SLE12-community-JeOS for s390
* Thu Jan 14 2016 ms@suse.de
- v7.03.49 released
* Tue Jan 12 2016 ms@suse.de
- Don't use filesystem specific mount option
  When mounting the read write filesystem, prevent using
  filesystem specific options like barrier
* Tue Jan 12 2016 ms@suse.de
- Use HYBRID_EXT4_OPTS in fat container filesystem
* Tue Jan 12 2016 ms@suse.de
- Check read write filesystem prior to mounting
  If a filesystem type could be identified on the read write
  partition check it before mounting to eliminate a potential
  dirty state
* Tue Jan 12 2016 ms@suse.de
- Cascade exfat mount
  try normal mount first, if this does not work try fuse mount
  Normally this is done automatically by the mount program but
  if not we will give the direct fuse mount a chance
* Mon Jan 11 2016 ms@suse.de
- Make createFileSystem more robust
  When passing in a loop file instead of a device name, the method
  should be smart enough to handle the name without shell evaluation
* Mon Jan 11 2016 ms@suse.de
- Compile rnc -> rng
* Mon Jan 11 2016 ms@suse.de
- Added support for exfat as hybrid filesystem
  In addition to fat also exfat is now supported as persistent
  write filesystem. Because of the limitations of a fat filesystem
  fat and exfat are only used as a container filesystem providing
  an ext4 linux filesystem as a cowfile. The algorithm to create
  the size of the cow file has also been changed to use half of
  the size of the write partition or on fat a max size of 4G.
  The size of the cowfile is also prepared to become overwritten.
  However the XML definition and implementation to do this
  is still missing
* Mon Jan 11 2016 ms@suse.de
- Reread partition table after hybrid setup
  The hybrid write partition is created via fdisk. Some version
  of fdisk does not send the ioctl to let the kernel reread the
  table or fdisk itself holds it busy. Thus we actively initiate
  a reread via blockdev
* Mon Jan 11 2016 ms@suse.de
- Optimize ext4 hybrid write filesystem options
  Optimized for 512kB erase block size
* Mon Jan 11 2016 ms@suse.de
- Use mount options to increase overlay performace
  For overlay filesystems not writing into a tmpfs performance is
  more important than safety. We use this combination of options
  for now, if you encounter stability problems please let us know
* Mon Jan 11 2016 ms@suse.de
- Use -f force option for extX filesystem checker
* Mon Jan 11 2016 ms@suse.de
- Refactor and cleanup setupReadWrite
  Fix misleading error message and refactor the code to be less
  complex and more clear in the processing of tasks
* Mon Jan 11 2016 ms@suse.de
- Allow custom cowfile name for persistent data
  Instead of a fixed name 'cowfile' we allow a custom name which is
  predefined in HYBRID_PERSISTENT_FILENAME and prepared to become
  overwritten by an XML defintion whose implementation will follow
  later. Reason for the change is that a cowfile is visible as
  plain data file to the operating system if e.g used on a live
  stick. It should be more clear to the user what this file is
  good for
* Mon Jan 11 2016 ms@suse.de
- Protect mkfs.exfat from being deleted
  Added to the strip tools section in order to keep it in the initrd
* Mon Jan 11 2016 ms@suse.de
- Added support for exfat creation and probing
  In preparation to use exfat instead of vfat in a loop container
  for persistent data it's required to provide support for mkfs.exfat
* Mon Jan 11 2016 ms@suse.de
- Make loop_setup and loop_delete more robust
  The methods did not cope well with filenames containing bash
  characters with special meaning e.g spaces. For use with a
  iso hybrid cowfile whose name is visible in the OS the methods
  should be able to work with any given filename
* Sat Dec 26 2015 cyberorg@opensuse.org
- fix message of missing command
* Wed Dec 23 2015 ms@suse.de
- v7.03.48 released
* Wed Dec 23 2015 ms@suse.de
- Fixed import of kernel parameters including spaces
  Kernel parameters like PRODUCT_TYPE=âPRODUCT BANANAâ breaks
  the code in includeKernelParameters. This patch allows spaces
  for values in a way that it replaces the embedded whitespace
  with \030 before parsing and then reverting after parsing.
  Thanks to Jay Nitikman for providing the patch
* Wed Dec 23 2015 ms@suse.de
- Fixed uninstall target for buildroot use case
* Wed Dec 23 2015 ms@suse.de
- v7.03.47 released
* Wed Dec 23 2015 ms@suse.de
- Fixed LUKS setup for dracut
  The system image has to provide /etc/crypttab to allow dracut
  to create a working initrd for reboot. In addition the name
  of the luks map must be 'luks' to make dracut happy.
* Wed Dec 23 2015 ms@suse.de
- Fixed installation of documentation
* Wed Dec 23 2015 ms@suse.de
- Update documentation
  Also put each doc target into its own directory
* Wed Dec 23 2015 ms@suse.de
- Delete binary picture data
* Wed Dec 23 2015 ms@suse.de
- Delete unmaintained documentation sources
* Tue Dec 22 2015 fs@suse.de
- Stylecheck
* Tue Dec 22 2015 fs@suse.de
- Specllchecked
* Tue Dec 22 2015 fs@suse.de
- Kiwi Doc Revision Pt. 13: Appliance and Migration
* Tue Dec 22 2015 fs@suse.de
- Kiwi Doc Revision Pt. 12: XEN chapter
* Tue Dec 22 2015 afaerber@suse.de
- Handle /boot/vc files for Raspberry Pi
  openSUSE Tumbleweed raspberrypi-firmware[-branding-openSUSE] packages
  have been updated to install files to /boot/vc rather than /boot.
  Ensure that all files in /boot/vc find their way into the vboot partition
  and on the boot partition prepare vc as potential mount point.
  Signed-off-by: Andreas FÃ¤rber <afaerber@suse.de>
* Mon Dec 21 2015 fs@suse.de
- Kiwi Doc Revision Pt. 11: OEM chapter
* Mon Dec 21 2015 fs@suse.de
- Kiwi Doc Revision Pt. 10 (final): PXE chapter
* Mon Dec 21 2015 ms@suse.de
- Fixed JeOS templates configured for efi boot
  in case of efi the efi modules should be installed to the system.
  Even though it's not a problem for kiwi because it takes the modules
  from the self build initrd it could become a problem when grub2
  is used for reconfiguration on the system later. It is also
  questionable whether it is a good idea from kiwi to install
  the efi modules as part of the initrd just for the purpose to
  take them from there at build time when they are not really needed
  in the initrd at boot time. The new (next generation) kiwi version
  will lookup modules from the system if possible and will not
  keep them inside of the initrd
* Mon Dec 21 2015 ms@suse.de
- Fixed suse-SLE12-community-JeOS description
  kernel-debug is not installed, no need to have it in the
  delete section
* Sat Dec 19 2015 martin.koegler@chello.at
- Honor RW filesystem type
* Sat Dec 19 2015 martin.koegler@chello.at
- Refactor file system check
* Thu Dec 17 2015 ms@suse.de
- v7.03.46 released
* Thu Dec 17 2015 ms@suse.de
- Update manual page info about targetdevice option
  This is related to (bnc#956484)
* Thu Dec 17 2015 ms@suse.de
- use sudo for kiwi when running from git source
* Thu Dec 17 2015 ms@suse.de
- Improve validation of targetDevice
  If called with --targetdevice the target must be a device block
  special and nothing else, no symlink, no other node type
  This fixes (bnc#956484)
* Wed Dec 16 2015 martin.koegler@chello.at
- Add label support for xfs
* Tue Dec 15 2015 ms@suse.de
- v7.03.45 released
* Tue Dec 15 2015 ms@suse.de
- Inform user if dracut is called in background mode
* Tue Dec 15 2015 ms@suse.de
- Fixed validation of updates/weak-updates modules
  suseStripKernel took the update and weak-update modules only
  into account if they are mentioned in the drivers list. But
  these modules are considered p1 and should always be included
  and also checked against its dependencies
* Tue Dec 15 2015 martin.koegler@chello.at
- Allow xfs as hybrid RW file system
* Thu Dec 10 2015 ms@suse.de
- v7.03.44 released
* Thu Dec 10 2015 ms@suse.de
- Fixed user setup
  If multiple users are setup in the same users section the
  commandline is broken because not reset to empty after a
  previous user setup run
* Wed Dec  9 2015 ms@suse.de
- Delete use of DOMURD_MODULES
  The predefined values were wrong and the information is not
  used anymore since mkinitrd / dracut takes the list of loaded
  modules into account
* Wed Dec  9 2015 ms@suse.de
- Run dracut as background process for vmx images
  The dracut process takes quite some time and blocks the boot
  process. In cloud frameworks instance boot time matters and
  with this patch the dracut process runs in parallel with the
  rest of the boot process.
* Sun Dec  6 2015 jonas@ekhorva.se
- Translated using Weblate (Swedish)
  Currently translated at 100.0%% (28 of 28 strings)
* Fri Dec  4 2015 ms@suse.de
- v7.03.43 released
* Fri Dec  4 2015 ms@suse.de
- Make sure dbus mountpoint exists
* Fri Dec  4 2015 ms@suse.de
- Follow up fix for bnc#957008
  not recursively removing the temp dir structure causes
  some directories to still be present which is not expected
  at a later point in the build process
* Fri Dec  4 2015 ms@suse.de
- v7.03.42 released
* Thu Dec  3 2015 adrian@suse.de
- syntax fixes for spec file
* Wed Dec  2 2015 ms@suse.de
- v7.03.41 released
* Wed Dec  2 2015 ms@suse.de
- Added information about mysystems macro to spec
  The creation of the -requires packages is based on a macro written
  by Adrian called %%mysystems. It expands to the kiwi boot image
  description name according to the buildservice build distribution.
  It's important to see the value it has expanded to in the buildlog
* Wed Dec  2 2015 ms@suse.de
- v7.03.40 released
* Wed Dec  2 2015 ms@suse.de
- Fixed syntax of spec file macros to be more robust
* Wed Dec  2 2015 ms@suse.de
- v7.03.39 released
* Wed Dec  2 2015 ms@suse.de
- Fixed creation of /var/run vs. /run
  It should not be kiwi's task to handle that but it seems we will
  not be able to fix this in a clean way on the package level. Thus
  I added a bad hack to check for the desired distro from the value
  of the boot attribute and create either /run with a symlink /var/run
  or /var/run
* Wed Dec  2 2015 ms@suse.de
- Fixed spec file requirements
  for older systems (SLE11), the pidof program as used by kiwi is
  provided with the sysvinit package not with sysvinit-tools
* Mon Nov 30 2015 ms@suse.de
- Don't recursively remove tmpdir structure
  If the master /tmp directory is empty there is the potential
  risk that /tmp gets removed too, which would cause many bad
  after effects bnc#957008
* Mon Nov 30 2015 ms@suse.de
- Use tmpfs not ramdisk for overlayfs union images
  overlayfs based iso images (flags="overlay") used a ramdisk of a
  fixed ramsize as temporary write space if used on read-only media.
  This limits the write space to the configured ramdisk size and
  is now changed to a tmpfs location. Fixes #513
* Sat Nov 28 2015 seife+dev@b1-sytems.com
- make .checksum.md5 contents reproducible
  In order to have reproducible builds in OBS with unchanged sources, sort
  the file list before feeding it to "md5sum". Without, rebuilds would
  differ in that file as the file list order was random.
  Also, get rid of "find | grep -v ... | grep -v ..." for ignoring
  filenames and just use find's options to achieve that. Saves two fork()
  and a few CPU cycles :-)
* Fri Nov 27 2015 seife+dev@b1-sytems.com
- KIWIBoot: add grub2-mkimage prefix option
  grub2-mkimage on CentOS/RHEL7 *needs* the "-p <prefix>" option or it
  will abort with an error.
  On openSUSE's grub2-mkimage, prefix defaults to "/boot/grub2".
  Add "-p /boot/grub2" to all grub2-mkimage calls, so that they can work
  with CentOS, too. This *should* not break things on SUSE base ;-)
* Fri Nov 27 2015 ms@suse.de
- v7.03.38 released
* Fri Nov 27 2015 seife+dev@b1-sytems.com
- fix spec file parts for RHEL/CentOS 7
* Fri Nov 27 2015 fs@suse.de
- Fix for bsc #955939
  Link in KIWI documentation to "KIWI Wiki" is broken
* Thu Nov 26 2015 ms@suse.de
- v7.03.37 released
* Thu Nov 26 2015 ms@suse.de
- Update suse-leap-42.1-JeOS
  Use ext4 as write filesystem in overlayfs, btrfs is broken
  for this use case (bnc#950999)
* Thu Nov 26 2015 ms@suse.de
- Allow ext4 to be set in hybridpersistent_filesystem
* Wed Nov 25 2015 guillaume.gardet@free.fr
- Update copyBootCode function:
  Add support to check for /boot/dtb* since DTB files
  can be stored in /boot/dtb/ folder but also in
  /boot/dtb-<version>/ folder with /boot/dtb a symlink
* Sat Nov 21 2015 dmueller@suse.com
- Add warning to extractkernel for aarch64/armv7/s390x
  For those architectures, the kernel can only be found if
  suseStripKernel was called. Add a warning with a hint
  on what went wrong.
* Fri Nov 20 2015 ms@suse.de
- v7.03.36 released
* Thu Nov 19 2015 cschum@suse.de
- Add btrfs to general documentation of volume setup
  Kiwi supports two options for setting up storage layouts with sub volumes, LVM
  and btrfs. Chapter 17 explains this in detail. The overview section in the
  general documentation didn't reference this. This patch fixes this.
* Wed Nov 18 2015 adrian@suse.de
- fix appdata generation on product builds with multiple media
* Tue Nov 17 2015 ms@suse.de
- v7.03.35 released
* Tue Nov 17 2015 ms@suse.de
- Retrieve vm tools version from vmtoolsd
* Mon Nov 16 2015 ms@suse.de
- Deleted __checkMountDependencies runtime check
  I'm afraid but this check causes more false positives than the
  correct detection of an inconsistency in the mount table. Checking
  if the string 'kiwi' appears in the process list is not enough,
  especially in contained environment where the host kernel shares
  mount information with a VM or container guest this check is
  always wrong. We need a better solution here. Fixes Issue#501
* Mon Nov 16 2015 ms@suse.de
- Added Leap 42.1 support for kiwi --describe
  Allow to analyse Leap Systems, fixes Issue #516
* Tue Nov 10 2015 seife+dev@b1-sytems.com
- Bundle all built OEM images
  it is valid to build multiple OEM targets, e.g. with
  <type ... installiso='true' installpxe='true' image='oem'> and
  KIWI correctly builds an install.iso and an install.tar.xz in
  this case. However, when using OBS only the install.iso is
  exported. This is, because "kiwi --bundle-build" will only export
  one image and return.
  Change this to export all: .iso, .raw and .tar.xz
* Fri Nov  6 2015 mpost@suse.com
- Made some spelling corrections and slight changes in wording.
  Signed-off-by: markkp <mpost@suse.com>
* Thu Nov  5 2015 freek@opensuse.org
- Translated using Weblate (Dutch)
  Currently translated at 82.1%% (23 of 28 strings)
* Mon Nov  2 2015 alex239@gmail.com
- Translated using Weblate (Russian)
  Currently translated at 100.0%% (28 of 28 strings)
* Sun Nov  1 2015 martin.mohring@5eecosystems.com
  [kiwi] add searching in the parent directory for the current path for device drivers, kernel modules packages like openSUSE xen-kmp-default put the drivers there
* Thu Oct 29 2015 fitoschido@gmail.com
- Translated using Weblate (Spanish)
  Currently translated at 100.0%% (28 of 28 strings)
* Wed Oct 28 2015 ms@suse.de
- Added vmdk descriptor update
  VMWare applications are made aware that an image has vm-tools installed
  via tags appended to the VMDK's metadata. Typically, the tools write
  the metadata during their first run, but in our case the first run of
  the tools is the first boot of the appliance, so the host application
  is not aware of tools until after a VM has been rebooted, missing a
  critical opportunity to configure an instance before or during the
  first boot. In order to allow VMWare applications (include vCloud)
  to be aware that vm-tools are installed, we need to add the appropriate
  metadata to the image during its creation
* Tue Oct 20 2015 ms@suse.de
- v7.03.34 released
* Tue Oct 20 2015 ms@suse.de
- Make check for running udev daemon more stable
* Mon Oct 19 2015 ms@suse.de
- v7.03.33 released
* Mon Oct 19 2015 ms@suse.de
- Fixed __checkRootDirOutsideImageDescription
  The check failed in kiwi --create mode
* Mon Oct 19 2015 ms@suse.de
- Fixed kernelcmdline setup for EFI live ISO images
  EFI boot of live ISO images is handled via grub2, the configuration
  was missing the information provided in the kernelcmdline attribute
* Mon Oct 19 2015 ms@suse.de
- Cleanup validation of multipath and ataraid scan
  Those two were the only ones which are matched against its
  false value and not against its true value. Fixing this
  inconsistency make it easier to read the code and applies
  better to the next generation kiwi-horizon branch
* Mon Oct 19 2015 ms@suse.de
- v7.03.32 released
* Mon Oct 19 2015 ms@suse.de
- Set noudevsync only if udevd is not running
  LVM commands support the --noudevsync option which should be
  used only if udevd is not running (bnc#950735)
* Mon Oct 19 2015 ms@suse.de
- v7.03.31 released
* Mon Oct 19 2015 ms@suse.de
- actively relocate GPT backup data at end of disk
  Instead of hanging around with parted and its inconsistent state
  between different versions kiwi now actively moves the backup GPT
  to the current end of the disk before starting the repartition
  step based on parted. The tool to move the data is gdisk which
  is now required for GPT images build with kiwi
* Mon Oct 19 2015 ms@suse.de
- Add ramdisk device filter for leap JeOS
  On Leap hwinfo reports ramdisk devices, thus the list of
  disks to select for install in kiwi's install image contains
  all ramdisk devices. For JeOS this is unwanted and we added
  a filter rule to filter them out
* Sat Oct 17 2015 rbrown@suse.com
- Translated using Weblate (English (United Kingdom))
  Currently translated at 100.0%% (28 of 28 strings)
* Sat Oct 17 2015 ramaxlo@gmail.com
- Translated using Weblate (Chinese (Taiwan))
  Currently translated at 100.0%% (28 of 28 strings)
* Thu Oct 15 2015 medipas@gmail.com
- Translated using Weblate (Catalan)
  Currently translated at 100.0%% (28 of 28 strings)
* Thu Oct 15 2015 ms@suse.de
- v7.03.30 released
* Thu Oct 15 2015 ms@suse.de
- Added __checkRootDirOutsideImageDescription
  It should be avoided to create a new root image tree inside of
  the image description directory. This could lead to infinite loops
  or unexpected behavior if e.g the new root directory is named 'root'
  which conflicts with the image description overlay directory also
  named 'root'
* Wed Oct 14 2015 ms@suse.de
- v7.03.29 released
* Wed Oct 14 2015 ms@suse.de
- v7.03.28 released
* Wed Oct 14 2015 adrian@suse.de
- Apply missing syntax fix
* Wed Oct 14 2015 medipas@gmail.com
- Translated using Weblate (Catalan)
  Currently translated at 100.0%% (28 of 28 strings)
* Tue Oct 13 2015 adrian@suse.de
- Add SLE-12-SP1 plugin
  using the new appstream handling for appdata
* Mon Oct 12 2015 frantisek.komarek@gmail.com
- Translated using Weblate (Polish)
  Currently translated at 82.1%% (23 of 28 strings)
* Sun Oct 11 2015 belphegor@belbel.or.jp
- Translated using Weblate (Japanese)
  Currently translated at 100.0%% (28 of 28 strings)
* Sat Oct 10 2015 mpluskal@suse.com
- Translated using Weblate (Czech)
  Currently translated at 96.4%% (28 of 28 strings)
* Sat Oct 10 2015 frantisek.komarek@gmail.com
- Translated using Weblate (Czech)
  Currently translated at 96.4%% (27 of 28 strings)
* Sat Oct 10 2015 galko.ferdinand@gmail.com
- Translated using Weblate (Slovak)
  Currently translated at 100.0%% (28 of 28 strings)
* Sat Oct 10 2015 galko.ferdinand@gmail.com
- Translated using Weblate (Slovak)
  Currently translated at 89.2%% (25 of 28 strings)
* Sat Oct 10 2015 andriykopanytsia@gmail.com
- Translated using Weblate (Ukrainian)
  Currently translated at 100.0%% (28 of 28 strings)
* Sat Oct 10 2015 ronisbr@gmail.com
- Translated using Weblate (Portuguese (Brazil))
  Currently translated at 100.0%% (28 of 28 strings)
* Sat Oct 10 2015 galko.ferdinand@gmail.com
- Translated using Weblate (Slovak)
  Currently translated at 89.2%% (25 of 28 strings)
* Fri Oct  9 2015 sbrabec@suse.com
- Update translations from LCN SVN trunk revision 93546.
* Fri Oct  9 2015 ms@suse.de
- v7.03.27 released
* Thu Oct  8 2015 ms@suse.de
- Support generic multipath lookup
  Instead if limiting the support for multipath boot devices this is
  now checked for all architectures which should also allow iSCSI
  boot devices. (bnc#946387)
* Wed Oct  7 2015 ms@suse.de
- Support multipath lookup for ZFCP devices on s390
  The disk device the image was ipl'ed from might be configured to be
  in a multipath stack. In this case it's required to use the mapped
  device instead of one of the multipath targets directly. This is
  related to (bnc#944017)
* Wed Oct  7 2015 ms@suse.de
- Provide a startMultipathd method
  Move the start of the multipath daemon from the oem boot code
  specific identifyMultipath method to its own method in the
  global space
* Tue Oct  6 2015 ms@suse.de
- v7.03.26 released
* Tue Oct  6 2015 ms@suse.de
- Update -requires matcher for SLE12 SP1
  The macro %%{suse_version} returns 1316 for SLE12 SP1, this must be
  addressed in the spec file to let the internal -requires packages
  contain the correct list for building images inside of the
  buildservice (bsc#949046)
* Tue Oct  6 2015 ms@suse.de
- Rename SLE JeOS descriptions
  In order to avoid a naming conflict with the JeOS product we agreed
  on renaming the SLE JeOS description in kiwi to contain the community
  keyword to separate this descriptions from the SUSE JeOS product
  This addresses (fate#319430)
* Tue Oct  6 2015 ms@suse.de
- Fixed resetBootBind copy of boot data
  Make sure to take hidden files into account
* Thu Oct  1 2015 ms@suse.de
- Update suse-13.2-JeOS
  There is no need to have kernel-debug in the delete section
  actually the package is not installed
* Thu Oct  1 2015 martin.mohring@5eecosystems.com
- fixed: RHEL 6 and CentOS 6 and derivatives using boot='vmxboot/rhel-06.0' or similiar should be handled like SLE 11 not using a tmpfs on /run
* Wed Sep 30 2015 ms@suse.de
- v7.03.25 released
* Tue Sep 29 2015 dvaleev@suse.com
- Drop imagePrepDevice
  imagePrepDeivce was never set, lets drop it.
  Signed-off-by: Dinar Valeev <dvaleev@suse.com>
* Tue Sep 29 2015 ms@suse.de
- v7.03.24 released
* Tue Sep 29 2015 ms@suse.de
- Added basic support for grub2 serial console
  The required configuration steps were added to the bootloader
  configuration. However there is currently no attribute to select
  the serial console case from the XML description. This will
  be added on demand
* Fri Sep 25 2015 dvaleev@suse.com
- Set PReP device
  We need to set PReP device, otherwise we just call grub2-install,
  which is not installing a bootloader
  Signed-off-by: Dinar Valeev <dvaleev@suse.com>
* Thu Sep 24 2015 dvaleev@suse.com
- Fix grub2-mkimage on PowerPC
  Signed-off-by: Dinar Valeev <dvaleev@suse.com>
* Thu Sep 24 2015 ludwig.nussel@suse.de
- insmod video drivers (bsc#947328)
* Thu Sep 24 2015 ludwig.nussel@suse.de
- don't overwrite grub2 background image
  The background image is already defined in theme.txt. Overwriting
  breaks the editing menu (bsc#947326).
* Thu Sep 24 2015 ms@suse.de
- Added arm suse-tumbleweed vmx|oemboot descriptions
* Wed Sep 23 2015 ms@suse.de
- Support SLE12 and leap42.1 boot images for arm
  Deleted 13.2 and non stable tumbleweed from arm based descriptions
* Tue Sep 22 2015 cyberorg@opensuse.org
- use obs://factory/repo/oss/ for tumbleweed boot images
* Tue Sep 22 2015 ms@suse.de
- Fixed toram live boot mode
  The recent implementation broke the standard method which
  mounted the CD instead of copying it
* Mon Sep 21 2015 cyberorg@opensuse.org
- tabs to spaces
* Mon Sep 21 2015 ms@suse.de
- Add root filesystem label to images
  In order to allow devicepersistency="by-label" also for the
  root filesystem, the setupFilesystem method has been extended
  for all supported filesystems to add a root label too. The
  default name for the root label is 'ROOT'. This addresses
  bnc#946236
* Mon Sep 21 2015 cyberorg@opensuse.org
- Echo, rmdir and remove full paths from commands
* Mon Sep 21 2015 ms@suse.de
- Added documentation for the toram option
  Implementation of the toram option is done in PR
  https://github.com/openSUSE/kiwi/pull/492
* Mon Sep 21 2015 ms@suse.de
- v7.03.23 released
* Fri Sep 18 2015 cyberorg@opensuse.org
- rename mountLivecd to mountOrCopyLiveCD, use cp -ar, remove $SIZE test
* Fri Sep 18 2015 cyberorg@opensuse.org
- Add "toram" boot parameter to allow running the live system entirely from RAM
* Fri Sep 18 2015 ms@suse.de
- Make sure kiwi_BootPart variable is written
  kiwi_BootPart is expected to exist in the initrd environment
  Thus it's required to write it in config.partids in any case.
  If there is no extra boot partition kiwi_BootPart equals
  kiwi_RootPart. This fixes bnc#946387
* Fri Sep 18 2015 ms@suse.de
- v7.03.22 released
* Fri Sep 18 2015 ms@suse.de
- Prevent prefix setup in grub.cfg for Xen
  This is because Xen PV guests boot via a first stage loader pygrub/pvgrub
  and interpret the grub config file differently. One inconsistency is that
  pvgrub searches for the grub modules at a different place. Setting up the
  prefix will point pvgrub to the wrong place and the system fail to boot.
* Thu Sep 17 2015 ms@suse.de
- Prevent command variables for Xen domU grub2 setup
  Xen PV images which boot via pvgrub have the problem that pvgrub
  is not able to correctly read in the kiwi written grub.cfg file.
  This is because kiwi uses a variable which contains the loader
  command e.g $linux instead of the loader command directly. grub2
  supports this but pvgrub is not able to interpret this information.
  Therefore this patch prevents the use of the variable if the
  target image is Xen, domU and the firmware type is set to bios
* Thu Sep 17 2015 ms@suse.de
- Embed LOADER_TYPE into double quotes
  required to make perl-bootloader happy
* Wed Sep 16 2015 dmueller@suse.com
- Add vmxboot support for aarch64 on SLE12 and leap42.1
* Tue Sep 15 2015 schwab@suse.de
- Add suse-tumbleweed boot image descriptions
* Mon Sep 14 2015 ms@suse.de
- v7.03.21 released
* Mon Sep 14 2015 ms@suse.de
- Fixed mysystems spec file macro for Leap
* Mon Sep 14 2015 ms@suse.de
- v7.03.20 released
* Mon Sep 14 2015 ms@suse.de
- Deleted obsolete openSUSE 12.3 templates
* Mon Sep 14 2015 ms@suse.de
- v7.03.19 released
* Mon Sep 14 2015 ms@suse.de
- Make sure suse-leap-42.1-JeOS is installed
* Mon Sep 14 2015 ms@suse.de
- Rename leap boot descriptions to naming convention
* Mon Sep 14 2015 ms@suse.de
- Added leap-42.1-JeOS template
* Mon Sep 14 2015 ms@suse.de
- Added leap-42.1 boot image descriptions
* Mon Sep 14 2015 ms@suse.de
- Added Tumbleweed and Leap42 as known distributions
  The kiwi spec file also build metadata packages used internally
  by the buildservice. These so called -requires packages needs
  to find the right kiwi provided boot image descriptions according
  to the image distribution. For The Leap42 and Tumbleweed distros
  an extra pattern match needed to be added
* Mon Sep 14 2015 ms@suse.de
- Deleted obsolete openSUSE 12.3 descriptions
  A new image template for SUSE Leap42 will follow next
* Mon Sep 14 2015 ms@suse.de
- Deleted obsolete SLED boot descriptions
  For building SLED images the SLES boot image descriptions can be used
* Mon Sep 14 2015 ms@suse.de
- Deleted deprecated oemboot descriptions for arm
* Mon Sep 14 2015 ms@suse.de
- Added SLE12/aarch64 JeOS template
* Mon Sep 14 2015 ms@suse.de
- Fixed SLE12/aarch64 oemboot descriptions
  The description should not contain a copy of the common linuxrc boot code.
* Sun Sep 13 2015 dmueller@suse.com
- Add oemboot support for SLE12/aarch64 (fate#318444)
* Sat Sep 12 2015 dimstar@opensuse.org
- openSUSE Tumbleweed boot images
* Fri Sep 11 2015 ms@suse.de
- v7.03.18 released
* Fri Sep 11 2015 ms@suse.de
- Added mtools requirement (bnc#945212)
  syslinux no longer requires mtools, but kiwi does so we have to
  explicitly add this requirement for oem targets
* Tue Sep  8 2015 ms@suse.de
- v7.03.17 released
* Tue Sep  8 2015 ms@suse.de
- Revert "Remove genisoimage and cdrkit-cdrtools-compat dependency"
  This reverts commit 0c7b2885c37b16d69e46caf7c365d2eacb615cd9.
* Tue Sep  8 2015 ms@suse.de
- v7.03.16 released
* Tue Sep  8 2015 ms@suse.de
- System to boot inheritance for wwid_wait_timeout
  Added missing transfer of wwid_wait_timeout from the system
  image description into the boot image description
* Tue Sep  8 2015 ms@suse.de
- Fixed unrecognized variable: kiwi_wwid_wait_timeout
* Mon Sep  7 2015 ms@suse.de
- Delete live patch for dracut module
  With the correct /var/run symlink the broken dracut module is
  not called and thus the problem in dracut is workarounded
  Nevertheless dracut needs the fix
* Mon Sep  7 2015 ms@suse.de
- Fixed setup of /var/run location
  /var/run is a symlink to /run on newer systems and a directory
  on older systems. We need to properly handle that
* Mon Sep  7 2015 ms@suse.de
- Fixed jenkins build preparation
  For some reason no mkisofs package is available anymore. Thus the
  jenkins prepare script should not rely on it to be installed
* Mon Sep  7 2015 ms@suse.de
- Renamed bootloader ziplgrub to grub2_s390x_emu
  We don't want to populate a non existing bootloader. Thus the
  decision was to use the grub2 platform name for the SLE12 s390
  boot workflow (bnc#944017)
* Mon Sep  7 2015 ms@suse.de
- Update s390 JeOS description
  adding hotfix patches requires patch program to be installed
* Mon Sep  7 2015 ms@suse.de
- Update s390 JeOS description
  Added a temporary live patch for the broken dracut module
  30convertfs/do-convertfs.sh
* Fri Sep  4 2015 ms@suse.de
- Fixed clicfs race condition
  sleep for a while before accessing the mounted filesystem
* Fri Sep  4 2015 ms@suse.de
- There is no mkisofs on s390
* Fri Sep  4 2015 ms@suse.de
- Fixed openSUSE 13.2 diskless netboot profile
  kernel version 3.x uses another structure to store the network
  drivers. Thus the drivers matching in the netboot/suse-13.2/config.xml
  did not match anymore (bnc#943888)
* Thu Sep  3 2015 jochen.keil@gmail.com
- Test whether file is executable instead mere existence
* Thu Sep  3 2015 jochen.keil@gmail.com
- Make sure to use the correct isoinfo executable
  In order to remove the cdrkit-cdrtools-compat dependency (and in turn
  wodim), it is necessary to check whether to use /usr/bin/isoinfo or
  /usr/lib/genisoimage/isoinfo.
* Mon Aug 31 2015 ms@suse.de
- Added required packages to SLE12 s390 images
  * added grub2 and grub2-s390x-emu to vmx|oem boot images
  * added grub2, grub2-s390x-emu and kexec-tools to JeOS templates
  * extend JeOS template by some useful tool, e.g parted, ip, less
* Mon Aug 31 2015 schwab@suse.de
- Increase fsoverhead for btrfs again
* Mon Aug 31 2015 ms@suse.de
- Fixed use of undefined value
* Mon Aug 31 2015 ms@suse.de
- Support for stacked zipl plus grub2 boot
  In SLES12 zipl and btrfs are incompatible because the block where
  the initrd and the kernel live could change in a btrfs filesystem.
  Because IBM is not going to fix zipl to work with btrfs a new boot
  process has been invented by the SLES team which impacts kiwi too.
* Mon Aug 31 2015 ms@suse.de
- Fixed build type setup for boot images
* Mon Aug 31 2015 ms@suse.de
- Fixed typos in default boot image repos
* Thu Aug 27 2015 ms@suse.de
- v7.03.15 released
* Thu Aug 27 2015 ms@suse.de
- Added type attribute wwid_wait_timeout
  multipath devices from a SAN system take some time to appear on
  the host. In order to have all presented wwn's available on the
  host it's required to wait some time because we can't poll for
  the appearance of a specific device the wait period is now
  customizable. The default wait period is 3 seconds
* Tue Aug 25 2015 ms@suse.de
- Revert "Remove genisoimage and cdrkit-cdrtools-compat dependency"
* Mon Aug 24 2015 ms@suse.de
- v7.03.14 released
* Mon Aug 24 2015 ms@suse.de
- Skip loopback nic in interface selection
  setupNetworkStatic selects the last interface to be used for
  the setup. This is not a smart selection but it should not
  select the loopback interface in any case. Whether or not it's
  possible to automatically just select the "right" nic is still
  an open task.
* Mon Aug 24 2015 ms@suse.de
- Fixed reading of search path for editboot* scripts
  In build and create mode the origin path of the XML description was
  not correctly initialized. kiwi skipped reading the meta information
  from the unpacked image root tree because it already has a pointer
  to the XML description, however this data set does not provide the
  origin path of the kiwi call
* Tue Aug 18 2015 schwab@suse.de
- Remove duplicate provide of kiwi-image:tbz
* Thu Aug 13 2015 jochen.keil@gmail.com
- Don't fix the catalog when it's already correct
  In contrast to genisoimage, mkisofs generates a proper boot catalog
  entry. Thus it is not necessary to fix it.
- Don't fix the catalog when it's already correct
  In contrast to genisoimage, mkisofs generates a proper boot catalog
  entry. Thus it is not necessary to fix it.
* Wed Aug 12 2015 jochen.keil@gmail.com
- Remove genisoimage and cdrkit-cdrtools-compat dependency
  * cdrkit-cdrtools-compat provides a symlink from mkisofs to genisoimage
  * It should be safe to use mkisofs as drop-in replacement for genisoimage
  * Removing these dependencies is one step towards removing wodim
- Remove genisoimage and cdrkit-cdrtools-compat dependency
  * cdrkit-cdrtools-compat provides a symlink from mkisofs to genisoimage
  * It should be safe to use mkisofs as drop-in replacement for genisoimage
  * Removing these dependencies is one step towards removing wodim
* Mon Aug  3 2015 ms@suse.de
- v7.03.13 released
* Mon Aug  3 2015 rjschwei@suse.com
- Add a line that helps solver debugging, commented out by default
* Fri Jul 31 2015 fs@suse.de
- Kiwi Doc Revision Pt. 10_WIP: PXE chapter
* Thu Jul 30 2015 ms@suse.de
- Fixed XML writer for array of objects
  Elements which can appear multiple times like the vagrantconfig
  element are stored as array of objects. The XML writer has to
  iterate over the array and ask for the XML setup of each of
  the objects inside of the array
* Wed Jul 29 2015 fs@suse.de
- Kiwi Doc Revision Pt. 9: Vagrant Chapter
* Wed Jul 29 2015 fs@suse.de
- Kiwi Doc Revision Pt. 8: Docker Chapter
* Wed Jul 29 2015 ms@suse.de
- v7.03.12 released
* Wed Jul 29 2015 ms@suse.de
- Fixed RHEL recovery
  delete recovery of zypp database backup, this does not exist
  on rhel systems
* Tue Jul 28 2015 ms@suse.de
- v7.03.11 released
* Tue Jul 28 2015 ms@suse.de
- Update RHEL6 JeOS
  use group id names instead of the description
* Tue Jul 28 2015 fs@suse.de
- Kiwi Doc Revision Pt. 7: VMX Chapter
* Tue Jul 28 2015 ms@suse.de
- Deleted yum grouplist check
  Prior to installing yum groups, kiwi performed a grouplist
  to check if the group exists. That's because yum groupinstall
  does only print a warning message if a non existing group
  should be installed. The problem here is that the group names
  displayed by yum grouplist are the description names like
  "Console internet tools" but the group id name in this case
  "console-internet" is not displayed. This makes it impossible
  for kiwi to use the yum group id names which we should prefer
  over the description texts, because the texts could contain
  special characters which makes it hard to validate the content
  in a stable way. In addition yum groupinstall works more
  reliable if the group id names are used
* Tue Jul 28 2015 ms@suse.de
- v7.03.10 released
* Tue Jul 28 2015 ms@suse.de
- Fixed installation of recovery grub for RHEL
* Tue Jul 28 2015 ms@suse.de
- Update spec file to package updated RHEL JeOS
* Tue Jul 28 2015 ms@suse.de
- Update RHEL6 JeOS template
  Update to rhel server v6.6
* Mon Jul 27 2015 fs@suse.de
- Kiwi Doc Revision Pt. 6: Maintenance Chapter
* Mon Jul 27 2015 ms@suse.de
- Fixed disk size adaption for in place recovery
  The size of the disk is increased by the require space to
  create the recovery tar archive at boot time. However the
  value was not in the xml instance because KIWIBoot creates
  their own instance of KIWIXML. This is fixed now by passing
  along the origin XML instance when available
* Mon Jul 27 2015 ms@suse.de
- Fixed in place recovery
  The information about the size of the recovery partition was
  missing inside of the initrd. The information is now available
  as variable in the profile environment
* Fri Jul 24 2015 fs@suse.de
- Maintenance chapter, still WIP
* Fri Jul 24 2015 fs@suse.de
- Kiwi Doc Revision Pt. 5: ISO images
* Fri Jul 24 2015 fs@suse.de
- Added TODO list
* Fri Jul 24 2015 ms@suse.de
- v7.03.9 released
* Fri Jul 24 2015 ms@suse.de
- Added custom hybridpersistent_filesystem attribute
  By default kiwi creates a btrfs partition as write space for hybrid
  live systems. With the new attribute one can specify also the 'fat'
  filesystem as write space. This would allow to create hybrid live
  images which are compatible with the Windows OS in a similar way
  like kiwi's livestick tool does it. This Fixes #475
* Thu Jul 23 2015 fs@suse.de
- Kiwi Doc Revision Pt. 4: Moving RAID, LUKS, LVM and Cache to Advanced Config
* Tue Jul 21 2015 fs@suse.de
- Kiwi Doc Revision Pt. 3: Creating Appliances
* Mon Jul 20 2015 fs@suse.de
- Kiwi Doc Revision Pt. 2: Basic Workflow
* Fri Jul 17 2015 ms@suse.de
- v7.03.8 released
* Fri Jul 17 2015 ms@suse.de
- Update Makefile clean target
  delete possible .dice / .vagrant directories
* Thu Jul 16 2015 ms@suse.de
- Update SLE12 JeOS image description
  xen-tools conflicts with xen-tools-domU
* Thu Jul 16 2015 ms@suse.de
- Update dice configuration files
  Use the new dice docker buildsystem instead of vagrant calling
  docker. There is also a kiwi-build-box container on dockerhub
  which is automatically used for the build
* Wed Jul 15 2015 ms@suse.de
- v7.03.7 released
* Tue Jul 14 2015 ms@suse.de
- Use defined macro to check if variable is defined
  The perl version in tumbleweed seems to behave more strict on this
* Tue Jul 14 2015 ms@suse.de
- v7.03.6 released
* Tue Jul 14 2015 ms@suse.de
- Allow containers to be build without systemd
  the container setup procedure by default disable some services.
  In order to do this either systemctl or chkconfig is used.
  However this should not be a mandatory task because it is ok
  to build containers without service tools installed
* Mon Jul 13 2015 ms@suse.de
- Follow up fix for repo detection in kiwi describe
  The data fields of zypper in newer versions has changed. Thus
  split by the field separator and extract the information.
  Fortunately the ordering hasn't changed
* Mon Jul 13 2015 ms@suse.de
- Fixed repo detection in describer module
  The zypper syntax has changed, thus detection of the repo state
  leads to incorrect results
* Mon Jul 13 2015 fs@suse.de
- Kiwi Doc Revision Pt. 1: Legal stuff, Introduction and Installation
- Kiwi Doc Revision Pt. 1: Legal stuff, Introduction and Installation
* Fri Jul 10 2015 ms@suse.de
- v7.03.5 released
* Fri Jul 10 2015 ms@suse.de
- Use by-uuid device names for livestick tool
* Thu Jul  9 2015 fs@suse.de
- Added doc/emacs specific stuff to .gitignore
* Thu Jul  9 2015 fs@suse.de
- Pretty formatting the sources, standardized the use of lists
* Wed Jul  8 2015 ms@suse.de
- DB: rebuild documentation
* Tue Jul  7 2015 ms@suse.de
- Added __checkImageIncludeApplicable runtime check
  The imageinclude attribute is currently not supported with all
  URI types. Therefore we test if the repo URL uses obs|iso and
  provide a message to the user. If we want to support this in the
  future for obs URI types the imageinclude feature has to auto
  map the obs URI into the correct http URI which will only work
  for repositories in the public part of the open buildservice
  This Fixes #472
* Tue Jul  7 2015 ms@suse.de
- v7.03.4 released
* Tue Jul  7 2015 ms@suse.de
- Fixed createOVFConfiguration
  Make sure destination directory exists prior to moving data
* Mon Jul  6 2015 schwab@suse.de
- Increase fsoverhead for btrfs
* Wed Jul  1 2015 ms@suse.de
- v7.03.3 released
* Wed Jul  1 2015 ms@suse.de
- Follow up Fix for grub2 setup on btrfs
  Only if no bootpartition is used and a volume setup exists
  it's required to adapt the boot path with the initial '@'
  subvolume
* Wed Jul  1 2015 ms@suse.de
- Update examples, don't use clicfs
* Mon Jun 29 2015 ms@suse.de
- v7.03.2 released
* Mon Jun 29 2015 ms@suse.de
- DB: rebuild documentation
* Mon Jun 29 2015 ms@suse.de
- v7.03.1 released
* Mon Jun 29 2015 ms@suse.de
- DB: rebuild documentation
* Mon Jun 29 2015 ms@suse.de
- Editorial review Chapter 19-20
* Mon Jun 29 2015 ms@suse.de
- Editorial review Chapter 16
* Mon Jun 29 2015 ms@suse.de
- Fixed __checkPreferencesDefinition runtime check
  The check for the uniqueness of the profile name is based on
  a regular expression. However the expression matches a subset
  of names which causes 'foo' and 'foofoo' to be triggered as
  the same name
* Mon Jun 29 2015 ms@suse.de
- Update SLE12 JeOS
  Added Xen HVM type setup to be referenced in the documentation
  Deleted ec2 image build. This will eventually become a new chapter
  referencing the images as we build it in the buildservice later
* Mon Jun 29 2015 ms@suse.de
- Editorial review Chapter 17
  EC2 documentation deleted, this chapter needs a rewrite
  with regards to tools developed in the public cloud
  development team. I would also not mention any sequence
  to support s3 baked images, we should focus on EBS
  baked images
* Mon Jun 29 2015 ms@suse.de
- v7.02.58 released
* Mon Jun 29 2015 ms@suse.de
- Add uuid support in createFilesystem for btrfs
* Fri Jun 26 2015 fs@suse.de
- Update documentation structure for DAPS
  DAPS is the toolkit used in the documentation department to
  build, validate and submit documentation. The kiwi documentation
  will be integrated into the SUSE documentation department
  and therefore the structure in the source repository needs
  to be compatible with the SUSE documentation process
* Wed Jun 24 2015 ms@suse.de
- Fixed custom image size use
  Allow use of the custom image size even if it is smaller than
  the kiwi calculated one. Especially for the btrfs filesystem
  the calculation is sometimes not accurate enough
* Mon Jun 22 2015 ms@suse.de
- Fixed shell variable quoting in compare statements
* Mon Jun 22 2015 ms@suse.de
- Prevent createHybridPersistent waiting for devs
  Check if the write partition creation returns success before
  waiting for the expected device to become created. This prevents
  a long wait period on a device which never will come up if the
  partition could not be created. This Fixes #466
* Mon Jun 22 2015 ms@suse.de
- Fixed legacy grub install for install stick images
  Installing legacy grub can happen using the image grub or the
  build host grub. However for install stick disks there is no
  grub in the install image even if it is present in the system
  image the stick installs. Therefore the host installed grub
  should be used as a fallback. This Fixes #471
* Sun Jun 21 2015 ms@suse.de
- Changed search for boot from hardisk for efi
  Instead of looking for a fixed partition id, let grub2
  search for the EFI label
* Sat Jun 20 2015 ms@suse.de
- Fixed RHEL 6 JeOS template
  default bootloader for this distribution is grub not grub2
* Fri Jun 19 2015 ms@suse.de
- v7.02.57 released
* Fri Jun 19 2015 ms@suse.de
- Fixed grub.cfg for Xen dom0 images
  bogus information was added within a menuentry section
* Fri Jun 19 2015 ms@suse.de
- Editorial review Chapter 15
* Thu Jun 18 2015 ms@suse.de
- Editorial review Chapter 14
* Thu Jun 18 2015 ms@suse.de
- Update SLE12 JeOS
  Added pxe configuration to be referenced in the documentation
* Thu Jun 18 2015 ms@suse.de
- Fixed zipl setup
  zipl does not allow a targetgeometry if the target type is
  different from CDL or LDL
* Thu Jun 18 2015 ms@suse.de
- Fixed use of union type in pxe setup
  The reference on clicfs was still present in the schema and the
  runtime checks. However clicfs is out of support and overlayfs
  is the only union filesystem we really support
* Wed Jun 17 2015 ms@suse.de
- Update s390 JeOS image description
  for the oem and vmx types build the disk for a DASD target
  in CDL mode (ECKD). Also make this clear in the name of the
  generated image
* Wed Jun 17 2015 ms@suse.de
- Fixed diskOffset calcuation for s390
  zipl wants the number of blocks to indicate the start of
  the first partition, not the number of tracks
* Wed Jun 17 2015 ms@suse.de
- Fixed zipl installation for LDL/CDL on loop device
  Installing zipl on the LDL/CDL target device types requires
  to specify the disk geometry. zipl is not able to get that
  information from a loop device. Therefore we need to hand
  over a targetgeometry which matches the loop geometry
* Wed Jun 17 2015 bgeuken@suse.de
- TypoFix: for for -> do for
* Tue Jun 16 2015 ms@suse.de
- Editorial review Chapter 12-13
* Tue Jun 16 2015 ms@suse.de
- Update SLE12 JeOS
  Added vagrant and docker configurations to be referenced
  in the documentation
* Tue Jun 16 2015 ms@suse.de
- Update selector for partitioner tool
  If we are building a dasd image using the new loop driver which
  supports 4k devices, we need a way to select fdasd as partitioner
  on s390. This can be done via commandline options but is now also
  auto selected if a zipl_targettype of CDL or LDL is specified
* Tue Jun 16 2015 ms@suse.de
- Implement setup of loop logical sector size
  The new loop driver capability allows to set a custom blocksize
  on setup of the loop device. The attribute value from the
  target_blocksize attribute is used in losetup as follows:
-L target_blocksize
  This fixes (bnc#931634)
* Tue Jun 16 2015 ms@suse.de
- Editorial review Chapter 11
* Mon Jun 15 2015 ms@suse.de
- Editorial review Chapter 10
* Mon Jun 15 2015 ms@suse.de
- Editorial review Chapters 6-9
* Sun Jun 14 2015 ms@suse.de
- Editorial review Chapters 1-5
* Fri Jun 12 2015 ms@suse.de
- v7.02.56 released
* Fri Jun 12 2015 ms@suse.de
- Fixed installation of Archive into root system
  Archives marked as bootinclude were excluded from being installed
  into the image too. This is an unexpected behaviour change and
  is fixed now
* Tue Jun  9 2015 ms@suse.de
- v7.02.55 released
* Tue Jun  9 2015 ms@suse.de
- Allow to overwrite root= via kernelcmdline
  If one of the ec2 firmware types is used the root= variable is
  explicitly set to a static value. There was no way for the user
  to set an alternative device via the kernelcmdline attribute in
  the image description
* Tue Jun  9 2015 ms@suse.de
- Fixed zipl installBootLoader blocksize usage
  There is now the target_blocksize attribute which is used. If not
  specified the default blocksize of 512 bytes applies (bnc#931634)
* Tue Jun  9 2015 ms@suse.de
- Fixed zipl installBootLoader blocksize retrieval
  In order to find the target blocksize for the zipl configuration
  kiwi asked for the pyhiscal blocksize. However the logical block
  size should be used when zipl accesses the device (bnc#931634)
* Tue Jun  9 2015 adrian@suse.de
- fix version detection for debug packages
* Mon Jun  8 2015 ms@suse.de
- v7.02.54 released
* Mon Jun  8 2015 ms@suse.de
- Added __checkVolumeSetup runtime check
  Checks for improper combination of boot volumes in combination
  with an extra boot partition
* Mon Jun  8 2015 ms@suse.de
- Added runtime check for internal field separator
  Using the internal path field separator in volume names (_)
  requires to specify the path in an additional mountpoint
  attribute
* Mon Jun  8 2015 ms@suse.de
- Fixed volume name adaptions for btrfs and zfs
  There is no need to replace any character in the name for the volume
  of a filesystem which includes a volume manager. Fixes (bnc#933909)
* Mon Jun  8 2015 ms@suse.de
- Fixed evaluation of bootincluded archives
  Archives set in the bootstrap section and marked as bootinclude
  were not really used and therefore its contents were missing in
  the kiwi initrd
* Mon Jun  8 2015 ms@suse.de
- Revert "Implement setup of loop blocksize"
  The user space interface will change because in order to set the
  pyhsical blocksize the value must be present on loop creation. This
  required options to the losetup call and can't be done afterwards.
  Therefore the implementation in kiwi will be reverted until the
  user space interface for losetup is final
  This reverts commit d2dfead392a7dd2064afbd59df4c4d67bcacbc98.
* Mon Jun  8 2015 ms@suse.de
- Implement setup of loop blocksize
  The new loop driver capability allows to set a custom blocksize
  This patch makes use of it with the value from the optional
  target_blocksize attribute (bnc#931634)
* Fri Jun  5 2015 ms@suse.de
- v7.02.53 released
* Fri Jun  5 2015 ms@suse.de
- Follow up fix for btrfs grub2 boot path
  For iso media the adaption of the boot path to /@/... is wrong
  because in this case we read from iso9660 and not from btrfs.
  This is related to (bnc#933664)
* Fri Jun  5 2015 ms@suse.de
- Fixed grub2 setup on btrfs without boot partition
  If the image is built with btrfs and no extra boot partition is requested
  the grub2 btrfs module is used to read the boot data from the filesystem.
  However in kiwi we setup a btrfs filesystem in a way that all subvolumes
  are nested below a master '@' volume. Within the scope of grub2 it's
  required to adapt any path in the filesystem to match this because it's
  not possible to specify a subvolume set-default here. Because of this
  /boot/grub2/grub.cfg becomes /@/boot/grub2/grub.cfg within grub2.
  This fixes (bnc#933664)
* Wed Jun  3 2015 ms@suse.de
- v7.02.52 released
* Thu May 28 2015 ms@suse.de
- Fixed result tracking from ovftool
  The temporary directory created for this has the same name
  as the ovf file created inside of it. On move of the data
  to the result dir this causes trouble which is fixed by
  this commit
* Thu May 28 2015 ms@suse.de
- Added target_blocksize attribute in type section
  In preparation to support custom blocksize values for loops
  the attribute target_blocksize was implemented like the folowing
  example shows:
  <type ... target_blocksize="4096"/>
  This will set a 4k blocksize used for all loops setup during
  image build and on first boot of the image. The actual code to
  apply the blocksize to the loop is not yet implemented because
  we are still waiting for the loop driver to support it. This is
  related to (bnc#931634)
* Wed May 27 2015 ms@suse.de
- Added pointer to XML description for loop_setup
  In preparation to support custom blocksize values for loops
  access to the XML description is needed to read the specified
  target_blocksize value once support for this value will be
  added
* Wed May 27 2015 ms@suse.de
- Fixed ova guestOS value for 13.2 JeOS
* Wed May 27 2015 ms@suse.de
- Cleanup use of losetup
  In preparation to support custom blocksize values for loops
  global methods to loop setup/delete has been added. This
  is related to (bnc#931634)
* Wed May 27 2015 ms@suse.de
- Added runtime check for overlay systems
  The __checkBootPartitionOverlaySystem runtime check makes sure
  the use of a boot partition is not switched off. If the root
  system is a read-only location the boot space must be writable
* Fri May 22 2015 ms@suse.de
- v7.02.51 released
* Thu May 21 2015 matwey.kornilov@gmail.com
- Provide kiwi-image:aci in kiwi.spec
* Thu May 21 2015 ms@suse.de
- Update all JeOS templates, no rpm signature check
  Due to upcomming changes in zypper the --non-interactive option
  will no longer do what the name says and will prevent using
  packages with invalid or not checkable rpm signatures unless
  the option to skip the check is set. Therefore all JeOS templates
  now comes with
  <rpm-check-signatures>false</rpm-check-signatures>
* Thu May 21 2015 ms@suse.de
- DB: rebuild documentation
* Thu May 21 2015 ms@suse.de
- Update documentation due to OEM_ variable change
* Thu May 21 2015 ms@suse.de
- Cleanup use of OEM variables
  Deleted baseSetupOEMPartition and therefore the translation of
  variables from the profile into OEM_ variables by writing the
  environment file config.oempartition. Instead the boot now
  directly uses the variables from the profile which are all
  prefixed by kiwi_oem*
* Thu May 21 2015 ms@suse.de
- Deleted fixed parmfile name PARM-S11 on s390
  Instead a new OEM element called: <oem-vmcp-parmfile> has been
  added. Using this element allows to specify the parmfile name
  without the userid. The userid is queried on demand. If no
  parmfile name is specified the default name PARM-S11 applies
  for backward compatibility. This fix relates to (bnc#931436)
* Thu May 21 2015 ms@suse.de
- Fixed loading of vmcp on s390
  In SLE12 vmcp is compiled into the kernel, thus loading
  it as a module will cause an exception which is misleading
  This fixes (bnc#931436)
* Wed May 20 2015 ms@suse.de
- Provide suseService method for compatibility
  Old image descriptions using this method will fail to build
  with newer kiwi versions if the function does not exist
* Wed May 20 2015 ms@suse.de
- Fixed setup of imageBootDevice on repart
  make use of the kiwi_BootPart information. This was overlooked
  in OEMRepartStandard, all other repartition methods makes use
  of it
* Mon May 18 2015 ms@suse.de
- Use KIWI_IGNORE_OLD_MOUNTS for make valid target
* Mon May 18 2015 ms@suse.de
- v7.02.50 released
* Mon May 18 2015 ms@suse.de
- Make sure reco_uuid is not used uninitialized
* Mon May 18 2015 ms@suse.de
- Fixed setup of boot timeout in elilo compat mode
* Sun May 17 2015 ms@suse.de
- Auto validation of templates
* Sun May 17 2015 ms@suse.de
- v7.02.49 released
* Sun May 17 2015 ms@suse.de
- Fixed use of prefix in updateBootDeviceFstab
  prefix should indicate the prefixed root mount path and
  not the temporary config files path. Due to that misuse
  the check for boot_bind was wrong and no boot mount was
  written to fstab
* Fri May 15 2015 ms@suse.de
- Fixed use of prefix in updateRootDeviceFstab
  prefix should indicate the prefixed root mount path and
  not the temporary config files path. Due to that misuse
  the wrong information was passed to the btrfs tool to
  ask for the list of subvolumes
* Wed May 13 2015 ms@suse.de
- v7.02.48 released
* Wed May 13 2015 ms@suse.de
- Update 13.2 JeOS, auto adaption from validation
* Wed May 13 2015 ms@suse.de
- Fixed btrfs based factory restore
  On factory restore the btrfs subvolumes were recreated but no
  default subvolume was defined. Because of this the restore of
  the data was not correctly shared across the subvolumes
* Wed May 13 2015 ms@suse.de
- Added __checkVMConfigExist runtime check
  The ova and ovf formats requires a machine section to be specified
  in the XML description. This check makes sure it exists
* Wed May 13 2015 ms@suse.de
- Fixed creation of btrfs filesystem
  Delete potentially existing btrfs signature prior to creating
  a new filesystem. If used with a UUID mkfs.btrfs refuses to
  create the filesystem even with the force option enabled if
  there is the same uuid already present in the metadata
* Wed May 13 2015 ms@suse.de
- Cleanup use of /mnt string in common boot code
  All function using /mnt hold on a prefix variable containing the value
* Tue May 12 2015 ms@suse.de
- Don't log errors from udevSystemStop
  in case udevadm has no control command don't log this error
  because the process will be stopped in a second attempt by kill
* Tue May 12 2015 ms@suse.de
- v7.02.47 released
* Tue May 12 2015 ms@suse.de
- Google doesn't like pretty print of json metadata
* Tue May 12 2015 ms@suse.de
- v7.02.46 released
* Tue May 12 2015 ms@suse.de
- Fixed console initialization on exception
  If multiple consoles are used like console=tty0 console=ttyS0
  the output is multiplexed among all consoles if plymouth or blogd
  is in use. However if a system shell exception occurs the
  exception shell was not correctly initialized as controlling
  terminal. In order to fix this the sulogin program is used and
  the shell .bashrc will reset the spawned console first.
  This fixes (bnc#928090)
* Mon May 11 2015 matwey.kornilov@gmail.com
- Introduce initial support for App Container Image (aci)
  Here is initial implementation of App Container Image (aci) format.
  This commit is able to build .aci images conforming to SPEC.
  [1] https://github.com/appc/spec/blob/master/SPEC.md#app-container-image
* Mon May 11 2015 ms@suse.de
- Fixed use of ovftool v3.5.x
  If format="ova" is specified kiwi uses VMware's ovftool if installed
  on the host to generated the ova tarball. In addition kiwi extracts
  the vmdk and ovf metadata from the ovftool generated data and overwrites
  it with the files created by kiwi. This allows us to create vmdk
  versions like VSphere needs it
* Fri May  8 2015 ms@suse.de
- v7.02.45 released
* Fri May  8 2015 ms@suse.de
- Allow archives to be bootstrap or image archives
  Archives listed in the bootstrap section should be installed
  as part of the bootstrap phase. before this patch all archives
  from all packages sections were collected and installed in one
  shot after all packages were installed.
* Fri May  8 2015 ms@suse.de
- Fixed creation of bootincluded_archives.filelist
  This should only be done for archives marked as bootinclude
* Thu May  7 2015 ms@suse.de
- v7.02.44 released
* Thu May  7 2015 ms@suse.de
- Follow up fix for kiwi repository runtime script
  The temporary creation of KIWIAnalyse.tgz should be done with
  the login user identity
* Thu May  7 2015 ms@suse.de
- v7.02.43 released
* Thu May  7 2015 ms@suse.de
- Fixed kiwi repository runtime script
  It unpacked metadata/KIWIAnalyse.tgz even if the data already exists
* Thu May  7 2015 ms@suse.de
- Follow up fix for grub_cpu validation
  Incorrect shell syntax
* Thu May  7 2015 ms@suse.de
- Added runtime check for target directories
  Setting the target directory as part of /var/cache/kiwi leads
  to busy mount processes because this shared cache location is
  used by kiwi as part of the building process
* Thu May  7 2015 ms@suse.de
- Fixed cache selector
  Calling the cache selector while in init-cache mode doesn't make sense
* Thu May  7 2015 ms@suse.de
- Changed default image cache location
  The previous location was set to /var/cache/kiwi/image but this leads
  to busy mounts when preparing a cache image below this path because
  /var/cache/kiwi is bind mounted during preparation of a cache. Thus
  the default cache location is set to /var/cache/kiwi-images
* Thu May  7 2015 ms@suse.de
- Fixed error message on --init-cache
  If the given cache dir does not exist display a proper error message
* Tue May  5 2015 bgeuken@suse.de
- Fix lvm volume regex to allow volume names that are just have a forbidden name as prefix
* Mon May  4 2015 ms@suse.de
- Make sure btrfs subvolumes are listed in fstab
  In order to leave a rollback prepared system after first boot
  it's important to configure SUSE_BTRFS_SNAPSHOT_BOOTING as
  well as add all subvolumes as single mountpoints to the fstab
  file
* Mon May  4 2015 ms@suse.de
- Added support to filter install devices
  There is now a <oem-device-filter> element which allows to receive
  a free form text evaluated as input for the bash regexp operator.
  Every device matching the rule is filtered out and not part of
  the selection list for the install targets in an oem installation
  process. This addresses (bnc #924436)
* Mon May  4 2015 ms@suse.de
- Fixed use of fdasd on SLE12
  when using fdasd on an empty disk two questions raises which
  needs to be answered/confirmed before kiwi can proceed to create
  partitions (bnc #928550)
* Fri May  1 2015 ms@suse.de
- v7.02.42 released
* Thu Apr 30 2015 ms@suse.de
- Update RHEL7 JeOS template
  Added lan0 udev rule, don't use lvm to simplify setup
* Thu Apr 30 2015 ms@suse.de
- Fixed use of custom kernel options for recovery
  custom kernel paratmers are stored in $kiwi_cmdline inside
  of the boot code. The information was not used for the recovery
  grub config. Therefore a difference in kernel boot options for
  standard boot and for recovery boot could happen which should
  not be the case
* Thu Apr 30 2015 ms@suse.de
- Fixed boot_efilabel for elilo compat mode
  The efi boot label should match the title set in the bootloader
  menu. This is should be set to kiwi_oemtitle
* Wed Apr 29 2015 ms@suse.de
- v7.02.41 released
* Wed Apr 29 2015 ms@suse.de
- Run lvcreate with --noudevsync
  This allows to build LVM images in container systems
  which doesn't have udev running
* Wed Apr 29 2015 ms@suse.de
- Update SLE12 JeOS description
  The new pattern system requires libsolv >= 0.6.5 to be installed on
  the building host. Thus solve patterns as package to stay compatible
  with older build host systems
* Wed Apr 29 2015 ms@suse.de
- Added dice buildsystem config to x86 JeOS images
* Wed Apr 29 2015 rjschwei@suse.com
- The linuxefi and initrdefi commands only exists on x86 and x86_64.
  Write the grub config setting for linuxefi and initrdefi only on these
  platforms, for all others the appropriate command is linux and initrd.
* Fri Apr 24 2015 ms@suse.de
- Keep terminal reset utility inside boot images
* Fri Apr 24 2015 ms@suse.de
- Fixed useless use of greediness modifier '+' in regex
* Thu Apr 23 2015 rjschwei@suse.com
- Builder infrastructure
  + Integrate ext* file system image builds into the "builder"
    infrastructure to simplify and improve the structure of image builds
* Thu Apr 23 2015 ms@suse.de
- Style changes for mount dependency checker
  * Use here documents to construct messages
  * Use pstree to show sub tree of processes
  * Use perl builtin methods to read from proc
* Wed Apr 22 2015 ms@suse.de
- Fixed product name in SLE12 s390 JeOS
* Wed Apr 22 2015 ms@suse.de
- Better description for pattern use in 13.2 JeOS
* Wed Apr 22 2015 ms@suse.de
- Fetch errno($!) directly after call
  Reading of $! later will not provide the information
* Wed Apr 22 2015 ms@suse.de
- Added __checkMountDependencies runtime check
  The check looks for processes which holds onto mounts created by a
  previos kiwi run. In such a condition kiwi is not able to release
  its own mount table and shows information about the processes which
  keeps these mount points busy. We still don't understand why there
  could be non kiwi related processes holding onto mounts kiwi has
  created during its run but kiwi should provide a way to tell this
  information to the user and stop if the environment is still tainted
  by such processes (bnc #895204)
* Tue Apr 21 2015 ms@suse.de
- Added __checkDeprecatedFilesystem runtime check
  The use of clicfs is deprecated, a hint to use overlayfs if
  possible is shown as a warning message to the user
* Tue Apr 21 2015 ms@suse.de
- Delete kernel/adaptec-firmware from boot images
  For s390 there are no such packages in the SLE12 code base
* Tue Apr 21 2015 ms@suse.de
- v7.02.40 released
* Tue Apr 21 2015 adrian@suse.de
- remove call to addAppdata again
  merge error
* Mon Apr 20 2015 ms@suse.de
- v7.02.39 released
* Mon Apr 20 2015 adrian@suse.de
- prefer packages by priority of repositories, not by architectures.
* Mon Apr 20 2015 ms@suse.de
- Ensure recovery entry is appended for elilo compat
  elilo does not support adding custom entries to the written
  grub configuration. Thus we have to make sure the recovery
  entry doesn't get lost after a recovery run. Therefore the
  menu entry is added as part of the installBootloader function
  because this function is called after a recovery run while
  the installBootloaderRecovery functions are only called once
  at initialization time of the recovery partition
* Mon Apr 20 2015 ms@suse.de
- Fixed missing boot/efi mount path after recovery
  In recovery/repair mode the boot/efi path is not umounted
  correctly when init/systemd is started. Both paths /boot and
  /boot/efi are part of the fstab and if boot/efi is already
  mounted when fstab is processed the mount of /boot will
  cover and therefore hide the contents of boot/efi
* Fri Apr 17 2015 ms@suse.de
- v7.02.38 released
* Thu Apr 16 2015 ms@suse.de
- Revert "Added gptfdisk to SLE11 oemboot descriptions"
  This reverts commit 8a49b0d75f583cc4f18fdb57fb36722777e71725.
* Thu Apr 16 2015 ms@suse.de
- Revert "Update SLE11 JeOS description"
  This reverts commit 5cec0de206a4b2bcf15216ec8696cbedaa9a5c77.
* Wed Apr 15 2015 ms@suse.de
- Added elilo compat mode to recovery boot setup
  In normal grub2 mode the recovery entry is just written as a custom
  menu entry and processed by grub2-mkconfig. However if the elilo
  compat mode is in use on SLES11 with efi the recovery menu entry
  must be written to the elilo generated grub.cfg
* Wed Apr 15 2015 ms@suse.de
- Disable uuid support in createFilesystem for btrfs
  This will be changed once SLES11 SP4 is out to have a
  compatible version out until then
* Mon Apr 13 2015 ms@suse.de
- Recovery fixes and improvements
  * Added root.uuid / boot.uuid information to the recovery
    The UUID is used on restore to create the filesystem with
    the same UUID as before. This also allows to use the same
    efi binary as before and avoids the hack of copy over a
    standard efi binary
  * Allow createFilesystem to receive an optional UUID parameter
    In order to set the UUID for xfs the xfs_admin tool has been
    set to be a persistent part of the boot image(initrd)
  * Better messages for bootloader setup. Distinguish between
    boot loader setup for recovery and root system
  * Fixed description setup in elilo.conf for SLE11 efi compat
    mode. If kiwi_oemtitle is not set use kiwi_displayname
    to avoid an empty title in the boot menu
* Mon Apr 13 2015 ms@suse.de
- Added gptfdisk to SLE11 oemboot descriptions
* Mon Apr 13 2015 ms@suse.de
- Update SLE11 JeOS description
  Added SP4 repos, use repo source from download.suse.de
* Fri Apr 10 2015 ms@suse.de
- v7.02.37 released
* Fri Apr 10 2015 ms@suse.de
- DB: rebuild documentation
* Fri Apr 10 2015 ms@suse.de
- Update documentation
  Added information about recovery hooks
* Fri Apr 10 2015 ms@suse.de
- Added recovery hooks
  * preRecovery / postRecovery
    called before or after the recovery is processed
  * preRecoverySetup / postRecoverySetup
    called before or after the setup of the recovery files
    and tarballs is processed
* Fri Apr 10 2015 ms@suse.de
- v7.02.36 released
* Thu Apr  9 2015 ms@suse.de
- Fixed OEMFindPartitions
  * partition size of install target must be greater than
    the size of the image partition, equal the size is not
    enough
  * change error message to exactly point to the partinfo
    file which contains the information how the requested
    target partitions must look like
  * change the partinfo file to include the gpt partition
    code as gdisk knows it in case of a GPT
* Thu Apr  9 2015 ms@suse.de
- Fixed partedGetPartitionID
  In case of a GPT parted has no information about a partition id
  Therefore we mapped the id to the known msdos values according
  to the name kiwi defines for the partition. Any GPT specific
  partition got the same id 'ee' which results in not being able
  to distinguish them. However for the partition based install
  in EFI mode it's required to identify any potential target install
  partition by an id. Therefore partedGetPartitionID will return
  the sgdisk partition code and will only map to the old legacy
  values if sgdisk is not available
* Thu Apr  9 2015 ms@suse.de
- Update spec file
  make the gptfdisk package a requirement for distros which
  provides it
* Thu Apr  9 2015 ms@suse.de
- Fixed setup of GPT partition table
  kiwi uses parted to create partition tables. In case of GPT
  a linux default partition table has a guid set which points
  to a Microsoft base partition. This is wrong and I did not
  find a way to correct this with parted. Therefore the sgdisk
  utility will be used to correct the partition code so that
  we can at least see the right values when using sgdisk
* Wed Apr  8 2015 ms@suse.de
- Changed validation in OEM partition install mode
  In partition based install kiwi checks if the current partitions
  can be used for installation. Part of the validation was to check
  if a filesystem signature could be found. If yes the partition
  was not offered for installation. However this test is too strict
  because in order to remove the filesystem signature the filesystem
  must be actively destroyed. It's better to check for the filesystem
  UUID instead. In order to allow the installer to use the partition
  one can clear the uuid with the appropriate filesystem utility
  e.g
  e2fstune -U clear
  for extX based filesystems and that will not destroy the filesystem
  integrity. This means an active system can be prepared for install
  by clearing the uuid instead of self destructing it
* Wed Apr  8 2015 ms@suse.de
- v7.02.35 released
* Wed Apr  8 2015 ms@suse.de
- Delete rt kernel profile for SLE11
  kernel-rt is not always available to customers and the
  realtime kernel can be selected via the custom kernel
  profile if needed
* Wed Apr  8 2015 ms@suse.de
- Implement support for importing gce license
  If gcelicense is specified the information is included into
  the gce format tarball
* Wed Apr  8 2015 ms@suse.de
- Added gcelicense attribute in <type> section
  The gcelicense attribute receives a free form text information
  which is used to create a manifest file in the gce image format.
  The gce image format is Google's expected Compute Engine image
  format for uploading and registering an OS image in GCE
* Tue Mar 24 2015 ms@suse.de
- Setup kernel symlinks in sle11 elilo compat mode
* Tue Mar 24 2015 ms@suse.de
- Use filesystem UUID to identify the recovery
* Mon Mar 23 2015 ms@suse.de
- v7.02.34 released
* Mon Mar 23 2015 dimstar@opensuse.org
- Complete KIWI's appdata handlling removal
  Commit f4b7df2 removed the general handling, but missed a reference in
  KIWICollect.pm
* Thu Mar 19 2015 ms@suse.de
- v7.02.33 released
* Wed Mar 18 2015 dvaleev@suse.com
- Changes to instsource requirements
  In order to make syslinux requirement conditional we need to build
  kiwi-instsource arch specific package.
  This commit is needed because we can't Require kiwi-isoboot in Factory
  anymore since we started to build PowerPC in Rings
  Signed-off-by: Dinar Valeev <dvaleev@suse.com>
* Wed Mar 18 2015 ms@suse.de
- v7.02.32 released
* Wed Mar 18 2015 ms@suse.de
- Fixed service setup for lxc containers
  No chroot required to for relinking services
* Wed Mar 18 2015 ms@suse.de
- Fixed contents of lxc configuration
  Use autodev and disable kmsg. In addition rework the way
  systemd services gets disabled and update the list of
  systemd services not allowed to run in a container. This
  fixes (bnc #920692)
* Wed Mar 18 2015 ms@suse.de
- Follow up fix for variable import errors
* Tue Mar 17 2015 ms@suse.de
- Ignore variable import syntax errors
  In case of malformed shell syntax a message on eval of the
  expression is printed to the log. Having them twice is not
  needed
* Tue Mar 17 2015 ms@suse.de
- Deleted createOriginSnapshot
  In combination with btrfs this function created an origin snapshot
  prior to the first boot. This conflicts with the SUSE built in
  snapshot setup used by snapper.
* Tue Mar 17 2015 ms@suse.de
- Fixed use of volume variables in profile env
  Instead of evaluating the variable to get their content
  we directly parse the value. This allows to have key
  values including special characters normally not allowed
  in shell variable names like the dot('.'). volumes names
  like '.snapshot' will become possible
* Tue Mar 17 2015 dimstar@opensuse.org
- Remove KIWI's appdata handling
  The format is just too complex to be handled in this symlistic way.
  Appdata.xml (a subset of Appstream) evolved and changed for example
  from "applications" to "components"; now, some packages export one type,
  other packages export the other type. Merging them without normalising
  is resulting in a structure like:
  <applications>
  <application>
  [...]
  </application>
  <component>
  [...]
  </components>
  </applications>
  whereas 'components' is no valid child of applications per spec (neither
  is application a valid child of components).
  Hence: if KIWI ought to do that proper, the full format must be
  understood, analysed, normalised and merged.
  for openSUSE, KIWI now uses appstream-builder, which is created in close
  relationship with the AppStream metadata in mind.
  Having this code still in KIWI results in the builder producing valid
  appdata.xml.gz PLUS an uncompressed appdata.xml (~18MB) to be part of
  the repository metadata (thus slowing repo refresh down a lot).
* Tue Mar 17 2015 ms@suse.de
- Fixed restoreBtrfsSubVolumes
  if a subvolume for e.g /var/crash should be restored, kiwi
  failed because the /var path did not exist. As a workaround
  people could add /var as a volume but if only /var/crash
  should be a volume and not /var there was no way to do it.
  This commit fixed it in a way that kiwi checks if the path
  to the volume exists and if not it is created prior to the
  restore of the subvolume
* Mon Mar 16 2015 ms@suse.de
- v7.02.31 released
* Mon Mar 16 2015 ms@suse.de
- Added runtime check for docker and lxc definitions
  Those require a container name to be specified
* Mon Mar 16 2015 ms@suse.de
- Fixed Result packer for docker and lxc images
  The kiwi.buildinfo basename was wrong and did not include
  the extension name. In addition the result packer was not
  aware that lxc/docker images are tarballs
* Fri Mar 13 2015 ms@suse.de
- v7.02.30 released
* Thu Mar 12 2015 ms@suse.de
- Fixed accident change in 13.2 JeOS
* Thu Mar 12 2015 ms@suse.de
- Cleanup calling basename
  Make sure basename is not called with a missing operand
* Thu Mar 12 2015 ms@suse.de
- Mount EFI partition only if not already mounted
* Wed Mar 11 2015 ms@suse.de
- Update elilo compat mode
  Support copy of vendor specific EFI boot config
  In addition use the oem boot title as title for the
  elilo configuration too
* Tue Mar 10 2015 ms@suse.de
- Fixed boot deleting packages
  A package marked with the bootdelete="true" flag was not removed
  from the boot image if it was placed in the <delete> section of
  the system image.
* Fri Mar  6 2015 ms@suse.de
- v7.02.29 released
* Thu Mar  5 2015 ms@suse.de
- Move loader install tool check to the right place
  Only if a bootloader must be installed check if the tool
  to perform the call is present on the host
* Thu Mar  5 2015 schneemann@b1-systems.de
- dhclient has no option for timeout
  The dhclient in openSUSE 13.2 has no parameter for timeout, but it
  is specified in the setupNetworkDHCLIENT function. The timeout is
  taken from the configuration file as mentioned in the manpage.
* Wed Mar  4 2015 ms@suse.de
- Fixed __checkSelectedBootLoaderIncluded check
  The runtime check for grub2 has the choice for several packages
  Especially on SLE11 only grub2-x86_64-efi exists.
* Wed Mar  4 2015 ms@suse.de
- Increase the EFI/vboot fat partition
  Instead of 32MB use 200MB to allow holding a little more
  data like firmware and/or loaders
* Wed Mar  4 2015 rjschwei@suse.com
- Fix consistency check for LXC builds
  + Prior to the emergence of systemd the lxc package provided a special
    init script, lxc-init. This was necessary as SysV-init was not container
    aware. systemd is container aware, thus including systemd as the init
    system is sufficient.
* Tue Mar  3 2015 ms@suse.de
- v7.02.28 released
* Tue Mar  3 2015 ms@suse.de
- XZ compress vhdfixed disks in result bundler
* Wed Feb 25 2015 ms@suse.de
- Update description for suse-pxe-client
  The template is designed for a netboot only system. Therefore
  many parts are actively deleted, e.g the kernel which prevents
  this system from booting standalone. The description now points
  that out to indicate that for another use case the images.sh
  script might need some changes
* Wed Feb 25 2015 ms@suse.de
- Add in code comment for s390 zipl setup
  A static offset address to load the initrd from is used
  but no explanation why was given
* Mon Feb 23 2015 ms@suse.de
- v7.02.27 released
* Mon Feb 23 2015 ms@suse.de
- Fixed critic for KIWIMiniIsoPlugin.pm
* Mon Feb 23 2015 ms@suse.de
- Fixed critic for KIWIDescrPlugin.pm
* Mon Feb 23 2015 ms@suse.de
- Fixed potential link attack security issue
  kiwi statically creates a tmp executable in /dev/shm. Apart from
  the fact that it's the wrong place in the filesystem to do this
  kiwi should use a correctly created tmpfile. This Fixes #444
* Mon Feb 23 2015 ms@suse.de
- Fixed zero block analyser
  If all free blocks in a filesystem contain a zero the compression
  result of the later image is better compared to if there is any
  random junk in it. In order to have all free blocks set to a zero
  byte kiwi used the dd + rm method which had the disadvantage of
  destroying the sparseness of the image file. Because of that the
  method was applied only if the image was built from a real disk
  device which did not allow us to strip away a sparse image from
  anyways. However this is not very flexible because:
  1. In most cases an image is built from a loop device mapped
  against a sparse file. Thus the method is not called most
  of the time
  2. With filesystems using more complex internal structures like
  xfs btrfs, zfs and friends there is not much difference in
  the compression results, but the time to create a huge empty
  file which is removed later is signifcantly recognized
  Thus this change deletes the old way of zero out free blocks and
  uses a tool to do the job for us. For extX based filesystems the
  zerofree utility exists and is used if installed. For other
  filesystems I'm not aware of a tool and thus we don't handle
  them at the moment. If there is tool available kiwi print a
  warning message
* Mon Feb 23 2015 ms@suse.de
- DB: rebuild documentation
* Mon Feb 23 2015 ms@suse.de
- DB: added chapter how to create vagrant boxes
* Sun Feb 22 2015 matwey.kornilov@gmail.com
- Revert archives to consistent state
  Following three files were probably corrupted by f69d1d7bc3104f9e221abf8fc5efdf94ee0eb8b1
  template/armv7l/suse-12.3-JeOS/uboot-setup.tgz
  tools/livestick/theme/upstream/booting.tgz
  tools/livestick/theme/upstream/tooling.tgz
* Wed Feb 18 2015 ludwig.nussel@suse.de
- pass repo url for NET iso via linuxrc (bnc#916175)
* Fri Feb 13 2015 jmassaguerpla@suse.de
- check user_name is defined when checking file tree
  It is possible to have files that should be owned by root which
  are owned by a non-existing user, meaning the uid has no corresponding
  username. When this happens, the check used to give the error
  "Use of uninitialized value $user_name in concatenation (.) or string
  at /usr/share/kiwi/modules/KIWIRuntimeChecker.pm line 1558."
  Thus we need to check whether the user exists.
* Thu Feb 12 2015 jmassaguerpla@suse.de
- remove plymouth packages from s390x boot image
  We don't need graphical boot on s390x.
* Thu Feb 12 2015 ms@suse.de
- v7.02.26 released
* Wed Feb 11 2015 ms@suse.de
- Make sure cleanupRPMDatabase is called correctly
  The function also has to be called if there are packages
  to delete in the queue and not only if there are packages
  to install in the queue
* Wed Feb 11 2015 ms@suse.de
- Explicitly add kbd package to boot images
* Wed Feb 11 2015 ms@suse.de
- Make sure the default console font is setup
  While kiwi runs fbiterm the default console font is not
  properly restored when the session ends. In order to enter
  the system with a correctly initialized console font
  kiwi actively calls setfont with the default8x16 font.
  This is related to (bnc #879994)
* Wed Feb 11 2015 schwab@suse.de
- Remove obsolete 12.2 templates
* Tue Feb 10 2015 jmason@suse.com
- Move the vhdfixed tag to 64K offset.
  The tag specification calls for moving the tag from a 16K offset to a 64K
  offset to avoid conflicting with the GPT.
* Mon Feb  9 2015 ms@suse.de
- v7.02.25 released
* Mon Feb  2 2015 ms@suse.de
- DB: rebuild documentation
* Mon Feb  2 2015 ms@suse.de
- DB: man page clarify use of images.sh/config.sh
* Sat Jan 31 2015 dmueller@suse.com
- aarch64: Load full EFI emulation size
-boot-load-size 1 is not a recommended option. First of all
  a loader size that is not divideable by 4 is rejected by
  most EFI firmwares. In addition we need to load all of the
  EFI code into memory. When the option is not set, genisoimage
  uses the full length by default, which is what we want.
* Fri Jan 30 2015 ms@suse.de
- v7.02.24 released
* Fri Jan 30 2015 ms@suse.de
- Fixed callPartitioner
  Instead of making the decision for the correct partition tool
  by the name of the device use a method which knows better about
  the type of the storage device. This applies to s390 only were
  a dasd device could be a real dasd with 4k blocksize or an
  emulated dasd with 512byte blocksize. In the first case fdasd
  is used and in the other case parted must be used. The decision
  for the tool is now based on the result if isDASDDevice()
  which returns false for emulated dasd devices because we
  only distinguish a different handling if the blocksize of the
  device is _not_ 512byte
* Fri Jan 30 2015 ms@suse.de
- Fixed critic testing via perlcritic
  perlcritic on 13.2 reports a module to not end with a true value
  which is wrong and older versions of perlcritic do not complain
  about the same code. As I don't want to dig into what perlcritic
  does I decided to move the module in question to be not level 4
  clean
* Fri Jan 30 2015 ms@suse.de
- Fixed handling of zipl options
  For some reason it was not possible to provide the
  information as commandline arguments. Thus we wrote
  it into the menu section. In addition the verbose
  zipl installation information is now part of the
  kiwi build log file
* Fri Jan 30 2015 ms@suse.de
- Fixed import of emulated dasd device
  dasd_configure is required to be called but kiwi
  skipped that step for emulated dasd devices and
  thus they did not exist on boot
* Fri Jan 30 2015 ms@suse.de
- Added support for emulated DASD devices on s390
  an emulated dasd is a dasd device in FBA mode using
  512byte blocksize. kiwi did not properly install zipl
  to allow to boot from such devices
* Thu Jan 29 2015 guillaume.gardet@opensuse.org
- Fix ARM build
* Thu Jan 29 2015 adrian@suse.de
- collecting of -debuginfo packages from special suffixed packages
* Thu Jan 29 2015 ms@suse.de
- Fixed importHostPackageKeys
  Import on systems which doesn't have a
  /usr/lib/rpm/gnupg/keys structure failed
* Thu Jan 29 2015 ms@suse.de
- Fixed exception handling if device type is unknown
* Thu Jan 29 2015 ms@suse.de
- Added support for s390 emulated DASD devices
  An emulated DASD device is a disk with 512byte blocksize
  like it is the case for real zFCP (scsi) devices. Therefore
  kiwi handles an emulated DASD like a zFCP device but does
  not configure host and disk adapter for it
* Wed Jan 28 2015 ms@suse.de
- Fixed SLES12 s390 JeOS image template
  deleted obsolete packages, update pattern name
* Wed Jan 28 2015 ms@suse.de
- Fixed resetBootBind
  make sure the tmp directory is removed while moving the
  boot data one hierarchy level up
* Wed Jan 28 2015 ms@suse.de
- DB: rebuild documentation
* Wed Jan 28 2015 ms@suse.de
- DB: update man page
* Wed Jan 28 2015 ms@suse.de
- Cleanup service handling config functions
  Enable/Disable a service is no longer done using the suse
  specific insserv tool. Instead chkconfig for sysVInit or
  systemctl for systemd based systems is used. This this
  methods can be considered generic and should be base
  functions
* Wed Jan 28 2015 ms@suse.de
- DB: rebuild documentation
* Wed Jan 28 2015 ms@suse.de
- DB: Update documentation and man page
* Tue Jan 27 2015 ms@suse.de
- v7.02.23 released
* Tue Jan 27 2015 ms@suse.de
- Fixed creation of split images
  The filename for the splitfile which is the read-write portion
  of the image was build taking the displayname into account.
  Only if the displayname was not set the filename was correct
  because in that case the displayname and the diskname are the
  same. If a custom displayname is set the splitfile name was
  wrong and the read-write data was not included to the image
  In addition this patch uses the kiwi.buildinfo file to check
  for the image type instead of taking weird assumptions based
  on file names
* Mon Jan 26 2015 ms@suse.de
- Make sure to handle all udev daemon processes
  If the call to udevadm control for some reason did not
  stop all udev daemon processes kiwi checks the pids it
  found and kills them manually. However kiwi just looked
  up one process even though there might be more
* Mon Jan 26 2015 ms@suse.de
- Use udevadm control to exit udev daemon
  Killing the udevd is done in two steps. First we issue
  an udevadm call to exit udevd the documented way. According
  to the man page the call waits until udevd is stopped.
  After the call we check against the process ID of udevd
  we know about if they really have been stopped. If not we
  kill them
* Fri Jan 23 2015 ms@suse.de
- v7.02.22 released
* Fri Jan 23 2015 ms@suse.de
- Don't use /mnt as mount point in a kiwi process
  It could cause conflicts if the building system has /mnt
  mounted for some reasons. Especially if the image target
  directory is set to /mnt kiwi failed because it over
  mounted its own results
* Wed Jan 21 2015 ms@suse.de
- Update SLE12 JeOS template for ppc
  The description was missing firmware packages and did
  not use grub2 as the bootloader which is the default
  for sles12 on ppc
* Mon Jan 19 2015 magist3r@gmail.com
- Use symlink instead of copy for /etc/localtime.
* Mon Jan 19 2015 ms@suse.de
- Don't remove the docs from the RHEL JeOS templates
* Fri Jan 16 2015 ms@suse.de
- v7.02.21 released
* Fri Jan 16 2015 ms@suse.de
- v7.02.20 released
* Fri Jan 16 2015 dimstar@opensuse.org
- sha256sum generation: change cwd to tmpdir and only pass filename to $sha->addfile
  The full path passed to $sha->addfile is written into the .sha256 file, which results in
  the file not 'really' usable for verification by users. Passing only the relative filename
  works around this.
* Wed Jan 14 2015 ms@suse.de
- DB: rebuild documentation
* Wed Jan 14 2015 ms@suse.de
- DB: fixed LVM documentation
  with regards to btrfs subvolume support the docu
  was unclear and not complete
* Mon Jan 12 2015 dimstar@opensuse.org
- Switch to using appstream-builder instead of XML parsing
* Mon Jan 12 2015 ms@suse.de
- Revert "Disable yum repos from centos-releases"
  This seems to break the repo handling completely
  This reverts commit 4d48fd0b296343368d7bb76b97857d779ab13273.
* Mon Jan 12 2015 t1locs@gmail.com
- Disable yum repos from centos-releases
* Mon Jan 12 2015 ms@suse.de
- v7.02.19 released
* Mon Jan 12 2015 ms@suse.de
- Fixed kiwi-find-boot-requires.sh build helper
  Added Adrian as the author of the script and put some comment
  what this script does. Fixed error handling if boot config
  file is missing for the checked arch/os (bnc #911231)
* Mon Jan 12 2015 Pass-Automated-Testing-Suite@zx2c4.com
- mediacheck: give the user 5s time to actually see the result (also helps openQA to catch it) - Failure waits for user input already
* Mon Jan 12 2015 ms@suse.de
- Fixed spec file for rhel and centos builds
  With regards to https://en.opensuse.org/openSUSE:Build_Service_cross_distribution_howto
  the use of the dist macros has been fixed. In addition the setup of the correct templates
  per distribution has been fixed for rhel6/7 and centos6 (bnc #911231)
* Wed Jan  7 2015 adrian@suse.de
- fix debug package unique key handling.
* Fri Dec 19 2014 ms@suse.de
- v7.02.18 released
* Fri Dec 19 2014 ms@suse.de
- Fixed post install script from kiwi-templates
  it should not end with a non zero exit code
* Thu Dec 18 2014 ms@suse.de
- v7.02.17 released
* Thu Dec 18 2014 ms@suse.de
- Fixed bootloader setup for SLE11 JeOS template
  legacy grub is default unless uefi firmware is selected
* Thu Dec 18 2014 ms@suse.de
- v7.02.16 released
* Tue Dec 16 2014 ms@suse.de
- Fixed spec file for CentOS package
  On CentOS squashfs is packaged in squashfs-tools
* Tue Dec 16 2014 ms@suse.de
- Fixed kiwi-templates %%post scriptlet
  Check if old image description exists before deleting it.
  This prevents warning messages spit out by rpm on install
* Mon Dec 15 2014 ledest@gmail.com
- Fix bashisms in image.sh shell scripts
  Replace '&>/dev/null' output redirections to '>/dev/null 2>&1'.
* Mon Dec 15 2014 dimstar@opensuse.org
- Fall back to lazyly umount /dev nodes in case of failure
* Mon Dec 15 2014 ms@suse.de
- v7.02.15 released
* Mon Dec 15 2014 ms@suse.de
- Fixed use of uninitialized value $format
* Mon Dec 15 2014 ms@suse.de
- Fixup logging with a logfile
  If a logfile is used the state of the call if it was successful
  or not is also part of the logfile and not exposed to the calling
  terminal. With this patch the overall success or error information
  is also printed on the calling terminal.
* Mon Dec 15 2014 ms@suse.de
- Print a message if the target directory is created
* Mon Dec 15 2014 ms@suse.de
- Code cleanup
  use createDirInteractive and replace redundant parts
* Fri Dec 12 2014 ms@suse.de
- v7.02.14 released
* Fri Dec 12 2014 ms@suse.de
- DB: rebuild documentation
* Fri Dec 12 2014 ms@suse.de
- v7.02.13 released
* Thu Dec 11 2014 ms@suse.de
- Added support for custom qemu-img format options
  When kiwi calls qemu-img to convert the image into the format
  the user has specified in the XML description it might be
  required to pass on additional format options like the compat
  mode for the qcow2 format. This can now be done like the
  following example shows:
  <type ... formatoptions="compat=0.10"/>
* Thu Dec 11 2014 ms@suse.de
- Eliminate weird kiwi revision from unit tests
  The unit test environment sets a static kiwi revision
  number 4711 which is odd because it can easily use the
  correct git revision from the git metadata
* Thu Dec 11 2014 ms@suse.de
- Fixed print() on closed filehandle
* Tue Dec  9 2014 ms@suse.de
- v7.02.12 released
* Mon Dec  8 2014 ms@suse.de
- Eliminate grub2-efi path
  At the beginning of grub2 the home in boot was set to grub2-efi
  as well as some tools take this information in their name. It's
  time to cleanup this. In addition kiwi now creates a grub.cfg
  which is able to check for grub_platform in order to distinguish
  between efi and non efi configuration differences if there are
  any
* Mon Dec  8 2014 ms@suse.de
- Added EFI support for none aarch64 arm systems
  There are armv7 based boards which comes with an EFI
  firmware. In order to boot them we have to make sure
  to use grub2 bootarm.efi and call the right grub2
  bootloader configuration methods (bnc #908469)
* Sun Dec  7 2014 ms@suse.de
- Follow up fix for overlayfs changes in kernel 3.18
  overlayfs complains: upperdir and workdir must be in separate
  subtrees. Thus we create workdir and upperdir in different
  subdirs below read-write
* Fri Dec  5 2014 ms@suse.de
- Follow up fix for overlayfs changes in kernel 3.18
  overlayfs complains: workdir and upperdir must reside under
  the same mount. Thus we create work-stage below read-write
* Fri Dec  5 2014 ms@suse.de
- Fixed setupBootLoaderGrub2 GRUB_TERMINAL setup
  in case of uefi we configured a text console terminal but
  graphics terminal works well with the shim efi module now
* Fri Dec  5 2014 ms@suse.de
- Apply former overlayfs adaption to kiwi caching
  kiwi image caches are also based on overlayfs. Thus the
  changes in the mount call has to be adapted there too
* Fri Dec  5 2014 ms@suse.de
- Adapt changes in overlayfs in kernel 3.18
  Starting with overlayfs v22 the workdir mount option is required.
  In addition the module has been renamed from overlayfs to overlay
  which also impacts the mount options. In order to stay compatible
  kiwi implements a two way mount call, first with the legacy mount
  options and second with the current mount options
* Thu Dec  4 2014 ms@suse.de
- v7.02.11 released
* Thu Dec  4 2014 ms@suse.de
- Fixed setupBTRFSSubVolumes
  if a subvolume for e.g /var/spool should be created kiwi
  failed because the /var path did not exist. As a workaround
  people could add /var as a volume but if only /var/spool
  should be a volume and not /var there was no way to do it.
  This commit fixed it in a way that kiwi checks if the path
  to the volume exists and if not it is created prior to the
  creation of the subvolume
* Thu Dec  4 2014 adrian@suse.de
- fix handling of source rpms when binaries require src and nosrc version
  The is the case when using glibc i686 or -32bit packages
* Wed Dec  3 2014 ms@suse.de
- v7.02.10 released
* Wed Dec  3 2014 ms@suse.de
- Fixed recovery of EFI bootdata
  + restore EFI module provided by the rpm package. The one kiwi
    created is specific to the uuid of the root filesystem which
    changes on factory restore.
  + make sure correct linux/linuxefi and initrd/initrdefi commands
    are used in recovery grub config by checking against grub_platform
    to allow recovery in BIOS and EFI mode
  + make sure mkfs.fat exists in the initrd to allow recovery of
    EFI fat partition, actually implement recovery of EFI fat
    partition
* Tue Dec  2 2014 ms@suse.de
- Added restore of btrfs subvolumes in restore mode (bnc #908011)
  In oem recovery (restore) mode a new function named
  restoreBtrfsSubVolumes will be called if the root filesystem
  is btrfs based. The function will restore the configured
  subvolumes back to the factory state
* Tue Dec  2 2014 ms@suse.de
- Force creation of recovery filesystem
  When kiwi setup the recovery partition with a filesystem it
  might find a bootloader installation in the recovery partition
  from an earlier attempt. This leads to a question on mke2fs and
  an abort of the oem installation as consequence.
* Mon Dec  1 2014 ms@suse.de
- Be more exact which sector size value one can set
  It's the logical sector size one can specify for the target
* Mon Dec  1 2014 ms@suse.de
- Deleted unused global information
  back in the time kiwi used device mapper snapshot to
  implemenet filesystem overlay techniques information
  about the snapshot size was needed. today kiwi uses
  overlayfs and thus this information is no longer
  used
* Fri Nov 28 2014 ms@suse.de
- v7.02.9 released
* Thu Nov 27 2014 ms@suse.de
- Call updateProtectiveMBR in GPT recovery mode
  for some reasons parted leaves an active partition in the
  protective MBR which can cause some EFIs to ignore the disk
* Thu Nov 27 2014 ms@suse.de
- Fixed backup of disk layout in recovery mode
  kiwi recovery creates a backup of the disk layout which includes
  bootloader code and partitions. For GPT there was no code to
  correctly store the table
* Thu Nov 27 2014 ms@suse.de
- Cleanup use of efi path
* Thu Nov 27 2014 ms@suse.de
- Fixed use of linuxefi/initrdefi commands for recovery grub2 setup
* Wed Nov 26 2014 ms@suse.de
- Make sure the preferlvm attribute is inherited
  If this information is not present the useLVM
  method in KIWIGlobals will not be able to provide
  the correct result whether LVM is used or not
* Wed Nov 26 2014 ms@suse.de
- Fixed use of uninitialized value
* Tue Nov 25 2014 ms@suse.de
- v7.02.8 released
* Tue Nov 25 2014 ms@suse.de
- Update all descriptions to schema 6.2
* Tue Nov 25 2014 ms@suse.de
- Update schema version from 6.1 to 6.2
* Tue Nov 25 2014 ms@suse.de
- Set default bootloader to grub2
  A new schema version 6.2 has been introduced in order to
  check for the bootloader attribute. If not set the bootloader
  is set to grub2. suboptimal bootloader settings based on
  arch and/or firmware in the code has been removed. The
  consistency of the bootloader setup will be handled by
  runtime checks exclusively
* Tue Nov 25 2014 ms@suse.de
- Update openSUSE 13.2 and SLES12 JeOS image descriptions
  Added which and dhcp-client packages explicitly to avoid
  conflicts for tools which uses which and not type. In
  addition the network stack requires dhcp-client config
  files under certain circumstances
* Mon Nov 24 2014 ms@suse.de
- v7.02.7 released
* Mon Nov 24 2014 ms@suse.de
- Check if hybrid disk device really exists
  Don't try to create a partition on a device which does
  not exist. This prevents a long loop of probing for a
  partition device which never can appear
* Sat Nov 22 2014 matwey@sai.msu.ru
- Activate new swap after repartitioning
- Activate new swap after repartitioning
- Activate new swap after repartitioning
* Fri Nov 21 2014 ms@suse.de
- v7.02.6 released
* Fri Nov 21 2014 ms@suse.de
- Fixed Makefile clean target
  make sure all autogenerated data is wiped on clean
  make sure clean target is called on build of package
* Fri Nov 21 2014 ms@suse.de
- v7.02.5 released
* Fri Nov 21 2014 ms@suse.de
- Allow to run kiwi --describe from git checkout
* Fri Nov 21 2014 ms@suse.de
- Fixed typo in 13.2 os release matcher
* Fri Nov 21 2014 ms@suse.de
- Support kiwi --describe for openSUSE 13.2
  analysing and cloning of 13.2 systems added
* Thu Nov 20 2014 ms@suse.de
- Added fribidi and fbiterm to kiwi-media-requires package
  Unfortunately these two packages are not on the openSUSE 13.2
  DVD. But kiwi uses fbiterm in the boot images. Thus users
  have to add the online repo in order to build. For 13.2 it's
  too late but with this change I hope the two packages will
  be placed on the DVD again
* Tue Nov 18 2014 ms@suse.de
- Cleanup use of installBootLoader
  Instead of building device nodes out of the partition id's hash
  use the already existing device map information. That eliminates
  some unneeded logic as well as two helper methods used to find
  the right place for the device when only the partition id is
  known
* Mon Nov 17 2014 ms@suse.de
- Fixed suseStripKernel for updates/ modules
  If the dependency checker finds a dependency to a module in the updates
  or weak-updates directory the move of the module will fail because kiwi
  always uses updates/weak-updates modules and has moved them already.
  The dependency code however creates a new updates/weak-updates directory
  for the affected module and that causes a conflict when the original
  updates/weak-updates are moved back to the final place. In the end the
  result is that no updates/weak-updates module are present in the initrd
* Mon Nov 17 2014 ms@suse.de
- Better error message in pxeSetupDownloadServer
  Be more descriptive if the PXE download server can't be
  found. In addition cleanup suse/rhel-dump to call
  pxeSetupDownloadServer instead of duplicating the code
* Mon Nov 17 2014 schwab@suse.de
- Don't remove kernel and initrd in KIWIMiniIsoPlugin
* Mon Nov 17 2014 ms@suse.de
- Make sure drivers/virtio is part of netboot initrd
  This allows to use the virtio network from qemu if
  started with the virtio-net-pci driver
* Mon Nov 17 2014 ms@suse.de
- Added 12.2 to the cleanup list in the spec file
* Mon Nov 17 2014 ms@suse.de
- fix bashism in post script
  Use a simple string list in the spec file to walk through
  the list of distribution names in order to cleanup old ones
  Original patch by: Led <ledest@gmail.com>
* Thu Nov 13 2014 ms@suse.de
- v7.02.4 released
* Thu Nov 13 2014 ms@suse.de
- Fixed and cleanup unit test processing
  When running the unit tests the class KIWILog is overwritten
  in a way that a global kiwi logger is created from Common::ktLog
  but there is no declaration which really overwrites the KIWILog
  package to be a Common::ktLog. This patch fixes this and makes
  unit testing work in travis again. In addition methods from
  Common::ktLog no longer present in KIWILog were removed too
* Wed Nov 12 2014 ms@suse.de
- Fixed result bundler for vhd-fixed format
  There is a small inconsistency between the schema format setup
  and the extension used in the result file. The schema wants
  format="vhd-fixed" and the file is written as file.vhdfixed
* Wed Nov 12 2014 ms@suse.de
- v7.02.3 released
* Wed Nov 12 2014 ms@suse.de
- Compress install PXE tarball using XZ
  Instead of tar's -z we use now -J for xz compression and
  also changed the output name to *.install.tar.xz in order
  to allow the buildservice to match this file as a result
* Wed Nov 12 2014 ms@suse.de
- v7.02.2 released
* Wed Nov 12 2014 ms@suse.de
- DB: rebuild documentation, build for factory version
* Wed Nov 12 2014 ms@suse.de
- v7.02.1 released
* Tue Nov 11 2014 ms@suse.de
- Fixed broken travis script
* Tue Nov 11 2014 ms@suse.de
- Run travis using perl 5.18
* Tue Nov 11 2014 ms@suse.de
- Run Travis checks only for master
* Tue Nov 11 2014 ms@suse.de
- Revert "Update .travis.yml, run clean target before test"
  This reverts commit 67b5d1880ef36b4ded9879ca4ba07dea7f3293f6.
* Tue Nov 11 2014 ms@suse.de
- Update .travis.yml, run clean target before test
* Tue Nov 11 2014 ms@suse.de
- Update 13.2 JeOS description
  added less and iproute2 packages by default
* Tue Nov 11 2014 ms@suse.de
- Update 13.2 JeOS template
  added default network setup on lan0
* Tue Nov 11 2014 ms@suse.de
- Fixed use of rpm tools
  rpm has removed the db related options --initdb and --rebuilddb
  from the master rpm command. They are only available in the rpmdb
  command. Thus kiwi should better search for the rpm tool chain
  and decide for the commands to use according to their existence
* Tue Nov 11 2014 ms@suse.de
- Update source path in 13.2 JeOS image description
* Wed Nov  5 2014 ms@suse.de
- Update jenkins prepare.sh test
  the jenkins worker needs dosfstools installed to work with
  efi build tests
* Wed Nov  5 2014 ms@suse.de
- Revert "Fixed check for revision file"
  This reverts commit d288c9f7b2a52f42b86023f76e0b055bcd748925.
  It was not the check itself which was broken it was the fact
  that running make test and make valid in parallel conflicts
  with each other
* Wed Nov  5 2014 ms@suse.de
- Fixed make test Makefile target
  Don't remove the .revision file as part of make test because
  this conflicts with running make valid in parallel as done
  on jenkins. Only the make clean target should remove it
* Wed Nov  5 2014 ms@suse.de
- Fixed logging of first message
  The file handle for the first message log was not available at the time
* Wed Nov  5 2014 ms@suse.de
- Fixed use of repository alias names containing spaces
  All spaces are replaced by an underscore
* Mon Nov  3 2014 ms@suse.de
- Fixed check for revision file
  make sure to create one if it does not exist and kiwi
  is called locally from a git checkout
* Mon Nov  3 2014 ms@suse.de
- Fixed typo in suse-SLE12-JeOS, wrong indention
* Mon Nov  3 2014 ms@suse.de
- Delete obsolete openSUSE 12.2 based extra image templates
* Mon Nov  3 2014 ms@suse.de
- Fixed instsource plugin code to be perl critic clean
* Mon Nov  3 2014 ms@suse.de
- Fixed pre-commit git hook script
  correctly parse all existing instsource plugins and set
  the include path to the plugin dirs when running perlcritic
* Mon Nov  3 2014 ms@suse.de
- Don't write to an undefined file handle
* Mon Nov  3 2014 ms@suse.de
- Delete obsolete instsource-plugins
* Sat Nov  1 2014 ms@suse.de
- openSUSE 13.2 is gold :-)
  delete obsolete openSUSE 12.2 JeOS template and boot descriptions
* Thu Oct 30 2014 chingpang@gmail.com
- Correct the loader type of grub2
  For the UEFI machines, the loader type has to be "grub2-efi" to
  make grub2-install search the efi modules.
* Thu Oct 30 2014 ms@suse.de
- Activate efi support in suse-13.2-JeOS template
* Thu Oct 30 2014 ms@suse.de
- Fixed git tag helper
  report only first tag matching current version
* Mon Oct 27 2014 ms@suse.de
- Don't remove libdrm from boot images
* Mon Oct 27 2014 schwab@suse.de
- Set proper boot catalog in aarch64_efi
* Fri Oct 24 2014 ms@suse.de
- Don't call makeIsoEFIBootable for product iso's
  The required data is provided by the installation-images-<distro>
  package and doesn't need to be created. In addition the method
  checks for the underlaying architecture which does not work when
  creating product iso's because there the underlaying architecture
  does not necessarily have to match the distro architecture
* Wed Oct 22 2014 ms@suse.de
- v7.01.16 released
* Wed Oct 22 2014 ms@suse.de
- Fixed setupDefaultFstab (bnc #900280)
  Instead of overwriting a potentially existing fstab file
  the function now adds missing entries and also checks if
  the source mount device really exists.
* Wed Oct 22 2014 ms@suse.de
- Use btrfs as write partition for hybrid images (bnc #900922)
  For hybrid live iso images there is the optional support to
  create a write partition for data persistency. The initial
  creation of the filesystem can take a long time on e.g USB
  sticks. The creation of a btrfs filesystem without static
  inode tables is much faster. Thus the switch to btrfs
* Tue Oct 21 2014 ms@suse.de
- v7.01.15 released
* Tue Oct 21 2014 ms@suse.de
- Print /var/log/boot.kiwi file on reboot exception
  If a reboot exception is thrown in the boot code kiwi will
  print the current log file contents to the console before
  reboot. This allows systems like public clouds to provide
  a verbose information about the boot process
* Mon Oct 20 2014 ms@suse.de
- v7.01.14 released
* Mon Oct 20 2014 ms@suse.de
- Throw exception if specified root device does not appear
* Mon Oct 20 2014 ms@suse.de
- v7.01.13 released
* Mon Oct 20 2014 ms@suse.de
- Fixed grub2 setup for use with EC2
* Mon Oct 20 2014 ms@suse.de
- v7.01.12 released
* Mon Oct 20 2014 ms@suse.de
- Don't skip grub2 prefix setup for ec2|ec2hvm
* Mon Oct 20 2014 ms@suse.de
- v7.01.11 released
* Mon Oct 20 2014 ms@suse.de
- Fixed grub2 xen module list
  Some modules available in grub2 are not available for grub2
  in xen, e.g chain
* Mon Oct 20 2014 ms@suse.de
- v7.01.10 released
* Mon Oct 20 2014 ms@suse.de
- Make sure to wait for the storage device if set in root=
* Mon Oct 20 2014 ms@suse.de
- Fixed typo: boottimout -> boottimeout
* Mon Oct 20 2014 ms@suse.de
- Make sure correct grub2 module path is used for ec2hvm firmware
  Currently the grub2 module path is set correctly with firmware
  set to 'ec2' but not if set to 'ec2hvm'
* Mon Oct 20 2014 coolo@suse.de
- readd lost promo dvd plugin
* Fri Oct 17 2014 ms@suse.de
- Fixed setup of zypper repository name if no alias is specified
  If no alias name is given in the kiwi <repository> section, kiwi
  builds a name from the given source URI. If the source URI does
  contain credentials information appended as token after the RFC
  specified '?' sign the repo name contains this information too
  which results in an invalid repository name for zypper. In order
  to prevent this kiwi cuts off the information '\?.*' from the
  URI and build the name from the remaining part
* Thu Oct 16 2014 ms@suse.de
- Redirect stderr from cp command so that we can catch it
* Wed Oct 15 2014 ms@suse.de
- v7.01.9 released
* Wed Oct 15 2014 ms@suse.de
- Fixed error logging to default log file
* Wed Oct 15 2014 ms@suse.de
- Cleanup with regards to coding style guide
* Mon Oct 13 2014 ms@suse.de
- v7.01.8 released
* Fri Oct 10 2014 fcastelli@suse.com
- Compress Docker images using XZ
  This results in images requiring less disk space.
* Fri Oct 10 2014 ms@suse.de
- Use -o loop for mounting read-write image
  Older systems (e.g RHEL 6) mount command is not able to detect
  a loop mount and requires the -o loop option in order to work
* Fri Oct 10 2014 adrian@suse.de
- fix dependencies of s390 requires
  * zipl was never an own package, it is part of s390-tools
  * syslinux does not exist on SLES 12 s390
* Fri Oct 10 2014 adrian@suse.de
- Also support new appdata format
* Wed Oct  8 2014 ms@suse.de
- Again Fixed use of zypper package cache
  Not only the addrepo command but also other ones seems to remove
  the pkg-cache-dir if there is no associated repo available. Thus
  the preserve and restore of the package cache happens now before
  and after all zypper repo setup related commands are called
* Tue Oct  7 2014 ms@suse.de
- v7.01.7 released
* Tue Oct  7 2014 ms@suse.de
- Update dhclientImportInfo
  Allow the function to export DHCPSIADDR from the
  dhcp-server-identifier information stored in the
  lease file created by the dhclient call
* Tue Oct  7 2014 ms@suse.de
- Make sure u-boot bootargs will be escaped (bnc #900007)
* Mon Oct  6 2014 ms@suse.de
- Make kiwi --info thread safe
* Mon Oct  6 2014 ms@suse.de
- v7.01.6 released
* Mon Oct  6 2014 ms@suse.de
- Added bundle task for GCE images
* Thu Oct  2 2014 ms@suse.de
- Fixup createGoogleComputeEngine
  no paths allowed inside the tarball, only the disk.raw
  they are really strict on their checks :-)
* Thu Oct  2 2014 ms@suse.de
- Fixup createGoogleComputeEngine
  There are some conventions around the naming and content of
  a GCE tarball. This patch hopefully addresses all of them
* Thu Oct  2 2014 ms@suse.de
- Added sudo to package list for SLE12 JeOS template
* Thu Oct  2 2014 ms@suse.de
- Update SLE12 JeOS template to provide a kiwi user
* Thu Oct  2 2014 ms@suse.de
- Added support for format="gce"
  This is for creating Google Compute Engine ready images to be
  uploaded into a bucket in the google cloud storage via gsutil
* Thu Oct  2 2014 ms@suse.de
- v7.01.5 released
* Wed Oct  1 2014 ms@suse.de
- Fixed use of zypper package cache
  For unknown reasons zypper removes the pkg-cache-dir when
  calling the addrepo command. Because this is unwanted kiwi
  temporarly moves the current cache dir and moves it back
  after the addrepo call is done
* Wed Oct  1 2014 ms@suse.de
- DB: rebuild documentation
* Wed Oct  1 2014 ms@suse.de
- DB: update documentation
  first review by the documentation department
* Tue Sep 30 2014 ms@suse.de
- v7.01.4 released
* Tue Sep 30 2014 ms@suse.de
- Added support for custom boxname for vagrant images (bnc #896205)
  By default the name set to the vagrant .json file is the name
  of the image as specified in the kiwi XML description. However,
  in the world of https://vagrantcloud.com/, the convention for
  "fully-qualified" box names is "ORGANIZATION/BOXNAME" which does
  not apply to a standard kiwi image name. With the new boxname
  attribute people can now specify the name of the box to be
  vagrantcloud conform. e.g
  <vagrantconfig ... boxname="opensuse/minimal-13.1"/>
* Tue Sep 30 2014 ms@suse.de
- v7.01.3 released
* Tue Sep 30 2014 ms@suse.de
- Add error message to log file if downloadFile failed
* Tue Sep 30 2014 ms@suse.de
- Fixed uninstall make target
  Delete /dev/shm/lwp-download created by kiwi
* Tue Sep 30 2014 ms@suse.de
- v7.01.2 released
* Tue Sep 30 2014 ms@suse.de
- DB: rebuild documentation for version 7
* Tue Sep 30 2014 ms@suse.de
- Branch created for SLE12, master open for development at version 7
* Mon Sep 29 2014 ms@suse.de
- Fixed use of uninitialized value $time
* Mon Sep 29 2014 schwab@suse.de
- Add support for EFI on aarch64
* Fri Sep 26 2014 ms@suse.de
- v5.06.165 released
* Fri Sep 26 2014 ms@suse.de
- Make sure to wait for nic link up (bnc #898505)
* Thu Sep 25 2014 ms@suse.de
- Fixed double encoded luks system (bnc #898249)
  when kiwi builds a disk image it can either dump a filesystem
  image onto a raw partition or it rsync a tree of files onto
  a partition which has a filesystem created on top of a subsystem
  or a subsystem stack like lvm, luks, etc. In kiwi this is
  controlled by the value of the $treeAccess variable. If
  treeAccess is disabled but the support for syncing a tree in
  the given configuration is implemented this results in
  duplicate preparation of the filesystem and the subsystems
  which results in an unbootable mess.
* Thu Sep 25 2014 ms@suse.de
- Fixed passthrough of luks cipher (bnc #898249)
  kiwi passed the ciper using a shell echo command which is
  bad because the shell evaluates the contents of this information
  and might break the cipher if it contains shell meta characters.
  This patch fixes this by using a simple pipe stream to the
  cryptsetup process without invoking a shell command
* Thu Sep 25 2014 ms@suse.de
- Fixed URI credentials setup
  Make sure the ?credentials=kiwiRepoCredentials flag is only added
  to the url if the appropriate credentials file exists
* Tue Sep 23 2014 ms@suse.de
- v5.06.164 released
* Tue Sep 23 2014 ms@suse.de
- Added missing filesystem provides for the xfs filesystem (bnc #897935)
  With the kiwi-filesystem:xfs Provides the buildservice is able
  to setup a build environment including the needed tools called
  by kiwi when building inside this environment
* Sun Sep 21 2014 ms@suse.de
- v5.06.163 released
* Sun Sep 21 2014 ms@suse.de
- Follow up fix for max storage device wait period (bnc #897516)
  Hannes Reinecke suggested to increase it to 60 seconds; 30 seconds
  is the typical I/O timeout value, so I'd be giving it double the
  time to allow error handling to complete.
* Fri Sep 19 2014 ms@suse.de
- v5.06.162 released
* Fri Sep 19 2014 ms@suse.de
- Increase max per storage device wait period to 30 sec (bnc #897516)
* Fri Sep 19 2014 ms@suse.de
- Prevent activation of a partition on non x86 systems (bnc #897507)
  The active flag is used by legacy BIOS systems on x86 systems.
  On other architectures it could cause trouble because that
  information is not expected
* Fri Sep 19 2014 ms@suse.de
- Eliminate use of haveBootPartition variable in the initrd code
  kiwi provides exact information in the partition ID's variables
  created when the image is build in setupPartIDs. The indicator if
  a boot partition is in use was not set correctly by the existing
  function. The indicator for a boot partition should be the
  filesystem label set to 'BOOT' and the check if this partition is
  not equal to the root partition. In the repartition code the
  partition ID for the root partition is always defined correctly
  by the kiwi_RootPart variable and should not depend on any
  condition. That way there was no code left which requires and
  extra boolean haveBootPartition variable and also fixes the wrong
  pID assignment described in bug (bnc #897497)
* Fri Sep 19 2014 coolo@suse.de
- remove media check from mini iso (bnc#895021)
* Thu Sep 18 2014 coolo@suse.de
- make the mini isos reasonable size again
  instead of just removing the root file, remove all files actually downloaded
  from NET repo
* Wed Sep 17 2014 ms@suse.de
- v5.06.161 released
* Wed Sep 17 2014 ms@suse.de
- Add a post install script for kiwi
  The file /dev/shm/lwp-download will be removed in order to
  allow kiwi to create this file with the permissions it needs.
  The support to allow kiwi to run kiwi --info as non root user
  requires this cleanup step because lwp-download is created
  with permissions which allows root and normal users to call
  the script. former versions leaves a version of the script
  which doesn't allow non root users to call or change it which
  results in a raise condition for a non privileged --info
  call
* Wed Sep 17 2014 ms@suse.de
- Really fixed package update from sle11 to sle12 (bnc #893340)
  the man pages were moved from kiwi-doc to the main kiwi package
  between sle11 and sle12. Thus the main kiwi package has to set
  a conflicts for the kiwi-doc package in versions < 5
* Wed Sep 17 2014 adrian@suse.de
- KIWICollect: handle POOL flavors as "ftp" flavors (bnc#896930)
* Wed Sep 17 2014 ms@suse.de
- Fixed spec file by adding missing requirements; tar and psmisc
* Tue Sep 16 2014 ms@suse.de
- Allow kiwi --info to be called without root permission
  There is one exception though. If the repo is an iso file
  which needs to be loop mounted we still need root privileges
  to call the mount system call. In such a case kiwi will
  exit with a useful error message
* Tue Sep 16 2014 ms@suse.de
- v5.06.160 released
* Tue Sep 16 2014 ms@suse.de
- Improve spee of nic setup in netboot initrd (bnc #893788)
  With this commit the list of preferred interfaces which are
  either the BOOTIF interface or the list of all detected ones
  is used to run the dhcp discovery. The first successfully
  discovered interface is used to setup the default gateway
  and route as there can only be one
* Tue Sep 16 2014 schwab@suse.de
- linuxefi only exists in grub2 on x86
* Mon Sep 15 2014 ms@suse.de
- Fixed package build due to failed unit tests
  The unit tests failed when building on non x86 architectures
  because the test reference files for these architectures
  contained an unexpected newline at the end of the file. In
  addition subsequent tests should not fail which was the case
  because existing test tmpdirs were not correctly cleaned up
* Fri Sep 12 2014 ms@suse.de
- Use legacy bios_grub partition only on ix86 and x86_64 (bnc #896445)
* Fri Sep 12 2014 ms@suse.de
- v5.06.159 released
* Fri Sep 12 2014 ms@suse.de
- Fully document virtualsize attribute of <vagrantconfig> in schema
* Fri Sep 12 2014 ms@suse.de
- Move useLVM helper function into global space and explain
  conditions for using LVM or not in one central place
* Fri Sep 12 2014 ms@suse.de
- Added runtime check for the bootpartition requirements
  If the use of a bootpartition is explicitly disabled
  and one of the filesystems btrfs, zfs or xfs are used
  this is only supported with the grub2 bootloader.
* Fri Sep 12 2014 ms@suse.de
- Implement preferlvm="true|false" attribute for <systemdisk>
  When using filesystems which provides a volume management like
  btrfs and zfs do, kiwi will make use of it by default. With the
  preferlvm attribute the user can overwrite the default and prefer
  LVM for volume management
* Thu Sep 11 2014 opensuse@adamspiers.org
- make the two vagrant box templates more consistent
  This makes it easier to see the differences which really matter.
* Thu Sep 11 2014 opensuse@adamspiers.org
- remove pointless $xmlsize assignment
  This assignment is pointless since $xmlsize will always get set to
  another value soon after.
* Thu Sep 11 2014 adrian@suse.de
- do not publish appdata for source rpms
* Thu Sep 11 2014 ms@suse.de
- Make suseImportBuildKey more robust (bnc #896126)
  Check if dumpsigs tool exist and don't operate on
  files which do not exist
* Wed Sep 10 2014 ms@suse.de
- Prevent building iso with empty loader directory
* Wed Sep 10 2014 ms@suse.de
- Added test_virtualboxGuestOS unit test
* Wed Sep 10 2014 ms@suse.de
- Update unit tests due to ovf osType adaptions
* Wed Sep 10 2014 ms@suse.de
- Fixed OVF creation for writing osType
  osType is a subsection of the OperatingSystemSection not an attribute
  osType was supported for VMware vmw: flagged systems. This patch adds
  osType support for virtualbox vbox: flagged systems too
* Tue Sep  9 2014 ms@suse.de
- v5.06.158 released
* Tue Sep  9 2014 ms@suse.de
- Fixed spec file requirement for perl-Config-IniFiles (bnc #895623)
  Older versions of this module doesn't have the 'exists' method
  which is used by kiwi
* Tue Sep  9 2014 ms@suse.de
- Remove obsolete/unused code from KIWILog::setFlag
* Mon Sep  8 2014 ms@suse.de
- Follow up fix for message logging
  prevent obsolete in cache newline
* Mon Sep  8 2014 ms@suse.de
- Added missing lvmetad tool
  The tools is required to scan the LVM metadata if it does live
  on e.g md devices. It seems the default internal scanning did
  not work correctly on pvresize, vgchange, etc...
* Mon Sep  8 2014 aosthof@suse.de
- Fixed indentation
* Mon Sep  8 2014 aosthof@suse.de
- Corrected typo (s/sda1/hda1)
* Mon Sep  8 2014 ms@suse.de
- Fixed building of vagrant boxes (bnc #895353)
  If multiple boxes for different providers are built at once
  kiwi uses the result of the first build as input for the next
  one which is wrong because it should use the same raw disk
  file for all format conversions
* Mon Sep  8 2014 ms@suse.de
- Don't create /var/run (/run) tmpfs for SLE11 systems (bnc #895417)
* Mon Sep  8 2014 ms@suse.de
- Fixed message logging
  Due to the status flags the sequence of log messages could look
  broken because of missing newlines at the end of a log message.
  This patch checks if a newline is required for the previos message
  when the next message is on the way
* Mon Sep  8 2014 ms@suse.de
- Fixed reset of cursor position to work on both stderr _and_ stdout
  This fixes messages displayed in flag colors to be correctly
  displayed in the standard terminal output color
* Mon Sep  8 2014 ms@suse.de
- Put kiwiOVFConfigWriter.pm from critic level 2 to 3 because
  of too high code complexity for level 2. We need to refactor
  the ovf code but for now I just lowered the critic level
* Fri Sep  5 2014 opensuse@adamspiers.org
- make it clear which directory couldn't be created
  If a previous build failed, it might have left the root directory
  behind.  Giving the path in the error will help the user clean it up.
* Wed Sep  3 2014 aosthof@suse.de
- Added new firmware type 'ec2hvm' to handle EC2 HVM instances properly
* Tue Sep  2 2014 ms@suse.de
- Fixed grub2 EFI setup for aarch64 (bnc #894307)
* Tue Sep  2 2014 ms@suse.de
- Fixed baseSetupUserPermissions (bnc #894378)
  The function should not operate on system user accounts.
  The function should not operate on accounts without
  login shell
* Fri Aug 29 2014 ms@suse.de
- v5.06.157 released
* Fri Aug 29 2014 ms@suse.de
- Fixed KIWIOVFConfigWriter rasd:HostResource for ovf:/disk
  The reference ID was set to a wrong value not matching the
  ovf:DiskSection section
* Fri Aug 29 2014 ms@suse.de
- Fixed creation of virtualbox vagrant boxes
  Add hardlink box-disk1.vmdk to real vmdk image in box tarball
* Fri Aug 29 2014 ms@suse.de
- Cleanup KIWIOVFConfigWriter
  Prevent use of uninitialized values
* Fri Aug 29 2014 ms@suse.de
- Update vagrant example for virtualbox
* Fri Aug 29 2014 ms@suse.de
- Added missing format attribute in ovf:DiskSection in config writer
* Fri Aug 29 2014 ms@suse.de
- v5.06.156 released
* Fri Aug 29 2014 ms@suse.de
- Allow bootloader setup to run on aarch64 for grub2 and uboot (bnc #894214)
* Fri Aug 29 2014 ms@suse.de
- Added virtualbox-guest-tools in suse-13.1 vagrant example
* Fri Aug 29 2014 ms@suse.de
- Fixed broken ovf:href for image file
  Within the vagrant virtualbox box creation the vmdk file was
  renamed but this action broke the reference to that file inside
  the ovf config file
* Fri Aug 29 2014 ms@suse.de
- Prevent creation of custom /etc/ImagePackages in netboot
  The information there is created at image creation time
  already and the call increases the first boot time. This
  fixes (bnc #893776)
* Fri Aug 29 2014 ms@suse.de
- Make sure kiwi initrd creates /run/log
  dracut stores its log file there
* Tue Aug 26 2014 ms@suse.de
- v5.06.155 released
* Tue Aug 26 2014 ms@suse.de
- Make sure kiwi initrd creates /run/lock (bnc #893624)
  The location for /var/lock has been moved to /run/lock and /var/lock
  is a symlink instead. /run is a tmpfs and thus the directory must be
  created properly
* Tue Aug 26 2014 ms@suse.de
- v5.06.154 released
* Tue Aug 26 2014 ms@suse.de
- Don't prevent the pre-init stage if root= is set in the cmdline
  If a root= information is passed to the cmdline kiwi uses this
  device and wrongly indicates the system has completed the first
  boot by setting LOCAL_BOOT=yes This prevents the correct setup
  of the bootloader device.map as well as the bootloader config
  to be written (bnc #893368)
* Tue Aug 26 2014 ms@suse.de
- Prevent creation of custom /etc/ImagePackages file for the
  oem and vmx image types. The information there is created
  at image creation time already and the call increases the
  first boot time, related to (bnc #893368)
* Tue Aug 26 2014 ms@suse.de
- Fixed schema validation error output
  if the schema is invalid kiwi uses jing to create good error
  messages but the output of jing was not displayed
* Mon Aug 25 2014 ms@suse.de
- Adapt unit test due to last XSL change
* Mon Aug 25 2014 ms@suse.de
- Fixed xsl/convert58to59.xsl to convert old controller='scsi'
  to controller='lsilogic' and not 'ide' which unexpectedly
  changes the layout (bnc #893345)
* Mon Aug 25 2014 ms@suse.de
- Fixed NFS root mount, use nolock option (bnc #892672)
* Mon Aug 25 2014 ms@suse.de
- Fixed package update from sle11 to sle12 (bnc #893340)
  the man pages were moved from kiwi-doc to the main kiwi package
  between sle11 and sle12. Thus the main kiwi package has to set
  the correct file provides/obsoletes in order to avoid conflicts
* Mon Aug 25 2014 ms@suse.de
- make sure e2fsprogs is installed explicitly in isoboot
  boot image descriptions for openSUSE 13.1/13.2 and SLE12
  There is no package requirement for e2fsprogs which
  pulls it in (bnc #892087)
* Mon Aug 25 2014 ms@suse.de
- Fixed spec file requirements
  cdrkit-cdrtools-compat is a requirement on suse in order to
  correctly find the iso tools in the search path
* Mon Aug 25 2014 ms@suse.de
- Fixed legacy service insert/remove using chkconfig
  suseInsertService and suseRemoveService can deal with native systemd
  services and legacy SYS V init scripts stored in /etc/init.d/. In case
  of legacy services a call to "chkconfig /etc/init.d/${service} on|off"
  is issued but fails because chkconfig only expects a service name
  and not a full path.
* Sun Aug 24 2014 tbechtold@suse.com
- Set sudoers secure_path for vagrant examples
  secure_path is needed to find executables under i.e.
  /sbin/ when vagrant uses sudo.
  This fixes the problem when using vagrant-libvirt and
  sync a folder via 9p which leads currently to:
  ==> devstack1: mounting p9 share in guest
  modprobe 9p
  bash: line 2: modprobe: command not found
* Fri Aug 15 2014 ms@suse.de
- v5.06.153 released
* Fri Aug 15 2014 ms@suse.de
- Add RHEL7 JeOS template to kiwi-templates in spec file
* Fri Aug 15 2014 ms@suse.de
- RHEL7 parted cannot set swap flag, skip this flag setup
* Thu Aug 14 2014 ms@suse.de
- Added oemboot description for RHEL7
* Thu Aug 14 2014 ms@suse.de
- Added vmxboot description for RHEL7
* Thu Aug 14 2014 ms@suse.de
- Use lookup function to check for initrd tools pidof/killall5
* Thu Aug 14 2014 ms@suse.de
- Use menu.c32 for live ISO boot menu if not gfxboot theme exists
* Thu Aug 14 2014 rjschwei@suse.com
- fix ovf file generation
  + missing name space qualifiers for
- Description, Info, Network, OperatingSystem, Name
  + tag mismatch on line 38 of .ovf file
  + missing entry in schemaLocation
* Thu Aug 14 2014 ms@suse.de
- v5.06.152 released
* Thu Aug 14 2014 ms@suse.de
- Use group_command=compat in yum.conf
  if this is not used I get errors saying:
  There is no installed groups file.
* Thu Aug 14 2014 ms@suse.de
- Fixed file logging
  log messages were still written to stdout/stderr
  channels even if a logfile was set
* Thu Aug 14 2014 ms@suse.de
- Added RHEL7 JeOS template
* Thu Aug 14 2014 ms@suse.de
- Added isoboot description for RHEL7
* Thu Aug 14 2014 ms@suse.de
- v5.06.151 released
* Wed Aug 13 2014 ms@suse.de
- Update JeOS templates for SLE12 / Factory
  Fix ec2 type to use the correct loader and firmware setup
  Make use of LVM without boot partition as an example for the vmx type
* Wed Aug 13 2014 ms@suse.de
- Add grub2 modules for lvm and btrfs/xfs filesystems on demand
* Wed Aug 13 2014 ms@suse.de
- Update vmx|oemboot descriptions for SLE12 / Factory
  Make sure grub2-x86_64-xen is installed if a xen or ec2
  profile is in use and the architecture is x86_64
* Wed Aug 13 2014 ms@suse.de
- v5.06.150 released
* Wed Aug 13 2014 ms@suse.de
- Allow to boot LVM images without extra boot partition
  Added new type attribute bootpartition=true|false. The value
  controls the creation of a boot partition for disk images and
  overwrites the default layout kiwi would create if this is not
  specified. It's not guaranteed that the resulting image is able
  to boot with regards to the underlaying bootloader capabilities
  Given that grub2 in a recent version is used booting LVM images
  using extX and btrfs filesystems will work
* Wed Aug 13 2014 ms@suse.de
- v5.06.149 released
* Tue Aug 12 2014 ms@suse.de
- store result of kiwi --describe in /var/cache/kiwi/describe
  + ignore /var/cache for inspection
* Tue Aug 12 2014 ms@suse.de
- Fixed adding packages marked for deletion given by the
  command line option --del-package (bnc #890195)
* Mon Aug 11 2014 ms@suse.de
- v5.06.148 released
* Mon Aug 11 2014 ms@suse.de
- Fixed __createTarArchive exclude pattern
  * the pattern match for 'image' was too global as we only
    wanted to exlude the /image directory from the toplevel
* Mon Aug 11 2014 ms@suse.de
- Make sure e2fsprogs stay in netboot initrd for SLE12
* Mon Aug 11 2014 ms@suse.de
- v5.06.147 released
* Fri Aug  8 2014 ms@suse.de
- v5.06.146 released
* Fri Aug  8 2014 ms@suse.de
- keep console keytables and loadkeys in initrd for pwd dialogs
- keep klogconsole as debug helper tool in initrd
* Fri Aug  8 2014 rjschwei@suse.com
- set up the baseproduct link correctly fixe bnc #891120
  + SuSE-brand does not exist in newer distros, it has been replaced by
    /etc/os-release. Use the value there to try and provide our best guess
    about what the product is
* Fri Aug  8 2014 rjschwei@suse.com
- generate the proper name for the network definition for vmx files
  + this addresses bnc #891100
* Fri Aug  8 2014 ms@suse.de
- Use systemd-vconsole-setup to initialize the console if present
* Fri Aug  8 2014 ms@suse.de
- Optimize size of kiwi initrd
  * remove unneeded python installation which exists only
    due to building the initrd rootfs using zypper
  * make sure dracut scripts stays
* Thu Aug  7 2014 ms@suse.de
- Fixed use of IFS in bash boot code
  * don't use internal field separator in main boot scripts
    to avoid tainting of the global variable space
  * don't use internal field separator in user config
    functions in KIWIConfig.sh to avoid conflicts
  * make sure every function in the KIWILinuxRC.sh pool
    starts with a localized and default initialized IFS
    value
* Thu Aug  7 2014 dvaleev@suse.com
- Fix ofw firmware type
* Thu Aug  7 2014 dvaleev@suse.com
- SLED is x86 only
  Signed-off-by: Dinar Valeev <dvaleev@suse.com>
* Thu Aug  7 2014 rjschwei@suse.com
- Use the x86-64-xen or i386-xen format for the grub2 image creation on EC2
  + this is a follow up change for b1be72f59f5f4498 addressing bnc #887801
    we avoid the hacky symlink introduced by the previous commit.
    This change requires a grub release that contains
    http://git.savannah.gnu.org/cgit/grub.git/commit/ChangeLog?id=9612ebc0
* Thu Aug  7 2014 dvaleev@suse.com
- drop ppc64 profile for sle12
  Starting openSUSE 13.1 we have no longer kernel-ppc64 available
  anymore
  Signed-off-by: Dinar Valeev <dvaleev@suse.com>
* Thu Aug  7 2014 dvaleev@suse.com
- yaboot is deprecated on newer power distributions
  Signed-off-by: Dinar Valeev <dvaleev@suse.com>
* Thu Aug  7 2014 ms@suse.de
- v5.06.145 released
* Thu Aug  7 2014 ms@suse.de
- Added missing handling for recommends in the libsolv path
  Also fixed passing the patternType value from the XML to
  the solver module
* Wed Aug  6 2014 ms@suse.de
- v5.06.144 released
* Wed Aug  6 2014 ms@suse.de
- Fix report files generated by KIWICollect.pm
  The report files were reduced to only one package per included
  architecture, everything else was discarded. Fix done by
  Ruediger Oertel
* Wed Aug  6 2014 ms@suse.de
- v5.06.143 released
* Tue Aug  5 2014 ms@suse.de
- Update JeOS templates for SLE12 and openSUSE 13.2
  * pass splash to the kernel cmdline in order to display the
    default plymouth splash
* Tue Aug  5 2014 ms@suse.de
- Fixed kiwi --describe command
  * wrong metadata reference still in the code due to a rename
  * make sure exit code is set correctly
  * fixed broken jpg menu icons
* Mon Aug  4 2014 ms@suse.de
- v5.06.142 released
* Mon Aug  4 2014 ms@suse.de
- Fixed consoleInit, use /dev/console not tty0
* Mon Aug  4 2014 ms@suse.de
- Don't block initial boot by warning messages
* Mon Aug  4 2014 ms@suse.de
- Fixed union setup in kiwi boot code
  * rw/ro variables should not be overwritten with empty content
* Mon Aug  4 2014 ms@suse.de
- Fixed build.sh jenkins test
  * typo in option handling
* Mon Aug  4 2014 ms@suse.de
- v5.06.141 released
* Mon Aug  4 2014 ms@suse.de
- Fixed build.sh jenkins test
  * requires a mandatory arch parameter now
* Mon Aug  4 2014 ms@suse.de
- v5.06.140 released
* Mon Aug  4 2014 ms@suse.de
- Varios fixes around OVF creation
  * make sure return value from createOVFConfiguration is handled
    correctly in createVagrantBox
  * make sure output of messages is not jumbled up by status messages
  * make sure --format parameter is correctly handled when
    specified on the command line
* Mon Aug  4 2014 ms@suse.de
- v5.06.139 released
* Mon Aug  4 2014 ms@suse.de
- Adapt unit tests for OVF tests to be correct with regards
  to the size of the fake image and the size configured
* Mon Aug  4 2014 ms@suse.de
- Fixed KIWIOVFConfigWriter::writeConfigFile
  The size placed as ovf:capacity in the OVF metadata should
  be obtained from the real embedded image and not from the
  XML configuration. Reason is mostly that <size> is an option
  in the XML configuration and also does not exactly match
  the real byte value due to alignment adaptions
* Mon Aug  4 2014 ms@suse.de
- v5.06.138 released
* Mon Aug  4 2014 ms@suse.de
- Fixed jenkins test
  * don't require kiwi to be installed on the jenkins host
  * fixed tests to run kiwi from the git checkout
* Fri Aug  1 2014 ms@suse.de
- v5.06.137 released
* Fri Aug  1 2014 ms@suse.de
- Fixed kiwiOVFConfigWriter unit test
  The test has been written exclusively for the x86_64 architecture
  In order to not fail on other architectures I added an arch
  check when needed. Actually this is not an ideal solution and
  the test itself should be written arch independent. Thus I
  expect a follow up on this one soon
* Fri Aug  1 2014 ms@suse.de
- v5.06.136 released
* Fri Aug  1 2014 ms@suse.de
- Don't populate java classpath warnings to the user when
  calling jing for showing detailed validation errors in
  case of an invalid XML description
* Fri Aug  1 2014 ms@suse.de
- Several s390 fixes from Rudi
  * s390 can use grub2, make sure kiwi can make use of it
  * don't use route command, ip is the tool we want to use
  * make sure dasdinfo exists in initrd
  * fixed IFS restore bug in setupDNS
  * fixed use of test '-eq' vs '=' operator
* Fri Aug  1 2014 ms@suse.de
- Deleted indention helper script
* Fri Aug  1 2014 ms@suse.de
- DB: rebuild schema documentation
* Fri Aug  1 2014 rjschwei@suse.com
- Add platform dependent reference results for the OVF write tests
- Make the OVF write test platform independent
* Fri Aug  1 2014 ms@suse.de
- DB: rebuild documentation
* Fri Aug  1 2014 ms@suse.de
- Update indention level to 4 spaces
* Fri Aug  1 2014 ms@suse.de
- Update .indent helper script to use 4 spaces as indention
* Fri Aug  1 2014 ms@suse.de
- Fixed indention typos in createOVFConfiguration
* Fri Aug  1 2014 ms@suse.de
- Fixed disk partition alignment calculation. As we setup
  the disk by numbers of sectors it's required to handle
  the alignment boundary sectorsize conform
* Thu Jul 31 2014 rjschwei@suse.com
- oblige by the new indentation style
* Thu Jul 31 2014 ms@suse.de
- Fixed use of HERE documents in shell code
  The move from tabs to spaces needs an adaption of the
  end-of-document indicator
* Thu Jul 31 2014 rjschwei@suse.com
- Unit tests for the new OVF config file write
  + Include reference results using the new file comparison mechanism
* Thu Jul 31 2014 ms@suse.de
- Changed indention from tabs to spaces
* Thu Jul 31 2014 ms@suse.de
- Make sure disk alignment and start sector values used to create
  the image disk are stored in the initrd because they are needed
  when the disk is repartitioned in an OEM deploy process
* Thu Jul 31 2014 rjschwei@suse.com
- Implement OVF config writer class
  + This isolates the configuration writing functionality from other code
    and makes it unit testable.
  + Update the ovf file writing to more closely resemble what vCloud expects
  + Tie the new class into the config writer factory
  + Use the new code in ImageFormat directly, more restructuring is needed
    to use the factory.
- Only create a manifest file for OVA, it is not expected or needed for OVF
* Thu Jul 31 2014 ms@suse.de
- Fixed spec file Provides for kiwi-requires meta package
  The kiwi-requires package is used by the buildservice to resolve
  package requirements according to the selected build type. In
  case of docker and tbz types the needed Provides tag was missing
* Thu Jul 31 2014 thardeck@suse.de
- Prevent DiskStartSector values below the global default
  Since the DiskAlignment value is used to calculate the DiskStartSector
  it is possible to have a too small value.
  To prevent this the global DiskStartSector default is used if the
  DiskAlignment value is smaller.
  This behavior can be overwritten by using the parameter
--disk-start-sector.
* Thu Jul 31 2014 rjschwei@suse.com
- Add notset support to the test log
  + The KIWILog implements notset indicators. The test log needs to handle
    this to support testing more code
- Implement file comparison support
  + Thus far we have encoded reference results in the test directly. This is
    not practical when comparing larger generated files such as container or
    ovf configuration files. This implements support for storing reference
    results as files and using the reference results for comparison
* Thu Jul 31 2014 thardeck@suse.de
- Set disk alignment default value to 1 MB
  A value of 1 MB should be fine for most SSDs and doesn't have any impact
  on regular hard disks.
  It can be changed with the parameter --disk-alignment.
* Thu Jul 31 2014 ms@suse.de
- Added unit information to default values in KIWIGlobals
  Also set default disk alignment to 4 KB
* Thu Jul 31 2014 ms@suse.de
- Update .indent helper script
  * handle all files except Makefile and .git metadata
  * check and re-apply permission bits
  * use two spaces for one tab
* Thu Jul 31 2014 thardeck@suse.de
- Show information about disk alignment during build
* Thu Jul 31 2014 ms@suse.de
- v5.06.135 released
* Thu Jul 31 2014 thardeck@suse.de
- Adapt getSector to consider DiskAlignment values in KB
* Thu Jul 31 2014 ms@suse.de
- Be more clear in variable assignment with regards to name vs. content
* Thu Jul 31 2014 ms@suse.de
- Improve logging of errors for session scripts
  kiwi creates session scripts running in screen logging all
  output to the kiwi logfile. In case of an error we only want
  to see the stderr information and not the entire history
* Wed Jul 30 2014 ms@suse.de
- DB: rebuild documentation
* Wed Jul 30 2014 ms@suse.de
- Fixed typo in message texts
* Wed Jul 30 2014 ms@suse.de
- Update bash completion
  Added possible options for --upgrade
* Wed Jul 30 2014 ms@suse.de
- Delete git from Recommends list in the spec file
  SUSE by default installs all recommended packages which
  increases the amount of software installed when kiwi is
  installed by an unnecessary number of packages
* Wed Jul 30 2014 ms@suse.de
- Fixed logging module
  * delete obsolete and unused code from KIWILog
  * make sure error log messages are printed on stderr
  * delete obsolete --log-port option
* Wed Jul 30 2014 ms@suse.de
- use count information from IO::Select to loop through
  available data for reading
* Wed Jul 30 2014 thardeck@suse.de
- Use value of provided DiskAlignment for DiskStartSector
  If a value for DiskAlignment is provided by the user it is also used as
  base for DiskStartSector.
  If DiskStartSector is specified by the user it doesn't get overriden.
* Wed Jul 30 2014 thardeck@suse.de
- Fix comment about the default DiskStartSector size
* Tue Jul 29 2014 ms@suse.de
- Fixed OEM installer for LVM on LUKS images
* Tue Jul 29 2014 ms@suse.de
- Make sure LUKS encoding is not applied if the given device
  already contains a LUKS container
* Tue Jul 29 2014 ms@suse.de
- Don't call losetup with stderr redirected to stdout if the
  show option is used. potential error messages could then
  affect the standard output
* Tue Jul 29 2014 ms@suse.de
- Added check for given type name on the commandline compared to
  the selected build type in the checkType global function.
  If the commandline specified type is valid but not specified
  in the configuration kiwi exits
* Tue Jul 29 2014 ms@suse.de
- Call cryptsetup in one central encoding function in
  KIWIBoot for disk based images
* Tue Jul 29 2014 ms@suse.de
- Add info messages for intermediate steps when creating the
  disk layout such like information about creation of md raid
  or luks extensions
* Mon Jul 28 2014 ms@suse.de
- Support LUKS extension with LVM
* Mon Jul 28 2014 ms@suse.de
- Avoid blocking IO in callCmd if large chunks of data arrive
* Mon Jul 28 2014 adrian@suse.de
- fix open3 usage
* Mon Jul 28 2014 ms@suse.de
- Fixed --help output for disk-alignment
  The option value must be given in KBytes but the help did
  not explain that and the default value information used the
  wrong unit too
* Mon Jul 28 2014 adrian@suse.de
- avoid warnings when rpm-md repos are disabled
* Mon Jul 28 2014 adrian@suse.de
- avoid warnings when an info value is unset
* Mon Jul 28 2014 thardeck@suse.de
- Pass along the DataAlignment to LVM and LUKS
* Mon Jul 28 2014 adrian@suse.de
- fail when a product plugin dir is configured, but does not exist
* Thu Jul 24 2014 ms@suse.de
- v5.06.134 released
* Thu Jul 24 2014 ms@suse.de
- Fixed setup of object variable originXMLPath
  According to the XML read code moved from KIWIBoot into a function
  KIWIGlobals::readXMLFromImage the path information was stored in
  the wrong module. This had an impact to the search path of the
  editbootinstall/editbootconfig scripts so that they were not
  found anymore if specified relatively to the origin of the XML
  description
* Thu Jul 24 2014 ms@suse.de
- Fixed use of repo URI with credentials information
  If there is no ?credentials= tag in the repo URI kiwi uses the
  default credentials file name 'kiwiRepoCredentials' and does
  not fail using an uninitialized value $credFile
* Thu Jul 24 2014 ms@suse.de
- v5.06.133 released
* Wed Jul 23 2014 ms@suse.de
- Fixed creation of vagrant boxes for virtualbox provider
  vagrant's VBoxManage requires boxes containing ovf metadata
  which kiwi did not provide. This commit changes the raw box
  contents to match these requirements (github: #374)
* Fri Jul 18 2014 ms@suse.de
- v5.06.132 released
* Fri Jul 18 2014 ms@suse.de
- DB: rebuild documentation
* Fri Jul 18 2014 ms@suse.de
- DB: Update kiwi-doc-signkey.xml by native speaker
* Thu Jul 17 2014 ms@suse.de
- v5.06.131 released
* Thu Jul 17 2014 ms@suse.de
- Fixed xen dom0 image builds
  * problem was an invalid kernel pattern match
* Thu Jul 17 2014 ms@suse.de
- Fixed suseActivateDefaultServices
  * distinguish default services for systemd and sysVinit
  * add info message which service is activated
* Thu Jul 17 2014 rjschwei@suse.com
- properly setup grub2 for EC2 usage [bnc #887801]
  + PV-GRUB looks for the grub2 modules in /boot/grub2/xen-x86_64, although
    this is not a "real grub2 target. Symlinking to i386-pc does the trick.
    Using the prefix setting in the grub configuration trips up PV-GRUB.
* Wed Jul 16 2014 ms@suse.de
- Follow up fix for calling kiwi from git checkout
  * fixup broken locale links in source boot image descriptions
  * added Makefile target to check/update locale links on install
* Wed Jul 16 2014 ms@suse.de
- Cleanup KIWIArchList and KIWIUtil for style, conventions and perl critic
* Wed Jul 16 2014 ms@suse.de
- Cleanup use of modules and base classes
  * prevent redefine of class methods
* Wed Jul 16 2014 ms@suse.de
- Cleanup use of objects
  * write global function readXMLFromImage
  * use readXMLFromImage at all code parts which need to read
    the XML description from an image file
* Wed Jul 16 2014 ms@suse.de
- Cleanup use of objects
  * move xen check helper from KIWIBoot to global space
  * move kernel splash helper from KIWIBoot to global space
  * move buildmd5sum helper from KIWIBoot to global space
  * prevent instances of KIWIBoot just for the purpose of
    calling setupSplash and/or buildmd5sum
* Tue Jul 15 2014 ms@suse.de
- DB: update documentation (bnc #886791)
  * Added Chapter how to include rpm signing keys
* Tue Jul 15 2014 ms@suse.de
- make sure all KMS drivers are present in boot images (bnc #887148)
  * fixed for SLE12 and openSUSE boot descriptions
* Mon Jul 14 2014 ms@suse.de
- v5.06.130 released
* Mon Jul 14 2014 ms@suse.de
- Fixed Makefile, wrong use of pushd/popd
* Mon Jul 14 2014 ms@suse.de
- v5.06.129 released
* Mon Jul 14 2014 ms@suse.de
- Don't taint the system with rpm host package keys (bnc #886791)
  * kiwi imports host rpm package keys during preparation of the new
    root filesystem. This is ok but after preparation these keys
    should be removed again because we don't want to have host keys
    in the new root filesystem
* Mon Jul 14 2014 ms@suse.de
- Update bundler
  * raw disk images are now bundled as xz compressed files
* Mon Jul 14 2014 ms@suse.de
- Fixed typo in usage message
  * option is called --destdir not --dest-dir
* Mon Jul 14 2014 ms@suse.de
- Follow up fix for calling kiwi from git checkout
  * fixup broken include links in source boot image descriptions
  * added Makefile target to check/update include links on install
  * update kiwi call command to set System path
* Mon Jul 14 2014 ms@suse.de
- Added kiwi call command to run kiwi from a git checkout
* Mon Jul 14 2014 ms@suse.de
- Fixed lib path search in kiwi.pl
  * multiple lib statements overwrites each other.
    correct use is use lib LIST
* Fri Jul 11 2014 ms@suse.de
- v5.06.128 released
* Fri Jul 11 2014 ms@suse.de
- Added function updateProtectiveMBR to the boot code
  * if the protective MBR in a GPT table contains partitions
    marked as active this could cause the EFI firmware to
    ignore this disk. Thus it's important to check and update
    the protective MBR at deployment time
* Thu Jul 10 2014 ms@suse.de
- Fixed installBootLoaderGrub2 for EFI legacy BIOS boot
  * in this mode we have to install the bootloader for the i386-pc target
* Thu Jul 10 2014 ms@suse.de
- Fixed installBootLoader to work with x86 architecture again
* Thu Jul 10 2014 ms@suse.de
- Prevent lazy umounts
  * revert commit: 58308ed, can't cleanly umount devpts here
    this needs to be done differently
  * if the kernel can't free the resource there is no chance
    for the user to even see that it was mounted before
* Thu Jul 10 2014 ms@suse.de
- Follow up fix for ppc installBootLoaderGrub2 changes
  * add a message if no bootloader installation will be done
* Thu Jul 10 2014 ms@suse.de
- Make sure devpts and sysfs exists in bootstrap phase too
* Thu Jul 10 2014 ms@suse.de
- Cleanup for coding style and conventions
* Thu Jul 10 2014 dvaleev@suse.com
- Rewrite searchOFBoot function
  Use chosen/bootpath from device-tree to find a device we've booted from.
  This is more reliable than searching for PROM id, which is not available
  under KVM
  Signed-off-by: Dinar Valeev <dvaleev@suse.com>
* Thu Jul 10 2014 dvaleev@suse.com
- Don't write MBR ID on non x86 architectures
  Signed-off-by: Dinar Valeev <dvaleev@suse.com>
* Thu Jul 10 2014 dvaleev@suse.com
- PowerPC kernel is vmlinux
  Signed-off-by: Dinar Valeev <dvaleev@suse.com>
* Wed Jul  9 2014 ms@suse.de
- Update setupBootLoaderGrub2Recovery function
  + video_bochs and video_cirrus were removed from grub2
* Wed Jul  9 2014 ms@suse.de
- Follow up fix for; Don't use video_ grub2 modules
  + video_bochs and video_cirrus were removed from grub2
    Thus don't use this modules for efi grub2 images too
* Mon Jul  7 2014 ms@suse.de
- v5.06.127 released
* Mon Jul  7 2014 ms@suse.de
- Make sure squashfs module is loaded in any case
  Depending on the install method udev does not auto load
  the squashfs module if there is a cascade of loop devices
  to the target file. This happens if e.g the install iso
  is used as a disk in hybrid mode
* Mon Jul  7 2014 ms@suse.de
- v5.06.126 released
* Mon Jul  7 2014 ms@suse.de
- DB: rebuild documentation
* Mon Jul  7 2014 ms@suse.de
- DB: update documentation
  + Added information about handleSplash hook
* Mon Jul  7 2014 ms@suse.de
- Prevent initrd code to break console setup
  Many people using more than one active console stumbled over
  the problem that messages gets lost while the system is booting
  the first time with the kiwi initrd. The following changes
  fixes this:
  * Setting up console by using udev's console_init
  * Added handleSplash hook at the end of the hideSplash function
    and let kiwi only disable the splash if there is one active
    console
  * There is not much value using klogconsole to set the kernel
    default loglevel. Delete this code and the no longer needed
    klogconsole tool from the kiwi initrd
* Mon Jul  7 2014 ms@suse.de
- Don't use video_ grub2 modules
  + video_bochs and video_cirrus were removed from grub2
* Mon Jul  7 2014 ms@suse.de
- Deleted ifplugd from SLE12 JeOS template
  + ifplugd does not exist in main SLE12 repo
* Fri Jul  4 2014 ms@suse.de
- v5.06.125 released
* Fri Jul  4 2014 ms@suse.de
- Enhance installation procedure for legacy grub loader
  If a system root tree is present we install the loader from
  within the system root tree via chroot. This is to allow use
  of legacy grub on host systems which dropped grub
* Thu Jul  3 2014 ms@suse.de
- v5.06.124 released
* Thu Jul  3 2014 dvaleev@suse.com
- SLE12 PowerPC template fix
  SLE12 switched to default kernel flavor for Power
* Thu Jul  3 2014 dvaleev@suse.com
- Add ofw firmware type for Power
* Thu Jul  3 2014 dvaleev@suse.com
- Some architectures have kernel unpacked
* Thu Jul  3 2014 ms@suse.de
- travis setup up and running, removed prophet scripts and data
* Thu Jul  3 2014 ms@suse.de
- Fixed kiwiRuntimeChecker unit test
  + the case without zypper installed is not an error. Thus the
    return message is of type info not error
* Thu Jul  3 2014 ms@suse.de
- Update travis setup
  + we need syslinux for the tests
* Thu Jul  3 2014 ms@suse.de
- Update travis setup
  + we need xsltproc for the tests
* Thu Jul  3 2014 ms@suse.de
- Fixed running tests in travis
  + changed kiwiLocator test to check for bash instead of perl
    because in travis perl is relinked to perlbrew
  + call prove with perl prove in order to make sure the perlbrew
    linked interpreter is called including all module INC paths
* Wed Jul  2 2014 dvaleev@suse.com
- Add grub2 for Power
  Signed-off-by: Dinar Valeev <dvaleev@suse.com>
* Wed Jul  2 2014 ms@suse.de
- Update perl module list
  + remove modules required by modules that's auto resolved
* Wed Jul  2 2014 ms@suse.de
- Update module include path for prove calls
* Wed Jul  2 2014 ms@suse.de
- Update travis script
  + force install of modules with cpanm
* Wed Jul  2 2014 ms@suse.de
- Update travis script
  + add more information about installed prerequiremets
* Wed Jul  2 2014 ms@suse.de
- Update .perlmodules list for travis
  + List::MoreUtils was missing
* Wed Jul  2 2014 ms@suse.de
- Update travis script
  + make sure all required perl modules are fetched
* Wed Jul  2 2014 ms@suse.de
- Fixed perl include path for calling tests in travis
* Wed Jul  2 2014 ms@suse.de
- Update travis script
  + install perl modules as system modules
* Wed Jul  2 2014 ms@suse.de
- Fixed perl include path for calling tests in travis
* Wed Jul  2 2014 adrian@suse.de
- avoid listing packages twice if target destination is the same.
  eg. noarch on multi-arch medias
* Wed Jul  2 2014 ms@suse.de
- Provide additional module include path for travis
  It looks like the install routine in travis installs in /home/travis
  thus we need to use this path as additional include path in prove
* Wed Jul  2 2014 ms@suse.de
- Update travis script
  + don't stick to a specific perl version
* Wed Jul  2 2014 ms@suse.de
- Make sure unit test cleanup scripts runs using bash
* Wed Jul  2 2014 ms@suse.de
- Update travis script
  + require Test::Unit::Lite in install section
* Wed Jul  2 2014 ms@suse.de
- Rename markdown files to use the .md extension
* Wed Jul  2 2014 ms@suse.de
- Update repository README
* Wed Jul  2 2014 ms@suse.de
- Update travis script command to match kiwi tests
* Wed Jul  2 2014 ms@suse.de
- Added Travis configuration file
  Would like to use travis-ci.org instead of prophet because
  there we just can use the hosting service for open projects
  like kiwi is one
* Mon Jun 30 2014 ms@suse.de
- v5.06.123 released
* Mon Jun 30 2014 ms@suse.de
- Added prophet setup script
  Prophet uses the git api to set status messages in pull requests.
  In kiwi it's used to auto run the unit tests for each open request
* Sat Jun 28 2014 rjschwei@suse.com
- allow "raw" as a format specifier
  + raw is the default image creation format and kiwi always creates a
    .raw file. However the user may want to specify the default as the
    format and we should not error out when the default is explicitly
    specified, as is the case today.
* Thu Jun 26 2014 ms@suse.de
- v5.06.122 released
* Thu Jun 26 2014 ms@suse.de
- Fixed provides tags for main kiwi package
  The buildservice handles provides tags named kiwi-image:<type>
  taken into account for setting up a buildsystem when an image
  build is requested. The tbz provides was missing and the lxc
  provides was wrong
* Thu Jun 26 2014 adrian@suse.de
- link COPYING files to satisfy license checks of kiwi-instsource submissions
* Thu Jun 26 2014 adrian@suse.de
- KIWICollect: no leading dash in zypp product file when release is undefined
* Wed Jun 25 2014 ms@suse.de
- Update openSUSE 13.2 JeOS template
  + Set openSUSE:Factory/snapshot repository
  + Set namedCollection base pattern
  + Set openSUSE-release
* Wed Jun 25 2014 ms@suse.de
- Added URI pattern to correctly resolve openSUSE:Factory/snapshot
* Wed Jun 25 2014 adrian@suse.de
- copy also README.BETA to .license directory (bnc#882034)
* Tue Jun 24 2014 ms@suse.de
- v5.06.121 released
* Tue Jun 24 2014 ms@suse.de
- Fixed buildservice -requires meta package requirements
  In SLE12 grub is obsoleted by sles-release thus no package
  is allowed to require it
* Tue Jun 24 2014 ms@suse.de
- v5.06.120 released
* Mon Jun 23 2014 tbechtold@suse.com
- Add suse-SLES11/suse-vagrant-box example
* Mon Jun 23 2014 ms@suse.de
- Fixed solvable pattern metadata creation
  The new pattern system allows to pass the option -X to the
  libsolv *2solv tools. If this option is not passed no pattern
  metadata is created in the solvable file. kiwi now checks if
  the libsolv tools are capable of -X and passes the option
* Mon Jun 23 2014 ms@suse.de
- v5.06.119 released
* Sat Jun 21 2014 ms@suse.de
- Update bash completion file
  * split into commands and options for commands
* Fri Jun 20 2014 ms@suse.de
- Follow up implementation for sha256 hash creation
  Use perl's Digest module instead of calling an external program
* Fri Jun 20 2014 ms@suse.de
- Added creation of sha256 hash to product bundler
* Fri Jun 20 2014 ms@suse.de
- Correctly duplex stdout to /dev/console
  I still have the problem if we call e.g dialog in a new controlling
  terminal using setctsid all subsequent messages are only shown on
  this terminal even though the console might point to more devices
  which were correctly duplexed before setting a controlling terminal
* Wed Jun 18 2014 ms@suse.de
- Fixed building of firmware="ec2" image in combination with grub2
  The partition table type was set to gpt in this case but that
  is not desired for ec2 cloud images. In addition the partition
  setup was incomplete to allow successful installing of grub2
  without a bios_grub partition which was not created for ec2
  typed firmware images
* Tue Jun 17 2014 ms@suse.de
- v5.06.118 released
* Tue Jun 17 2014 ms@suse.de
- Make livestick tool more robust
  * added image check to make sure only a kiwi live iso can be used
  * fixed signature check if the stick already has been deployed with
    a kiwi live iso
* Tue Jun 17 2014 ms@suse.de
- make sure __getInstallData returns a uniq and sorted list of items
* Tue Jun 17 2014 ms@suse.de
- v5.06.117 released
* Tue Jun 17 2014 ms@suse.de
- DB: rebuild documentation
* Tue Jun 17 2014 ms@suse.de
- DB: update documentation
  + add information about installpxe option in the man page
  + make it more clear which file is expected to the --install*-system option
* Tue Jun 17 2014 ms@suse.de
- Fixed command call quoting bug in __isInstallBootImage
  leading to a Use of uninitialized value $2 in concatenation
  error
* Tue Jun 17 2014 ms@suse.de
- Fixed __getHomeDirs in analyser code
  * initialize pwd field with an empty (*) password
* Tue Jun 17 2014 adrian@suse.de
- fix handling of product variables containing just a "0"
* Mon Jun 16 2014 ms@suse.de
- v5.06.116 released
* Mon Jun 16 2014 ms@suse.de
- Fixed install of grub2 in bios_grub mode
  * Use grub2-install with correct options instead of
    raw calling grub2-bios-setup
* Mon Jun 16 2014 ms@suse.de
- Fixed error handling in recovery mode
  * the progress information is shown by the continous output
    of a sub process of the calling shell. The sub-process has
    no access to the controlling terminal thus calling system
    exceptions there cause a hangup of the process at that
    stage. This patch fixes it by not calling exceptions and
    handling the result exit code of the sub-process outside
* Mon Jun 16 2014 ms@suse.de
- Fixed createFilesystem boot code function
  * make sure btrfs creation uses -f option to force creation
    of filesystem even if another fs exists
* Mon Jun 16 2014 ms@suse.de
- Fixed creation of recovery filesystem and rootfs type detection
  * wait for the recovery partition device to appear
  * use a journaled (ext3) filesystem for the recovery
  * wait for the root device to appear
* Mon Jun 16 2014 ms@suse.de
- Fixed minor mkdir issue in setupBootLoaderGrub2Recovery
  * use -p switch and don't complain when it already exists
* Fri Jun 13 2014 ms@suse.de
- v5.06.115 released
* Fri Jun 13 2014 ms@suse.de
- Fixed user data view to take only users with a real password
  into account. System users are no real users in this scope
* Fri Jun 13 2014 ms@suse.de
- Fixed use of of uninitialized value $homedir
* Fri Jun 13 2014 ms@suse.de
- Added user data view to custom files report page
* Fri Jun 13 2014 ms@suse.de
- Update KIWIAnalyse.filter
  * filter out var/tmp and var/lib
* Fri Jun 13 2014 rjschwei@suse.com
- fix access to potentially undefined data structure
* Thu Jun 12 2014 ms@suse.de
- v5.06.114 released
* Thu Jun 12 2014 ms@suse.de
- Added better handling of custom/unpackaged file in analyser
  Instead of an auto generated sync script the code to sync
  the data moved into KIWIAnalyseSystem. by default no sync
  file information is configured but a descriptive markdown
  readme including an example is added to the generated
  description. The user now only needs to place a file called
  custom.sync
  describing which files/directories should be content
  controlled and any subsequent call of kiwi --describe will
  do the job
* Thu Jun 12 2014 adrian@suse.de
- do not overwrite product release number if it is set to "0"
* Wed Jun 11 2014 ms@suse.de
- Update createCustomDataSyncScript
  * the script now requires an argument which could be the kiwi
    generated custom.files file. if called without argument an
    information how to use the custom.sync script is displayed
    The reason why we changed from default use of custom.files
    to a self provided information is that on real systems many
    custom files and directories exists but not all of them
    needs to be tracked
* Wed Jun 11 2014 ms@suse.de
- v5.06.113 released
* Wed Jun 11 2014 adrian@suse.de
- fix missing dependency to grub(1) for vmx and oem builds
* Wed Jun 11 2014 ms@suse.de
- Fixed KIWIGlobals::downloadFile function
  * quote shell escape chars because the url is passed to lwp-download
  * fix regexp extracting url credentials. the expression matches too
    much of a file path in the first ancor
  * fixed cleanup of files downloaded if solvable creation out of
    this data has failed. Don't leave waste of data in this case
* Wed Jun 11 2014 ms@suse.de
- Fixed kiwi --info <image-description> --select repo-patterns
  * For SLE12 and Factory the new pattern system is based on
    rpm packages. Thus the solvable metadata has changed. This
    commit allows to get the patterns from the repo for the old
    and the new pattern system
* Wed Jun 11 2014 adrian@suse.de
- require at least one instsource plugin via generic provide
* Tue Jun 10 2014 ms@suse.de
- v5.06.112 released
* Tue Jun 10 2014 ms@suse.de
- Fixed return value for __checkQemuImg helper in image
  format creation. The function has to return the path
  to the qemu-img binary
* Tue Jun 10 2014 ms@suse.de
- v5.06.111 released
* Tue Jun 10 2014 ms@suse.de
- Added kiwi-image:<type> -requires package provides for OBS
* Tue Jun 10 2014 adrian@suse.de
- support usage of PRODUCT_RELEASE definitions
* Tue Jun 10 2014 ms@suse.de
- v5.06.110 released
* Tue Jun 10 2014 ms@suse.de
- Update Summary and description for -requires meta packages
* Tue Jun 10 2014 adrian@suse.de
- Add the OBS provides to -requires packages
  This avoids the need to manually track kiwi dependencies in OBS prjconf substitute
  rules. However, we need to disable the rules for current distros, but that
  will phase out via time :)
* Tue Jun 10 2014 ms@suse.de
- v5.06.109 released
* Tue Jun 10 2014 ms@suse.de
- Make sure temporary copy of data from the initrd to the
  system is removed correctly within the cleanImage method
* Tue Jun 10 2014 ms@suse.de
- v5.06.108 released
* Tue Jun 10 2014 ms@suse.de
- Update SLE12 JeOS description
  * make sure kiwi-templates will be installed
* Tue Jun 10 2014 ms@suse.de
- Use the KIWILocator to find tools qemu-img, mksquashfs and
  modinfo and call them with full path instead of relying on
  the caller shell PATH setup
* Fri Jun  6 2014 ms@suse.de
- Make sure getBootIncludePackages returns a uniq sorted list
* Fri Jun  6 2014 ms@suse.de
- Added argument check for disk device in livestick tool
* Fri Jun  6 2014 ms@suse.de
- Added ntfs modules to be present in isoboot initrd
  if used for creation of a livestick it enables people to do
  that on USB sticks with preformatted NTFS filesystem
* Fri Jun  6 2014 ms@suse.de
- v5.06.107 released
* Fri Jun  6 2014 ms@suse.de
- Fixed grub2 recovery setup
  * Recovery menu entry was not populated to all config files
* Thu Jun  5 2014 ms@suse.de
- v5.06.106 released
* Thu Jun  5 2014 ms@suse.de
- Use menu.c32 for isolinux to display a text menu if no
  graphics theme is available
* Wed Jun  4 2014 ms@suse.de
- Fixed bundle-build result for vagrant image results
* Wed Jun  4 2014 ms@suse.de
- Follow up change for --bundle-build command
  Make sure the build metadata files .packages/.verified/.channel
  are part of the bundle
* Wed Jun  4 2014 ms@suse.de
- Fixed typo, surplus status flag
* Tue Jun  3 2014 ms@suse.de
- Follow up patch for KIWICollect::indexOfArray
  * follow coding style and conventions
* Tue Jun  3 2014 ms@suse.de
- Added new class KIWIResult and command:
  kiwi --bundle-build <build-number> --dest-dir <dir>
  Along with the new KIWIResult class the above command was added.
  With bundle-build and the given build number and build target
  directory kiwi takes the information from the build target
  directory and bundles the user relevant image files as single
  files and/or tarball suitable for publishing.
* Tue Jun  3 2014 adrian@suse.de
- KIWICollect: fix order of architectures if one repository contains multiple architecture
  versions of same rpm.
* Tue Jun  3 2014 ms@suse.de
- Write a kiwi.buildinfo file for each build
  The buildinfo file contains information about the build which
  will be used to collect user relevant image files according
  to the requested image type and parameters. The result of a
  kiwi build could contain intermediate build results which
  will be embedded in the final result and stay in the result
  directory in order to allow faster rebuilds. There will be
  a new kiwi post processing command which collects only the
  important result image files and provide them together with
  a build number.
* Mon Jun  2 2014 ms@suse.de
- In preparation to support enable/disable of boot partition
  + remove obsolete boot_id/root_id code from grub2 codebase
    for grub2 we don't search via id, we search either by uuid
    or by flag file
  + for other bootloaders make sure boot_id is set to the root
    partition id if no explicit boot partition exists
* Mon Jun  2 2014 ms@suse.de
- v5.06.105 released
* Mon Jun  2 2014 ms@suse.de
- Make sure the selected build type is used in upgrade mode.
  With the wrong build type this could lead to unneeded
  runtime checks called and failing (bnc #880744)
* Mon Jun  2 2014 ms@suse.de
- Fixed spec file, kiwi-templates contains arch specific
  templates thus it's wrong to make this a noarch package
* Mon Jun  2 2014 ms@suse.de
- Fixed grub.conf setup for RHEL systems using legacy grub
  on RHEL grub.conf is a link to the menu.lst file
* Fri May 30 2014 ms@suse.de
- v5.06.104 released
* Fri May 30 2014 ms@suse.de
- make sure KIWISatSolver correctly quotes repo alias names
  in a way that the shell can still find files with e.g spaces
* Fri May 30 2014 ms@suse.de
- make sure kiwi scripts runs in C locale (bnc #880674)
* Wed May 28 2014 ms@suse.de
- Follow up update jenkins prepare worker script
  + make sure validation runtime checks find all tools on the host
* Wed May 28 2014 ms@suse.de
- Update jenkins prepare worker script
  + make sure validation runtime checks find all tools on the host
* Tue May 27 2014 ms@suse.de
- v5.06.103 released
* Tue May 27 2014 ms@suse.de
- Fixed creation of versioned vagrant box json file
* Tue May 27 2014 ms@suse.de
- v5.06.102 released
* Tue May 27 2014 ms@suse.de
- Update suse-13.1/suse-vagrant-box example
  + build for two providers, libvirt and virtualbox
* Tue May 27 2014 ms@suse.de
- Allow to specify multiple vagrantconfig sections
  + one can build boxes for different providers in one build
  + report missing machine configuration only when it makes sense
* Tue May 27 2014 ms@suse.de
- v5.06.101 released
* Tue May 27 2014 ms@suse.de
- Cleanup examples and templates
  + remove obsolete openSUSE 12.1 examples
  + fix package lists and type setup according to result
    of preparation runtime checks
* Tue May 27 2014 ms@suse.de
- Update Makefile
  + don't use shell backticks, instead use make's shell command
  + limit scope of 'make valid' target to the present architecture
* Tue May 27 2014 ms@suse.de
- Extend scope of kiwi --check-config
  Additionally call the prepare runtime checks after validation
* Tue May 27 2014 ms@suse.de
- Added runtime check __checkSelectedBootLoaderIncluded
  Check if the selected bootloader will also be installed into the image
* Tue May 27 2014 ms@suse.de
- Fixed typo in suse-13.1/suse-vagrant-box definition
  * wrong indention
* Tue May 27 2014 ms@suse.de
- v5.06.100 released
* Tue May 27 2014 ms@suse.de
- Fixed search path for *.kiwi control files in getControlFile
* Mon May 26 2014 ms@suse.de
- DB: rebuild documentation
* Mon May 26 2014 ms@suse.de
- DB: update documentation, remove obsolete kiwistderr information
* Mon May 26 2014 ms@suse.de
- Removed obsolete setup of kiwistderr cmdline value.
  The kiwi boot code does not handle this information since
  quite some time
* Mon May 26 2014 ms@suse.de
- v5.06.99 released
* Mon May 26 2014 ms@suse.de
- Update rhel-dump with regards to xz vs gzip change: 10aa35e3
* Mon May 26 2014 ms@suse.de
- Don't start klogconsole if quiet boot is set (bnc #879768)
* Sun May 25 2014 ms@suse.de
- Be a bit smarter in best guess of the minimum size for
  the boot partition if we need one. The function __getBootSize
  now calculates the size using some parameters to keep
  roughly 100MB free. This is more accurate than using a
  fixed size min default value. Setting a custom value for the
  boot partition using the bootpartsize attribute results in
  + Use of bootpartsize without any message if it is bigger
    than recommended value
  + Use of bootpartsize with warning if it is smaller than
    recommended value
* Fri May 23 2014 ms@suse.de
- v5.06.98 released
* Fri May 23 2014 ms@suse.de
- Make sure the auto inclusion of a system strip section
  according to the bootincluded packages happens before
  image.sh is called
* Fri May 23 2014 ms@suse.de
- break up too long lines of code
* Fri May 23 2014 ms@suse.de
- Better error message
  * if no rpm db was found tell us where we searched for it
* Fri May 23 2014 ms@suse.de
- Removed code duplication for calling images.sh
* Thu May 22 2014 ms@suse.de
- v5.06.97 released
* Thu May 22 2014 ms@suse.de
- Fixed syntax typo in warning call
* Thu May 22 2014 ms@suse.de
- v5.06.96 released
* Thu May 22 2014 ms@suse.de
- Make sure tools in bootincluded packages and archives
  automatically stay inside the boot image (initrd) without
  having the need for an additional <strip> section
* Thu May 22 2014 ms@suse.de
- Fixed Use of uninitialized value $ENV{PATH}
* Wed May 21 2014 ms@suse.de
- don't call the rpm dump/reload if all packages are specified
  in the bootstrap section. In that case no rpm action happens
  inside the chroot. Thus it's not needed to dump/reload the
  rpm database.
  + It's not required to have the rpm db tools installed on the host
- The rpm database inside the new root tree stays incompatible
* Tue May 20 2014 ms@suse.de
- v5.06.95 released
* Tue May 20 2014 ms@suse.de
- make sure we have /var/run and /run with the same bind
  contents inside the initrd and in the later system
* Tue May 20 2014 ms@suse.de
- Removed obsolete KIWISchemaTest reference. image testing is
  implemented using os-autoinst
* Tue May 20 2014 ms@suse.de
- DB: rebuild documentation
* Tue May 20 2014 ms@suse.de
- DB: update manual page
* Mon May 19 2014 ms@suse.de
- v5.06.94 released
* Mon May 19 2014 ms@suse.de
- Cleanup KIWIPromoDVDPlugin.pm to critic level 3
* Mon May 19 2014 ms@suse.de
- Cleanup KIWILiveTreePlugin.pm to critic level 3
* Mon May 19 2014 ms@suse.de
- Cleanup KIWIFinishEFIPlugin.pm to critic level 3
* Mon May 19 2014 ms@suse.de
- Cleanup KIWIPatternsPlugin.pm to critic level 3
* Mon May 19 2014 ms@suse.de
- Cleanup KIWIMiniIsoPlugin.pm to critic level 3
* Mon May 19 2014 ms@suse.de
- Cleanup KIWIEulaPlugin.pm to critic level 3
* Mon May 19 2014 ms@suse.de
- Update pre-commit not-clean list
* Mon May 19 2014 ms@suse.de
- Cleanup KIWIDescrPlugin.pm to critic level 3
* Mon May 19 2014 ms@suse.de
- Added callCmd helper function to KIWIBasePlugin.pm
* Mon May 19 2014 ms@suse.de
- Cleanup KIWIContentPlugin.pm to critic level 3
* Sun May 18 2014 ms@suse.de
- v5.06.93 released
* Sat May 17 2014 ms@suse.de
- Fixed __isValidBootFS constructor check in KIWIXMLTypeData
  The ext4 filesystem is valid for booting
* Sat May 17 2014 ms@suse.de
- Fixed livestick tool, the kiwi_hybridpersistent option
  takes a true|false value not a yes|no value
* Fri May 16 2014 ms@suse.de
- v5.06.92 released
* Thu May 15 2014 ms@suse.de
- Don't use the fsmountoptions to mount the filesystems
  created for the installstick disk. The filesystem used to
  store the system image on the stick disk is different from
  the configured system image filesystem, thus the options
  does not fit.
* Thu May 15 2014 ms@suse.de
- v5.06.91 released
* Thu May 15 2014 ms@suse.de
- Instead of a symlink named box.img to the actual image file
  in a vagrant box, directly store the image file under the
  name box.img. Older versions of vagrant did not work if
  box.img is a symlink
* Thu May 15 2014 ms@suse.de
- v5.06.90 released
* Wed May 14 2014 ms@suse.de
- Added rsync to suse-vagrant-box example template
  vagrant requires rsync to be present in a base box
* Wed May 14 2014 ms@suse.de
- Update vagrant support
  + also create a vagrant cloud configuration file
  + add box.img link to be present in the .box file
* Wed May 14 2014 ms@suse.de
- Added Vagrant box example template description
  + extras/suse-13.1/suse-vagrant-box
* Wed May 14 2014 ms@suse.de
- Fixed invalid entries in /etc/mtab
  On systems with /etc/mtab as a file and not as a link to proc
  kiwi left entries from the host system in the file which are
  wrong when the image boots up
* Wed May 14 2014 ms@suse.de
- v5.06.89 released
* Wed May 14 2014 ms@suse.de
- Fixed setupUnionFS (bnc #877451)
  * update UNIONFS_CONFIG only if all parameters have a value
* Wed May 14 2014 ms@suse.de
- v5.06.88 released
* Tue May 13 2014 fcastelli@suse.com
- Remove lxc package from the docker example
  The lxc pacakge is not required by docker images, hence it can be
  removed from the template shipped with the examples.
* Tue May 13 2014 dvaleev@suse.com
- Don't generate TRANS.TBL for POWER iso
  It seems only POWER does TRANS.TBL generation. Let be consentive with
  other architectures.
  Signed-off-by: Dinar Valeev <dvaleev@suse.com>
* Tue May 13 2014 adrian@suse.de
- drop license.tar.gz in root dir for rpm-md repos
- fail when license.tar.gz misses one of the required files
  * license.txt
  * directory.yast
    license.tar.gz is still part of the rpm-md metadata directory
* Tue May 13 2014 ms@suse.de
- Added support for creating vagrant boxes
  In order to create a vagrant box the format parameter in the
  image type acts as trigger to start the box creation. Vagrant
  boxes requires some metadata in order to allow adding the box
  for a specific provider. Thus the following minimal type spec
  is needed e.g:
  <type image="vmx" ... format="vagrant">
  <vagrantconfig provider="libvirt" virtualsize="16"/>
  </type>
  The result .box file can be added to vagrant as follows
  vagrant box add <name> /path/to/file.box
  Once added vagrant can run the box using the specified provider
  Please note the kiwi image for vagrant needs to provide some
  configuration like the existence of a user vagrant and ssh
  keys. All this can be achieved in a kiwi image description.
  For details visit:
  http://docs.vagrantup.com/v2/boxes/base.html
* Tue May 13 2014 ms@suse.de
- DB: rebuild documentation
* Tue May 13 2014 ms@suse.de
- DB: update OEM PXE installation documentation
* Tue May 13 2014 ms@suse.de
- Use xz instead of gzip to compress the raw disk file in an
  oem PXE installation tarball. xz produces smaller results
  compared to gzip.
* Tue May 13 2014 ms@suse.de
- Added xz tool to oem boot image descriptions
* Tue May 13 2014 ms@suse.de
- Removed suse-12.1 boot descriptions
* Mon May 12 2014 ms@suse.de
- v5.06.87 released
* Mon May 12 2014 ms@suse.de
- Fixed __checkContainerHasLXC runtime check
  * if docker is used it's not required to have lxc installed
    as part of the container
* Mon May 12 2014 ms@suse.de
- Fixed suseSetupProduct
  * if no /etc/products.d directory exists, prevent creating
    a broken baseproduct link
* Mon May 12 2014 ms@suse.de
- Fixed kiwi root init() function
  * make sure manually created toplevel directories belong to root:root
* Mon May 12 2014 ms@suse.de
- Added __isInstallBootImage sanity check for all
  install media postprocessing modes:
  kiwi --installcd
  kiwi --installstick
  kiwi --installpxe
  If the given boot image does not provide install
  capabilities the user will find out on first boot
  which is a bad experience
* Mon May 12 2014 ms@suse.de
- Fixed service disablement in docker types for non
  systemd based distributions e.g SLE11
* Fri May  9 2014 ms@suse.de
- Fixed creation of live iso images with flags="compressed"
  In this mode the live setup is based on a split image type and
  did not allow to have a persistent data block available in the
  iso. This patch changed this so that you can also use the
  hybridpersistent="true" feature when using the hybrid iso on
  e.g a usb stick to store new data persistently
* Fri May  9 2014 ms@suse.de
- Added live iso type to SLE11 JeOS template
* Thu May  8 2014 ms@suse.de
- Looks like memtest86+ does not exist for SLE11 anymore
  Thus removed it from the SLE11 boot image descriptions
* Thu May  8 2014 ms@suse.de
- DB: rebuild documentation
* Thu May  8 2014 ms@suse.de
- DB: Update documentation, remove obsolete information
* Thu May  8 2014 ms@suse.de
- v5.06.86 released
* Thu May  8 2014 ms@suse.de
- fixed typo in spec file, unbalanced %%if
* Thu May  8 2014 ms@suse.de
- v5.06.85 released
* Thu May  8 2014 ms@suse.de
- Cleanup list of authors per package in spec file
* Thu May  8 2014 ms@suse.de
- Update package helper tools to auto update the kiwi-schema
  provides in the spec file if the kiwi RNC schema has changed
* Thu May  8 2014 ms@suse.de
- Added kiwi-schema metadata provides to spec file
  This was requested by the slepos team to be able to require
  the right kiwi version and schema to yast2-product-creator
* Thu May  8 2014 ms@suse.de
- Added compatibility fix for fetchFile function
  * Instead of matching for the exact value 'uncompressed' the
    function treats all values matching the expression '^uncomp'
    as a statement to indicate an uncompressed image
* Wed May  7 2014 ms@suse.de
- Fixed __hasBootDescription runtime check
  * the check should also work with custom user boot descriptions
* Wed May  7 2014 ms@suse.de
- Follup up fix for spec file requirements:
  * need virt-utils for SLE11, use qemu-tools for anything else
  * add virt-utils/qemu-tools to base kiwi package only
* Wed May  7 2014 ms@suse.de
- Added custom filters for kiwi --describe in KIWIAnalyse.filter
* Wed May  7 2014 ms@suse.de
- DB: rebuild man pages
* Wed May  7 2014 ms@suse.de
- DB: update man page
* Wed May  7 2014 ms@suse.de
- v5.06.84 released
* Wed May  7 2014 ms@suse.de
- Fixed spec file requirements:
  Replaced virt-utils with qemu-tools, virt-utils was dropped
* Wed May  7 2014 ms@suse.de
- v5.06.83 released
* Wed May  7 2014 ms@suse.de
- DB: update schema documentation
* Wed May  7 2014 ms@suse.de
- Follow up fix for directory check in cleanMount
  use the exact same parameter for test as for umount
* Tue May  6 2014 ms@suse.de
- Fixed SLE12 JeOS template
  * install patterns with the namedCollection attribute
  * make sure the desired release package is installed in
    the bootstrap phase to avoid the installation of this
    strange dummy-release package which I don't understand
    what it is good for at all
* Tue May  6 2014 ms@suse.de
- Fixed directory check in cleanMount
  If no repo alias is set the repo uri is also used as name for
  the mount point directory. In this case the name could contain
  quoted characters. Perl's test operator can't deal with shell
  escaped directory names. Thus we check with the shell test
  built-in if the mount point directory exists
* Mon May  5 2014 ms@suse.de
- v5.06.82 released
* Mon May  5 2014 ms@suse.de
- DB: rebuild documentation
* Mon May  5 2014 tom_schr@web.de
- Added some info about Docker and KIWI
* Mon May  5 2014 ms@suse.de
- Fixed check for .repo file
  The repo path is stored quoted for use use with the shell
  but the perl test operator can't deal with shell escaped
  characters and failed. Thus shell's test built-in is used
  instead
* Fri May  2 2014 ms@suse.de
- v5.06.81 released
* Fri May  2 2014 ms@suse.de
- Fixed suseService function
  * Use of undefined variable $action where it should be $target
* Fri May  2 2014 ms@suse.de
- Fixed 32bit EFI build
  * if secure boot is requested, warn and switch to non
    secure EFI boot. shim only exists for 64bit linux
  * fixed lookup of bootloader stage files. In case of
    32bit EFI the lookup path must be 'i386-efi'
* Fri May  2 2014 ms@suse.de
- Added 32bit efi modules package to boot descriptions
  for openSUSE 12.3 iso | oem and vmxboot
* Fri May  2 2014 ms@suse.de
- Fixed unit test Test/kiwiContainerConfigWriter.pm
  * message output has changed in the container code
* Fri May  2 2014 fcastelli@suse.com
- Added openSUSE 13.1 template for docker target.
* Thu May  1 2014 ms@suse.de
- Fixed __populateRepos in software analyser
  * The CD/DVD repos from zypper were not correctly added
    as iso repo in the kiwi generated clone configuration
* Thu May  1 2014 ms@suse.de
- Fixed container image name extension
  * if docker is set the extension should be set to docker and not lxc
* Wed Apr 30 2014 ms@suse.de
- Added support for docker image types
  kiwi supports creation of lxc images which are stored below
  var/lib/lxc/<container-name>. The docker subsystem expects
  the image to be packed differently. Thus we added a new type:
  <type image="docker">
  The information about the container name is optional in this
  case and if specified not used for docker type images
* Wed Apr 30 2014 ms@suse.de
- Fixed typo in function name
* Tue Apr 29 2014 ms@suse.de
- v5.06.80 released
* Tue Apr 29 2014 ms@suse.de
- Fixed KIWIBasePlugin for style and conventions
  * in addition make the code perl critic level 3 clean
* Tue Apr 29 2014 ms@suse.de
- Update jenkins build script
  * don't force output directory, leave it up to the test call
    to set an appropriate output directory
* Tue Apr 29 2014 ms@suse.de
- Update SLE12 product plugin for style/convention
  * also fixed code to be perl critic level 3 clean
* Tue Apr 29 2014 ms@suse.de
- Make sure wpa_supplicant stay as tool in the initrd
* Tue Apr 29 2014 ms@suse.de
- moved from xfs_check to xfs_repair, related to (bnc #853253)
  * xfs_check will be gone in June 2014
* Tue Apr 29 2014 ms@suse.de
- Cleanup/Fix messages displayed in resizeFilesystem
  * print information about check and resize separately
  * print information when we don't know how to resize
  * be more verbose which device is resized
* Tue Apr 29 2014 ms@suse.de
- Fixed typo in boot message
  Calling mkswap creates a swap space but does not activate it.
  The intention is to create the swap space thus the message
  should tell the user this and nothing misleading
* Mon Apr 28 2014 schwab@linux-m68k.org
- Spelling fixes
* Mon Apr 28 2014 adrian@suse.de
- extract licenses in extra media directory for SLE 12
* Thu Apr 24 2014 ms@suse.de
- v5.06.79 released
* Thu Apr 24 2014 ms@suse.de
- Fixed value and handling for profile variable kiwi_allFreeVolume
  * If a volume with size="all" is specified and in addition this
    volume takes a custom volume name with a custom mountpoint,
    the variable was setup with the kiwi default volume naming
    schema but not with the real volume name which lead to a
    boot problem when kiwi could not find the volume
* Thu Apr 24 2014 ms@suse.de
- v5.06.78 released
* Thu Apr 24 2014 ms@suse.de
- Allow ext4 as boot filesystem
* Thu Apr 24 2014 thardeck@suse.de
- Use existing credentials name for repositories
  * Don't add a credentials name to repositories if there is already one
* Thu Apr 24 2014 ms@suse.de
- Fixed pxePartitionInputGeneric
  In case of a raid setup via pxeboot the required partition type 'fd'
  is not explicitly provided in the PART line of the client config.
  Instead the raid information is given in an additional RAID variable.
  Thus the pxePartitionInputGeneric function has to set the partition
  type 'fd' if the RAID variable is set too.
* Wed Apr 23 2014 ms@suse.de
- Follow up fix for partedGetPartitionID
  * return if no partition label could be detected
* Wed Apr 23 2014 ms@suse.de
- Make partedGetPartitionID more robust
  * If we can't find a partition label for the disk don't proceed
    checking for a partition ID and return an unknown ID 'xx'
* Wed Apr 23 2014 ms@suse.de
- Fixed message displayed in __checkCorrectRootFSPermissons
  LSB standard does not prescribe UID and GID values
* Wed Apr 23 2014 ms@suse.de
- Fixed __checkCorrectRootFSPermissons runtime check
  * Don't check for root/root permissions in root's home
    It's ok to have custom files with custom permissions
    there
* Wed Apr 23 2014 ms@suse.de
- Fixed recovery grub2 setup
  * don't use fixed class and theme names
* Wed Apr 23 2014 ms@suse.de
- Use suse parted 'type' command extension to setup swap partition
  type. This is done because the upstream way of setting swap type
  is broken in the suse parted.
* Tue Apr 22 2014 ms@suse.de
- Fixed message displayed when the partition table is created/updated.
  Even in the case of creating a new partition table the message said
  something about repartition of the disk which is misleading. Thus
  the message changed to just tell the user about a partition
  process happening now
* Tue Apr 22 2014 ms@suse.de
- v5.06.77 released
* Tue Apr 22 2014 ms@suse.de
- Fixed cache creation in --init-cache mode
* Sun Apr 20 2014 ms@suse.de
- Fixed --bootcd post processing mode
* Sun Apr 20 2014 ms@suse.de
- Fixed --bootusb post processing mode
* Thu Apr 17 2014 ms@suse.de
- v5.06.76 released
* Thu Apr 17 2014 ms@suse.de
- Fixed __hasBootDescription() runtime check for pxe type
  The type in the XML is 'pxe' but the boot description is
  named 'netboot'
* Thu Apr 17 2014 ms@suse.de
- v5.06.75 released
* Thu Apr 17 2014 ms@suse.de
- Remove suseCloneRunlevel calls from EC2 and Xen guest
  templates. They are obsolete since sysVInit has been
  replaced with systemd
* Thu Apr 17 2014 ms@suse.de
- Update service support functions
  * remove obsolete suseCloneRunlevel and suseActivateServices
  * use chkconfig instead of insserv
  * enhance suseService to be called with on|off and
    sysVInit runlevels like chkconfig supports it. For
    systemd this value would be ignored
* Thu Apr 17 2014 ms@suse.de
- Update baseSetRunlevel() function
  * support custom systemd target names
* Thu Apr 17 2014 ms@suse.de
- Use linuxefi/initrdefi grub2 commands only for EFI secure boot
* Wed Apr 16 2014 adrian@suse.de
- installed prod file parsing is not important anymore
  disable horrible code for openSUSE 13.2 and SLE 12 :)
* Wed Apr 16 2014 ms@suse.de
- v5.06.74 released
* Wed Apr 16 2014 ms@suse.de
- Fixed legacy boot support for EFI install stick images (git #341)
* Wed Apr 16 2014 ms@suse.de
- Fixed build of install stick in EFI firmware mode (git #341)
* Wed Apr 16 2014 ms@suse.de
- Update media collect code to match coding style and
  conventions as well as remove/rewrite comments which
  are obviosly wrong with regards to the current code
* Wed Apr 16 2014 adrian@suse.de
- fix parsing of product summary label on new openSUSE 13.2/SLE12 medias
* Tue Apr 15 2014 ms@suse.de
- v5.06.73 released
* Tue Apr 15 2014 adrian@suse.de
- drop .channel files for products, generate .report files instead
  The approach to generate _channel file for OBS maintenance is not working,
  since it requires the knowledge of OBS setup internas. There we drop this
  here, let kiwi generate instead report files which document which files got
  used.
  We can use them for diffing results, for tracking build results in OBS and
  obs worker can generate _channel files with knowledge of setup internas.
* Tue Apr 15 2014 ms@suse.de
- Make sure lvm2 tools stay in oemboot for RHEL
* Tue Apr 15 2014 ms@suse.de
- Apply sleep for a while to wait for wwids to
  other architectures boot code
* Tue Apr 15 2014 ms@suse.de
- sleep for a while after multipathd and udev events are
  processed. it seems the data in /etc/sysconfig is not
  in sync with udev
* Tue Apr 15 2014 ms@suse.de
- Removed invalid URL type log message
* Mon Apr 14 2014 ms@suse.de
- v5.06.72 released
* Mon Apr 14 2014 ms@suse.de
- Fixed message logging
  * don't log message to already closed file descriptor
* Mon Apr 14 2014 thardeck@suse.de
- Removed done statement from last Kiwi message
  * The Done message at the last line was confusing, especially when
    KIWI exited with errors.
    To keep consistency and since the done message wasn't really needed
    because the last message is not a task it was also removed for
    the success messages.
* Mon Apr 14 2014 ms@suse.de
- Added __hasBootDescription runtime check
  Code written by Tim Hardeck. The test looks up the required
  boot image description according to the selected build type
  if no such description exists the build exit with an error
  telling the user which rpm package is missing on the build
  machine
* Mon Apr 14 2014 ms@suse.de
- Fixed tests for KIWIRuntimeChecker code
  * for each test call the corresponding runtime checker function
    and not the container method which always calls all of them
  * added variable KIWI_NO_FS which allows to switch off runtime
    checks which accesses the filesystem. They can only be safely
    called if the filesystem environment is controlled too
* Mon Apr 14 2014 ms@suse.de
- Fixed __hasBootLoaderTools() runtime check to check for
  the bootloader tool if 'grub' is selected
* Mon Apr 14 2014 ms@suse.de
- Apply /etc/multipath directory exists when starting
  multipathd also to other architectures boot code
* Mon Apr 14 2014 ms@suse.de
- Follow up fix for the URL resolver
  * really prevent LWP browsing calls
* Mon Apr 14 2014 ms@suse.de
- Cleanup indention of templates and examples due to XML validation
* Mon Apr 14 2014 ms@suse.de
- Fixed URL pattern matcher and resolver
  * eval on an expression violates perl critic expression eval rule
  * avoid LWP browsing calls because this is often rejected
* Mon Apr 14 2014 ms@suse.de
- Make sure /etc/multipath directory exists when starting
  multipathd inside the kiwi boot image (initrd)
* Fri Apr 11 2014 thardeck@suse.de
- Show an error message for missing bootloaders
* Thu Apr 10 2014 ms@suse.de
- v5.06.71 released
* Thu Apr 10 2014 adrian@suse.de
- do not write binary arch as channel scheduler arch
- write full input file into channel files
* Thu Apr 10 2014 ms@suse.de
- Revert "Change repo of current openSUSE 13.2 to point to openSUSE-current"
  This reverts commit ee40f60594fa. We will use the final repo path and
  point via commandline options to openSUSE-current as long as it's not
  released
* Thu Apr 10 2014 ms@suse.de
- v5.06.70 released
* Thu Apr 10 2014 ms@suse.de
- Merge latest changes from oemboot suse-dump to rhel-dump
* Thu Apr 10 2014 ms@suse.de
- Extend getDiskID function to work correctly for device
  mapper devices pointing to /dev/dm-X
* Thu Apr 10 2014 ms@suse.de
- Extend device search in identifyDevice to by-uuid by-label
  and /dev/mapper for multipath devices
* Thu Apr 10 2014 ms@suse.de
- Fixed wrong comment in schema for the lookup path of
  the oem-unattended-id device name
* Thu Apr 10 2014 ms@suse.de
- Update jenkins product.sh script
  Support a hop host to allow searching for build results
* Thu Apr 10 2014 ms@suse.de
- Update SLE11 JeOS template, use SMT repos
* Thu Apr 10 2014 ms@suse.de
- Update jenkins build.sh script
  Allow to pass additional parameters to the build
* Thu Apr 10 2014 ms@suse.de
- Change repo of current openSUSE 13.2 to point to openSUSE-current
  This distribution is currently under development. Thus the repo
  path will change right before GA. This fixes the jenkins build
  test for 13.2
* Wed Apr  9 2014 ms@suse.de
- Added support for multipath devices
  <oem-multipath-scan>true|false</oem-multipath-scan>
  by default the scanning for multipath devices is turned on.
  The code in the initrd looking up multipath devices also
  checks for preconditions like the ability to start the
  multipathd and use the multipath tools. If you don't see
  the multipath devices in the selection list but expect
  this according to the oemconfig setup please refer to the
  kiwi boot log file for further details
* Wed Apr  9 2014 ms@suse.de
- fixed diskOffset() function
  In case of DASD devices over a loop, fdasd needs to be used
  to get the offset to the first partition. In addition improve
  error handling and logging of the calls
* Mon Apr  7 2014 ms@suse.de
- Don't remove unconditionally the gconv directory in
  basestripLocales function
* Mon Apr  7 2014 ms@suse.de
- v5.06.69 released
* Mon Apr  7 2014 ms@suse.de
- Update livestick kiwi tool
  * Use 'upstream' branding by default
  * fixed grub2 config, keep the gfxpayload
    livestick allows to deploy kiwi live iso images to
    the USB stick without destroying any existing data
    on the stick
* Mon Apr  7 2014 ms@suse.de
- Make sure overlayfs kernel module is part of vmxboot
* Mon Apr  7 2014 ms@suse.de
- Fixed creation of disk image if filesystem type is set
  to 'squashfs'. In this mode a read-only root partition
  is required but the flag to indicate it was not set
  with this filesystem name
* Sat Apr  5 2014 ms@suse.de
- v5.06.68 released
* Sat Apr  5 2014 ms@suse.de
- Call fdasd with force option to allow to work with loop devices
* Fri Apr  4 2014 ms@suse.de
- return early with error from setStoragePartition if tool
  to create the partition table can't be found
* Fri Apr  4 2014 ms@suse.de
- v5.06.67 released
* Fri Apr  4 2014 ms@suse.de
- Fixed runtime check __hasBootLoaderTools
  check for grub2-bios-setup only if the firmare is set to: bios
* Fri Apr  4 2014 ms@suse.de
- Avoid use of fixed 512 byte blocksize (bnc #864285)
  * in order to just zero out some space where it does not
    matter if it's 512byte or more, use 4k instead. This is
    to stay compatible with 4k storage devices
  * in order to write the correct zipl.conf for targetbase
    and targetblocksize check for the real physical blocksize
    and don't assume 512byte
* Fri Apr  4 2014 ms@suse.de
- Allow the partitioner to also be set as part of the XML
  description (bnc #864285) Example:
  <preferences>
  <partitioner>parted|fdasd</partitioner>
  </preference>
* Fri Apr  4 2014 ms@suse.de
- v5.06.66 released
* Fri Apr  4 2014 ms@suse.de
- By accident the wicked package was added to 12.3 boot image
  descriptions, but wicked does not exist there
* Fri Apr  4 2014 ms@suse.de
- Be more clear on the error message displayed when there
  are not test cases defined for the given image type
* Thu Apr  3 2014 ms@suse.de
- Added better information about test results when calling
  os-autoinst tests. There is a json formatted results.json
  file which contains an overall test result information.
* Thu Apr  3 2014 ms@suse.de
- Update SLE12 and SLE11 JeOS os-autoinst tests
  * Added a needle for the console picture to match
  * Mark test as 'important' in the test flags section
* Thu Apr  3 2014 ms@suse.de
- v5.06.65 released
* Thu Apr  3 2014 ms@suse.de
- Fixed spec file arch flag for kiwi-desc-*boot packages
  Depending on which architecture the package is build the
  contents of the kiwi-desc-*boot packages differ. Thus they
  are not architecture independent
* Thu Apr  3 2014 ms@suse.de
- Added os-autoinst test case for SLE12 JeOS
  In addition update the test cases to the latest os-autoinst version
* Thu Apr  3 2014 adrian@suse.de
- support new directory of appdata for products when building in OBS 2.5
* Thu Apr  3 2014 Kanstantsin_Shautsou@epam.com
- Print epoch for .packages listing
* Thu Apr  3 2014 ms@suse.de
- In preparation of multipath support make sure the tools
  and libs are part of the initrd for SLES12 and SLES11
* Wed Apr  2 2014 ms@suse.de
- v5.06.64 released
* Tue Apr  1 2014 ms@suse.de
- Update SLE12 JeOS
  * use correct product name 'SLES'
  * use Minimal pattern
* Tue Apr  1 2014 ms@suse.de
- v5.06.63 released
* Mon Mar 31 2014 ms@suse.de
- Prefer switch_root over pivot_root
* Mon Mar 31 2014 ms@suse.de
- v5.06.62 released
* Mon Mar 31 2014 ms@suse.de
- UDEV_LOG env variable behaves differently between udev
  versions. Thus don't explicitly set it and take the default
* Mon Mar 31 2014 ms@suse.de
- Make sure sshd service is activated in SLE11 JeOS
* Mon Mar 31 2014 ms@suse.de
- Fixed SLE12 product detection in kiwi software analyser
* Mon Mar 31 2014 ms@suse.de
- Make setup of repotype an optional value:
  * the <repository> section is now allowed to be specified
    without a type attribute
  * the --set|add-repo commandline switches are now
    allowed to be specified without --set|add-repotype
    if zypper is used as package manager and no type is set for
    the repository the zypper auto detection is used. In case of
    any other package manager the default repository type rpm-md
    is used. An information about the selected type is printed if
    no type is explicitly set
    In a sequence of repositories added via commandline arguments
    using --add-repotype still requires to specify the type for
    all given repositories in order to be able to correctly
    assign the type to the added repository in the same way as
    this is required for alias and priority information
* Mon Mar 31 2014 ms@suse.de
- removed zypper version check from KIWIManagerZypper backend
* Fri Mar 28 2014 ms@suse.de
- v5.06.61 released
* Fri Mar 28 2014 ms@suse.de
- Fixed udevPending, make sure access to proc is granted
* Fri Mar 28 2014 ms@suse.de
- Make sure pidof command exists in preinit phase even if
  sysvinit-tools was not installed as part of the system
  image
* Fri Mar 28 2014 ms@suse.de
- Make sure pidof tool is part of the initrd. This tool is
  provided in sysvinit-tools thus had to fix the boot image
  descriptions for SLE12, openSUSE 13.2 and RHEL
* Fri Mar 28 2014 ms@suse.de
- Fixed start of udevd
  * prefer systemd-udevd if it exists
  * provide only one function to actually start the daemon
  * set UDEV_LOG level to info
* Fri Mar 28 2014 ms@suse.de
- Fixed startPlymouth to reset the console after plymouth
  has messed with it using console_init provided by udev
* Fri Mar 28 2014 ms@suse.de
- Don't unconditionally set splash=silent
  * this conflicts with a possible value set in the kernelcmdline attribute
  * splash=silent impacts 'plymouth show-splash' in SLE12 not showing
    any splash which is not the desired behavior
* Fri Mar 28 2014 ms@suse.de
- Added jenkins test script for testing OBS product results
* Fri Mar 28 2014 ms@suse.de
- Update jenkins tests
  * added information about possible execution parameters
  * make sure osc tool will be installed in prepare
* Thu Mar 27 2014 ms@suse.de
- Fixed jenkins/prepare.sh to be more robust with regards to
  local changes in the kiwi git checkout. basically the checkout
  is not meant for anybody to perform local modifications
* Thu Mar 27 2014 ms@suse.de
- Added overlayfs to be present in oemboot initrd
* Thu Mar 27 2014 ms@suse.de
- DB: rebuild documentation
* Thu Mar 27 2014 ms@suse.de
- Fixed documentation about displayname
* Thu Mar 27 2014 ms@suse.de
- Update RHEL JeOS
  * fixed repos for CentOS profile
  * Added Oracle profile
* Thu Mar 27 2014 ms@suse.de
- Update RHEL JeOS to newer version of yum-utils
* Mon Mar 24 2014 ms@suse.de
- v5.06.60 released
* Mon Mar 24 2014 ms@suse.de
- Fixed SLE12 JeOS image description
  * exactly state which release package should be installed
    I decided for sles-release-DVD
* Mon Mar 24 2014 ms@suse.de
- Don't waste too much time for waiting on link up.
  In addition wicked's dhcp client does that more efficiently
* Mon Mar 24 2014 ms@suse.de
- Fixed SLE12 JeOS template description
  * module-init-tools is not part of SLE12 media
  * release package is called sles-release
* Fri Mar 21 2014 ms@suse.de
- v5.06.59 released
* Fri Mar 21 2014 ms@suse.de
- Fixed spec file typo
* Fri Mar 21 2014 ms@suse.de
- v5.06.58 released
* Fri Mar 21 2014 ms@suse.de
- Fixed setupNetworkWicked
  * check for the exit code from wicked_dhcp4
  * use debug and --test-output options for calling wicked_dhcp4
  * add sleep between ip up and dhcp call
* Fri Mar 21 2014 ms@suse.de
- Follow up fix for creation of %%mysystems macro
  * Add some comments which explain why we build the macro that way
  * Restructure the conditions to be more readable
  * remove building %%mysystems macro for sle10
* Fri Mar 21 2014 ms@suse.de
- Support creation of install iso images > 4g
* Thu Mar 20 2014 ms@suse.de
- v5.06.57 released
* Thu Mar 20 2014 rjschwei@suse.com
- Allow newer versions of kiwi to be built in SUSE internal build service
  for older versions of SLE
  + SUSE internal build service does not define the sles_version macro, need
    to do ugly nexted if conditions. Luckyly we no longer build openSUSE
    versions that have the same version identifiers as older SLE versions
* Thu Mar 20 2014 ms@suse.de
- Fixed fixupOverlayFilesOwnership function
  The matching of files mentioned in passwd was broken
* Wed Mar 19 2014 ms@suse.de
- Fixed invalid conversion in printf call
* Wed Mar 19 2014 ms@suse.de
- Fixed block size used to check for boot sector code in the
  MBR after legacy grub has finished the installation
* Wed Mar 19 2014 ms@suse.de
- v5.06.56 released
* Wed Mar 19 2014 ms@suse.de
- Don't use Miscellanea::RequireRcsKeywords in perl critic
  This module is not provided with the current perl-Perl-Critic
  packages.
* Wed Mar 19 2014 ms@suse.de
- Reduce size of boot images for SLE12 and openSUSE 13.2
  * packages installed by requires python and dracut are not
    required inside the kiwi initrd on first boot
* Wed Mar 19 2014 ms@suse.de
- Display license(s) only if this was explicitly configured
  with <showlicense> statements in the XML description
* Tue Mar 18 2014 ms@suse.de
- Added jenkins test script for running build jobs
* Tue Mar 18 2014 ms@suse.de
- Update suse-13.2-JeOS template
  The same changes with regards to products and patterns like
  on SLE12 applies to this distribution as well
* Tue Mar 18 2014 ms@suse.de
- v5.06.55 released
* Tue Mar 18 2014 ms@suse.de
- Fixed use of <showlicense> support
  * the value was not correctly added to the .profile environment
  * In addition <showlicense> is often used in combination with
    the repository attribute prefer-license which downloads the
    license information and unpacks it below /etc/YaST2/licenses/base
    In order to let the displayEULA() function in the boot code find
    this files we had to extend the license search path
* Tue Mar 18 2014 ms@suse.de
- Simplify jenkins codebase job script
* Mon Mar 17 2014 ms@suse.de
- Update jenkins prepare worker script
  * install kiwi on worker to allow validation and building
* Mon Mar 17 2014 ms@suse.de
- Fixed Makefile
  * target 'valid' should return non zero exit code in error case
* Mon Mar 17 2014 ms@suse.de
- Fixed jenkins prepare worker script
  * typo in path name
* Mon Mar 17 2014 ms@suse.de
- Fixed jenkins prepare worker script
  * don't use relative path names, we don't know where we are
* Mon Mar 17 2014 ms@suse.de
- Fixed jenkins prepare worker script
  * make sure it exits with an error if there was an error
* Mon Mar 17 2014 ms@suse.de
- Fixed jenkins prepare worker script
  * path to git repo checkout was wrong for pull
* Mon Mar 17 2014 ms@suse.de
- Make sure jenkins/codebase.sh update the git before calling the job
* Mon Mar 17 2014 ms@suse.de
- Added jenkins scripts:
  * jenkins/prepare.sh: setup a worker
  * jenkins/codebase.sh: allow to call unit/validation
    and critic tests
* Mon Mar 17 2014 ms@suse.de
- v5.06.54 released
* Mon Mar 17 2014 adrian@suse.de
- patterns are handled via rpm dependencies now.
  drop the plugin to extract old suse-style patterns
* Mon Mar 17 2014 ms@suse.de
- Fixup KIWICollect.pm for coding style and code comments
  There is a lot more to do in this module to make the code
  more readable and understandable. Thus this is just a start
* Mon Mar 17 2014 ms@suse.de
- Provide more verbose warning message in __checkVMConverterExist
* Sun Mar 16 2014 ms@suse.de
- Removed clicfs from RHEL boot descriptions
  Switch to a split ext3+squashfs live iso type instead
* Sun Mar 16 2014 ms@suse.de
- Fixed rhel-06.0-JeOS template
  * allow easy overwrite via --set-repo of the RHEL distro repo
  * yum-priorities listed twice
* Sun Mar 16 2014 ms@suse.de
- Update SLE11 and RHEL6 JeOS templates to use same source
  pool from the Virtualization:/Appliances project
* Sun Mar 16 2014 magist3r@gmail.com
- Dramatically reduce creation time of persistent storage. Also disable journal and use ext4 instead of ext3 to enable unibit_bg option
* Sat Mar 15 2014 ms@suse.de
- Fixed spec file: directory /srv/tftpboot listed twice
* Sat Mar 15 2014 ms@suse.de
- Fixed spec file requires to be valid for rhel and fedora builds
* Fri Mar 14 2014 adrian@suse.de
- fix package names for subpackage containers
* Fri Mar 14 2014 adrian@suse.de
- use correct attribute for supportstatus
* Fri Mar 14 2014 adrian@suse.de
- fix missing space for channel file
* Fri Mar 14 2014 adrian@suse.de
- call create_sha1sum also when descrdir is not set
* Fri Mar 14 2014 ms@suse.de
- v5.06.53 released
* Fri Mar 14 2014 ms@suse.de
- Make sure empty directories still appear as directory node
  on the kiwi analyse report page
* Fri Mar 14 2014 ms@suse.de
- Fixed accounting of items in subtree at KIWIAnalyseSystem
* Fri Mar 14 2014 ms@suse.de
- Don't display a link to a non existing page on the report page
* Fri Mar 14 2014 ms@suse.de
- Added openssh to the suse-SLE12-JeOS template
* Fri Mar 14 2014 ms@suse.de
- Fixed product detection in kiwi --describe for SLE12
* Fri Mar 14 2014 ms@suse.de
- Fixed git check in kiwi --describe
* Fri Mar 14 2014 ms@suse.de
- The installation of patterns and products in SLE12 requires
  the use of zypper for SLE12. That's because the repository
  metadata has changed with regards to the product definition
  and in addition patterns are now provided as extra packages.
  In order to stay compatible the suse-SLE12-JeOS template
  adds the installation of the base pattern and the SLES
  product by installing the appropriate packages and includes
  a comment describing that the definition of <product> and
  <namedCollection> only works if the build host uses the
  SLE12 zypper
* Thu Mar 13 2014 adrian@suse.de
- skip createpackagedescr and package translations for empty DESCRDIR case
* Thu Mar 13 2014 adrian@suse.de
- skip createsha1sums and directory.yast creation if DESCRDIR is not set
* Thu Mar 13 2014 ms@suse.de
- added compatibility mode for EFI images on SLE11
  * SLE11 supports EFI only via the elilo bootloader with one
    exception which is secure boot. In that mode the grub2
    signed module is used and the functionality is hidden
    behind an elilo wrapper program so that all tools e.g yast
    doesn't have to really support grub2. In order to leave
    a SLES image in a supported state it was required to adapt
    to this layout in kiwi
* Thu Mar 13 2014 rjschwei@suse.com
- use cloud-init
  + cloud-init works for us now, we no longer need to depend on the acient
    sles-ami-tools scripts.
* Thu Mar 13 2014 ms@suse.de
- v5.06.52 released
* Thu Mar 13 2014 ms@suse.de
- Fixed handling of volume size if no size/freespace is set
  In this case a default freespace of 20MB applies
* Thu Mar 13 2014 ms@suse.de
- Added 'pvscsi' and 'lsisas1068' as allowed disk controller types
* Thu Mar 13 2014 ms@suse.de
- Don't set partition type if the default 0x83 type is requested
  In that case it's not needed to set a partition type because
  the parted default type is the same. In addition this workarounds
  the problem that the SUSE 'type' extension is no longer present
  in parted 3.x
* Thu Mar 13 2014 Kanstantsin_Shautsou@epam.com
- Don't force ovftool for ova.
* Wed Mar 12 2014 ms@suse.de
- Add wicked to isoboot boot descriptions for SLE12 and openSUSE 12.3
- Add wicked to oem|netboot descriptions for SLE12 on ppc and s390
* Wed Mar 12 2014 ms@suse.de
- Removed dhcpcd from isoboot descriptions. wicked is used instead
- Removed memtest86+ from isoboot descriptions. It's not on the media
  if you need memtest add it as bootinclude to the system image XML
  <package name="memtest86+" bootinclude="true"/>
* Wed Mar 12 2014 ms@suse.de
- Code cleanup, shorten long lines
* Wed Mar 12 2014 ms@suse.de
- Fixed use of efi suffix to control when linux/linuxefi and
  initrd/initrdefi commands are used in the grub.cfg file
* Wed Mar 12 2014 ms@suse.de
- Fixed grub2 core image creation
  Make sure we use the grub modules from the target distro
  and not the ones from the build host
* Wed Mar 12 2014 ms@suse.de
- Activate bootloader graphics for secure boot
* Wed Mar 12 2014 ms@suse.de
- Fixed grub2 legacy bios prefix setup
  If firmware is set to efi the prefix for the legacy bios
  grub.cfg was also set to the efi path which was wrong
* Wed Mar 12 2014 ms@suse.de
- Update suse-SLE12-JeOS image template
  Use EFI setup by default, kiwi uses parted's bios_grub flag to stay
  compatible with the legacy BIOS
* Wed Mar 12 2014 ms@suse.de
- Removed clicfs from boot descriptions for SLE12 and openSUSE 13.2
  With overlayfs there is a successor provided with the kernel. In
  order to use clicfs add the package with the bootinclude attribute
  as part of your system image description
* Wed Mar 12 2014 ms@suse.de
- Removed clicfs from boot images for ppc and s390
* Wed Mar 12 2014 ms@suse.de
- Update suse-SLE12-JeOS image template
  Update packages names for plymouth, grub2 and gfxboot branding packages
  Update theme name, for SLE12 it's 'SLE'
* Wed Mar 12 2014 ms@suse.de
- Added 'fs/isofs/*' to the boot image descriptions for SLE12
  and openSUSE 13.2. The kernel people decided to build ISO9660
  support as module now (bnc #867834)
* Wed Mar 12 2014 ms@suse.de
- Fixed netboot overlay setup code
  Make sure setupUnionFS is called if UNIONFS_CONFIG is set
  In addition correctly update the devices set in the variable
  by the setupUnionFS function and make sure unionFST has a
  value in all union modes
* Wed Mar 12 2014 ms@suse.de
- Removed master-boot-code to be a required package
  The mbr provided with this package is only used if kiwi is called
  with the --grub-chainload option and the concept also only works
  with legacy grub which is on its way to becoe obsolete
* Wed Mar 12 2014 ms@suse.de
- Fixed listImage() to print a message if no templates can be found
* Wed Mar 12 2014 ms@suse.de
- Cleanup/Improve usage output
  If you just call kiwi without any arguments you got the long
  usage list which is not very helpful. Thus this has changed
  to print a message what you could do next including a list
  of currently available templates
* Tue Mar 11 2014 ms@suse.de
- Removed unionfs-fuse from package list of netboot images
  because it's not part of the medias. If you need the support
  add the package in the system image XML as follows:
  <package name="unionfs-fuse" bootinclude="true"/>
* Tue Mar 11 2014 ms@suse.de
- Removed templates for rhel_5. Due to the latest move of RH
  with regards to CentOS we focus on supporting CentOS/RHEL
  starting with version 6
* Mon Mar 10 2014 ms@suse.de
- v5.06.51 released
* Mon Mar 10 2014 ms@suse.de
- Fixed spec file, use fdupes for SUSE only
* Mon Mar 10 2014 ms@suse.de
- Removed obsolete run-init tool from kiwi-tools
* Mon Mar 10 2014 ms@suse.de
- v5.06.50 released
* Mon Mar 10 2014 ms@suse.de
- Removed obsolete lxc requires (bnc #867394)
* Mon Mar 10 2014 ms@suse.de
- Update suse-SLE12-JeOS template
  * build UEFI capable image by default
  * build hybrid capable install image by default
  * activate SLES boot graphics for ISO type
* Mon Mar 10 2014 ms@suse.de
- Fixed indention and variable quoting in the functions
  baseStripAndKeep and baseStripTools of KIWIConfig.sh
* Mon Mar 10 2014 ms@suse.de
- Added gettext in RHEL boot image descriptions
* Mon Mar 10 2014 ms@suse.de
- Fixed build, make sure setctsid is provided in kiwi-tools
  for distributions which doesn't provide it
* Mon Mar 10 2014 ms@suse.de
- Fixed initrd creation tool call dracut vs. mkinitrd
  Merge the two function into one setupInitrd function and
  remove code duplication. Also prefer dracut if installed
* Mon Mar 10 2014 ms@suse.de
- v5.06.49 released
* Mon Mar 10 2014 ms@suse.de
- Removed obsolete comment from suse-SLE12-JeOS description
* Mon Mar 10 2014 ms@suse.de
- Fixed media collect code to match required perl critic level
  * don't define scope of variables more than once
  * return properly from functions
  * use FileHandle
* Mon Mar 10 2014 ms@suse.de
- Cleanup unit test code
  * remove obsolete ec2 tests
  * fix Common/ktTestCase.pm to include required perl unit test
    perl modules
* Mon Mar 10 2014 ms@suse.de
- Added 'make critic' target for kiwi which calls percritic on the
  code. This will be used as one test in the integration testing
  system we currently setup
* Sun Mar  9 2014 ms@suse.de
- Fixed createCustomDataForType in analyser code
  Don't ignore empty directories
- Added custom strip implementation in __stripCustomData which
  provides only the name of the directory if all data below this
  directory contains only custom files. Problem is that other
  types of data e.g repo checkouts might vanish from the report
  which is imho unwanted. Therefore the code is currently
  deactivated
* Fri Mar  7 2014 ms@suse.de
- v5.06.48 released
* Fri Mar  7 2014 adrian@suse.de
- support for user defined subdirs for susetag meta data
  written by Rudi
* Fri Mar  7 2014 adrian@suse.de
- support generation of support flags into channel files, if defined via .kwd file format
* Fri Mar  7 2014 ms@suse.de
- Fixed misleading error message in setupReadWrite (bnc #867174)
  The function uses 'mount' to test if the read-write location
  can be mounted. If not or RELOAD_IMAGE is set the read-write part
  is created from scratch and that action is logged accordingly.
  The possible error message from the mount call is a false positive
  information here and just makes people nervous :) Thus should
  not be logged
* Fri Mar  7 2014 adrian@suse.de
- support non-standard rpm directories for products
  Can be used to create pool channels without a suse/ subdirectory.
  Written by ro@suse.de
* Fri Mar  7 2014 ms@suse.de
- Fixed kiwi completion. Don't loose default completion
* Thu Mar  6 2014 ms@suse.de
- v5.06.47 released
* Thu Mar  6 2014 ms@suse.de
- Fixed getNicNames in kiwi boot code (bnc #867148)
  * The function should ignore the loopback nic 'lo'
  * The network code should not deal with any fixed interface
    name like 'eth0'
* Thu Mar  6 2014 ms@suse.de
- Make sure 'ip' and 'fuser' commands also exists for the
  boot descriptions for s390/ppc and arm architectures
* Thu Mar  6 2014 ms@suse.de
- Make sure package providing 'fuser' command is installed in
  all boot image descriptions
* Thu Mar  6 2014 ms@suse.de
- Make sure package providing 'ip' command is installed in
  all boot image descriptions because the code using the obsolete
  ifconfig tool has been replaced by using the 'ip' command
* Thu Mar  6 2014 adrian@suse.de
- create channel file templates for products
  This is replacing the .packages generation code since it is similar,
  but the channel files are better defined and structured.
* Thu Mar  6 2014 ms@suse.de
- Add check for EFI fat image on iso media in makeIsoEFIBootable
  If the EFI fat image already exists don't recreate it. When building
  product media the image is provided by the installation-images-*
  package thus no need to create the same thing again. Also add
  a loginfo entry in this case
* Thu Mar  6 2014 ms@suse.de
- Fixed typo in function call for addBootLive
  It does not receive a parameter
* Thu Mar  6 2014 ms@suse.de
- Allow Expand/Collapse of section in the kiwi --describe report page
* Wed Mar  5 2014 ms@suse.de
- v5.06.46 released
* Wed Mar  5 2014 coolo@suse.de
- Skip invalid appdata files in KIWICollect
  For this we parse the XML and if it succeeds, we rewind and continue concat
  the XML snippets
* Wed Mar  5 2014 ms@suse.de
- v5.06.45 released
* Wed Mar  5 2014 ms@suse.de
- Make sure GATEWAYS information from the wicked dhcp request
  is used to update the default route accordingly
* Tue Mar  4 2014 ms@suse.de
- Added bash completion script
  * completes all long commandline options
  * completes option values for --build|--prepare and --type
* Tue Mar  4 2014 ms@suse.de
- Cleanup options list format
  long option first, short option next, option constraint last
* Tue Mar  4 2014 adrian@suse.de
- support appdata rpmmd repos
- skip sqlite databases in rpmmd
- default to sha256 checksums
* Tue Mar  4 2014 adrian@suse.de
- support creation of repoid tags inside of rpmmd repos
- sync 13.2 code base with SLE 12
* Tue Mar  4 2014 ms@suse.de
- Fixed use of add-repoprio and add-repoalias options
  If either a repository priority or alias is specified on the
  commandline it must be specified for all added repositories
  in order to make clear for which repository the parameters
  should apply (bnc #865230)
* Tue Mar  4 2014 ms@suse.de
- v5.06.44 released
* Tue Mar  4 2014 ms@suse.de
- Update SLE12 JeOS template
  There is still no product definition in the DVD repo
* Tue Mar  4 2014 ms@suse.de
- Fixed use of uninitialized value $logdata
  If there is an undefined value passed as log data we should
  no do anything with it. In addition fixed a typo for the
  subsequent error message, missing newline
* Tue Mar  4 2014 dvaleev@suse.com
- GRUB2 binary got renamed to fit HFS 8.3
  We should have grub2 binary compatible with HFS's 8.3 format
  Signed-off-by: Dinar Valeev <dvaleev@suse.com>
* Tue Mar  4 2014 dvaleev@suse.com
- Adapt to ppc media layout change
  Media layout for ppc now looks like media layout on other arches
  Signed-off-by: Dinar Valeev <dvaleev@suse.com>
* Tue Mar  4 2014 ms@suse.de
- Fixed order of fstab entries created by updateBootDeviceFstab
  If /boot/efi is first it will be covered by /boot. Thus the
  order must be /boot first and /boot/efi second
* Mon Mar  3 2014 ms@suse.de
- fixed typo in kiwi-media-requires recommends list 'K' vs 'k'
* Mon Mar  3 2014 ms@suse.de
- v5.06.43 released
* Mon Mar  3 2014 ms@suse.de
- Revert "- the controller type 'scsi' does not exist for VMware"
  This reverts commit 78077282df830e1f7d7b4e47f0953246186cca15
  I did something stupid here and changed the key name of the
  config file which makes the config file invalid
* Mon Mar  3 2014 ms@suse.de
- Make git a recommended package in the spec file
  Modularize analyser code to work with and without git
* Mon Mar  3 2014 ms@suse.de
- Fixed suseGFXBoot graphics boot setup with gfxboot-devel
  Because of the change which uses isolinux as loader for install
  ISO media and not the configured disk bootloader as eltorito
  alternative loader we need both boot graphics formats available
  the one for isolinux as well as the one for the selected system
  bootloader. The code in suseGFXBoot reflects this for the
  boot graphics provided by packages but not if the user provides
  a custom tarball for use with gfxboot-devel
* Mon Mar  3 2014 ms@suse.de
- Fixed misleading function names
  getInstallFailsafe -> getInstallProvideFailsafe
  setInstallFailsafe -> setInstallProvideFailsafe
  This is all about if a failsafe menu entry should be provided
  to the image boot configuration or not. Thus the function
  names should describe this and not lead to the assumption
  that one can select the failsafe entry from the boot menu
  which is actually done by the installboot="failsafe-install"
  attribute
* Mon Mar  3 2014 ms@suse.de
- the controller type 'scsi' does not exist for VMware
  lsilogic and buslogic define scsi controllers. Thus
  use lsilogic as the default scsi controller
* Sat Mar  1 2014 Kanstantsin_Shautsou@epam.com
- Fix installiso for oem image type.
* Fri Feb 28 2014 ms@suse.de
- v5.06.42 released
* Thu Feb 27 2014 ms@suse.de
- Fixed createS390CDLoader() for s390 media creator
  The s390 loader file cd.ikr was created on demand but the new
  installation-images packages provide this file. Thus there is
  no reason to create it if it already exists
* Thu Feb 27 2014 ms@suse.de
- Fixed custom files analyser
  More intuitive and not only directory based level 1 search in /
  Fix for rpm directory strip, expression would match e.g /emil
  in the same way as /emil1 which is wrong
* Thu Feb 27 2014 ms@suse.de
- v5.06.41 released
* Thu Feb 27 2014 ms@suse.de
- Fixed build for ppc and s390
  Accidentally leaving broken links in the vmxboot descriptions
* Thu Feb 27 2014 ms@suse.de
- v5.06.40 released
* Thu Feb 27 2014 ms@suse.de
- Fixed spec file
  kiwi-tools should specify the %%{_defaultdocdir}/kiwi as a directory
  entry otherwise we might end up with the directory not belonging to
  any package but files inside do belong to a package
* Thu Feb 27 2014 ms@suse.de
- Fixed setupNetworkWicked
  Use bin/wickedd-dhcp4 instead of the mainstream wicked program
  wicked relies on dbus which is not helpful within an initrd
  environment. Fortunately there is the wickedd-dhcp4 helper which
  just asks for the lease from the DHCP. The setup of the network
  interface and routing is then done by setupNetworkWicked but will
  change in the future if wicked becomes more mature
* Wed Feb 26 2014 ms@suse.de
- Make sure ip command is part of the oem and netboot image
  descriptions starting with openSUSE 13.2 and SLE12. Instead
  ifconfig is no longer part of these descriptions
* Wed Feb 26 2014 ms@suse.de
- Make sure wicked is part of the oem and netboot image
  descriptions starting with openSUSE 13.2 and SLE12
* Wed Feb 26 2014 ms@suse.de
- Added SLES12 boot image descriptions for s390 and ppc
* Wed Feb 26 2014 ms@suse.de
- Update netboot/suse-SLES12 boot image descriptions
  Package nbd does not exist on SLES12
* Wed Feb 26 2014 ms@suse.de
- Added command call information into kiwi log
* Wed Feb 26 2014 ms@suse.de
- Fixed spec file
  * Summary is first line after %%package
  * Summary texts more clear and not specific to openSUSE
  * Update recommended list of packages for kiwi-media-requires
  * Correct url for submitting issues
* Tue Feb 25 2014 ms@suse.de
- KIWILinuxRC boot code fixes
  * Added support for setting up the network with wicked
    Used by the PXE boot code in kiwi: setupNetworkWicked
  * Eliminate the use of ifconfig in the boot code. write
    functions based on ip instead
* Tue Feb 25 2014 ms@suse.de
- Update unit tests to work with new schema version
* Tue Feb 25 2014 ms@suse.de
- Update all templates and examples to new schema version
* Tue Feb 25 2014 ms@suse.de
- Update schema version from 6.0 to 6.1
  * added xslt stylesheet auto updating the schema version
  * added xslt stylesheet auto updating opensuseProduct to
    product section
* Tue Feb 25 2014 ms@suse.de
- Rename misleading <opensuseProduct> to <product> section
  Something like <opensuseProduct name="SUSE_SLES"/> was weird
* Tue Feb 25 2014 ms@suse.de
- Fixed spec file recommends
  db45-utils and db48-utils should be recommended in a row
* Tue Feb 25 2014 ms@suse.de
- Update list of recommended packages in spec file
  Problem here is that by default SUSE installs with recommended
  packages which in case of kiwi will cause a huge workload
  because e.g the recommended jing package pulls the entire
  java stack. Because of that the list of recommends has been
  reduced
* Tue Feb 25 2014 ms@suse.de
- Added virt-utils requires for kiwi-instsource package
  qemu-img is used for building products (bnc #865242)
* Tue Feb 25 2014 ms@suse.de
- Fixed call of file search method used with grub2
* Mon Feb 24 2014 ms@suse.de
- v5.06.39 released
* Mon Feb 24 2014 ms@suse.de
- Make sure makeIsoEFIBootable is called in the SUSE/SLE
  installation media creator aka: KIWICollect (bnc #865242)
* Mon Feb 24 2014 ms@suse.de
- Follow up fix for makeIsoEFIBootable (bnc #865242)
  Architecture string was not correctly validated
* Mon Feb 24 2014 ms@suse.de
- Moved creation of isolinux efi fat image into its own
  function KIWIIsoLinux::makeIsoEFIBootable() and reduce
  code duplication. Related to (bnc #865242)
* Mon Feb 24 2014 ms@suse.de
- v5.06.38 released
* Mon Feb 24 2014 ms@suse.de
- Update netboot boot descriptions for 13.1 and 13.2
  Added unionfs-fuse package by default (bnc #865229)
* Mon Feb 24 2014 ms@suse.de
- Allow to use --add-package option also when building boot
  images. This is related to (bnc #865229)
* Mon Feb 24 2014 ms@suse.de
- DB: rebuild documentation
* Mon Feb 24 2014 ms@suse.de
- DB: update NBD documentation (bnc #865237)
  NBD has changed their negotiation style from port to name based
* Mon Feb 24 2014 ms@suse.de
- Fixed nbd-client invocation in netboot (bnc #865237)
  nbd has changed it's negotiation style from port based server to
  name based exports. Thus the client has to connect to an export
  name and not a port the server listens to
  Example NBD server config:
  [generic]
  user  = root
  group = root
  [export1]
  exportname = /some/file
  Example NBD localhost test:
  nbd-server -C config-file
  nbd-client -N export1 localhost /dev/nbd0
* Sun Feb 23 2014 ms@suse.de
- make sure overlayfs and ext4 are part of the netboot boot
  image descriptions for 13.1/13.2 SLED12/SLES12 (bnc #865229)
* Sun Feb 23 2014 ms@suse.de
- Follow up patch for commit (bnc #865229)
  The copy of the initrd to /run/initramfs has to skip the special
  paths used for overlay filesystems
* Sat Feb 22 2014 ms@suse.de
- Follow up patch for last commit (bnc #865229)
  Call resetBootBind only if NETBOOT_ONLY is _not_ set
* Sat Feb 22 2014 ms@suse.de
- Fixed setupBootPartitionPXE
  in a NFSROOT setup the variable imageRootDevice is not empty but
  does not point to a real local device, it points to an nfs root
  mountpoint. Thus we need to leave the function early because
  setting up a boot partition doesn't make any sense (bnc #865229)
* Fri Feb 21 2014 ms@suse.de
- Fixed kiwi --info
  * if there are solver problems, display the error information
  * added object destructor to cleanup repo loop mounts
  * exit with error if requested information can't be delivered
* Fri Feb 21 2014 ms@suse.de
- v5.06.37 released
* Fri Feb 21 2014 ms@suse.de
- Fixed creation of custom.files
  * target directory was not set correctly
* Fri Feb 21 2014 ms@suse.de
- v5.06.36 released
* Fri Feb 21 2014 ms@suse.de
- Fixed spec file requires and recommends
  * lxc doesn't need to be recommended because the plain building task
    does not require lxc to be around
  * clicfs has a successor with overlayfs and should no longer be
    recommended
  * lvm2, squashfs and master-boot-code are relevant requires for
    building disk based images. Thus they are needed along with
    the kiwi-desc-vmx|oemboot sub-packages but not with the kiwi
    base package
* Fri Feb 21 2014 ms@suse.de
- Compatibility fix for the 'git init' call
  older versions of git do not accept a directory as parameter
  like the version we have in SLE11
* Fri Feb 21 2014 ms@suse.de
- v5.06.35 released
* Fri Feb 21 2014 ms@suse.de
- Fixed writeXML
  * The creation of the package items should use the native
    XML methods and not directly hook into the internal data
    structure
* Fri Feb 21 2014 ms@suse.de
- Removed code reducing a package list to the minimum required
  solver list. The result is correct but it takes long if many
  packages are installed and the result is not uniq
* Fri Feb 21 2014 ms@suse.de
- v5.06.34 released
* Fri Feb 21 2014 ms@suse.de
- Fixed creation of kiwi template description in kiwi --describe
  * use a fixed bootstrap section as default to avoid solver problems
    when building a new system from scratch
  * add analysed packages and patterns to the image section and not
    to bootstrap so that they will be installed by the native installer
    inside the chroot
  * instead of adding items to a delete section add them as ignore
    this will make use of the zypper al feature and is the better
    approach
* Fri Feb 21 2014 ms@suse.de
- Fixed capability check for old satsolver perl binding
* Fri Feb 21 2014 ms@suse.de
- v5.06.33 released
* Fri Feb 21 2014 ms@suse.de
- Added git clone url to the result of kiwi --describe
  * also added a function getIPAddress which is used for the
    clone url as well as for the custom files sync script
* Fri Feb 21 2014 ms@suse.de
- Fixed return value for getHardwareDependantPackages
  if no such packages was found the function should return undef
  instead of a pointer to an empty data structure
* Fri Feb 21 2014 ms@suse.de
- Fixed udev rule for suse-SLE12-JeOS lan0 nic name
  the match for KERNEL was still based on eth*
* Wed Feb 19 2014 ms@suse.de
- v5.06.32 released
* Wed Feb 19 2014 ms@suse.de
- Added lan0 persistent nic interface name based on a udev rule
  and a dhcp interface configuration for it to the SLE12
  JeOS template
* Tue Feb 18 2014 ms@suse.de
- Fixed calculation of rest items on a leaf
* Tue Feb 18 2014 ms@suse.de
- Flag hidden directories as 'hidden-directory', hidden
  file as 'hidden-file' and a file in a hidden directory
  as 'file-in-hidden-path'
* Tue Feb 18 2014 ms@suse.de
- Make max_child an argument to createCustomDataForType
  Set max_child to 5 items for the big text files view but
  don't set a limit for binaries and modified files
* Tue Feb 18 2014 ms@suse.de
- Added wicked as package for SLE12 JeOS
* Tue Feb 18 2014 ms@suse.de
- Fixed report page, not all views got a hyper link
* Tue Feb 18 2014 ms@suse.de
- Changed the way how custom files are populated in kiwi --describe
  * Formerly this was done by creating a hard linked list below
    a directory called custom/ But this has bad effects e.g on
    programs checking how many hardlinks exist on a config file
    like it is done by e.g postfix. Thus we now store a file
    custom.files instead of an entire tree containing all custom
    files as input to an auto generated rsync script custom.sync
    On the report page the script is described and the user can
    now either sync all of its custom files which is in most cases
    not wanted or adapt the custom.files prio to the sync.
    Later there might also be a more convenient way to fiddle
    with custom.files
* Tue Feb 18 2014 ms@suse.de
- Stop D3 displayed items at max_child = 5 and display the
  information how many more items exists
* Mon Feb 17 2014 ms@suse.de
- Make sure to canonical encode the perl hash to json
* Mon Feb 17 2014 ms@suse.de
- Fixed typos in analyser code
  * git user.email instead if user.mail
  * don't forgot to close open file descriptor
* Mon Feb 17 2014 ms@suse.de
- Make sure analysis report page builds the menu in
  the correct sort order
* Mon Feb 17 2014 ms@suse.de
- Make sure RPM modified files get their own D3 report and
  land as custom files in the custom directory
* Mon Feb 17 2014 ms@suse.de
- Fixed setup of git repo for analysis report
  * transaction commit was not done after successful analysis
  * git user and email were missing
* Mon Feb 17 2014 ms@suse.de
- Added warning message if no repos are configured on the
  analysed machine when using kiwi -describe
* Mon Feb 17 2014 ms@suse.de
- Fixed use of uninitialized values in analyser code
* Mon Feb 17 2014 ms@suse.de
- Added SLE12 as target for the kiwi system analyser
* Mon Feb 17 2014 ms@suse.de
- Update SLE12 JeOS image description
  Fixed a type referencing an openSUSE branding package
* Fri Feb 14 2014 ms@suse.de
- v5.06.31 released
* Fri Feb 14 2014 ms@suse.de
- Fixed call of distro initrd tool
  * don't rely on run-init helper program, does not exist with
    dracut and therefore not on SLE12 or RHEL
  * add generic setupInitrd function which checks for either
    dracut or mkinitrd and prefers dracut if present
* Fri Feb 14 2014 ms@suse.de
- Fix suse-SLE12-JeOS description to work fur current Alpha Release
  * Patterns are broken at the moment. They contain packages not part
    of SLE12 at the moment, e.g yast2-mouse. Thus comment out use of
    base pattern for the moment
  * There are no SLES12 branding packages available. Thus comment out
    grub2 and plymouth branding
* Thu Feb 13 2014 ms@suse.de
- Improve searching for custom files
  Make the code more readable, also skip proc/devpts/sysfs filesystems
  Along with that search in junks and make sure the xargs limit is not
  exceeded. Also reduce the list of searched directories with regards
  to the recursive search done by find
* Wed Feb 12 2014 ms@suse.de
- Fixed use of config-yast-autoyast.xml
  If this file is present in the kiwi configuration directory, kiwi
  setup an environment which activates the call of autoyast on first
  boot. The file install.inf controlls this environment. With this
  patch the parameter 'Textmode' will be set to '0' which activates
  the start of yast on a X-Server and falls back to ncurses mode if
  no X-Server can be started
* Wed Feb 12 2014 dvaleev@suse.com
- Bless grub2 binary for pmac
  Signed-off-by: Dinar Valeev <dvaleev@suse.com>
* Tue Feb 11 2014 ms@suse.de
- Make sure xfs_db is not deleted from initrd
* Mon Feb 10 2014 ms@suse.de
- v5.06.30 released
* Mon Feb 10 2014 ms@suse.de
- Incorporate KIWICollect patch by ro@suse.de
  downgrade isohybrid error to warning, this does not work
  on all architectures
* Mon Feb 10 2014 ms@suse.de
- v5.06.29 released
* Fri Feb  7 2014 adrian@suse.de
- handled the very special SLE 12 case for requires
* Fri Feb  7 2014 ms@suse.de
- v5.06.28 released
* Fri Feb  7 2014 ms@suse.de
- DB: rebuild schema documentation
* Fri Feb  7 2014 ms@suse.de
- DB: rebuild documentation
* Fri Feb  7 2014 ms@suse.de
- v5.06.27 released
* Fri Feb  7 2014 ms@suse.de
- Fixed spec file
  KIWIIsoLinux-AppleFileMapping.txt was moved
* Fri Feb  7 2014 ms@suse.de
- v5.06.26 released
* Fri Feb  7 2014 ms@suse.de
- Moved KIWIIsoLinux-AppleFileMapping.txt to metadata directory
  In addition change the prefix to .map
* Fri Feb  7 2014 ms@suse.de
- Present custom files view links in a table
* Fri Feb  7 2014 ms@suse.de
- Fixed .changelog helper tool
  don't include conflict and merge commits
* Thu Feb  6 2014 Kanstantsin_Shautsou@epam.com
- Print user/group IDs.
* Wed Feb  5 2014 ms@suse.de
- Added preCallInit hook call to netboot boot image descriptions
  This hook already existed in oem and vmx boot images and was
  still not added to netboot
* Tue Feb  4 2014 ms@suse.de
- Added __checkYaSTenvironment() runtime check
  With this check kiwi searches the given package list for entries
  starting with 'yast2' in order to make sure the user has at least
  added one yast client module if either the use of autoyast or the
  yast2 firstboot service was requested as part of the image
  description. It has turned out that people using autoyast in
  kiwi often forget to add the required YaST client packages. This
  check cannot make sure that the autoyast profile works correctly,
  it also does not know which client packages are required but it
  at least gives a hint if no yast stack is installed
* Tue Feb  4 2014 ms@suse.de
- Fixed JeOS image descriptions
  Added a function suseRemoveYaST which removes the yast packages
  if they are not needed by e.g autoyast or firstboot service.
  Replaced the unconditional remove of yast packages in all
  JeOS config.sh scripts by the new function
* Tue Feb  4 2014 ms@suse.de
- Implementation of new analyser code.
  Refactor the existing code to run faster and removed unused
  analyser code. In addition some tasks are done by shell scripts
  with regards to be able to use the same code in the Alfred
  project
* Fri Jan 31 2014 ms@suse.de
- don't limit suseInsertService to .service suffix for systemd
  * The service file is now searched in several directories and
    as suffix .system and .mount is allowed
* Fri Jan 31 2014 ms@suse.de
- v5.06.25 released
* Fri Jan 31 2014 ms@suse.de
- fixed setupNetwork() function
  in order to assign a network interface according to the BOOTIF MAC
  address information kiwi searches through a list of mac addresses
  and if found assigns the appropriate interface. This search was
  broken because the MAC from BOOTIF is lowercase whereas the mac
  list contains upper case data. Thus the mac list data is turned
  into lowercase to allow a correct matching
* Fri Jan 31 2014 ms@suse.de
- Make sure image is filled with random data prior to
  the creation of a luksFormat on it
* Fri Jan 31 2014 ms@suse.de
- Added __hasBootLoaderTools runtime check
  With this check we test if the tool chain to install the requested
  bootloader is installed on the image build machine
* Fri Jan 31 2014 ms@suse.de
- added type attribute <type ... luksOS="distribution"/>
  This attribute allows to select a specific set of options passed
  to the cryptsetup call in order to create a consistent luks format
  supported by the capabilities of the selected distribution.
  With this commit luksOS="sle11" will be supported
* Fri Jan 31 2014 Kanstantsin_Shautsou@epam.com
- Added fedora deps.
* Thu Jan 30 2014 ms@suse.de
- v5.06.24 released
* Wed Jan 29 2014 ms@suse.de
- KIWIAnalyseTemplate
  * use single quotes for URL and Alias when setting up repos in
    the auto generated config.sh template. This is needed if the
    URL uses special characters which are evaluated in the shell
* Wed Jan 29 2014 ms@suse.de
- KIWIAnalyseManagedSoftware
  * added analyser for packages to become deleted. when inspecting the
    system the code now also compares the result of the solved required
    packages list with the currently installed packages. packages
    required by the solver but not installed are treated as unwanted
    and put into a delete typed packages section
* Tue Jan 28 2014 ms@suse.de
- Remove desktop profile from SLE12 boot image descriptions (bnc #860792)
  * SLES12 will not provide a kernel-desktop package
* Tue Jan 28 2014 ms@suse.de
- Fixed volume setup
  * make sure non existing mount point directories are created
  * allow the volume name .snapshot(s) to be a valid name
* Tue Jan 28 2014 ms@suse.de
- Added __checkHaveTypeToBuild runtime check
  With this check the presence and selection of a build type is checked
* Tue Jan 28 2014 ms@suse.de
- Added __checkCorrectRootFSPermissons runtime check
  With this check kiwi validates the consistency of the created
  unpacked root tree while calling the create step. Consistency
  means a number of LSB toplevel directories is checked for
  their correct root/root owner and group name. Recently people
  using NFS or ZFS as image target directory ran into the problem
  that the filesystem stores files under the nobody user identity
  even if the caller was root. The result is a completely broken
  system which should be prevented by this runtime check
* Mon Jan 27 2014 rjschwei@suse.com
- generate "scsi" as the device type prefix for all controllers except for ide
  in the .vmx file
* Mon Jan 27 2014 rjschwei@suse.com
- support a boottimeout value of 0
  + at present we checked for boottimeout value to evaluate to true, but in
    Perl the string "0" evaluates to false although the string is not empty,
    thus the truth test failed an we used the default of 10
* Fri Jan 24 2014 ms@suse.de
- v5.06.23 released
* Fri Jan 24 2014 ms@suse.de
- Fixed GRUB_TIMEOUT setup in etc/default/grub
  the kiwi boot code did not hand over the value from the XML space
  to the appropriate grub config file so that grub2-mkconfig did
  not incorporate the value
* Fri Jan 24 2014 ms@suse.de
- Fixed invocation of oemboot::postImageDump hook script
  The hook should be called in any case no matter which other
  oem install options are defined
* Fri Jan 24 2014 rjschwei@suse.com
- ec2 example for 13.1
  + forgot to commit this with the doc changes in 87b49253440eda
* Thu Jan 23 2014 ms@suse.de
- v5.06.22 released
* Thu Jan 23 2014 ms@suse.de
- make sure /var/cache/kiwi/satsolver exists when running a
  solver job
* Thu Jan 23 2014 ms@suse.de
- Fixed spec file, cleanup and update package descriptions
* Thu Jan 23 2014 ms@suse.de
- Fixed spec file, cleanup obsolete build requires
* Thu Jan 23 2014 ms@suse.de
- Fixed spec, starting with openSUSE 12.1 libsolv is used
* Thu Jan 23 2014 ms@suse.de
- Fixed spec file, the perl requirement should not be strictly
  set on a specific perl version, >= the distro version is more
  accurate
* Thu Jan 23 2014 ms@suse.de
- Fixed spec file, db45-utils should be a generic recommendation
* Thu Jan 23 2014 ms@suse.de
- Fixed spec file, squashfs exists on all supported versions
  no suse_version check needed anymore
* Thu Jan 23 2014 ms@suse.de
- Fixed spec file, clicfs is not a requirement
* Thu Jan 23 2014 ms@suse.de
- Added libsolv support to KIWISatSolver
  The class supports libsatsolver and libsolv, if libsolv is present
  it is preferred because it's the successor of libsatsolver
* Wed Jan 22 2014 ms@suse.de
- restructure KIWISatSolver class
  In preparation to support libsolv the satsolver class has been
  redesigned to work with both the libsatsolver and the libsolv
  implementations. Support for libsolv will follow soon
* Wed Jan 22 2014 ms@suse.de
- fixed use of system installed solvables in KIWIAnalyseManagedSoftware
  * instead of reading all existing solv files in /var/cache/zypp we
    only use those which are enabled in the zypper repo list
* Wed Jan 22 2014 adrian@suse.de
- add new mediastyles openSUSE 13.2 and SLE 12 to support handling of cpeid tags
* Wed Jan 22 2014 ms@suse.de
- fixed typo in suse-12.3-JeOS/config.xml
  * accidentally committed an attribute change which was only meant
    to test a runtime check
* Wed Jan 22 2014 ms@suse.de
- some changes to the arm suse-13.2-JeOS template and code
  * currently suse-13.2-JeOS contains only a profile for raspberry
  * the vboot support uses no gpt if the berryboot loader is set
  * vboot + berryboot creates a boot setup which let the standard
    raspberry loader chainload our uboot which then loads the
    kernel and initrd from a linux ext2 second partition
* Wed Jan 22 2014 ms@suse.de
- DB: rebuild documentation
  * updates EC2 chapter, kiwi uses disk images instead of flat
    filesystem images now to support EC2
* Wed Jan 22 2014 ms@suse.de
- Fixed docbook syntax for changes recently done in kiwi-doc-ec2.xml
* Wed Jan 22 2014 ms@suse.de
- Fixed KIWISatSolver to work with new solvables
  Unfortunately I was told that the current solver bindings provided
  with the perl-satsolver package will no longer be maintained. Instead
  there will be a new lib and package called libsolv. kiwi needs to
  adapt to the bindings for libsolv in order to stay compatible with
  the solver results of the zypper package manager. At the moment the
  problem of the new "self-conflict" feature could be solved by
  setting set_allow_self_conflicts in the old satsolver library,
  which is what this patch does. For the future we need to support
  libsolv though
* Tue Jan 21 2014 rjschwei@suse.com
- final touches for EC2 changes
  + let kiwi add root= to the kernel command line for EC2 images
    this is needed to get the drivers to load properly
  + consider installfailsafe setting for grub vmx images
* Tue Jan 21 2014 rjschwei@suse.com
- update the documentation for the EC2 image build
  + document new commands to use for uploading images aws-cli vs ec2-*
    commands
  + changes due to the new way of building images
- we no longer create the bundle in kiwi
  _ adjust for removed XML elements
- update the examples to reflect the new type element setup for EC2
* Tue Jan 21 2014 rjschwei@suse.com
- fix spelling EC2 not Ec2
* Tue Jan 21 2014 ms@suse.de
- follow up fix for KIWIGlobals::mount() method
  let the check for disk or filesystem also work if blkid does
  not support PTTYPE detection. In this case we assume a disk if
  we don't get any blkid information. Older versions of blkid
  don't support partition table type detection
* Tue Jan 21 2014 ms@suse.de
- Fixed vmx type definition for EC2 usage in all templates
  * use ec2 and ec2k boot and kernel profiles
* Tue Jan 21 2014 ms@suse.de
- Update oem/vmx boot image descriptions to allow selecting
  an ec2 setup profile and an ec2 kernel profile
* Tue Jan 21 2014 ms@suse.de
- Support creation of install CD images for Xen dom0 oem type
* Tue Jan 21 2014 ms@suse.de
- Fixed KIWIGlobals::mount() method
  The detection for a disk device is now done by checking for PTTYPE using blkid
* Mon Jan 20 2014 ms@suse.de
- Fixed typo, missing result flag
* Mon Jan 20 2014 rjschwei@suse.com
- Change the way we create an EC2 image
  + Previously we created an EC2 image as a flat filesystem image
    this requred some special codeing and we ended up calling mkinitrd
    from within kiwi. As mkinitrd evolved to require a live root filesystem
    and with the impending move to dracut we need to start using a kiwi
    generated initrd. Therefore, EC2 image will now be created as disk
    images just like other vmx images. We also drop the use of the
    external ec2-ami-tools. Creating abundle is relatively easy and this
    functionality requires people to add thei EC2 credentials to the config
    file. That makes it easy to accidentally share private information.
  + Remove XML elemnts ec2config and its children
    ec2accountnr, ec2certfile, ec2privatekeyfile, ec2region
  + Introduce "ec2" as a firmware option
    we need this to set the partition table to be gpt instead of msdos
  + Print an error message for format="ec2" during XML validation
    we maintain format="ec2" in the schema for now to allow us to generate
    a more sensible error message than the parser would. This is an
    incompatible schema change
  + Remove EC2 region check in Validator
  + Remove KIWIEC2Region.txt
  + Update unit tests
  + Properly pass the boottimeout setting to the initrd config
  + Remove the XMLEC2Data object and its unit tests
  + Remove special code for EC2 initrd creation calling mkinitrd
* Mon Jan 20 2014 ms@suse.de
- Fixed ec2 kernel profile for 13.1/13.2 and SLE11/12
  the required xen drivers were not added when using ec2 profile
  the xen package must not be installed when using ec2 profile
* Mon Jan 20 2014 ms@suse.de
- added ec2Flavour profile to create EC2 VMX disk image types along
  with this change the examples using format="ec2" were adapted to
  disk layout instead of flat (filesystem) layout too
* Mon Jan 20 2014 ms@suse.de
- Fixed spec file
  Provide a better and more detailed description about the
  use and scope of the kiwi-tools sub-package
* Mon Jan 20 2014 ms@suse.de
- Follup fix for suse-13.2 arm JeOS image template, again repo setup
* Mon Jan 20 2014 ms@suse.de
- Fixed suse-13.2 arm JeOS image template, repository setup
* Fri Jan 17 2014 ms@suse.de
- v5.06.21 released
* Fri Jan 17 2014 ms@suse.de
- Fixed typo in output message, wrong indention
* Fri Jan 17 2014 ms@suse.de
- Fixed call of setBuildType in KIWIBoot
  Do this only if a system image/directory is passed to the object
* Fri Jan 17 2014 ms@suse.de
- Print information about which kernel is extracted from the initrd
* Fri Jan 17 2014 ms@suse.de
- Changed SLES/SLED boot image descriptions to install all packages
  in one host zypper controlled bootstrap step. This allows using
  these descriptions also with older SLES products which provides
  a not supported zypper version
* Fri Jan 17 2014 ms@suse.de
- fixed misleading error message when mapping the kernel file name
  to a common name. If a file with this name alredy exists we print
  an error but there is no error.
* Fri Jan 17 2014 ms@suse.de
- Update template/armv7l/suse-13.2-JeOS
  * fix source path for Factory ARM, remove obsolete driver data
* Thu Jan 16 2014 ms@suse.de
- v5.06.20 released
* Thu Jan 16 2014 ms@suse.de
- Fixed use of new KIWIFilesystemOptions object
  There were still references using fsopts as array and not
  object reference
* Thu Jan 16 2014 ms@suse.de
- v5.06.19 released
* Thu Jan 16 2014 ms@suse.de
- handle packages marked as bootincluded in the bootstrap phase
  of the image build and not in the image phase.
* Thu Jan 16 2014 ms@suse.de
- Update arm JeOS image descriptions
* Wed Jan 15 2014 ms@suse.de
- Fixed labels configured in isolinux.msg
  The isolinux.msg is the text file displayed if no graphics theme
  could be displayed in the isolinux bootloader. In that message
  file the label "Boot from Hard Disk" was missing
* Wed Jan 15 2014 ms@suse.de
- KIWIManagerZypper, allow package locks
  Using an ignore statement in the <packages> section like this
  <ignore name="some-package"/>
  did not had an effect because kiwi did not set a zypper add lock
  on the specified items. This patch now takes care for the ignore
  setup and allows to prevent the installation of packages even
  if zypper would have selected them. If a hard required package
  e.g glibc is set to become ignored this of course will cause a
  non solvable conflict and the process exits with an error
* Wed Jan 15 2014 ms@suse.de
- Added install ISO compatibility link for non standard EFI firmware
  EFI/Boot -> EFI/BOOT
* Wed Jan 15 2014 ms@suse.de
- Fixed grub2 prefix setup in grub.cfg. if $root is changed by a
  search it's important to update the prefix accordingly
- Fixed grub2-bios-setup call
  If the install disk is loop mounted while calling grub2-bios-setup
  the call fails the install command can't deal with disk devices
  mapped in /dev/mapper
* Wed Jan 15 2014 ms@suse.de
- KIWIImageFormat
  fixed use of qemu-img adapter_type option. If controller ist
  set to 'ide' no adapter_type needs to be specified because ide
  is the default
* Wed Jan 15 2014 ms@suse.de
- Allow vmxboot to boot Xen EC2 instances
  In order to do that the boot device setup code now also searches
  for the presence of the 'root=...' information from cmdline as it
  is passed when booting via EC2. If found the given device is used
  and the system boots in LOCAL_BOOT mode
* Tue Jan 14 2014 ms@suse.de
- KIWIAnalyseManagedSoftware
  use system installed solvables from /var/cache/zypp/solv. This
  speedup the system inspection task (kiwi --describe)
* Mon Jan 13 2014 ms@suse.de
- v5.06.18 released
* Mon Jan 13 2014 ms@suse.de
- diffChangedConfigFiles
  Be more verbose if a content diff for a modified configuration
  file can't be created
* Mon Jan 13 2014 ms@suse.de
- KIWIAnalyseSUSE.kiwi
  use international standardized example domain and names
* Mon Jan 13 2014 ms@suse.de
- KIWIAnalyseManagedSoftware
  * added a post solver task which reduces the full solved list
    of packages into a list of only needed packages with regards
    to the package requirements
* Mon Jan 13 2014 ms@suse.de
- KIWISatSolver
  * The quiet parameter was not evaluted correctly and caused
    a wrong code workflow and broke the solver result
  * Improved performance of the solver. The preparation of the
    pool should happen only once
* Sun Jan 12 2014 ms@suse.de
- DB: rebuild schema documentation
* Fri Jan 10 2014 ms@suse.de
- Removed static eth0 dhcp network setup from JeOS 13.1/13.2/SLE12
  templates. Reason for the change is that network device names are no
  longer persistent starting with openSUSE 13.1. Thus we don't know about
  the device at build time and cannot safely provide an ifcfg-<device>
  configuration.
* Fri Jan 10 2014 ms@suse.de
- Added in code debug switch for grub2
  Currently grub2 debugging is switched off by default but for
  getting more information while grub2 loads it's useful to
  activate the debug flag by commenting out the line in the code
* Fri Jan 10 2014 ms@suse.de
- added gfxboot-branding-SLES package to SLES JeOS image template
  when building install media we want graphics :-)
* Fri Jan 10 2014 ms@suse.de
- added cleanup code for /var/cache/kiwi/zypper/repos
  kiwi should only use the relevant .repo files according to the
  repositories specified in the XML description
* Thu Jan  9 2014 ms@suse.de
- mount isofrom location with -o nolock (bnc #857824)
* Thu Jan  9 2014 ms@suse.de
- update all templates to schema version 6.0
* Thu Jan  9 2014 ms@suse.de
- added XSL stylesheet to auto update from 5.9 to 6.0
  * oem-align-partition element will be deleted if present
* Thu Jan  9 2014 ms@suse.de
- increase schema version from 5.9 to 6.0
  * oem-align-partition has been deleted
* Thu Jan  9 2014 ms@suse.de
- DB: rebuild documentation
* Thu Jan  9 2014 ms@suse.de
- DB: remove information about obsolete oem-align-partition
* Thu Jan  9 2014 ms@suse.de
- removed obsolete oem-align-partition setup in oemconfig section
  * partitions will always be aligned
* Thu Jan  9 2014 ms@suse.de
- v5.06.17 released
* Thu Jan  9 2014 ms@suse.de
- fixed evaluation of $hybrid variable in createImageLiveCD
  The value is an integer not a string, thus checking for "true"
  will not cause the correct effect. This fixes the problem that
  isohybrid was not called even if the hybrid attribute was set
  in the XML description
* Wed Jan  8 2014 ms@suse.de
- make sure mountpoint and checkproc tools stay in initrd (bnc #857824)
* Tue Jan  7 2014 ms@suse.de
- fixed test for mounted directory in unit test ktTestCase.pm helper module
  * if /kiwi is a mountpoint the script takes the wrong decision
* Tue Jan  7 2014 ms@suse.de
- compatibility fix for prove command on older versions of perl
  * the option -f does not exist on older versions of prove
* Tue Jan  7 2014 ms@suse.de
- fixed test for mounted directory in unit test cleanup helper
  * if /kiwi is a mountpoint the script takes the wrong decision
* Tue Jan  7 2014 ms@suse.de
- v5.06.16 released
* Tue Jan  7 2014 ms@suse.de
- fixed KTFilesystemOptions unit test
  the Test::Unit::Lite framework is used for kiwi
* Tue Jan  7 2014 ms@suse.de
- fixed .changelog helper tool to allow transformation of git
  commit style comments into suse package changelog format
* Tue Jan  7 2014 ms@suse.de
- fixed push to array to work also with older perl versions
* Sat Jan  4 2014 rjschwei@suse.com
- move the filesystem options into an Object
  + eliminate a method in the Globals singleton that is FS independent,
    confusing and returns data structure that gets indexed, making data
    access error prone
  + first step to moving filesystem options into XML and unifying it
    with existing ZFS setting in the XML
  + we should not have disconnected ways of dealing with filesystem options
  + this will help with the implementation of *Builder classes for the
    various filesystems
- fix type in the command line test trigger
- fix inconsistency when applying tune options for ext file systems for the
  root file system
  + previously it was possible that both user specified tune options and
    built in kiwi option were passed to tune2fs. The tune2fs manpage does
    not specify the behavior when the same option is specified twice
* Thu Jan  2 2014 dmueller@suse.com
- Switch to kmod-compat
  Otherwise you'll get a conflict in the build service:
  conflict for provider of module-init-tools needed by
  kiwi-desc-oemboot-requires, (provider module-init-tools is conflicted by
  installed kmod-compat)
* Fri Dec 20 2013 ms@suse.de
- v5.06.15 released
* Fri Dec 20 2013 ms@suse.de
- Cleanup isoboot code
  * prevent use of fixed loop device name
* Fri Dec 20 2013 ms@suse.de
- cleanup variable setup for oemboot
  * remove unused variable required for isoboot only
* Fri Dec 20 2013 ms@suse.de
- fixed boot of split systems
  * the loop device setup for the read-only squashfs part was broken
* Wed Dec 18 2013 ms@suse.de
- KIWIAnalyeCustomData:
  Create a custom.json file in addition to the custom dir tree
  The custom.json file contains the name, directory, binary
  and permission information for each file we found and
  categorized as unmanaged
* Mon Dec 16 2013 ms@suse.de
- v5.06.14 released
* Mon Dec 16 2013 dvaleev@suse.de
- Add templates for ppc64le
* Mon Dec 16 2013 ms@suse.de
- arm: berryboot fixes
  * berryboot can't read directories, thus we have to keep kernel
    and initrd and all other files on the toplevel of the fat32
  * berryboot does not pass ATAG_INITRD2 to the kernel, thus we
    have to set address and size ourselves
* Mon Dec 16 2013 ms@suse.de
- make sure gfxterm and gfxmenu are embedded into grub loader module
* Fri Dec 13 2013 ms@suse.de
- arm: make sure the fat32 filesystem is created with the -I option
  + See mkdosfs for details on the -I switch. This finally fixes
    the boot problems on the Raspberry-Pi boards
* Fri Dec 13 2013 guillaume.gardet@oliseo.fr
- Update copyBootCode function
  * Add support to check for /boot/dtb/ since DTB files
    will be stored in this folder
* Fri Dec 13 2013 ms@suse.de
- arm: make sure there is no x86 boot code in MBR
* Fri Dec 13 2013 ms@suse.de
- fixed setupBootLoaderStages grub module setup (bnc #847912)
  * prevent the use of insmod and put them into the grub2 loader
    module directly. For secure boot dynamic loading of modules
    is not allowed and we also fix the undefined symbols problem
    as described in the bug
* Fri Dec 13 2013 ms@suse.de
- fixed dn() function to work correctly with loop devices (bnc #855288)
* Thu Dec 12 2013 ms@suse.de
- Update all JeOS templates to include the gfxboot-branding if
  the selected image type is "oem". This is done to have a graphics
  boot menu for install iso images
* Thu Dec 12 2013 ms@suse.de
- Use isolinux to boot an install CD
  + Instead of using the bootloader selected for the image raw
    disk to boot the install iso we use isolinux which is the
    correct loader for an iso. In addition this now also allows
    to create hybrid install iso images
* Wed Dec 11 2013 ms@suse.de
- on construction of a KIWIXML instance, return early if no
  pointer to the image configuration directory is defined
* Wed Dec 11 2013 ms@suse.de
- added better comments describing what eltorito boot image
  is used for an install ISO
* Tue Dec 10 2013 ms@suse.de
- v5.06.13 released
* Tue Dec 10 2013 ms@suse.de
- fixed creation of report page in kiwi --describe
  * better information about gem list, only system gems are listed
  * clean list view, no empty lines
* Tue Dec 10 2013 ms@suse.de
- v5.06.12 released
* Tue Dec 10 2013 ms@suse.de
- Added better in-code documentation in KIWIAnalyseCustomData
  and improved the code flow by reducing the set of unmanaged
  data with the rpm managed data in the first place
- fixed all KIWIQX::qxx calls which are called in list context
  The result of KIWIQX::qxx is always in scalar context, calling
  in list context will put the result as one element of the list
* Tue Dec 10 2013 rjschwei@suse.com
- cleanup the evaluation of kiwi_ variables inside the initrd
  + the following elements/attributes accepts true|false values:
    <oem-kiwi-initrd>, compressed, hybrid, hybridpersistent and ramonly
    These settings are propagated without changes to the linuxrc code
    that evaluates the variable to decide whether or not to perform
    an action. The evaluation in the shell code was based on yes|no
    an old relic that used to be use in the XML a long time ago.
    This update changes the evaluation in the shell code
    to true|false.
* Mon Dec  9 2013 ms@suse.de
- v5.06.11 released
* Mon Dec  9 2013 ms@suse.de
- update releasetags helper tool
  * list all committed versions which hasn't been tagged and
    print the git tag command to tag it. stop at the current
    version which has been tagged
* Mon Dec  9 2013 ms@suse.de
- v5.06.10 released
* Mon Dec  9 2013 ms@suse.de
- fixed setup of size of boot partition of an install stick
  * the original code just uses the size of the initrd to estimate
    a size for the boot partition of the install stick. But this
    might be too small. Thus the function __getBootSize which
    also evaluates the value of the bootpartsize attribute
    is used
* Mon Dec  9 2013 dvaleev@suse.de
- Added ppc64le link to system/repo
* Mon Dec  9 2013 ms@suse.de
- v5.06.9 released
* Mon Dec  9 2013 ms@suse.de
- arm: fixed suse-13.1-JeOS for Raspberry-Pi
  * there is no MLO for raspberry, thus no need to check for it
* Mon Dec  9 2013 ms@suse.de
- arm: berryboot fixed setup in config.txt
  * The initial kiwi initrd and the kernel are in boot/
* Mon Dec  9 2013 adrian@suse.de
- fixed instsource-plugins support for kiwi v5.06.8
  * the change in the KIWIQX module no longer exporting qxx
    had an impact on the instsource-plugin code. This patch
    changes the call to a class method call KIWIQX::qxx
* Mon Dec  9 2013 ms@suse.de
- fixed KIWIRuntimeChecker::__checkSystemDiskData
  * if a mountpoint with a custom name is given for a volume
    the check incorrectly used the name as path but it should
    use the mountpoint as path in this case
* Mon Dec  9 2013 ms@suse.de
- arm: berryboot fixes:
  * make sure KIWIConfig::suseGFXBoot copies all required
    firmware and loader files from the boot image to the
    system image below /image/loader
* Sun Dec  8 2013 ms@suse.de
- fixed simple initrd creation mode (bnc #854321)
  * in this mode the inheritance of data from a system to the
    boot image is not needed because there is no system image
    just the boot image description. This fixes the handling
    of profiles passed on the commandline
* Sun Dec  8 2013 ms@suse.de
- fixed simple initrd creation mode (bnc #854321)
  * in this mode no image type was passed because the default build
    type from the configuration 'cpio' should be used. Depending on
    the type the selection to build a boot image or not is done but
    at the time of the selection the selected build type variable
    was not set
* Fri Dec  6 2013 ms@suse.de
- fixed copyBootCode method
  * if no jump partition is set the function still has to proceed
    in order to check for boot code which needs to be copied if
    other bootloaders e.g uboot/berryboot are in use
* Fri Dec  6 2013 ms@suse.de
- v5.06.8 released
* Fri Dec  6 2013 ms@suse.de
- berryboot fixes:
  * make sure the boot partition indicator is set, because we need
    a fat32 boot filesystem to boot
* Fri Dec  6 2013 ms@suse.de
- added openSUSE 13.1 JeOS template for raspberry Pi
* Fri Dec  6 2013 ms@suse.de
- added support for berryboot bootloader
  * This loader is used on arm Raspberry-Pi systems
* Fri Dec  6 2013 ms@suse.de
- fixed use of uninitialized variable $screenLogs
  * if logging to the terminal is requested this variable is empty
* Thu Dec  5 2013 ms@suse.de
- Simplify and cleanup the command executor module KIWIQX
  * There is no code creating instances of KIWIQX, thus we
    only need class methods and should call as such
  * If called within the package context the exit status will
    stay but can still be evaluated as part of the package.
    That way we can keep the backtrace feature and can better
    check if enough resources to call the command existed
* Wed Dec  4 2013 ms@suse.de
- fixed extending the LVRoot volume
  * if the size of the root volume is set via the @root attribute
    in systemdisk and no other allfree volume was specified the
    LVRoot volume was extended twice times. first with the specified
    size which is ok and later to the full space because no other
    volume was specified to take the rest space. The last resize
    is unwanted in that case.
* Wed Dec  4 2013 ms@suse.de
- DB: rebuild documentation
* Wed Dec  4 2013 ms@suse.de
- DB: update kiwi man page
  * added information about new options added in previos commit
* Wed Dec  4 2013 ms@suse.de
- Added the following options to the analyse custom files code
  1. [ --skip-gem-lookup ]\n";
  Don't check for files managed by gem. Files managed
  by gem will then appear as unmanaged files
  2. [ --skip-rcs-lookup ]
  Don't check for files managed by revision control systems
  like git, svn, osc, etc... Files from such repositories
  will then appear as unmanaged files.
  3. [ --skip-augeas-lookup ]
  Don't check for files known to augeas. Files managed
  by augeas will then appear as unmanaged files.
* Wed Dec  4 2013 ms@suse.de
- fixed kiwi analyser default skip list
  * proc, sys and others were not excluded because of an
    invalid search pattern
* Wed Dec  4 2013 dvaleev@suse.de
- Enable ppc64le architecture
  * Enable powerpc64le architecture, which is almost the same
    as powerpc64 but little endian
* Wed Dec  4 2013 dvaleev@suse.de
- kernel-ppc64 -> kernel-default
  * Starting with openSUSE 12.3, powerpc doesn't have special
    kernel flavor anymore.
* Tue Dec  3 2013 ms@suse.de
- update example image descriptions in doc/ to make use
  of suseConfig again as long as we don't have a solution
  to use the systemd tools inside a chroot without affecting
  the host system setup
* Tue Dec  3 2013 ms@suse.de
- deactivate the use of systemd helper tools
  * The following functions have been disabled because they
    use the systemd tools timedatectl and localectl. Problem
    is that these tools doesn't work correctly from within a
    chroot environment. They access the dbus daemon from the
    host system and thus they change the currently active
    configuration on the host system which is unwanted
    setupHWclock
    setupKeyboardMap
    setupLocale
    setupTimezone
    Instead the old suseConfig kiwi function is used again
    This function simply changes the configuration files
    inside the chrooted system tree. suseConfig is called
    as part of the config.sh kiwi script
* Mon Dec  2 2013 ms@suse.de
- make sure search via 'type -p' has a full path list
- make sure the --nocolor option is used with the spin indicator
* Fri Nov 29 2013 ms@suse.de
- v5.06.7 released
* Thu Nov 28 2013 magist3r@gmail.com
- Improve squashfs compression for overlayfs option
  * use architecture specific compression filter
* Wed Nov 27 2013 ms@suse.de
- eliminate the use of which in boot code
  * which is an extra tool, it was packages, splitted, dropped
    and is handled differently in the pool of distributions.
    Instead type -p provided as shell builtin is used
* Sun Nov 24 2013 magist3r@gmail.com
- Added xz compression support for initrd
  * by default gzip compression is in use but you can
    switch on xz compression with the following entry
    in the .kiwirc file
    our $IrdZipper = "xz"
* Fri Nov 22 2013 ms@suse.de
- fixed check for empty destination in cloneImage function
* Fri Nov 22 2013 ms@suse.de
- fixed OVA creation
  * when using ovftool extract the created vmdk image and
    manifest files from the created OVA. This is required to
    produce streamOptimized vmdk images which can't be
    generated with qemu
  * fixed Invalid value 'MB' for element 'VirtualQuantityUnits'
    for vSphere 5 in the .ovf file
  * fixed allocated units set in the .ovf, vSphere 5 requires
    a value here
* Thu Nov 21 2013 ms@suse.de
- print a name sorted list when calling 'kiwi --list'
* Thu Nov 21 2013 ms@suse.de
- support for SLE 10 is now deprecated
* Thu Nov 21 2013 ms@suse.de
- added templates and boot-descriptions for SLE12
* Thu Nov 21 2013 ms@suse.de
- removed obsolete fbiterm font files from boot descriptions
  * the bug in fbiterm which provided broken fonts is fixed
* Thu Nov 21 2013 ms@suse.de
- support for openSUSE 12.1 is now deprecated
* Thu Nov 21 2013 ms@suse.de
- added templates and boot-descriptions for openSUSE 13.2
* Thu Nov 21 2013 thardeck@suse.de
- improvements to KIWIAnalyse:
  + added functions to create a diff of changed configuration files
    all config files are checked against the rpm database and if they
    have changed the original packages are downloaded and a diff of
    them is created. The original config files are stored in the cache
    to prevent another download of the packages at next invocation.
    The result is stored in the file 'changed_config.diff'
* Thu Nov 21 2013 ms@suse.de
- prevent the use of which in the boot code
  * use type -p instead and provide a function called lookup()
* Thu Nov 21 2013 ms@suse.de
- fixed setup of /boot/efi directory
  * instead of checking for boot/efi check for the label EFI
    in the kiwi_JumpPart partition
  * even without a seperate boot partition there might be a
    an EFI partition which should be added into fstab
* Thu Nov 21 2013 ms@suse.de
- fixed KIWIIsoLinux genisoimage paramter list
  * if createLegacySortFile does not return a sort file the
    option -sort should also not be part of the commandline
    call
* Thu Nov 21 2013 ms@suse.de
- DB: rebuild documentation
* Wed Nov 20 2013 rjschwei@suse.com
- add missing " in <user> element doc
- fix attribute name in <user> element description
* Mon Nov 18 2013 cshorler@googlemail.com
- add default gfxmode for GRUB2 if no vga mode was set
* Mon Nov 18 2013 ms@suse.de
- fixed gfxmode/gfxpayload setup in kiwi grub2 setup
  * it's possible to set vga="0x<kernel-vesa-mode" in the kiwi
    XML description. If grub2 was used as bootloader the information
    was incorrectly transfered into gfxmode and gfxpayload values
    in the grub.cfg. In addition the values were not handed over
    to the initrd and the file /etc/default/grub. All this is
    fixed now
* Mon Nov 18 2013 ms@suse.de
- fixed company name in analyse report page
* Fri Nov 15 2013 ms@suse.de
- v5.06.06 released
* Thu Nov 14 2013 ms@suse.de
- enhance pxeSetupDownloadServer
  * if the image download server ip is not configured by $kiwiserver
    the function now also checks for the contents of the $ip variable
    which exists if pxelinux booted the kernel with 'IPAPPEND 1'
    only if we did not get information from $ip the default name
    tftp.$DOMAIN applies as it was before
* Wed Nov 13 2013 ms@suse.de
- fixed broken symlink due to move of results from intermediate
  build directory to final result directory
* Wed Nov 13 2013 ms@suse.de
- use ovftool to create an ova format/archive
  * unfortunately only ovftool supports the full featureset
    e.g streamOptimized images
  * added a runtime check to search for ovftool if the
    format="ova" is requested
* Wed Nov 13 2013 ms@suse.de
- removed support for controller="scsi" in KIWIImageFormat
  and adapted the runtime checker as well as the unit test
* Wed Nov 13 2013 ms@suse.de
- update all image descriptions to schema version 5.9
* Wed Nov 13 2013 ms@suse.de
- update kiwi schema to version 5.9
  * removed scsi as allowed value from vmdisk controller attribute
* Wed Nov 13 2013 ms@suse.de
- added new xsl stylesheet 5.8 -> 5.9
  * the controller type 'scsi' does not exist for VMware.
    lsilogic and buslogic define scsi controllers. Thus this
    attribute value is moved back to the default 'ide' value
    Using new controller types requires a specific version of
    qemu-img which means the only safe translation is back to
    ide
* Wed Nov 13 2013 ms@suse.de
- fixed OVF file diskname: file has to be the .vmdk
  in reference and not the .ovf
* Tue Nov 12 2013 cshorler@googlemail.com
- make sure etc/sysconfig directory exists before temporary
  copying the proxy configuration into the chroot
* Tue Nov 12 2013 cshorler@googlemail.com
- fixed nested File::Find method fixupLinks in cloneImage
  * entities found in $File::Find::name always exists, thus it's
    not needed to check their existence
  * moved the code searching for links with relative pointer
    into a perl closure method named findLinksRelative
  * moved the code fixing broken relative links into its
    own code block
* Mon Nov 11 2013 ms@suse.de
- fixed creation of rpmsort cache data in KIWIAnalyseManagedSoftware
  * the data was stored as reference but the reference
    was changed during the process
* Mon Nov 11 2013 ms@suse.de
- don't remove the satsolver cache when running kiwi --describe
* Mon Nov 11 2013 ms@suse.de
- open custom directory tree browser in a new tab
* Mon Nov 11 2013 ms@suse.de
- fixed creation of toplevel menu in kiwi analyse
  * the menu should only contain items found by the analyser
* Mon Nov 11 2013 ms@suse.de
- v5.06.05 released
* Mon Nov 11 2013 ms@suse.de
- fixed push to array to work also with older perl versions
* Mon Nov 11 2013 ms@suse.de
- v5.06.04 released
* Mon Nov 11 2013 ms@suse.de
- added new CSS and menu for the kiwi --describe report
* Mon Nov 11 2013 ms@suse.de
- fixed createDatabaseDump to force compression of database
  dump even if there is an older dump available
* Mon Nov 11 2013 ms@suse.de
- replaced static links by relative ones in the custom data report
  * this should allow to access the report in a different
    directory than the default one
* Mon Nov 11 2013 Kanstantsin_Shautsou@epam.com
- if format is set to ovf or ova it makes sense to create the
  standard VMware machine config file (.vmx) too
- rename log message from "Starting" to "Creating"
* Sun Nov 10 2013 cshorler@googlemail.com
- added missing gfxmenu module for grub2
  * This prevents the default boot screen to show a broken menu
* Sun Nov 10 2013 cshorler@googlemail.com
- fixed temporary setup of DNS/proxy if cache is used
  * the code returned before we could copy the appropriate files
    from the host to the chroot tree if in cache mode
* Sun Nov 10 2013 cshorler@googlemail.com
- fixed cloneImage function
  * if there are symlinks pointing to a relative destination
    we fixup the link still pointing to the right location
    with regards to the new origen of the cloned description
* Sat Nov  9 2013 cshorler@googlemail.com
- fixed openSUSE 13.1 boot descriptions
  * the default repo setup pointed to 12.3, but should point to 13.1
    This is just for completeness and does not hurt because the repo
    setup for the boot image is inherited by the repo setup from the
    system image. But for standalone boot image builds it's corrected
    now
- arm: fixed openSUSE 13.1 JeOS motd file
  * printed some old information about 12.3
* Sat Nov  9 2013 cshorler@googlemail.com
- fixed kiwi --init-cache to find the required typeinfo
* Sat Nov  9 2013 cshorler@googlemail.com
- added VDI support for VirtualBox
  * support format="vdi" in the kiwi type specification
* Sat Nov  9 2013 rjschwei@suse.com
- partial fix for initrd creation for EC2 images
  + With the latest release of mkinitrd the multipath.sh script
    no longer exists. We need to check for it's precense before moving it
* Fri Nov  8 2013 Kanstantsin_Shautsou@epam.com
- fixed OVF format creation
  * Rasd entries must be in alphabetical order
* Fri Nov  8 2013 ms@suse.de
- v5.06.03 released
* Fri Nov  8 2013 ms@suse.de
- follow up fix for spec file (bnc #845853)
  * in distributions <= openSUSE 12.2 groupadd/useradd is provided
    by the package pwdutils and not shadow
* Fri Nov  8 2013 ms@suse.de
- v5.06.02 released
* Fri Nov  8 2013 james@bear454.com
- update openSUSE 13.1 JeOS template
  * update etc/motd
* Fri Nov  8 2013 Kanstantsin_Shautsou@epam.com
- enhanced controller type setup in <machine> section for vmdk
  * added support for scsi, lsilogic and legacyESX
  * call qemu-img convert with correct adapter_type option
    and check if the installed qemu-img suports the option
  * write correct virtualDev entry for VMware machine setup
* Thu Nov  7 2013 ms@suse.de
- fixed spec file (bnc #845853)
  * the PreReq's for kiwi-pxeboot were missing the shadow tools
    this is needed because the %%post of kiwi-pxeboot checks for the
    user and group tftp and requires the tools useradd/groupadd to
    be installed at that time already
* Wed Nov  6 2013 Kanstantsin_Shautsou@epam.com
- added support to specify vmdk diskmode in <machine> section
  * monolithicSparse
  * monolithicFlat
  * twoGbMaxExtentSparse
  * twoGbMaxExtentFlat
  * streamOptimized
* Wed Nov  6 2013 rjschwei@suse.com
- need to turn off multipath setup in device-mapper for EC2 images
  + with multipath enabled EC2 images will not boot
* Wed Nov  6 2013 schwab@suse.de
- added basic dir structure/support for m68k architecture
* Wed Nov  6 2013 Kanstantsin_Shautsou@epam.com
- unbroke manifest.mf file:
  * exclude new line between entries
* Tue Nov  5 2013 Kanstantsin_Shautsou@epam.com
- fixed .ovf xml format
  * need a space as separator between attributes
* Tue Nov  5 2013 Kanstantsin_Shautsou@epam.com
- fixed building of ova format
* Mon Nov  4 2013 ms@suse.de
- keep error messages from db_test_cmd in createDatabaseDump
  under perl control
* Mon Nov  4 2013 rjschwei@suse.com
- move the vmx guest example forward to 13.1
* Mon Nov  4 2013 ms@suse.de
- v5.06.01 released
* Mon Nov  4 2013 ms@suse.de
- branched off kiwi for openSUSE 13.1
  * therefore rebuild documentation for next cycle starting at 5.06
* Mon Nov  4 2013 ms@suse.de
- follow up fix to prevent call of setupBootPartition (bnc #847893)
  * if the hybrid RW partition can't be created HYBRID_RW will be
    unset, thus setupBootPartition would be called but we are still
    in a hybrid mode. In order to make that clear a new variable
    skipSetupBootPartition is set to handle all cases
* Mon Nov  4 2013 rjschwei@suse.com
- remove %%arch as alowed value for the arch attribute of a <machine> element
  + OBS does not subsitutue this use of %%arch
  + kiwi has no substitution mechanism
- Implement consistency check for ovf type
  + when the format of the <type> is specified as ovf the ovftype
    attribute of the <machine> element must be set
* Mon Nov  4 2013 ms@suse.de
- fixed system to boot data inheritance:
  * make sure the value for rpm-check-signatures is moved
* Mon Nov  4 2013 ms@suse.de
- fixed zypper package manager backend:
  * make sure the value for rpm-check-signatures is used
* Mon Nov  4 2013 ms@suse.de
- fixed typo in kiwi --help usage message
  * --recycle-root doesn't take an argument
* Mon Nov  4 2013 ms@suse.de
- v5.05.44 released
* Mon Nov  4 2013 ms@suse.de
- fixed unit test data: patternTattrConsInvalid_2.xml
  * both profiles my-first and my-second were invalid. this caused
    either the one or the other error message which could lead to
    a successful or failed test result. I changed the test data to
    be clear on the error condition
* Fri Nov  1 2013 dvaleev@suse.de
- print nicer KIWICollect messages
  * round minutes to integer
* Thu Oct 31 2013 ms@suse.de
- v5.05.43 released
* Thu Oct 31 2013 ms@suse.de
- fixed __checkPatternTypeAttrConsistent test
  * the test checks for inconsistent patternType combinations
    in specified profile groups incl. the default group.
- changed the function getInstallOption() to decide for the
  patternType with the highest priority according to the
  selected profile group(s). The behavior before was to ignore
  the patternType if it was not the same value over all selected
  packages sections. This is imho too restrictive
- update the unit tests accordingly
* Thu Oct 31 2013 ms@suse.de
- on arm uboot can only boot with a uImage or a zImage
  thus in case of the zImage kiwi should make use of it
* Thu Oct 31 2013 ms@suse.de
- KIWIAnalyse: added function importDatabases() to KIWIConfig.sh
  in order to allow the import of complete database sets. This is
  the counterpart for the recently added KIWIAnalyseCustomData
  function createDatabaseDump()
- the config.sh created by KIWIAnalyse will automatically add an
  entry to call this function to allow the reimport of the databases
  during image creation
* Thu Oct 31 2013 ms@suse.de
- KIWIAnalyse: use `mysqladmin ping` instead of a
  netstat+grep to check for running mysql database
* Thu Oct 31 2013 ms@suse.de
- KIWIAnalyse: store exported dbs in <template>/root/var/cache/dbs
  so they will be imported automatically
* Thu Oct 31 2013 ms@suse.de
- fixed postprocessing modes
  * an empty configuration directory was passed
* Thu Oct 31 2013 ms@suse.de
- fixed usage information about --check-kernel option
* Thu Oct 31 2013 ms@suse.de
- make the checkKernel() function a real check and don't
  try to fix a detected kernel inconsistency. The check
  for the kernel consistency between the system image and
  the initrd still needs activation via the commandline
  option --check-kernel
* Thu Oct 31 2013 ms@suse.de
- fixed typo in openSUSE 12.3 JeOS for arm
  * wrong reference to boot image description
* Wed Oct 30 2013 ms@suse.de
- v5.05.42 released
* Wed Oct 30 2013 ms@suse.de
- fixed suse-12.3-JeOS for arm
  * insserv and pwdutils does not exist/renamed
  * update repo paths
* Wed Oct 30 2013 ms@suse.de
- added origenFlavour profile in 12.3 JeOS for arm
* Wed Oct 30 2013 ms@suse.de
- Revert "added origenFlavour profile in 13.1 JeOS for arm"
  * this was for the wrong distribution, there is no dtb for
    the Exynos 4210 CPU on 13.1, thus we can only use the
    kernel with the old board descriptions.
    This reverts commit 4c9dc8bb29
* Wed Oct 30 2013 ms@suse.de
- added origenFlavour profile in 13.1 JeOS for arm
* Wed Oct 30 2013 ms@suse.de
- follow up fix for the kernel search on arm
  * even if a zImage exists we use the vmlinux.gz like mkinitrd
    on arm does it at the moment. If this changes in the future
    that part in kiwi needs adaption as well
  * added a warning message to the log if the kernel
    mapping has failed
* Tue Oct 29 2013 ms@suse.de
- prefer the vmlinux-$VERSION.gz kernel file on arm
* Tue Oct 29 2013 ms@suse.de
- fixed partition alignment for image and repartitioning
  * images with more than one partition are not aligned
    for optimal performance except for the first partition
    This patch fixes this and also make sure the repartition
    code creates an aligned table too
* Tue Oct 29 2013 ms@suse.de
- fixed arm openSUSE 13.1 JeOS image description
  + some packages e.g insserv does not exist anymore
  + update kernel used for panda and beagle boards
  + update buildservice repository paths
* Mon Oct 28 2013 ms@suse.de
- fixed augeas import:
  * check for unknown escape sequences in the value
  * make sure values are embedded in a single pair of "..."
* Mon Oct 28 2013 ms@suse.de
- fixed typo in setupAugeasImport
* Mon Oct 28 2013 ms@suse.de
- fixed output path in createDatabaseDump
* Mon Oct 28 2013 ms@suse.de
- build a more self explaining target database export
  file name in the createDatabaseDump function
* Mon Oct 28 2013 ms@suse.de
- fixed .locale helper tool to operate on real .po changes only
* Mon Oct 28 2013 ms@suse.de
- add method createDatabaseDump() to KIWIAnalyseCustomData to
  check for running db's and if they are available try to export
  the entire content. Right now only Mysql is supported
* Mon Oct 28 2013 rjschwei@suse.com
- added live ISO image example for 13.1
* Fri Oct 25 2013 ms@suse.de
- v5.05.41 released
* Fri Oct 25 2013 ms@suse.de
- deactivate the use of lxc to run custom scripts (bnc #845617)
  * some tools e.g groupadd requires access to subsystems like PAM
    which did not work inside the lxc container because the required
    precondititions were not added while starting the container.
    Thus only simple scripts not accessing PAM, udev and other
    subsystems will work. In addition to that the environment the
    lxc container itself is started often does not provide the
    required subsystems e.g support for cgroups. All in all there
    are more problems than solutions with this concept which is
    the reason why I disable it for now
* Thu Oct 24 2013 ms@suse.de
- v5.05.40 released
* Thu Oct 24 2013 rjschwei@suse.com
- fix use of uninitialized variable
* Wed Oct 23 2013 rjschwei@suse.com
- add the live USB stick example for openSUSE 13.1
- adjust verification for firstboot logic install check
  + in 13.1 YaST has been converted to Ruby and firstboot is now a
    systemd service, thus we need to check for the new implementations
    as well
- eject conflicts with util-linux in 13.1, remove it from oemboot image
* Wed Oct 23 2013 ms@suse.de
- fixed postprocessing modes
  * e.g the --installstick mode did not work because an XML
    object was created before the preconditions to do that
    were fulfilled
* Tue Oct 22 2013 ms@suse.de
- v5.05.39 released
* Mon Oct 21 2013 rjschwei@suse.com
- fix setup of target image
  + at present the build image settings for keymap, timezone and other
    configuration settings are changed instead of applying the settings
    to the target image. This fix addresses this bug.
* Mon Oct 21 2013 adrian@suse.de
- do not ignore addarch, if also the base architecture got added
* Mon Oct 21 2013 ms@suse.de
- added custom bootkernel profile (bnc #846068)
  * with the bootkernel="custom" profile one can prevent the
    installation of a kernel in the kiwi boot image (initrd)
    This makes sense if a non profiled kernel or a specific
    version of a kernel is used as part of the system image
    XML description. Examples:
    <type ... bootkernel="custom"/>
    ==> version pinned kernel:
    <package name="kernel-default-3.7.10-1.16.1" bootinclude="true"/>
    ==> non profiled/custom kernel:
    <package name="kernel-bob" bootinclude="true"/>
    If the custom bootkernel attribute is used it's required to
    mark the kernel in the system image XML with bootinclude="true"
    If this is not done the initrd will not have a kernel/modules
    which is in most cases unwanted
* Sat Oct 19 2013 rjschwei@suse.com
- fix repository image inclusion behavior
  + adding imageinclude=true did not have the desirec effect of adding the
    specified repo to the image permanently. This changes fixes this
    problem
* Fri Oct 18 2013 ms@suse.de
- v5.05.38 released
* Fri Oct 18 2013 ms@suse.de
- fixed spec file for kiwi-pxeboot sub-package (bnc #845853)
  * kiwi-pxeboot creates files which belongs to user/group = tftp
    but it might be the case that the user/group does not exists
    Thus this patch as a %%pre section taking care for this
* Thu Oct 17 2013 ms@suse.de
- revert accidentally added test systemdisk section in
  suse-12.3-JeOS XML description
* Thu Oct 17 2013 ms@suse.de
- fixed missing mount and fstab entry for allfree volume
  * the volume flagged with freespace="all" was ignored in the
    mount and fstab setup code
* Thu Oct 17 2013 ms@suse.de
- fixed partids for LVM setup:
  * The value kiwi_RootPart must always be a number, whereas
    in case of LVM we also provide kiwi_RootPartVol which takes
    the name of the root volume
* Thu Oct 17 2013 ms@suse.de
- added better information about disk Volumes
* Thu Oct 17 2013 ms@suse.de
- allow standalone building of initrd images like in older version
  * The image type 'cpio' was handled as initrd image type but
    newer versions of kiwi just use it as an archive type for the
    system image. This is a bad incompatibility and also prevents
    us from just building kiwi initrd images
* Wed Oct 16 2013 rjschwei@suse.com
- fix cut and paste error of comment in the oem-recovery-part-size element
  definition
  + comment is displayed in the generated doc and was misleading
- add unit test for {g,s}etAtaRaidScan method on OEMConfig class
- add unit test for {g,s}setRecoveryPartSize method on OEMConfig class
- fix bug regarding oem_recoveryPartSize
  + the value was never set as member variable thus the get method
    always returned <undef>
- fix naming inconsistency between the get and set method for the
  recovery partition size
- add value check for the recovery partition ID
  + must be a 2 digit hex value
  + also add unit test for this verification
* Tue Oct 15 2013 ms@suse.de
- fixed grub2 recovery menu entry
  * in EFI mode chainloading is not possible, thus we use grub2
    to load the loader configuration from the recovery partition
    this requires at least a non destructed EFI boot partition
* Tue Oct 15 2013 ms@suse.de
- fixed partition to search for kiwi initrd in recovery setup
* Tue Oct 15 2013 ms@suse.de
- apply changes from commit: d9d0f3bee also to rhel-repart
* Tue Oct 15 2013 ms@suse.de
- always make sure devpts is mounted with mode=0620,gid=5 (bnc #845231)
* Tue Oct 15 2013 ms@suse.de
- fixed kiwi-desc-*boot-requires for openSUSE 13.1 (bnc #829429)
  * kernel-xen is supported on x86_64 only
* Mon Oct 14 2013 ms@suse.de
- fixed OEM repart/install code for EFI images
  * fixed creation of etc/grub.d/40_custom script to let
    grub2-mkconfig correctly create the Recovery menu entry
  * fixed partition ID's for repart operation. instead
    of incrementing kiwi_BootPart we should use the correct
    values for root,read-only,read-write,lvm as they are
    written into config.partids
* Mon Oct 14 2013 ms@suse.de
- rebuild schema from rnc to rng
* Mon Oct 14 2013 mmarek@suse.cz
- fixed project changelog creation tool:
  * avoid localized dates in the .changes file
* Mon Oct 14 2013 mmarek@suse.cz
- fixed project package tools:
  * instead of removing the .git directory when generating
    the tarball for the package, use tar's --exclude option
* Mon Oct 14 2013 mmarek@suse.cz
- Do not require graphical grub data for setting up the recovery
  data because e.g SLE11 does not provide this data
* Sat Oct 12 2013 rjschwei@suse.com
- add consistency check, the version element is required
  + bad things will happen in the code if there is no version
    we assumed the version is always present in many places in the
    code
- expand the validator unit tests
- add a trigger to rnu XML and XML Validator tests when the schema changes
* Fri Oct 11 2013 ms@suse.de
- v5.05.37 released
* Fri Oct 11 2013 rjschwei@suse.com
- implement consistency check for install media (bnc #845490)
  + using installstick="true" and hybrid="true" is inconsistent and
    will generate an error during XML verification
* Thu Oct 10 2013 ms@suse.de
- fixed installstick image boot code:
  * there was a name conflict in the config.partids information
    actually we have to distinguish between the image root part
    and the install root part of the stick disk layout. That's
    why I introduced a kiwi_InstallRootPart variable to make
    that clear
* Thu Oct 10 2013 ms@suse.de
- fixed netboot setupNetwork code
  * variable prefer_iface is local but used globally
  * variable DHCPCD_STARTED needs to be initialized with an
    empty string to avoid improper use
  * handle prefer_iface as array because it was assigned
    from array ${dev_list[*]}
* Thu Oct 10 2013 ms@suse.de
- DB: rebuild documentation
* Thu Oct 10 2013 ms@suse.de
- DB: fixed opensusePattern vs. namedCollection
* Thu Oct 10 2013 ms@suse.de
- moved __checkType function into the global space (checkType)
- fixed checkType function and set an isolinux compliant
  bootloader if the user requested a hybrid setup for any
  other than the iso image type
- make sure checkType is also called in KIWIBoot because this
  module reads the image description again from scratch which
  is needed to support postprocessing modes e.g --bootvm
* Wed Oct  9 2013 ms@suse.de
- fixed call of augtool print command in __populateCustomFiles
  * missing / in files source path
* Wed Oct  9 2013 ms@suse.de
- v5.05.36 released
* Wed Oct  9 2013 ms@suse.de
- fixed iso hybrid partition table for 32bit live iso images
  * if firmware="bios" is set the offset and table setup was
    incomplete, which results in a broken hybrid persistent
    partition if the iso was used as disk on e.g a USB stick
    This fixes (bnc #841392)
- fixed KIWICollect::addToReportFile function
  * perlcritic reports no return value set for this function
* Tue Oct  8 2013 ms@suse.de
- fixed spec file (bnc #844538):
  * missing obsolete information for old package kiwi-desc-xenboot
* Mon Oct  7 2013 ms@suse.de
- fixed writing preferences data from the system to the boot image
  * getPreferences returns a new KIWIXMLPreferenceData object
    containing combined information. Thus it's required to set
    the changed object back into the KIWIXML space
* Sun Oct  6 2013 ms@suse.de
- do not filter out packages marked for deletion prior to the
  installation of these packages. If one don't want to install
  a package it sould simply not be part of the packages list.
  But the reason for the delete list was to be able to remove
  packages installed but unwanted e.g by a pattern or by an
  invalid/unneeded requirement
* Wed Oct  2 2013 ms@suse.de
- protect packages from being deleted if they are explicitly
  stated to become installed by a bootinclude attribute
* Tue Oct  1 2013 ms@suse.de
- update false positive list in KIWIAnalyse.skip
* Tue Oct  1 2013 ms@suse.de
- fixed livestick cleanup code:
  * make sure stick mount will be released
* Tue Oct  1 2013 ms@suse.de
- remove pmtools package from the delete section of the
  oemboot/suse-SLE descriptions
* Tue Oct  1 2013 ms@suse.de
- fixed typo in function name, duplicate 'Boot' in name
* Fri Sep 27 2013 ms@suse.de
- v5.05.35 released
* Fri Sep 27 2013 ms@suse.de
- don't call setupBootPartition if HYBRID_RW is set (bnc #827520)
  * hybrid iso images contain a partition table written by isohybrid
    if such an iso is dumped on a disk and used in hybrid persistent
    mode we have to prevent the setup of the boot partition because
    there is no real boot partition in hybrid mode
* Thu Sep 26 2013 ms@suse.de
- fixed code block running with imageinclude="true"
  * in case the repo already exists, kiwi just updates the path
    with regards to chroot/non-chroot calls. In that case the
    imageinclude should not add a repo which is already there
* Tue Sep 24 2013 ms@suse.de
- v5.05.34 released
* Mon Sep 23 2013 ms@suse.de
- improvements to KIWIAnalyse:
  * move KIWIAnalyse.txt to KIWIAnalyse.systems, stores system ID's
  * add KIWIAnalyse.skip, provides exception list for false positives
  * fix creation of custom tree, don't create empty directories
  * fix handling of progress for empty lists, division by zero
* Mon Sep 23 2013 ms@suse.de
- fixed spec file requires:
  * the new KIWIAnalyse modules requires git to apply version
    control to the result of the created system description
* Mon Sep 23 2013 ms@suse.de
- fixed createHybridPersistent:
  * the function has to return if it detects that persistent writing
    is not possible and leave the block without setting HYBRID_RW
    that fixes (bnc #841662)
* Thu Sep 19 2013 ms@suse.de
- make sure the repo cache is cleared before running
  a new analayse process
* Thu Sep 19 2013 ms@suse.de
- enhance KIWIAnalyseReport:
  find if current active kernel version doesn't match any
  installed package and put that information in the report
* Thu Sep 19 2013 ms@suse.de
- fixed reading cache in KIWIAnalyse
* Thu Sep 19 2013 ms@suse.de
- fixed base path setup in __populateCustomFiles
  * use of uninitialized value after handling that case
* Thu Sep 19 2013 ms@suse.de
- fixed bios partition type setup:
  * upstream parted supports 'set partition flag state' whereas
    flag can't be a hex id as we need it when setting e.g a
    fat partition type. Thus we use the suse extension as fallback
    which allows to set: 'set partition type hexid'
* Wed Sep 18 2013 ms@suse.de
- added some notes in the KIWIAnalyse code:
  * it would be good to move packagemanager related calls into the
    KIWIManager abstraction class and support more than only zypper
* Wed Sep 18 2013 ms@suse.de
- make sure zypper calls runs in POSIX locale
* Tue Sep 17 2013 ms@suse.de
- allow bootinclude to be processed for bootstrap packages too
* Tue Sep 17 2013 ms@suse.de
- add more information to assert_array_equal in
  unit testing framework
* Tue Sep 17 2013 ms@suse.de
- split code in KIWIMigrate into classes:
  * KIWIAnalyse
  * KIWIAnalyseCustomData
  * KIWIAnalyseManagedSoftware
  * KIWIAnalyseReport
  * KIWIAnalyseTemplate
* Fri Sep 13 2013 ms@suse.de
- v5.05.33 released
* Fri Sep 13 2013 ms@suse.de
- fixed cache handler in KIWIMigrate
  * if cache is invalid it's a bad idea to store the path to the old cache
* Fri Sep 13 2013 ms@suse.de
- follow up fix for the IFS restore in kernelCheck function
  The local scope of IFS is visible to functions called from
  inside this block. Thus localizing IFS does not help, we have
  to reset the value inside the function (bnc #838921)
* Fri Sep 13 2013 ms@suse.de
- DB: rebuild documentation, smoother pictures
* Fri Sep 13 2013 ms@suse.de
- DB: rebuild documentation
* Fri Sep 13 2013 ms@suse.de
- DB: rebuild schema documentation
* Fri Sep 13 2013 ms@suse.de
- DB: update documentation about kiwi's caching system
* Fri Sep 13 2013 ms@suse.de
- DB: rebuild documentation
* Fri Sep 13 2013 ms@suse.de
- added support for custom LVM volume names (bnc #815204)
  * There is now an additional and optional attribute 'mountpoint'
    in the volume section. If a mountpoint information is provided
    the name given in the 'name' attribute can be any name according
    to the LVM logical volume name conventions. Example:
    <volume name="bob" mountpoint="tmp"/>
    this will create the logical volume 'bob' mounted to /tmp.
    If no mountpoint information is given the information in name
    is handled as before which means it's a path and a name
    information. Example:
    <volume name="tmp"/>
    this will create the logival volume 'LVtmp' mounted to /tmp.
    Thus this feature is fully backward compatible. With this
    implementation we solved one item on the feedback list.
* Fri Sep 13 2013 rjschwei@suse.com
- remove the superfluous getPriority method in the child class
  + the parent calss has the exact same implementation
* Fri Sep 13 2013 ms@suse.de
- DB: fixed kiwi man page description for conflicting option
* Fri Sep 13 2013 ms@suse.de
- fixed option clash in getopt list
* Fri Sep 13 2013 tom_schr@web.de
- DB: Improved consistency, fixed typos, corrected spelling
  * Corrected capitalization in titles
  * Fixed whitspace in <screen>s
  * Fixed kiwi, oem, ... spelling
* Thu Sep 12 2013 ms@suse.de
- improved caching in KIWIMigrate
  * store rpm based data, and re-use by the md5 sum of the database
  * added wait indicator for processing of files
- update information about installed kernel and how to use
  another than the default kernel for the image
- add ruby/gems to the ignore path, that's because we already
  provide gem information in the report by using gem directly
  thus the compiled gem data which is not part of the gem
  package taints the list of unmanaged data
* Wed Sep 11 2013 ms@suse.de
- fixed detection of buildservice repos in KIWIMigrate
* Wed Sep 11 2013 ms@suse.de
- make checking for empty directories fast in KIWIMigrate
* Wed Sep 11 2013 ms@suse.de
- add alternative 'kiwi --describe' option
  * update kiwi usage message. Don't talk about 'migration'
    Be more generic and talk about 'analyse & description'
    because that's in fact what the code does. migration is
    just one path one can perform.
* Wed Sep 11 2013 ms@suse.de
- DB: rebuild documentation
* Wed Sep 11 2013 ms@suse.de
- DB: update documentation and man pages for KIWIMigrate
* Wed Sep 11 2013 ms@suse.de
- make sure sort order stays consistent in KIWIMigrate
* Wed Sep 11 2013 ms@suse.de
- added support for openSUSE-13.1 in KIWIMigrate
* Wed Sep 11 2013 ms@suse.de
- added support for systemd service inspection in KIWIMigrate
* Wed Sep 11 2013 ms@suse.de
- added support for git transaction log in KIWIMigrate
* Wed Sep 11 2013 ms@suse.de
- added support for detecting buildservice repos in KIWIMigrate
* Tue Sep 10 2013 ms@suse.de
- follow up patch for setting systemIntegrity for netboot
  deployments into a ramdisk. Along with systemIntegrity the
  partition code has to check for haveRamDisk too (bnc #839157)
* Tue Sep 10 2013 ms@suse.de
- follow up patch for fetchFile() function. handling of
  uncompressed value was broken due to the changes to support
  the 'xz' compression (bnc #787400)
* Tue Sep 10 2013 adrian@suse.de
- add .packages support for product media
  * I am not proud of this code, but since we may need to backport it,
    it has to be minimal invasive. A general rework is needed anyway
* Tue Sep 10 2013 ms@suse.de
- some improvements to the migration module
  * split D3 visualisation parts into extra files
  * added information about binary vs. text data (ELF header only)
  * added configuration information from augeas
  * update logo
* Mon Sep  9 2013 ms@suse.de
- make sure systemIntegrity is set correctly to 'clean' for
  netboot deployments into a ramdisk (bnc #839157)
* Mon Sep  9 2013 ms@suse.de
- make sure IFS change in kernelCheck function will be
  applied only in local scope (bnc #838921)
* Mon Sep  9 2013 ms@suse.de
- added support for augeas into kiwi. The new function
  setupAugeasImport is called if the following file exists
  as part of the kiwi image description:
  config-augeas.xml
  The contents of this file follows the schema and format as
  it is provided by augeas. For an example check the output
  of the command: 'augtool dump-xml /files/*'. As example one
  can add another tty to /etc/securetty as follows:
  <augeas match="/files/*">
  <node label="etc" path="/files/etc">
  <node label="securetty">
  <node label="8">
  <value>tty8</value>
  </node>
  </node>
  </node>
  </augeas>
  kiwi will make use of this feature in the migration module
  when it populates the current configuration of the system
  augeas will be used instead of a plain copy of the config
  file
* Fri Sep  6 2013 ms@suse.de
- v5.05.32 released
* Thu Sep  5 2013 ms@suse.de
- fixed creation of overlay root files in migration mode
  * if the creation of a hardlink is not possible due to cross
    device references e.g /tmp not on the same device, we create
    a symbolic link instead.
* Thu Sep  5 2013 ms@suse.de
- fixed packages/collection setup in migration module
* Thu Sep  5 2013 ms@suse.de
- use the XML writer based on a template for the migration code
  * /usr/share/kiwi/modules/KIWIMigrate.kiwi forms the template
  * the migration reads in the template and operates on the
    xml object to add data. At the end writeXML() creates the
    new description file
* Thu Sep  5 2013 ms@suse.de
- fixed some typos in imageConfig comment block
* Wed Sep  4 2013 ms@suse.de
- added KIWIMigrate.kiwi template file for later use
  in KIWIMigrate when the XML writer will be used there
* Tue Sep  3 2013 ms@suse.de
- fixed writeXML
  * make sure __collectXMLListData works correctly with replaces data
  * make sure KIWIXMLPackageData::getXMLElement handle 'none'
    value in replace data correctly
* Tue Sep  3 2013 ms@suse.de
- fixed writeXML
  * don't write duplicate package entries
  * fixed target file setup in tests/writeTester
* Mon Sep  2 2013 ms@suse.de
- further enhance indent helper:
  * make sure kiwi.pl get the right permissions back after the change
  * make sure the xsl pretty printer also uses spaces and not tabs
  * make sure the schema RNG format is rebuild
* Mon Sep  2 2013 ms@suse.de
- added support to specify the size of the recovery partition
  <oem-recovery-part-size>integer-value</oem-recovery-part-size>
  The specified size is ignored if it is too small according to
  the minimum required size. In this case a warning message is
  printed to the /var/log/boot.kiwi file on first deployment.
  This implements enhancement (bnc #836657)
* Mon Sep  2 2013 ms@suse.de
- update .indent helper to check config.xml and *.rnc files too
* Fri Aug 30 2013 ms@suse.de
- fixed unit tests due to changed message layout in c:d8405713
* Fri Aug 30 2013 ms@suse.de
- prepare fetchFile() function to be able to handle 'xz'
  compressed files as well as 'gzip' compressed files. This
  is related to the enhancement report in (bnc #787400)
* Fri Aug 30 2013 rjschwei@suse.com
- fixed version number for openSUSE 13.1 boot images
- added cdrkit-cdrtools-compat package for the openSUSE 13.1
  isoboot boot description to get isoinfo back into the path
* Thu Aug 29 2013 ms@suse.de
- fixed typo in message output, surplus '\n' prior to status flag
* Thu Aug 29 2013 ms@suse.de
- added indention helper, tab to 4 spaces
* Thu Aug 29 2013 ms@suse.de
- removed obsolete modules/.test directory including
  unused and broken unit tests
* Thu Aug 29 2013 ms@suse.de
- v5.05.31 released
* Wed Aug 28 2013 adrian@suse.de
- add also noarch and armv6hl architectures
* Wed Aug 28 2013 adrian@suse.de
- add armv7hl and aarch64 as supported architectures
* Tue Aug 27 2013 ms@suse.de
- make the partition based installation smarter (bnc #836780)
  * the current implementation shows a list of partitions to select
    if there is a choice. however this could be done better by
    taking the size, partid and fs-label information into account.
    With this patch the user only has to choose a partition if there
    is really more than one partition which matches the size and
    partid and filesystem label constraints
* Tue Aug 27 2013 ms@suse.de
- fixed creation of EFI capable USB stick install images
  * the code which makes use of the bios_grub flag was not applied there
* Tue Aug 27 2013 ms@suse.de
- v5.05.30 released
* Tue Aug 27 2013 ms@suse.de
- fixed use of uninitialized value $oem{"kiwi_oemswap"}
  in KIWIProfileFile.pm
* Mon Aug 26 2013 ms@suse.de
- get the partition ID check back in OEMFindPartitions (bnc #836052)
  * if in oem-partition-install mode the function checked suitable
    partitions only by its size but not by its partition id. I had
    removed the support for it because the GPT doesn't have partition
    hex id's like the MBR table has it. But it has turned out this
    was a useful check. Thus I added it back by mapping GPT partition
    names to MBR hex id's. When installing a kiwi EFI image via the
    partition install mode it's important to name the partitions
    on the installation disk in the same way as it's done in the
    image. This is a small requirement for partition based EFI image
    installations.
* Mon Aug 26 2013 adrian@suse.de
- fixed kiwi instsource plugins:
  * added UEFI boot support
  * adapt to new data structure, deleting getImageTypeAndAttributes_legacy
* Mon Aug 26 2013 ms@suse.de
- added optional type attribute <type ... zfsoptions=...  />
  * the attribute value can be a comma separated list of ZFS
    options used on creation time of the ZFS pool. Thus the
    result are 'zfs set $option kiwipool' calls which allows
    to set pool attributes like compression and others
* Mon Aug 26 2013 ms@suse.de
- moved __quote function to the correct name space. It was
  formerly used as part of KIWIXML but due to the restructuring
  it's required in KIWIProfileFile now
* Fri Aug 23 2013 ms@suse.de
- v5.05.29 released
* Fri Aug 23 2013 ms@suse.de
- fixed typo in product building
* Fri Aug 23 2013 ms@suse.de
- v5.05.28 released
* Fri Aug 23 2013 ms@suse.de
- added __checkProfileConsistent() runtime check if the
  specified profile(s) exists
* Fri Aug 23 2013 ms@suse.de
- fixed root=... setup if zfs is used, stay compatible with dracut
* Fri Aug 23 2013 ms@suse.de
- make sure bootprofile 'default' is set if no other boot
  profile was specified
* Fri Aug 23 2013 ms@suse.de
- added KIWIURL::__realPath() helper function (bnc #836053):
  * the function translates existing local paths to its real
    path including collapse of path spec like /foo/../quux
* Fri Aug 23 2013 ms@suse.de
- changed __getBootSize() helper to allow a min boot
  partition size of 100 MB
* Thu Aug 22 2013 ms@suse.de
- fixed split creation, wrong use of KIWIXMLSplitData methods
* Thu Aug 22 2013 ms@suse.de
- finished XML restructuring and moved all XML handling
  into the new data structure. The code is now legacy code
  free. With the new internal structure in place data can
  also fly in from other protocols which might be needed
  in the future for e.g configuration management, CIM,
  cfengine
* Thu Aug 22 2013 ms@suse.de
- moved product/instsource handling to the new data structure.
  The following legacy function were removed:
  * getInstSourceArchList_legacy
  * getInstSourceDUDInstsys_legacy
  * getInstSourceDUDModules_legacy
  * getInstSourceDUDTargets_legacy
  * getInstSourceMetaPackageList_legacy
  * getInstSourceProductInfo_legacy
  * getInstSourceProductOption_legacy
  * getInstSourceProductStuff_legacy
  * getInstSourceProductVar_legacy
  * getInstSourceRepository_legacy
  * getInstSourcePackageList_legacy
  * getInstSourceMetaFiles_legacy
  * getInstSourceChrootList_legacy
  * getInstSourcePackageAttributes_legacy
  * getInstSourceDUDInstall_legacy
  * clearPackageAttributes_legacy
  * getList_legacy
  * getPackageAttributes_legacy
  * __getInstSourceDUDPackList_legacy
* Wed Aug 21 2013 ms@suse.de
- moved split tmp/persistent files handling to the new data structure
  Along with the change the following legacy functions were deleted:
  * getSplitPersistentExceptions_legacy
  * getSplitPersistentFiles_legacy
  * getSplitTempExceptions_legacy
  * getSplitTempFiles_legacy
* Wed Aug 21 2013 ms@suse.de
- deleted writeXMLDescription_legacy
  * the old data structure allowed to write changes applied to the
    XML objects to be written persistently. With the new data
    structure the XML object has a method writeXML which allows
    to write the current data set in the XML format. The work
    on the XML writer is not yet finished. Thus the support for
    writing changes back to the XML will be added back at a later
    point in time.
* Tue Aug 20 2013 ms@suse.de
- moved <size> handling over to the new data structure
  * deleted: getImageSize_legacy
  * deleted: getImageSizeAdditiveBytes_legacy
  * deleted: getImageSizeBytes_legacy
* Tue Aug 20 2013 ms@suse.de
- moved editbootinstall/editbootconfig handling to the new data structure
  * deleted getEditBootConfig_legacy
  * deleted getEditBootInstall_legacy
* Mon Aug 19 2013 ms@suse.de
- moved getInstSourceFile_legacy into the global space.
  This function is just a file downloader and does not belong
  to the legacy code. Along with the change the function was
  renamed to KIWIGlobals -> instance() -> downloadFile(...)
* Mon Aug 19 2013 ms@suse.de
- fixed grub2 graphics boot for openSUSE 13.1:
  * gfxterm must be compiled in
* Mon Aug 19 2013 ms@suse.de
- reduce the use of getPackageAttributes_legacy
* Mon Aug 19 2013 ms@suse.de
- set a useful default for the bootloader when building live iso images
* Mon Aug 19 2013 ms@suse.de
- moved handling of testsuite packages into the new data structure
  * deleted legacy function: getTestingList
- moved creation of .profile environment file into the new data structure
  * deleted legacy function: getImageConfig_legacy
  * deleted KIWIProfileFile method: updateFromHash
* Mon Aug 19 2013 ms@suse.de
- moved type attribute handling into the new data structure
  * renamed updateDescription to updateDescription_legacy
  * deleted the following legacy functions:
  + getImageTypeAndAttributes_legacy
  + __setTypeAttribute
* Mon Aug 19 2013 ms@suse.de
- added missing kiwi_oemskipverify variable to allowed
  variables in KIWIProfileFile
* Mon Aug 19 2013 ms@suse.de
- moved use of getImageTypeAndAttributes_legacy into
  class method calls of the new data structure
* Sat Aug 17 2013 ms@suse.de
- fixed md5file setup in oem installpxe mode:
  the raw disk image is stored compressed thus the zblocks
  information is required when atftp is used for the transfer
* Fri Aug 16 2013 ms@suse.de
- moved type attribute handling for the creation of
  the .profile environment into the new data structure
  respectively delete the handling from getImageConfig_legacy
- combine the inheritance code which transfers information
  from the system XML to the boot XML at one place
  which is the prepareBootImage() function
* Thu Aug 15 2013 ms@suse.de
- v5.05.27 released
* Thu Aug 15 2013 ms@suse.de
- moved handling for defaultroot attribute to new data structure
  and use the getPreferences() -> getDefaultRoot() access method
  The following legacy function were removed:
  * getImageDefaultDestination_legacy
  * getImageDefaultRoot_legacy
  * __getPreferencesNodeByTagName
* Thu Aug 15 2013 ms@suse.de
- fixed kiwi script calls if they are done contained via lxc
  the callContained() function was changed to use the lxc-start
  tool to run the scripts instead of wrapping around lxc-init
  and calling lxc-execute (bnc #832337)
* Wed Aug 14 2013 ms@suse.de
- moved handling of image data into the new data structure
  the following legacy function was deleted:
  * __setImageAttribute
* Wed Aug 14 2013 ms@suse.de
- moved handling of preferences data into the new data structure
  the following legacy functions were deleted:
  * getBootTheme_legacy
  * getLicenseNames_legacy
  * getLocale_legacy
  * __setOptionsElement
  * __addOptionsElement
* Wed Aug 14 2013 ms@suse.de
- moved LVM handling over to the new data structure
  the following legacy functions were deleted:
  * getLVMVolumes_legacy
  * __addVolume_legacy
* Tue Aug 13 2013 ms@suse.de
- moved handling of oemconfig information into the new data structure
  along with the change the following legacy functions disappeared
  * getOEMAlignPartition_legacy
  * getOEMBootTitle_legacy
  * getOEMBootWait_legacy
  * getOEMKiwiInitrd_legacy
  * getOEMPartitionInstall_legacy
  * getOEMReboot_legacy
  * getOEMRebootInter_legacy
  * getOEMRecovery_legacy
  * getOEMRecoveryID_legacy
  * getOEMRecoveryInPlace_legacy
  * getOEMShutdown_legacy
  * getOEMShutdownInter_legacy
  * getOEMSilentBoot_legacy
  * getOEMSilentInstall_legacy
  * getOEMSilentVerify_legacy
  * getOEMSkipVerify_legacy
  * getOEMAtaRaidScan_legacy
  * getOEMSwap_legacy
  * getOEMSwapSize_legacy
  * getOEMSystemSize_legacy
  * getOEMUnattended_legacy
  * getOEMUnattendedID_legacy
  * __setOEMOptionsElement
* Tue Aug 13 2013 dmueller@suse.com
- fixed sat solver support for armv6l
  * the system (uname) might reports armv6l but the package meta
    data stores armv6hl for both armv6l and armv6hl cpu types. In
    order to set the right arch to the sat pool the arch name has
    to be adapted in this case
- fixed the spec file setup for the myarch variable for
  armv6l/armv6hl. The script generating the requires list for the
  auto generated *boot-requires packages only deals with the arch
  name armv6l.
* Tue Aug 13 2013 ms@suse.de
- moved handling of xen domain into the new data structure
* Mon Aug 12 2013 ms@suse.de
- make KIWICache code legacy free
* Mon Aug 12 2013 ms@suse.de
- create a helper function __updateProfileEnvironment in the
  KIWIImageCreator code to reduce code duplication
- prepareBootImage and createBootImage always run in a sequence
  thus it's not required to read in the boot image description
  twice. The XML description for the boot (initrd) image is now
  read in once in boot prepare and just re-used next in the boot
  create step. This also simplifies the handling of inherited
  data from the system into the boot image
* Sun Aug 11 2013 ms@suse.de
- removed following legacy functions:
  * getTypeSpecificPackageList_legacy
  * getArchiveList_legacy
  * getBaseList_legacy
  * getDeleteList_legacy
  * getInstallList_legacy
  * getInstallSize_legacy
  * getPackageManager_legacy
  * setPackageManager_legacy
  * getURLHash_legacy
  * getRepoNodeList_legacy
  * addRemovePackages_legacy
  * getStripNodeList_legacy
  * getBootIncludes_legacy
  * addPatterns_legacy
  * addPackages_legacy
  * addImagePatterns_legacy
  * addImagePackages_legacy
  * addArchives_legacy
* Fri Aug  9 2013 ms@suse.de
- move KIWIXMLInfo module to use new data structure.
  The following legacy functions are not in use anymore:
  * getInstallSize_legacy
  * getURLHash_legacy
  * setPackageManager_legacy
  * __createURLList_legacy
* Fri Aug  9 2013 ms@suse.de
- improved information provided by .releasetags helper tool
* Fri Aug  9 2013 ms@suse.de
- change processing order of upgrade request:
  * handle the requested deletion of packages last
* Fri Aug  9 2013 ms@suse.de
- move package/archive handling into new data structure
  * remove getReplacePackageDelList/getReplacePackageAddList
  * implemented for kiwi's prepare, create and upgrade modes
  * reduced the use of the following legacy functions:
  + getArchiveList_legacy
  + getDeleteList_legacy
  + getBaseList_legacy
  + getTypeSpecificPackageList_legacy
  + getInstallList_legacy
* Thu Aug  8 2013 rjschwei@suse.com
- new tests to cover the newly implemented methods related to VHD tagging
* Wed Aug  7 2013 ms@suse.de
- remove obsolete kiwi_fixedpackbootincludes from .profile env
  * this information was used in the functions basePackBootIncludes
    and baseUnpackBootIncludes to preserve boot included data from
    being removed by kiwi's initrd strip processing. With the new
    system based and the <strip> section and also documented in:
    http://doc.opensuse.org/projects/kiwi/doc/#sec.bootcustomization
    these functions became obsolete.
* Wed Aug  7 2013 ms@suse.de
- fixed getDomain() call on undefined object reference
* Tue Aug  6 2013 ms@suse.de
- removed use of getXenConfig_legacy:
  * use new KIWIXMLVMachineData object to handle this part
* Tue Aug  6 2013 ms@suse.de
- update pre-commit hook:
  * add information about perl code verification
  * skip the unit test perl code from being verified by 'perl -w'
* Tue Aug  6 2013 ms@suse.de
- update openSUSE 12.3 JeOS
  * make sure kernel-desktop is not installed by default
    if the xen profile is active. For some strange reason
    zypper always installs kernel-desktop which is unwanted
* Tue Aug  6 2013 ms@suse.de
- cleanup KIWIImageFormat class:
  * make the format code legacy code free
* Tue Aug  6 2013 ms@suse.de
- added .releasetags helper script to find release commits
* Tue Aug  6 2013 ms@suse.de
- added disk tagging support for Windows Azure (bnc #815809)
  * added function writeVHDTag called in createVHDSubFormatFixed
  * added <type> attribute 'vhdfixedtag' to store the tag following
    the pattern: "[0-9a-f]{8}-([0-9a-f]{4}-){3}[0-9a-f]{12}"
* Fri Aug  2 2013 rjschwei@suse.com
- Create KIWIXMLDefStripData object:
  * encapsulate the KIWI defined default strip data
  * Use the new object in the ImageCreator to update the
    bootXML description accordingly plus some minor refactoring
    to avoid code duplication for the bootXML update
  * Implement unit tests
- Remove any knowledge of the default strip data from the
  XML class implementations
* Sun Jul 28 2013 ms@suse.de
- DB: added susesync for developer documentation
* Fri Jul 26 2013 ms@suse.de
- moved strip section handing into new data structure. The reading of
  the default strip section data has been moved to the
  prepare/createBootImage functions and is no longer part of the KIWIXML
  constructor. The following legacy functions will be removed:
  * removed __getStripDelete_legacy
  * removed __getStripTools_legacy
  * removed __getStripLibs_legacy
  * removed __addStrip_legacy
* Fri Jul 26 2013 ms@suse.de
- cleanup code:
  * removed unused repository data from changeset
  * removed unused variables in updateDescription
  * added comments for removed changeset sections
* Fri Jul 26 2013 ms@suse.de
- added call for genDevDoc as part of the doc Makefile
* Thu Jul 25 2013 ms@suse.de
- fixed createOriginSnapshot to take care for all btrfs subvolumes
* Thu Jul 25 2013 ms@suse.de
- fixed use of uninitialized value $reqSize in addition
* Thu Jul 25 2013 rjschwei@suse.com
- update EC2 example
  + it makes no sense to include plymouth, the branding of the boot
    screens is not visible in a cloud image
* Wed Jul 24 2013 ms@suse.de
- get rid of the loader variable in the kernel commandline
  kiwi stores this information as kiwi_bootloader variable in
  the initrd if set as part of the <type>. if not set the arch
  specific default applies
* Wed Jul 24 2013 ms@suse.de
- get rid of the VGROUP variable in the kernel commandline
  store this information in the kiwi initrd instead as
  variable kiwi_lvmgroup
* Wed Jul 24 2013 ms@suse.de
- cleanup disabled code
* Wed Jul 24 2013 ms@suse.de
- s390: respect specified boottimeout for zipl.conf
* Wed Jul 24 2013 ms@suse.de
- one -x file check in suseActivateDefaultServices is enough
* Tue Jul 23 2013 ms@suse.de
- fixed file check in KIWIConfig.sh::suseService
* Mon Jul 22 2013 ms@suse.de
- s390: fixed setStoragePartition to write a 'w' command
  to close the fdasd command queue
* Mon Jul 22 2013 ms@suse.de
- fixed creation of .packages and .verified meta data if a
  relative path is used in the kiwi create call
* Mon Jul 22 2013 ms@suse.de
- s390: update JeOS template description, repo setup for SP3
* Mon Jul 22 2013 ms@suse.de
- fixed broken shell string comparison in KIWILinuxRC
  if the variable $loader is not set (bnc #829537)
* Mon Jul 22 2013 ms@suse.de
- fixed creation of mdadm.conf. The file is missing if the
  original RAID setup is used without formatting (bnc #829504)
* Mon Jul 22 2013 ms@suse.de
- changed the code calling 'echo something >> file' to real
  perl code opening and closing the file for appending data
  including error checking
* Mon Jul 22 2013 ms@suse.de
- don't search for shell builtins like 'echo' by using
  KIWILocator. With the last change from 'which' to 'type -p'
  shell builtins will not be found anymore.
* Sat Jul 20 2013 ms@suse.de
- fixed 32bit efi builds. the created efi binary should be
  named bootx32.efi for this architecture
* Sat Jul 20 2013 ms@suse.de
- update unit tests due to i586/i686 vs ix86 arch name change
* Sat Jul 20 2013 ms@suse.de
- don't turn arch name i686/i586 into combined ix86 name. This is
  required with regards to the previous commit handling i586 and
  i686 specific packages setup (bnc #829429)
* Sat Jul 20 2013 ms@suse.de
- fixed boot image descriptions for 32bit x86 builds (bnc #829429)
  * kernel-desktop doesn't exist for i586 anymore
  * kernel-pae doesn't exist for i586 anymore
  * don't use ix86 as arch statement because this doesn't allow
    to distinguish between i686 and i586
* Wed Jul 17 2013 rjschwei@suse.com
- fix up the live ISO example for openSUSE 12.3
  + changes in patterns and removal of SuSEconfig break the
    existing example
* Tue Jul 16 2013 dmueller@suse.com
- fixed editboot path conversion when it applies to the
  working directory. The previous code change broke the
  logic for relative paths matching the current dir
* Mon Jul 15 2013 dmueller@suse.com
- fixed KIWILocator for openSUSE 13.1:
  * various commands were moved to /usr/sbin and this path
    is not in the search path for KIWILocator which results
    in the locator code not being able to find them.
  * Additionally the 'which' command got splitted into a
    separate package. In order to simplify the backward
    compatibility we decided to use 'type -p', which is a
    a standard bash builtin
* Fri Jul 12 2013 ms@suse.de
- wait for udev to finish the event queue before killing the daemon
* Fri Jul 12 2013 ms@suse.de
- v5.05.26 released
* Fri Jul 12 2013 ms@suse.de
- fixed spec file to match build requires with package requires
* Fri Jul 12 2013 ms@suse.de
- fixed default bootloader selection for s390 architecture
* Thu Jul 11 2013 ms@suse.de
- make sure setupBootLoaderGrub2() creates /boot/grub2/device.map
  which is required for suse tools to work correctly
* Thu Jul 11 2013 ms@suse.de
- fixed handling of bootincluded items:
  * packages and archives marked as bootinclude have to
    respect an optional arch setup like this example:
    <package name="foo" bootinclude="true" arch="ix86"/>
* Thu Jul 11 2013 ms@suse.de
- cleanup getBootIncludePackages(), I thought comments and
  variable names are misleading
* Thu Jul 11 2013 ms@suse.de
- fixed initrd creation for ec2 images done with mkinitrd
  * For EC2 images kiwi uses mkinitrd to create a targeted for EC2 initrd,
    rather than the usual kiwi initial intrd that generates a new initrd
    on firstboot. With SLE 11 SP3 mkinitrd got "smarter" to the
    disadvantage of building an initrd on system A that is targeted for
    system B. Therefore we were forced to create a so called "monster
    initrd". This monster initrd include basically everything, hence the
    name. While this in general is only a minor size concern in EC2 this
    has the ill effect that the image will not boot. The reason for the
    non booting image is the inclusion of multipath in the initrd.
    This patch moves the 61-multipath.sh away for the call of mkinitrd
    and put it back afterwards
* Wed Jul 10 2013 ms@suse.de
- v5.05.25 released
* Wed Jul 10 2013 ms@suse.de
- added build result meta data files
  * each build now contains two additional files:
    The .packages file which contains a list of all installed packages
    The .verified file which contains the result of rpm -Va
    These files are only created on rpm based systems and
    should help to compare build results better
* Wed Jul 10 2013 ms@suse.de
- allow the function partedWrite() to return instead of a
  rebootException on error and if the hybrid persistent feature
  is activated. In this case we want to proceed with the boot
  process but deactivate the persistent write feature
* Wed Jul 10 2013 ms@suse.de
- make sure 'sg_inq' tool stays in the initrd, this is new
  for udev in openSUSE 13.1
* Wed Jul 10 2013 ms@suse.de
- v5.05.24 released
* Wed Jul 10 2013 ms@suse.de
- isoinfo moved to /usr/lib/genisoimage which is not a default
  search path. Thus kiwi did not find the tool in openSUSE 13.1
  with this fix kiwi looks up the binary in /usr/bin and in
  /usr/lib/genisoimage
* Wed Jul 10 2013 ms@suse.de
- kiwi maps the arch name for intel 32bit to 'ix86' but many
  image descriptions used the name 'i686' which was wrong.
  This also fixed the 32bit live iso building because we
  use arch specific efi packages for building them
* Mon Jul  8 2013 ms@suse.de
- explicitly set firmware to 'bios' for older live iso
  image templates
* Mon Jul  8 2013 ms@suse.de
- return early in updatePartitionTable() if the image is a
  hybrid iso containing a GPT
* Fri Jul  5 2013 ms@suse.de
- improve messages in loadNetworkCardS390 to be more clear
* Fri Jul  5 2013 ms@suse.de
- if processing of loadNetworkCardS390 was skipped by a flag
  file the return value should be 1 not 0 to make sure we
  don't proceed with other network functions
* Thu Jul  4 2013 thardeck@suse.de
- prevent duplicates in resolv.conf managed by setupDNS
  * if setupDNS is called multiple times it added the same
    line again and again. This patch checks if the entry
    exists before adding it
* Wed Jul  3 2013 thardeck@suse.de
- s390: introduced new function loadNetworkCardS390
  * allow preconfiguring of s390 network cards. The function checks
    on a given host (DASD 191 in our case) for a parm file with the
    name <LINUX_USER_ID>.PARM-S11. If it is found the parameters
    normally read from the kernel cmdline are read from there and
    exported. The exported data takes effect later to set up the
    network with the setupNetworkInterfaceS390 function.
    The check for the parm file can be deactivated by a one-time
    flag file '/etc/deactivate_s390_network_config_from_dasd'
    which is removed when found and evaluated
* Wed Jul  3 2013 thardeck@suse.de
- extend includeKernelParameters to parse files
  * before this patch only /proc/cmdline was read in
    now an optional paramters allows to change this
* Wed Jul  3 2013 ms@suse.de
- fixed getRepos() in migration module to handle cd:// url types
  correctly and in the same way like dvd:// url types
* Wed Jul  3 2013 ms@suse.de
- fixed use of uninitialized value $reqSize in KIWIBoot
* Wed Jul  3 2013 ms@suse.de
- don't mount/umount the zfs pool let zpool import/export do it
* Tue Jul  2 2013 ms@suse.de
- fixed getOperatingSystemVersion() in the kiwi migration module
  to check for baseversion in addition to the version element
* Tue Jul  2 2013 ms@suse.de
- v5.05.23 released
* Tue Jul  2 2013 ms@suse.de
- follow up fix for parted invocation:
  * I broke the index counter in the flag setup
* Tue Jul  2 2013 ms@suse.de
- fixed pxePartitionInputGeneric():
  * it's required to pass the partition ID when setting the partition type
  * set lxboot instead of lxroot as partition name for the boot partition
- Unfortunately suse's parted doesn't understand the set call
  'set ... swap on|off' even though the man page explicitly say so
  thus I disabled this flag setup for now
* Tue Jul  2 2013 ms@suse.de
- removed use of grub2-efi for openSUSE 13.1, the package
  was dropped and instead the following grub2 packaging
  schema exists:
  grub2             => grub tools
  grub2-x86_64-efi  => grub efi modules 64bit
  grub2-i386-efi    => grub efi modules 32bit
  grub2-i386-pc     => grub bios modules
* Tue Jul  2 2013 ms@suse.de
- fixed return value of setupBTRFSSubVolumes if no volumes are configured
* Mon Jul  1 2013 ms@suse.de
- fixed ec2 image md5 file creation
  * after the ec2 format code has changed the contents of the
    image it's required to rebuild the md5 sum
* Mon Jul  1 2013 ms@suse.de
- v5.05.22 released
* Mon Jul  1 2013 ms@suse.de
- switched from perl-Test-Unit to perl-Test-Unit-Lite
  openSUSE 13.1 will not provide it anymore and also the
  author of perl-Test-Unit recommended to switch to the
  lite version: http://cpanratings.perl.org/dist/Test-Unit
* Mon Jul  1 2013 ms@suse.de
- fixed parted invocation:
  * don't use the suse only extension which allows to set the
    partition type by its hex ID, instead use the flags parted
    natively supports
* Fri Jun 28 2013 rjschwei@suse.com
- fix test in factory
  + fix logic error in XML processing, only mark the first type found
    as the first type. While the flag indicator was set to 0 at the end of
    the loop it was re-initialized with 1 at the beginning of the loop
- fix latent test bug
  + the order of calls was incorrect, thus when a file system tool
    was not present the test reacted to the output from the test itself,
    rather than from the code under test
* Fri Jun 28 2013 ms@suse.de
- fixed use of uninitialized value in string eq at KIWIBoot.pm
* Fri Jun 28 2013 ms@suse.de
- update rhel-06.0 JeOS template
* Fri Jun 28 2013 ms@suse.de
- update suse-oem-preload example
  * still use legacy grub not grub2 for the split example
    because grub2 tools are not prepared for splitted up
    root filesystem
* Fri Jun 28 2013 ms@suse.de
- DB: rebuild documentation
* Fri Jun 28 2013 ms@suse.de
- DB: fixed documentation: wrong kiwi commandline call
* Fri Jun 28 2013 ms@suse.de
- fixed use of uninitialized value $record{"filesystem"} in
  pattern match (m//) at KIWIXML.pm
* Thu Jun 27 2013 ms@suse.de
- renew partition creation code in KIWIBoot. make it more
  readable, reduce duplicate code and allow efi images without
  forcing a boot partition
* Thu Jun 27 2013 ms@suse.de
- zfs integration, make sure pool is exported on shutdown
  * added /run/initramfs/shutdown script compatible to dracut see:
    https://www.kernel.org/pub/linux/utils/boot/dracut/dracut.html
    section: #_dracut_on_shutdown for reference
* Wed Jun 26 2013 ms@suse.de
- fixed installBootLoader() to allow skipping the installation
  of the legacy bios grub2 loader if the system doesn't have the
  bios grub2 modules installed but EFI is selected as firmware
* Wed Jun 26 2013 rjschwei@suse.com
- improve EC2 initrd creation
  * consider filesystem used, do not blindly assume ext3
  * create a "monster" initrd to avoid the mkinitrd code from probing
    into the device tree. The device tree is different on the build
    machine than the target EC2 infrastructure
- exit early if no EC2 account credentials are defined
  * if no credentials are defined we cannot create a bundle, exit after
    initrd creation if no credentials exist
* Tue Jun 25 2013 ms@suse.de
- keep a copy of the initrd in /run/initramfs to allow systemd
  the jump back to the initrd. This is what a dracut initrd
  would do as well and it also allows operations after the root
  filesystem is umounted, e.g export the zfs pool
* Tue Jun 25 2013 ms@suse.de
- update root=... variable correctly if zfs is used
* Mon Jun 24 2013 ms@suse.de
- fixed editbootconfig/editbootinstall
  * make sure these options are evaluated for the iso type too
  * make sure absolute paths specified with commandline options
    are checked and used if the file exists
* Mon Jun 24 2013 ms@suse.de
- make sure FBOK also works if isconsole helper doesn't exist
* Mon Jun 24 2013 ms@suse.de
- use zfs set mountpoint instead of mount --move
* Fri Jun 21 2013 ms@suse.de
- v5.05.21 released
* Fri Jun 21 2013 ms@suse.de
- fixed profile setup, don't set lvm variable if zfs or btrfs is used
* Thu Jun 20 2013 ms@suse.de
- mount EFI (fat) jump partition to /boot/efi and not boot/EFI
  this is required to let suse tools work correctly (bnc #825221)
* Thu Jun 20 2013 ms@suse.de
- fixed legacy BIOS/CSM support for oem images
  * for some reason it's required to toggle the bios_grub flag
    after install and repart of an oem image to fix the EFI boot
  * use grub2-bios-setup directly instead of grub2-install because
    grub2-install for an EFI image does not install anything
* Thu Jun 20 2013 ms@suse.de
- removed the four primary partition limit in the oem repart code
* Thu Jun 20 2013 ms@suse.de
- fixed updatePartitionTable
  * if the disk geometry has changed parted's fix is to write
    a gpt_sync_mbr and destroy the gpt with it. In that case
    kiwi has to rewrite the entire table with a new GPT label
    This is related to (bnc #825221)
* Thu Jun 20 2013 ms@suse.de
- added grub2-efi by default for openSUSE 12.3 JeOS template
* Wed Jun 19 2013 ms@suse.de
- support <systemdisk> element for volume capable filesystems
  * The kiwi supported filesystems btrfs and zfs support their
    own volume management system. Because of this reason kiwi
    evaluates the contents of the optional systemdisk volumes
    for those filesystems by the native filesystem support and
    not via LVM
* Wed Jun 19 2013 ms@suse.de
- fixes for the zfs support
  * fixed handling of options in fsmountoptions passed to zpool
  * added support for zfs resize in resizeFilesystem
* Wed Jun 19 2013 ms@suse.de
- fixed regression in cylinder count detection in partedInit
  the unix device name is required to parse the parted output
  correctly but it might happen that the udev device name is
  passed to the function
* Tue Jun 18 2013 ms@suse.de
- fixed suse-12.3/suse-ec2-guest template
  * module-init-tools must be installed early as part of bootstrap
  * kernel-ec2-base conflicts with kernel-ec2
* Mon Jun 17 2013 ms@suse.de
- fixed creation of iso persistent write partition (bnc #825172)
  * fixed detection of cylinder count for isohybrid tables
  * use isohybrid EFI bootable image by default, the partition
    table written in this case allows standard partition device
    (e.g /dev/sda1) for EFI and protective MBR thus works in both
    worlds correctly and allows the creation of additional
    partitions without problems
  * don't use a fixed partition number, use the next one free
  * always create a filesystem on the write partition with
    the 'hybrid' label, even if the used overlay technique does
    not urgently requires this. The label helps to identify the
    write device on reboot
  * use parted instead of fdisk. fdisk is not suitable when adding
    partitions to the GPT, use kiwi's createPartitionerInput method
  * fixed clicfs cow file check, check clicfs only if clicfs is
    used, with the move to overlayfs there is a choice now
  * search for persistent write partition by a blkid label search
    and don't actually mount/umount the partition by label
  * syslinux >= 4.04 is required to make all this work
    correctly
* Fri Jun 14 2013 ms@suse.de
- v5.05.20 released
* Thu Jun 13 2013 ms@suse.de
- return early from setupBootPartitionPXE if $imageRootDevice
  is empty. This is the case when the netboot code checks the
  update case
* Thu Jun 13 2013 ms@suse.de
- moved __checkPackageUnique() test from an error message to
  a warning message. for the package manager this is not an
  error condition too so it shouldn't be one for kiwi
* Thu Jun 13 2013 ms@suse.de
- added isconsole helper program which checks the linux
  console mode with the KDGETMODE ioctl. The program is
  used in a new shell function named FBOK to check the
  framebuffer/console capabilities better in order to
  know if we can run fbiterm there or not
* Thu Jun 13 2013 ms@suse.de
- add elilo package to suse-SLE11-JeOS template for the uefi profiles
* Wed Jun 12 2013 ms@suse.de
- grub setup secure boot fixes:
  * don't use insmod when in uefi secure boot mode
  * don't use graphics, grub terminal is the console in this mode
* Tue Jun 11 2013 ms@suse.de
- added setupBootPartitionPXE() to check and setup the boot
  partition if any in case of a pxe image. The pxe image type
  offers different boot scenarios than the other kiwi supported
  image types. Thus it got its own function now and I could
  also cleanup the pxe specific hacks we had in the base
  setupBootPartition() function
* Tue Jun 11 2013 ms@suse.de
- Better integration of ZFS:
  * moved from kiwiroot to kiwipool as zfs pool name
  * evaluate fsmountoptions in zpool create
  * added function setupZFSPoolVolumes() which creates the
    zfs pool layout as suggested by the community
* Mon Jun 10 2013 ms@suse.de
- make kiwi locale files available in vmx type images too
* Mon Jun 10 2013 ms@suse.de
- follow up fix for (bnc #823617)
  * use message text from gettext catalog, i18n support
  * use the dialog program to display the message if it is installed
    as part of the image. We are already inside the running system
    when this message might be displayed. If no dialog is installed
    the message is just echo'ed on the console with a waitkey
    exception
* Mon Jun 10 2013 ms@suse.de
- update kiwi message text template kiwi.pot
  * added new text informing the user for a failed bootloader setup
* Mon Jun 10 2013 ms@suse.de
- adapted LVM resize in oem partition install mode
  according to the new @root volume setup
* Fri Jun  7 2013 ms@suse.de
- set GRUB_TERMINAL to console if no unicode font exists
* Fri Jun  7 2013 ms@suse.de
- v5.05.19 released
* Fri Jun  7 2013 ms@suse.de
- if the bootloader can't be installed stop the boot process
  and print a warning message to the user. Continue the boot
  with a wait-for-key exception (bnc #823617)
* Thu Jun  6 2013 ms@suse.de
- added support to specify the size of the root volume.
  With regards to the latest LVM consistency checks and adaptions
  it was only possible to set one volume as the one taking the
  rest space. This is either the root volume or the one flagged
  as freespace="all". The possibility to setup a specific size
  for the root volume and define another volume to take the rest
  space was lost. With this commit you can now optionally define
  the size of the root volume:
  <volume name="@root" size="..." | freespace="..."/>
  I also fixed the LVM setup when used with standard vmx virtual
  disks and introduced new consistency checks e.g it doesn't
  make sense to specify both size and freespace for one volume
* Tue Jun  4 2013 ms@suse.de
- fixed fetchFile function. The variable $imageBlkSize is
  not initialized, so it is better to use $chunk
* Tue Jun  4 2013 rjschwei@suse.com
- write dvd/cd device entry to vmx file if the device ide is 0 (bnc 822185)
* Mon Jun  3 2013 ms@suse.de
- fixed getSingleInstSourceSatSolvable()
  * instead of rely on the suffix of a file it's better to
    actually check if it's compressed or non compressed data
    due to redirections and symlinks it might happen that a
    file name e.g 'packages' is resolved into 'packages.en.gz'
    kiwi downloaded the file and failed to check that it's
    a compressed file (bnc #822247)
* Mon Jun  3 2013 ms@suse.de
- improved error output of failed schema validation
  * also check if the converted file can be created or not
* Mon Jun  3 2013 ms@suse.de
- fixed 5.7 to 5.8 xsl stylesheet
* Mon Jun  3 2013 ms@suse.de
- fixed evaluation of oem-ataraid-scan parameter
* Mon Jun  3 2013 ms@suse.de
- fixed raw disk size calculation for split images
  the boot partition size was not taken into account
* Sun Jun  2 2013 ms@suse.de
- added support for zfs filesystem
  * still problems with grub2-mkconfig, can't find canonical path
* Thu May 30 2013 ms@suse.de
- preserve haveged, related to (bnc #766720)
* Thu May 30 2013 ms@suse.de
- fixed OEMRepartLVM creation of recovery partition
  * the recovery partition eats up all free space but it should
    use only the needed space to store the recovery data.
* Thu May 30 2013 ms@suse.de
- cleanup fix, use long option --file in grub search
  instead of -f. That's consistent with the other grub
  search calls
* Wed May 29 2013 ms@suse.de
- make sure udev is installed and not udev-mini
* Wed May 29 2013 ms@suse.de
- fixed search method used in grub.cfg
  * we already moved to a uuid search in the early grub config
    but in the main grub.cfg it was still a file search which
    for some reasons is not as stable as the uuid search even
    though I always find the file in the grub shell with ls
* Wed May 29 2013 ms@suse.de
- make sure partition names are set back within the
  oem repartition code
* Wed May 29 2013 ms@suse.de
- fixed restore of boot partition
  * if a different filesystem is used for the root and the boot
    partition the problem appeared that the restore code uses
    the filesystem type of the root partition for the restore
    of the boot partition
* Wed May 29 2013 ms@suse.de
- fixed names set for partitions in the GPT
  * lxlvm, lxro, lxrw, lxroot, lxboot, legacy, UEFI are possible
  * use 2MB for the legacy BIOS boot partition
  * use 32MB for the UEFI fat partition
  * really evalute return values from parted calls
* Tue May 28 2013 ms@suse.de
- removed experimental code from oem partition install block
  if the partition table did not fit the need kiwi tried to
  read-only mount the not yet installed image via a device
  mapper snapshot and starts a X session with gparted to
  make it easier for the user to setup the partition table.
  The idea is nice but there are too many pitfalls and it
  has been proven that it's better to offline prepare the
  install target and not do that while inside a minimal
  initrd system
* Tue May 28 2013 ms@suse.de
- update XML description to new schema version
* Tue May 28 2013 ms@suse.de
- update schema version from 5.7 to 5.8
  * removed syncMBR attribute and create an xsl template for it
* Tue May 28 2013 ms@suse.de
- rewrite of the legacy BIOS/CSM support
  * removed the syncMBR attribute from the XML schema
  * changed the partition layout if firmware="efi" is specified.
    A new partition with flag 'bios_grub' is created
  * install the bios grub2 into the protective MBR which
    exists according to the EFI spec if a GPT is used. The
    special bios_grub flaged partition is required to allow
    grub2 to install
* Fri May 24 2013 ms@suse.de
- v5.05.18 released
* Fri May 24 2013 ms@suse.de
- fixes for the oem partition install mode:
  * fixed check for amount of required partitions
  * removed check for partid, does not work well with GPT
  * fixed handling to be more generic and more independent
    from the number of partitions in the image. Using the
    filesystem label for selecting the partitions
- fixed runInteractive function and call params:
  * don't use --stdout option for dialog, the written result
    contains escape characters which confuses the code.
    Instead use the default stderr channel where dialog
    write its results
* Thu May 23 2013 ms@suse.de
- fixed oem partition install mode. Use kpartx sync mode
  to make sure devices are created  on return of the call
* Thu May 23 2013 ms@suse.de
- v5.05.17 released
* Wed May 22 2013 ms@suse.de
- don't repart the disk if less than 5MB are free
* Wed May 22 2013 ms@suse.de
- fixed __checkLVMoemSizeSettings runtime check to work correctly
  with the 'all' size specification
* Wed May 22 2013 ms@suse.de
- create global function dsize() which implements a size method
  to calculate the size of all entities in a directory using the
  du utility. du is called in two passes first in standard mode
  counting disk usage and secondly in apparent mode also checking
  for files with holes, fragmentation, indirect blocks and the
  like. The biggest value is returned
* Tue May 21 2013 ms@suse.de
- fixed getInstSourceFile_legacy proxy setup:
  * Thanks to Roman for a better regexp to get the proxy url
  * prevent double inclusion of source locator
* Tue May 21 2013 ms@suse.de
- fixed suse-SLE11-JeOS template:
  * the package grub2 was dropped for SLES-SP3 RC2
* Tue May 21 2013 ms@suse.de
- fixed provideMediaLicense function. The url passed to the
  getInstSourceFile_legacy contained a weird quoting
* Tue May 21 2013 ms@suse.de
- v5.05.16 released
* Tue May 21 2013 ms@suse.de
- fixed getInstSourceFile_legacy to work correctly with proxy url's
  the function cut the proxy data together with the information which
  file to download and lost the file information
* Mon May 20 2013 ms@suse.de
- fixed and optimized disk size calculation
  * I had by default 40%% spare space on the root path which seems to
    be too much, I have 20%% spare on each volume so I adapted that
    to the root path as well.
  * for the size estimation I now use the --apparent-size option in
    du, which works better on files with holes and other or other
    attributes which makes a difference when copying those data.
  * Use a fixed value for the filesystem overhead each volume adds
    to the disk. It is wrong to calculate and add a 20%% spare/volume
    according to the size of the data in the volume to the disk,
    because that value has already been taken into account with
    the data spare calculation of the entire tree
* Mon May 20 2013 ms@suse.de
- fixed __checkSystemDiskData runtime check to work correctly
  with the 'all' size specification
* Sat May 18 2013 ms@suse.de
- restructure the use of prebuilt boot images
  * adapt to new data structure thus we get rid of
    checkAndSetupPrebuiltBootImage, getDefaultPrebuiltDir_legacy
  * moved the logic for using a prebuilt version of a boot image
    into the image creator code at the level of prepareBootImage
    and createBootImage. This saves us one KIWIXML instance
  * write one function createImageBootImage which does either
    the prepare/create of the boot image or the use of an existing
    prebuilt version. reduces some code duplication
* Sat May 18 2013 ms@suse.de
- adapt handling of bootkernel and bootprofile to new data structure
  * there is still the function __populateDefaultProfiles_legacy
    active and working but as soon as this code will go away the
    transfer of the 'bootkernel' and 'bootprofile' attributes from
    the system image into the boot image must follow the new data
    structure which is based on get and set methods. Actually this
    change also fixes the creation of the .profile kiwi_drivers
    data because the code writing this is already based on the new
    internal data structure and was missing the correct boot
    profile information according to bootkernel and bootprofile
* Fri May 17 2013 ms@suse.de
- fixed unaligned done flags
* Fri May 17 2013 ms@suse.de
- cleanup KIWIXML constructor
  * The object variables $this->{buildType} and $this->{defaultType}
    were used without any real context and are just a copy of
    $imageType and $this->{selectedType}
* Fri May 17 2013 ms@suse.de
- fixed __populateDriverInfo
  * the function did not work correctly with the default profile
    name. It uses the kiwi internal default profile name 'kiwi_default'
    as real profile name and failed to use a section as default
    section if the 'default' profile name was explicitly specified
    like it is the case for the netboot boot image descriptions
* Fri May 17 2013 ms@suse.de
- cleanup code, prevent warning messages
* Fri May 17 2013 ms@suse.de
- v5.05.15 released
* Fri May 17 2013 ms@suse.de
- fixed structure of unpacked image tree when build with a cache
  In order to avoid any conflicts concerning code operating on
  the unpacked image tree it's required that the structure with
  and without using a base cache image is the same
* Thu May 16 2013 ms@suse.de
- v5.05.14 released
* Thu May 16 2013 ms@suse.de
- DB: rebuild documentation
* Thu May 16 2013 ms@suse.de
- Revert "- DB: update documentation, changed cache location"
  This reverts commit: 5e8a4ba11f6a8b29e2a60df91bd16e0c27adca35
* Thu May 16 2013 ms@suse.de
- Revert "- moved default kiwi cache image location" according
  to FHS /var/tmp/kiwicache is not allowed. This reverts
  commit: 5d667b7bb2d1774fe02835e378788638fcf9c582
* Thu May 16 2013 ms@suse.de
- v5.05.13 released
* Wed May 15 2013 ms@suse.de
- fixes for openSUSE 13.1 boot descriptions
  * removed support for legacy grub
  * add Mesa to delete list, for some reason that gets
    pulled in now so we make sure it will be removed
* Wed May 15 2013 ms@suse.de
- use xz compressor for live iso's based on overlayfs
* Wed May 15 2013 ms@suse.de
- fixed suseGFXBoot to work correctly if a two bootloader
  setup is requested like it is the case with EFI capable
  hybrid iso's. They use isolinux/gfxboot for the bios boot
  case and grub2/grub2-branding for the EFI boot. Thus the
  branding data needs to be handled for both and not only
  one loader
* Wed May 15 2013 ms@suse.de
- update default strip data to make the initrd a bit smaller
  * remove /usr/share/grub2/backgrounds
  * remove /usr/share/kbd
  * remove /usr/lib/rpm
* Wed May 15 2013 ms@suse.de
- improved/changed image caching system
  * switched from btrfs to overlayfs
  * no loop mounts involved anymore, thus one layer less
  * using native kernel overlay filesystem which performs
    better than fuse based filesystems. btrfs has turned out
    to work unstable when using loop devices and I could not
    find a noticeable performance difference between
    btrfs seed devices and the overlayfs upper/lower system
  * no cache files but cache trees. full freedom for the user
    to store those data on NFS, tmpfs, read-only locations...
  * all package solver tasks now done via satsolver, solvables
    will also be cached, no hacky ignore of packages in the
    cache selection code
  * following the keep it simple principle. the caching code
    is now pretty straight forward
* Wed May 15 2013 ms@suse.de
- DB: rebuild documentation
* Wed May 15 2013 ms@suse.de
- DB: update documentation, changed cache location
* Wed May 15 2013 ms@suse.de
- allow options for mksquashfs in createImageSquashFS
* Tue May 14 2013 ms@suse.de
- cache creation fixes:
  * make sure there are no // in path spec of kiwi-root.cache
  * ignore warning about missing auxiliary vector
* Tue May 14 2013 ms@suse.de
- moved default kiwi cache image location to /var/tmp/kiwicache
  instead of /var/cache/kiwi. I found problems with bind mounts
  into the same directory level
* Tue May 14 2013 ms@suse.de
- v5.05.12 released
* Tue May 14 2013 ms@suse.de
- if a targetdevice is used instead of a loop we need to wait
  for udev to finish the event loop in the same way as it is
  done in bindDiskPartitions() when binding the partitions of
  a loop device (bnc #819772)
* Fri May 10 2013 ms@suse.de
- DB: rebuild documentation
* Fri May 10 2013 ms@suse.de
- DB: update documentation
  + added some notes about new postHWdetect hook
  + added some notes about how software raid works in kiwi images
* Fri May 10 2013 ms@suse.de
- add hook entry point called: postHWdetect
  * it allows to create/modify your own representation of the
    deviceDisks array containing the found install disk devices
* Fri May 10 2013 ms@suse.de
- allow to control whether kiwi searches for ata raid
  controllers or not using the dmraid utility. This is
  useful if an alternative control tool exists or the
  raid should be ignored in any case:
  <oem-ataraid-scan>true|false</oem-ataraid-scan>
  By default the search and activation happens if dmraid
  is installed. Implemented by user feedback
  request (bnc #815206)
* Tue May  7 2013 ms@suse.de
- fixed gettext import, the import was done prior to the
  export of the LANG environment which caused some texts
  to be in the wrong language
* Tue May  7 2013 ms@suse.de
- make sure there is an active boot/root partition after
  the oem code has repartitioned the disk
* Tue May  7 2013 ms@suse.de
- allow alternative grub2 search path lib/grub and share/grub
  as it is packaged on Fedora
* Tue May  7 2013 ms@suse.de
- fixed setupLocale to work with locale list separated by ','
* Sun May  5 2013 mkoegler@auto.tuwien.ac.at
- fixed CD/DVD boot of live iso images with activated hybridpersistent
  option. kiwi will try to create the read-write partition but will
  fail if this image is booted from a read-only medium. Thus it should
  deactivate the hybridpersistent feature and proceed the boot
* Sun May  5 2013 ms@suse.de
- fixed use of uninitialized value $key in KIWIManagerYum.pm
* Fri May  3 2013 ms@suse.de
- v5.05.11 released
* Fri May  3 2013 ms@suse.de
- fixed xen dom0 boot configuration
  * the xen hypervisor was copied by kiwi as 'xen.gz.vmx' but the
    configuration was written to search for xen.gz and failed
* Fri May  3 2013 ms@suse.de
- don't use the same inode count calculated for root for
  the boot and/or efi filesystem
* Fri May  3 2013 ms@suse.de
- fixed restore of boot partition in recovery/restore mode
  for systems which uses an extra boot partition
* Thu May  2 2013 ms@suse.de
- fixed activation of md-raid array if no repartition
  process takes place
* Thu May  2 2013 ms@suse.de
- fixed display of language selection dialog:
  * if lang is _not_ set in /proc/cmdline we will now use the
    first language set in kiwi_language for the boot image.
    Thus a language selection dialog only appears if lang
    is explicitly set to 'ask'
* Thu May  2 2013 ms@suse.de
- fixed setup of recovery in a raid image. The meta information
  telling the system how big the recovery partition should be
  is now stored in the kiwi initrd and not in the image as it
  was before. According to this the broken mount code at that
  place could be removed
* Tue Apr 30 2013 ms@suse.de
- netboot: fixed setup of swap device in $imageSwapDevice
  If the partition table stays untouched the variable
  was not set which caused a broken fstab entry for
  swap. This patch makes sure the swap device variable
  is set in any case
* Tue Apr 30 2013 ms@suse.de
- don't show the same message twice
* Tue Apr 30 2013 ms@suse.de
- removed unneeded/wrong message
* Mon Apr 29 2013 ms@suse.de
- changed grub2 early boot script to search for the fs-uuid
  of the boot filesystem in order to locate the config file
* Mon Apr 29 2013 ms@suse.de
- DB: rebuild documentation
* Mon Apr 29 2013 ms@suse.de
- DB: update config.sh manual page, template fix
* Mon Apr 29 2013 ms@suse.de
- use the new baseMount() function in all config.sh scripts
  provided by the kiwi JeOS templates
* Mon Apr 29 2013 ms@suse.de
- added function baseMount() to kiwi script functions. The
  function mounts all useful kernel filesystems e.g proc, sysfs
  devpts and binfmt_misc. if the kiwi scripts are called in a
  contained environment like it is the case if lxc is installed
  on the image build machine it is required to mount the base
  filesystems as one of the first steps in the script
* Mon Apr 29 2013 ms@suse.de
- make sure binfmt_misc is mounted in the context of config.sh
* Mon Apr 29 2013 ms@suse.de
- write etc/default/grub_installdevice, which is not required
  by grub2 at all but by other tools in openSUSE
* Thu Apr 25 2013 rjschwei@suse.com
- follow up to 3d0e1e944d169
  + add unit tests for skip-oem-verify
  + oem-skip-verify and oem-silent-verify are ambiguous if both are true
    generate appropriate error
* Wed Apr 24 2013 ms@suse.de
- v5.05.10 released
* Wed Apr 24 2013 ms@suse.de
- added 'which' package to boot image descriptions for
  openSUSE 13.1. which was formerly provided by util-linux
  and is now an own package (bnc #816709)
* Wed Apr 24 2013 ms@suse.de
- DB: rebuild documentation
* Wed Apr 24 2013 ms@suse.de
- DB: update documentation
* Wed Apr 24 2013 ms@suse.de
- fixed use of swapsize in oem size settings
  + the boot code adds the swap size as additional needed space
    to the oem-systemsize value thus it's wrong to test if swap
    fits into oem-systemsize. Robert had that before so this was
    correct, sorry Rob for changing this
* Tue Apr 23 2013 ms@suse.de
- v5.05.9 released
* Tue Apr 23 2013 ms@suse.de
- DB: rebuild documentation
* Tue Apr 23 2013 ms@suse.de
- reflect the change in the oem-systemsize handling also
  in the LVM repartition code
* Mon Apr 22 2013 rjschwei@suse.com
- follow up to OEM setup consistency checking
  + separate the checks to allow unit testing and create unit tests
  + update the documentation to explain the meaning and interplay
    between <oem-systemsize> and <systemdisk>
* Mon Apr 22 2013 ms@suse.de
- fixed misleading warning message in __getBootSize().
  if wanted and needed boot partition space is the same a
  warning message was printed which is not useful
* Mon Apr 22 2013 ms@suse.de
- fixed schema documentation:
  + if the size of a volume is set too small this is now treated
    as an error and kiwi exits. formerly this was ignored and kiwi
    used the value it calculated itself for the volume
* Mon Apr 22 2013 ms@suse.de
- with regards to (bnc #815200) following runtime checks were added
  + check if the specified system size is not smaller than the
    sum of the specified partition/volume sizes
  + recommend to specify a swap size if swap is requested and a
    specific system and or partition/volume size was specified
  + check if partition/volume path exists in the unpacked tree
  + check if size of partition/volume in the unpacked tree is smaller
    than the requested partition/volume size
  + check if specified system size is not smaller than the overall
    size of the unpacked tree
  + check if the calculated free space according to the requested
    system size value and the current size of the unpacked tree is
    big enough to resize the partitions/volumes to its requested
    size
* Mon Apr 22 2013 ms@suse.de
- fixed spec file, the mysystems macro for openSUSE was broken
  because it uses VER=1220 on a 12.3 system
* Sun Apr 21 2013 ms@suse.de
- fixed spec file, sync permissions with /srv/tftpboot
* Sun Apr 21 2013 ms@suse.de
- fixed SUSE product creation if specified MAIN_PRODUCT
  does not match the product name. In this case the collection
  of products is skipped with a warning message
* Fri Apr 19 2013 rjschwei@suse.com
- do not consider obsrun as a system group
* Thu Apr 18 2013 ms@suse.de
- allow to skip the md5 verification after image installation
  of an oem image. This speeds up the deployment but should
  not be de-activated for customer released images
  <oem-skip-verify>true|false</oem-skip-verify>
  Implemented by user feedback request (bnc #815199)
* Thu Apr 18 2013 ms@suse.de
- netboot: fixed conflicting use of global variables.
  + The function updateNeeded set among others the variable sum2
    which is used later in another context in suse-linuxrc. At
    that point it was expected that the variable is empty for
    the first round in a loop but that's not true if updateNeeded
    called before the loop sets the variable to some content. Thus
    updateNeeded should handle variables used locally in the
    function as real local variables
* Wed Apr 17 2013 ms@suse.de
- it does not make sense to specify '-i bytes-per-inode' in
  combination with '-N number-of-inodes'. Thus only the number
  of inodes is relevant as it's the result of the equation
  inodes = size / ratio. It had no bad impact to specify
  both -i and -N when creating the filesystem because mkfs.extX
  takes the value of -N with the highest priority. Thus this
  fix is just a cleanup of the mkfs.extX call
* Wed Apr 17 2013 ms@suse.de
- fixed setup of recovery boot data
  + the code there only uses the contents of the boot partition
    if LVM was enabled. But correct would be to use the contents
    of the boot partition if it exists and is not equal to the
    root partition
* Tue Apr 16 2013 ms@suse.de
- fixed setupBootLoaderGrub to write the udev device name
  into /boot/grub/device.map instead of the unix kernel
  device name (bnc #813216)
* Tue Apr 16 2013 ms@suse.de
- add missing suseImportBuildKey call to templates
* Tue Apr 16 2013 ms@suse.de
- fixed suseImportBuildKey to also work with keys
  present in /usr/lib/rpm/gnupg/keys/
* Tue Apr 16 2013 ms@suse.de
- fixed check if repartition task can be done or not.
  It's now based on free spaces vs. additional needed
  space. Also provide better information about the sizes
  if the repartition task can't be done
- fixed resize of LVM partition. It's important to add
  the swap size to be part of the LVM resize because swap
  is not an extra partition but a volume inside the vgroup
* Tue Apr 16 2013 ms@suse.de
- fixed typo nomodeseet -> nomodeset
* Tue Apr 16 2013 ms@suse.de
- fixed LVM resize of physical extents, pvresize works only
  with unix kernel device names and doesn't like udev links
* Tue Apr 16 2013 ms@suse.de
- use generic function resizeLVMPVs in OEMPartitionInstall too
* Tue Apr 16 2013 ms@suse.de
- fixed OEMRepartLVM, to pass correctly formated size value
  to createPartitionerInput, value requires a unit suffix
* Tue Apr 16 2013 ms@suse.de
- v5.05.8 released
* Tue Apr 16 2013 ms@suse.de
- use uuid search only in livestick, remove the flag file
* Mon Apr 15 2013 ms@suse.de
- fixed split createTmpTree, return if lstat returns undef
* Mon Apr 15 2013 ms@suse.de
- make sure index file will be removed in case of an error
  in the getSingleInstSourceSatSolvable() function
* Mon Apr 15 2013 ms@suse.de
- fixed use of lwp-download with complex zypper URL's
  containing additional proxy, proxy-user/pwd information
* Sat Apr 13 2013 ms@suse.de
- changed offset=64 to offset=0 for isohybrid. this fixes the
  problem of missing partition devices in legacy BIOS mode
* Sat Apr 13 2013 ms@suse.de
- fixed dereferencing of undefined values if no profiles are used
* Fri Apr 12 2013 ms@suse.de
- DB: rebuild documentation
* Fri Apr 12 2013 ms@suse.de
- fixed typos: Replace "(c|C)onfiguartion" with "(c|C)configuration"
* Fri Apr 12 2013 ms@suse.de
- fixed typos: Replace "(c|C)onfiguartion" with "(c|C)configuration"
* Fri Apr 12 2013 ms@suse.de
- fixed typos: Replace "(c|C)onfiguartion" with "(c|C)configuration"
* Fri Apr 12 2013 ms@suse.de
- added support for overlayfs as root filesystem for the
  disk based image types oem and vmx. Unfortunately the
  tool chain is not really prepared for such systems.
  I found the following issues which are not a kiwi
  business:
  * grub2-mkconfig failed to get canonical path of overlayfs
  * mkinitrd does not work if the rootfs is an overlayfs
    Thus when building an image with filesystem="overlayfs"
    it can be booted only once with the kiwi initrd. the
    subsequent reboot failed when using grub2. funny enough
    with the legacy grub it works because kiwi writes the
    config in this case
* Fri Apr 12 2013 ms@suse.de
- added helper tool called livestick:
  + allows deployment of live ISO images on USB sticks without
    destroying any data on the stick. The system is based on
    grub2 which loads via loopback the kernel and the initrd
    from the transfered iso image file. In addition to that
    custom writing happens into a cowfile and not into a
    partition. Using livestick recommends the use of the
    overlayfs filesystem (flags="overlay") because that has
    proven to work fast and nicely with a cowfile
* Fri Apr 12 2013 ms@suse.de
- follow up fix for the last commit concerning the unit tests
  make sure unwanted duplicate entries are replaced
* Fri Apr 12 2013 ms@suse.de
- don't use opensuse:// urls in unit tests. that sucks inside
  the buildservice if the service redirector is broken
* Fri Apr 12 2013 ms@suse.de
- added aarch64 as supported arch to the KIWIXML ctor
* Thu Apr 11 2013 ms@suse.de
- use a --label search for the grub2 setup if possible
* Thu Apr 11 2013 ms@suse.de
- make sure imx, dtb and elf files are moved correctly in
  the boot partition
* Thu Apr 11 2013 ms@suse.de
- fixed loading of network drivers in oemboot dump code
* Thu Apr 11 2013 ms@suse.de
- arm: make sure elf binaries (.elf) will be extracted
* Thu Apr 11 2013 ms@suse.de
- reduce code duplication for rsync call
* Thu Apr 11 2013 ms@suse.de
- fixed spec file to build correctly for aarch64
* Thu Apr 11 2013 ms@suse.de
- arm: added missing arch links in system/repo
* Thu Apr 11 2013 ms@suse.de
- arm: make sure device tree (.dtb) is extraced from the boot image
* Wed Apr 10 2013 ms@suse.de
- v5.05.7 released
* Wed Apr 10 2013 ms@suse.de
- added JeOS templates for openSUSE 13.1
* Wed Apr 10 2013 ms@suse.de
- call zeroMDRaidSuperBlock only if kiwi_RaidDev is specified
* Wed Apr 10 2013 rjschwei@suse.com
- add boot image link for armv6
- add armv6 and armv5el to list of supported architectures
- create setup for bootimage for 13.1
  + this will fix the package build in OBS
* Tue Apr  9 2013 ms@suse.de
- fixed regexp flags, causing trouble in older perl versions
* Tue Apr  9 2013 ms@suse.de
- remove 'mdadm' from the delete section of the SLES boot image
  descriptions. mdadm is used by the boot code if a raid setup
  is configured
* Mon Apr  8 2013 ms@suse.de
- make sure optional liveCD mount points /cow and /isofrom
  are moved into the system when they exist
* Mon Apr  8 2013 rjschwei@suse.com
- add armv5el boot architecture link
* Sun Apr  7 2013 ms@suse.de
- fixed plymouth splash activation in kiwi initrd. It's
  done in the same way systemd does it. after the start of
  the plymouth daemon it's required to wait for udev events
  to settle before showing the splash screen
* Sun Apr  7 2013 ms@suse.de
- make sure --solv-cache-dir points to the same base
  directory as --cache-dir. Without this setup the cookie
  cache gets lost inside the chroot and thus repositories
  with credentials might fail the authentication
* Sun Apr  7 2013 ms@suse.de
- fixed loop name collision in isofrom mode
* Sat Apr  6 2013 ms@suse.de
- use kiwi_cowdevice and kiwi_cowsystem instead of kiwi_cowfile
  the used colon as separator conflicts with the by-id names
* Sat Apr  6 2013 ms@suse.de
- fixed ctor test for improper LVM2 volume name
* Fri Apr  5 2013 ms@suse.de
- fixed kiwi_cowfile usage, broken return condition
* Fri Apr  5 2013 ms@suse.de
- allow both parted gpt_sync_mbr table type and the gptsync
  program. if gptsync is installed it will take over precedence
* Tue Apr  2 2013 rjschwei@suse.com
- allow lxc as a value for the packages type attribute to support
  container specific package specification
* Sat Mar 30 2013 bernhardout@lsmod.de
- reduce duplicate code
* Thu Mar 28 2013 ms@suse.de
- call syncGPT only if partedTableType is gpt
* Thu Mar 28 2013 ms@suse.de
- follow up fix for 12.3 openNebula examples:
  + grub2-branding has to stay installed inside the initrd
  + no theme was selected
* Thu Mar 28 2013 ms@suse.de
- make sure splash is deactivated for any dialogs displayed
  while inside the kiwi initrd (bnc #812099)
* Wed Mar 27 2013 rjschwei@suse.com
- fixup the openNebula example for 12.3
- use grub2 as bootloader
- switch the branding packages
- fixup the custom firstboot procedure to avoid an error
* Wed Mar 27 2013 ms@suse.de
- fixed checkmedia call if used in hybrid disk mode.
  in this mode a disk partition device was passed instead
  of the entire disk device (bnc #804160)
* Mon Mar 25 2013 ms@suse.de
- moved the check for the Amazon EC2 toolkit after the check
  for the credentials. If no or not enough credentials are provided
  the bundling is skipped and that's not an error. Thus it's ok
  to miss ec2-bundle-image at that point so the check needs to be
  done after successfully checking for the pre-conditions
* Mon Mar 25 2013 ms@suse.de
- fixed addBootEFILive function to work for 32bit ISO's
  + the boot path was hardcoded to boot/x86_64. With this
    patch the path to the bootloader files is searched
* Fri Mar 22 2013 rjschwei@suse.com
- follow up to driver data migration into new XML data structure
  + implement KIWIProfileFile class to represent data in
    the .profile file. This class allows us to gradually
    move data that is processed in the XML changeset and ends
    up in .profile without duplicating code in other places
- remove attempt to write kiwi_luks to the .profile file
  + kiwi_luks is not used, no longer needed
- add diffutils as build requires
  + diff needed by new unit tests
- unit tests for new code
* Thu Mar 21 2013 ms@suse.de
- v5.05.6 released
* Thu Mar 21 2013 ms@suse.de
- fixed use of uninitialized value
* Thu Mar 21 2013 ms@suse.de
- run XML validator on the code
* Thu Mar 21 2013 ms@suse.de
- fixed changelog build helper to correctly indent sub
  entries starting with a '+' or '*' prefix
* Wed Mar 20 2013 rjschwei@suse.com
- add unit test for syncMBR attribute
* Wed Mar 20 2013 ms@suse.de
- added attribute syncMBR in the type element to activate
  the MBR synchronisation into the GPT for efi images
* Wed Mar 20 2013 ms@suse.de
- fixed calculation of inode number if no XML size is set
  in this case the variable contains the value 'auto' and
  this can't be used in numeric expressions
* Wed Mar 20 2013 ms@suse.de
- make sure zImage kernels for arm gets detected
* Wed Mar 20 2013 rjschwei@suse.com
- add support for EC2 AP-Sydney region
* Wed Mar 20 2013 ms@suse.de
- fixed calculation of inode number in KIWIBoot constructor
  for vmx images which requested a specific size in the XML
  description it's required to calculate the inode count
  from the specified size and not from the size of the of
  the unpacked root tree. If the requested image size is
  much bigger than the unpacked root tree it might happen
  that we run out of inodes very soon in the later image
* Wed Mar 20 2013 rjschwei@suse.com
- v5.05.5 released
* Wed Mar 20 2013 rjschwei@suse.com
- fix build of split image type
  + regression introduced by restructuring effort, commit 853e6fc3
* Wed Mar 20 2013 ms@suse.de
- fixed typos and white space errors
* Wed Mar 20 2013 rjschwei@suse.com
- implement ImageBuilder for tar archives (KIWITarArchiveBuilder)
  + remove createImageTar from KIWIImage class
  + update the Factory to return the new builder type
  + update ImageCreator
  + update triggers
  + implement new unit tests
* Tue Mar 19 2013 rjschwei@suse.com
- update build and runtime requirements
  + add rsync as build requires, new test uses code path that requires rsync
  + add perl-Digest as build requires and requires, new test generates
    a checksum
- add code to handle absence of /proc/mounts
  + this is useful when working in a local osc sandbox with osc chroot
    where /proc/mounts does not exist
* Tue Mar 19 2013 rjschwei@suse.com
- move all the driver handling in the XML from the old
  data model to the new data model
  * remove addDrivers_legacy
  * remove getDriversNodeList_legacy
  * remove the driversNodeList class member
* Tue Mar 19 2013 ms@suse.de
- allow option for KIWIManager*::setupUpgrade() to operate
  in a mode which checks only for the requested package
  transactions and allow to skip the dist upgrade. This mode
  is used in the kiwi --create step to prevent auto dist
  upgrades which should only happen if kiwi --upgrade is
  called
* Mon Mar 18 2013 ms@suse.de
- fixed copyBootCode and suseGFXBoot to be more generic with
  regards to the different u-boot img/bin files
* Mon Mar 18 2013 ms@suse.de
- create aarch64 link to boot images. Currently this points
  to the same boot description files used for armv7 and armv5
* Mon Mar 18 2013 ms@suse.de
- make sure splash stays on screen when in oem-silentboot mode
* Mon Mar 18 2013 rjschwei@suse.com
- apply new method naming convention, use p_ as prefix for
  "protected" methods
* Mon Mar 18 2013 ms@suse.de
- don't use grub2 modules from host system if not found in initrd
  + instead enable/disable support according to stages (BIOS/EFI)
  + print better error message in case of missing required stages
  + allow plain BIOS, plain EFI and EFI+BIOS setup
* Mon Mar 18 2013 rjschwei@suse.com
- improve the KIWI*Builder framework
  + rename the ImageBuilder class to ImageBuilderBase to
    indicate base class status of the implementation
  + rename methods according to naming convention
  + add checksum creation capabilities to the
    ImageBuilderBase class
- add method to execute images.sh explicitly to the Image class
  + the image class will transition to only represent the
    unpacked image. The new methods executes images.sh in
    the unpacked image tree
  + fixup the destructor to avoid "uninitialized" messages
    from Perl if object creation fails
- improve the container build
  + run images.sh file
  + create a checksum for the container file
- add naming convention to the developer documentation
- fix up the pre-commit hook script to deal with file
  removal or renames. When moving/renaming or renaming
  a file, git still presents the old file name as "changed"
  previously this would break the code checking the
  modified files. Compile errors, registration errors,
  and perlcritic errors would be generated
- add entry to container configuration file indicating
  device handling. This is lxc version dependent and kiwi
  does not know the host where the container is deployed,
  thus we cannot add the setting to the configuration
  without guard
- create unit tests for the ImageBuilderBase class
- create a rudimentary unit test for the Image class
* Mon Mar 18 2013 ms@suse.de
- fixed stage directory check for grub2
* Mon Mar 18 2013 ms@suse.de
- make sure profile information is used in all kiwi modes
* Mon Mar 18 2013 ms@suse.de
- fixed call of undefined subroutine &KIWIGlobals::qxx
* Mon Mar 18 2013 ms@suse.de
- added option --force-bootstrap in combination with --recycle-root
  in the kiwi modes --prepare and/or --create. When using a base
  tree with --recycle-root kiwi normally skips the bootstrapping
  part because that data should all be part of the base tree. If
  the tree is not complete in this regard, e.g missing zypper one
  can now enforce the bootstrapping phase to be called.
* Sun Mar 17 2013 ms@suse.de
- fixed directory creation in KIWIImageCreator. the profile
  information was stored in a variable which was not used
* Sun Mar 17 2013 ms@suse.de
- fixed typo in function name
* Sat Mar 16 2013 rjschwei@suse.com
- make the methods of the XML data base class public
  + brings code into allignment with other OO use in other langauges
  + the base class nature is indicated by the name
* Fri Mar 15 2013 ms@suse.de
- added support for hybrid EFI disk images based on gptsync.
  * if gptsync is installed an MBR is added to the GPT table
  * this allows to boot plain vmx images via legacy BIOS and EFI
  * this allows to boot oem disk via legacy BIOS and EFI
    The repartition code of an EFI oem will overwrite the MBR
    placed by gptsync. Thus the kiwi initrd tries to re-add the
    information by calling syncGPT. The funtion requires the
    presence of gptsync and sfdisk inside the kiwi initrd.
    Both tools are not part of the kiwi initrd by default
  * this allows to boot oem install media via legacy BIOS and EFI
    oem install media are install ISOs and install sticks
  * please note placing an MBR into the GPT is outside of the
    EFI standard. It might happen that an EFI firmware refuse
    to boot a system which includes a MBR inside the GPT.
    Thus gptsync support should be seen as experimental
* Fri Mar 15 2013 ms@suse.de
- v5.05.4 released
* Fri Mar 15 2013 ms@suse.de
- fixed unit test: kiwiContainerBuilder
  + the test used the getArch() function from the global space
    this function turns any 32bit arch name into 'ix86' but the
    container builder code uses the value from 'uname -m' in
    the generateBuildImageName() function and thus the arch
    value used here is like 'i686'. Therefore the unit test
    will fail on all 32bit x86 architectures
* Fri Mar 15 2013 ms@suse.de
- v5.05.3 released
* Fri Mar 15 2013 ms@suse.de
- fixed package build, lxc is required for unit testing
* Fri Mar 15 2013 ms@suse.de
- v5.05.2 released
* Thu Mar 14 2013 ms@suse.de
- fixed getSingleInstSourceSatSolvable() in terms of pattern
  handling. the function stores projectxml always with the
  the suffix .gz which indicates a compressed version of the
  file. But the patterns information file could also contain
  a non compressed version of patterns.xml which is then
  wrongly used as compressed file
* Wed Mar 13 2013 ms@suse.de
- the btrfsctl utility is deprecated and will be removed soon
  There was one code path in kiwi which needs to be adapted to
  understand both btrfs and btrfsctl (bnc #808962)
* Tue Mar 12 2013 ms@suse.de
- fixed setup of selectedProfiles information. The way it was
  done before possibly overwrites information provided on the
  commandline
* Tue Mar 12 2013 ms@suse.de
- added openSUSE 12.3 boot and JeOS templates for armv7
* Mon Mar 11 2013 ms@suse.de
- more robust code:
  + getStorageSize, returns an error if device is not present
  + retry of partition creation no longer endless
* Mon Mar 11 2013 ms@suse.de
- removed unused function getRemovableUSBStorageDevices()
* Mon Mar 11 2013 ms@suse.de
- use kpartx sync mode to make sure devices are created
  on return of the call
* Mon Mar 11 2013 ms@suse.de
- make sure writeTester gets installed
* Fri Mar  8 2013 rjschwei@suse.com
- added tests/writeTester for XML import/export tests
* Fri Mar  8 2013 rjschwei@suse.com
- handle repositories in the new data structure
  + remove legacy methods for repository handling
    ~ getHttpsRepositoryCredentials_legacy
    ~ getRepositories_legacy
    ~ ignoreRepositories_legacy
    ~ setRepository_legacy
    ~ addRepositories_legacy
  + modify CommandLine object to handle KIWIXMLRepositoryData
    objects instead of handle arrays of disconnected
    repository data
  + modify the command line processor (kiwi.pl) to create
    KIWIXMLRepositoryData objects
  + eliminate the repository processing from the changeset
    that is used to modify the boot description. The
    information is still in the changeset but is no longer
    considered
* Thu Mar  7 2013 ms@suse.de
- fixed checks for already mounted system filesystems
- fixed race condition in bindDiskPartitions, kpartx returns
  early and sometimes before the devices in /dev/mapper were
  created
* Wed Mar  6 2013 ms@suse.de
- DB: rebuild documentation
* Wed Mar  6 2013 ms@suse.de
- DB: update documentation; add missing image types
* Wed Mar  6 2013 ms@suse.de
- moved from clicfs to overlayfs for 12.3 JeOS live iso
* Wed Mar  6 2013 ms@suse.de
- added support for overlayfs for live images
  + requires kernel >= 3.7 (openSUSE >= 12.3)
  + activate with <type image="iso" ... flags="overlay"/>
* Wed Mar  6 2013 ms@suse.de
- added SLED as possible target for kiwi --migrate (bnc #807469)
* Wed Mar  6 2013 ms@suse.de
- added SLES-SP3 as possible target for kiwi --migrate (bnc #807469)
* Wed Mar  6 2013 ms@suse.de
- DB: rebuild schema documentation
* Tue Mar  5 2013 ms@suse.de
- fixed getOperatingSystemVersion() in KIWIMigrate. Use the
  /etc/products.d/baseproduct information to find the OS name
* Tue Mar  5 2013 rjschwei@suse.com
- rename the getImageType method on the KIWIXMLTypeData object
  The name had an unfortunate overlap with the same name on
  the XML class
* Tue Mar  5 2013 ms@suse.de
- fixed oem-silent-install and oem-silent-verify options. They
  were not evaluated in __updateDescriptionFromChangeSet_legacy
* Tue Mar  5 2013 ms@suse.de
- eliminate getImageVersion_legacy method from XML
* Tue Mar  5 2013 ms@suse.de
- integrate KIWIImageBuilder approach better:
  + move __getBaseWorkingDir, __createWorkingDir, __cleanupWorkingDir
    and __getBaseWorkingDir into the KIWIContainerBuilder. They are
    specific to the creation of lxc containers
  + delete __provideResults from KIWIImageBuilder. what happens with
    the result belongs to KIWIImageCreator not to the plain builder
  + add __createBuildDir to the KIWIImageBuilder constructor.
    the creation of the intermediate build directory is done
    by the base class for all image builds. The result of the
    build is created there
  + integrate KIWIImageBuildFactory better into the KIWIImageCreator
    the first build is based on KIWIImageBuildFactory. If the image
    can't be build by this factory the image is build calling a
    creation function from the KIWIImage space. In the future more
    and more image creation code will be moved from KIWIImage to
    KIWIImageBuildFactory
  + format creation, build result archiving and move of result into
    user specified target directory applies to a successfull build
    no matter if it was done by the KIWIImageBuildFactory or by a
    image creation function from the KIWIImage space
  + adapt unit tests
* Tue Mar  5 2013 rjschwei@suse.com
- return an array ref from the createImage method
  + the array contains the files created by the builder. This will
    help us to eliminate the glob copy in the ImageCreator in the
    future
* Mon Mar  4 2013 ms@suse.de
- make sure all USB host controller drivers will become
  included by mkinitrd (bnc #805053)
* Mon Mar  4 2013 ms@suse.de
- DB: rebuild documentation
* Mon Mar  4 2013 ms@suse.de
- if secure boot is enabled it's required to tell that
  in /etc/default/grub to make grub2-mkconfig produce
  correct results
* Sun Mar  3 2013 rjschwei@suse.com
- allow the user to hide the install and verify ncurses progress
  dialogs during OEM image installation, needed by Tyco (bnc #791291)
  + implement oem-silent-install and oem-silent-verify elements
    both are childeren of oemconfig
* Fri Mar  1 2013 ms@suse.de
- fixed grub2 setup for older distros which packages into lib/grub2-efi
* Thu Feb 28 2013 ms@suse.de
- fixed KIWILinuxRC::installBootLoaderGrub2()
  + install grub2 only in BIOS mode, in EFI mode this doesn't make sense
  + make sure the grub2 config file also lands on the EFI (fat) partition
    when in UEFI mode the precompiled and signed grub.efi image searches
    there for the configuration
* Wed Feb 27 2013 ms@suse.de
- fixed UEFI bootloader setup for grub2 based disk images
  + fixed creation of image install CDs in EFI mode
  + call findAndCopyMagicBlock only if hybrid is requested
* Tue Feb 26 2013 rjschwei@suse.com
- implement support to build an image that runs as lxc container
  + add "lxc" as accepted value to image attribute
  + add container attribute to <type> element, this attribute
    is required for container building
  + create consistency check for container type
  + must have container attribute
  + container attribute value must be composed of word characters
  + container build must include lxc packsge (runtime check)
  + unit tests
  + implement processing of new attributes in the XML code
  + unit tests
- implement KIWIContainerConfigWriter
  + this class writes the configuration file and fstab file
    for a container
  + it is a child of KIWIConfigWriter
  + unit tests
- implement KIWIConfigWriter
  + base class for configuration file writers, at present it only
    has the container writer as a child. This class will help us
    to separate the code for other image types that have configuration
    file (ovf, vmware, xen) and create individual classes that are
    focused on only one thing
- implement KIWIConfigWriterFactory
  + factory class that hands out a *ConfigWriter objects based on
    the image type or image format being built
  + unit tests
- implement KIWIContainerBuilder
  + this class is responsible for the image creation for a container
    image only createImage is public and implements the creation
    procedure
  + is a child of KIWIImageBuilder
  + unit tests
- implement KIWIImageBuilder
  + base class for all *Builder classes, at present it only has the
    container builder as a child. This class will help us to peal
    apart the creation of various image types currently implemented
    in a tangle in KIWIImage and KIWIImageCreator
- implement KIWIImageBuildFactory
  + factory class that hands out *Builder objects based on the image
    type
  + unit tests
- integrate the new build infrastructure code into the image creation
  process for lxc containers
- add directory exist method to test case
- create container example for openSUSE 12.3 and 12.2
- examples
  + fix the text in the 12.3 examples to refer to 12.3, not 12.2
  + all network configurations, 12.2 and 13.3, STARTMODE
    value 'onboot' is no longer supported, changed to 'auto'
- add a chapter to the documentation providing information about
  the new container image type
* Tue Feb 26 2013 ms@suse.de
- added network drivers and nfs stack to isoboot for
  openSUSE 12.3. This allows to boot live ISO's via pxe
  as explained in (bnc #805771)
* Tue Feb 26 2013 ms@suse.de
- changed isofrom feature:
  + splitted information provided in isofrom into two parts
    isofrom_device= and isofrom_system= the two were set in
    common and seperated by a colon before. This caused
    trouble when the colon is part of the device information
  + added support for ISO from NFS (bnc #805771)
    isofrom_device=nfs:<ip>:<export-path>
* Tue Feb 26 2013 ms@suse.de
- DB: rebuild documentation
* Tue Feb 26 2013 ms@suse.de
- DB: update. wrote about the different union mount methods for pxe
* Mon Feb 25 2013 ms@suse.de
- added vmxFlavour-uefi and xenFlavour-uefi profiles to the
  suse-SLE11-JeOS template image description. Given that
  SLE11 SP3 is used these profiles can be used to build
  UEFI images based on grub2
* Fri Feb 22 2013 ms@suse.de
- fixed cleanMount function to work if $root dir can't be
  created. It might happen that at that point kiwi already
  mounted some stuff which can be released via cleanMount
  but cleanMount returned if no $root location was created.
* Fri Feb 22 2013 ms@suse.de
- fixed creation of KIWICache object, was missing the xml pointer
* Fri Feb 22 2013 ms@suse.de
- fixed default value for virtualHW version
* Thu Feb 21 2013 ms@suse.de
- make sure the openSUSE 12.3 JeOS set the correct console
  based systemd target and fix some typos in config.sh too
* Thu Feb 21 2013 ms@suse.de
- fixed default systemd target setup, baseSetRunlevel
  function a systemd target is not a number but something
  like multi-user.target or graphical.target
* Wed Feb 20 2013 adrian@suse.de
- fix iso creation for non-EFI medias again
* Wed Feb 20 2013 ms@suse.de
- make sure GRUB_TERMINAL is set in etc/default grub to make
  yast bootloader happy. if yast can't find this setting it
  switches to 'console' which deactivates the graphical grub2
  console (bnc #804725)
* Wed Feb 20 2013 adrian@suse.de
- fix product media creation for non-x86_64 when EFI
  boot support is enabled (bnc #804428)
* Wed Feb 20 2013 ms@suse.de
- fixed typo in function comment, still talking about
  opensusePattern instead of namedCollection
* Wed Feb 20 2013 ms@suse.de
- move from opensusePattern to namedCollection in KIWIMigrate
* Wed Feb 20 2013 ms@suse.de
- added missing setup of etc/sysconfig/bootloader setup for grub2
- fixed possible duplicate entries for quiet and splash= in
  etc/default/grub
* Tue Feb 19 2013 ms@suse.de
- KIWIISOLinux fixes:
  + added addBootEFILive magic block creation to the source
    media KIWICollect code too
  + extend magic block lookup in findAndCopyMagicBlock()
    from 2 to 8 files and from 4 to 8 blocks (bnc #804428)
* Tue Feb 19 2013 rjschwei@suse.com
- create a kiwi-test package
  + install the test code in the install directive
  + change permission on the test drivers to eliminate RPM lint warning
  + add filter to hide the test .kiwirc file warning
* Mon Feb 18 2013 ms@suse.de
- fixed use of uninitialized value in KIWIConfigure
* Mon Feb 18 2013 ms@suse.de
- switch back to firmware='bios' and print a warning if uefi
  is requested on another than the x86_64 architecture. on SUSE
  we provide signed loaders and kernels for x86_64 only
* Mon Feb 18 2013 ms@suse.de
- secure boot grub commands are linuxefi and initrdefi
  fix this also for oem disk images
* Mon Feb 18 2013 ms@suse.de
- fixed building of i386-efi (32bit) live EFI iso images
* Mon Feb 18 2013 ms@suse.de
- check for grub2 conf tool name before using it. with
  openSUSE 12.3 the grub2-efi-... tool chain was removed
  thus kiwi needs to check this before calling the mkconfig
  command
* Mon Feb 18 2013 ms@suse.de
- better logging messages for framebuffer device setup and
  initrd creation for reboot of the system by either dracut
  or mkinitrd
* Sun Feb 17 2013 ms@suse.de
- increased default boot partition size to 200MB (+50M)
  the plymouth splash data is huge. Just to give an example
  12.2 SUSE plymouth theme data is ~3M, 12.3 SUSE plymouth
  theme data is about 23M. That blows up the initrd and
  needs more space on the boot partition
* Sun Feb 17 2013 ms@suse.de
- make sure temporary config.lxc is removed after execution
* Sun Feb 17 2013 rjschwei@suse.com
- remove the <opensusePattern> and <rhelGroup> elements from the schema
  these elements are replaced by the new <namedCollection> element
- update all XML files to the latest schema version (5.7)
* Sun Feb 17 2013 ms@suse.de
- EFI/UEFI fixes according to standard
  * EFI/BOOT is required instead of efi/boot
  * eltorito alternative loader path must be boot/<arch>/efi
  * secure boot grub commands are linuxefi and initrdefi
  * check for 64bit or 32bit efi module
* Sun Feb 17 2013 ms@suse.de
- KIWICollect install media package collector fixes
  * pass all needed arguments to the KIWIIsoLinux constructor
  * set logfile to terminal
* Sun Feb 17 2013 rjschwei@suse.com
- fix the openSUSE 12.3 examples, add module-init-tools to bootstrap
  package list
* Sun Feb 17 2013 rjschwei@suse.com
- use the localectl and datetimectl implementations provided by
  systemd to set the configuration
  + short circuit the suseConfig function in the shell code
    if localectl exists
  + implement the configuration in Perl code, now all configuration
    settings are implemented in the same class
  + remove the call to suseConfig in the config.sh files of our examples
- clean up the KIWIConfigure implementation to critic level 3
- add deprecation message to the old implementation
* Fri Feb 15 2013 ms@suse.de
- systemd related fixes causing the first boot to hang
  * setupConsole should not run at all in case of systemd
  * systemd has been moved to /usr/lib/systemd/systemd thus
    /bin/systemd is now a link and that causes several
    bash test calls to fail
  * quit plymouth inside the initrd if the system image
    doesn't have plymouth installed
  * make debugging plymouth problems more easy by evaluating
    the options plymouth.enable and/or rd.plymouth like
    the mkinitrd scripts does it
* Fri Feb 15 2013 ms@suse.de
- systemd has been moved to /usr/lib/systemd with openSUSE 12.3
  thus the function baseSetRunlevel() needs to address old and
  new location
* Fri Feb 15 2013 rjschwei@suse.com
- remove the getImageName_legacy method from the code base
* Thu Feb 14 2013 rjschwei@suse.com
- add critic exception for the _new_instance private method in all
  singletons.
  + The method is called from the base class only and thus does not
    appear to be called when perlcritic parses the code.
- convert the Locator to a singleton
  + the locator holds no state and we really only need one per kiwi
    invocation
* Wed Feb 13 2013 ms@suse.de
- don't trigger udev device creation in pre-init. All devices
  are already there due to the initial start of udev. This
  could cause a hangup on first boot of the appliance
* Tue Feb 12 2013 ms@suse.de
- don't rely on boot.device-mapper init script, load
  device mapper module manually when needed
* Tue Feb 12 2013 ms@suse.de
- fixed start/stop of udev in pre-init. while using sysV init
  it was possible to run a startup script without a running
  init process. With systemd you cannot really run a service
  when systemd does not run
* Tue Feb 12 2013 ms@suse.de
- fixed corrupted fbiterm fonts for openSUSE 12.3 (bnc #803276)
* Tue Feb 12 2013 rjschwei@suse.com
- implement writeXML method in XML class
  + write an xml file based on the data in the data structure
- do not write data to the generated XML if a default value
  was set programmatically
- add a "namedCollection" element to the XML
  + this is in preparation for the removal of opensusePattern and rhelGroup
  + the KIWIXMLPackageCollection class already writes the <namedCollection>
    element as there is no way to differentiate one collection from the
    other <opensusePattern> vs. <rhelGroup>. Therefore, the schema has to
    support the new element name prior to the old collection names
    being removed.
- alpha sort the element declarations in the schema
  + benign change, but it aides XML code development
- kiwi now depends on File::Slurp
- implement a writeTest script that can be used to verify that
  round tripping of XML data works
- create a sample config.xml file for round trip testing
* Tue Feb 12 2013 ms@suse.de
- use global variable kernel_cmdline to store paramters
  passed to the linuxrc/init script and don't hand them
  over via sub-functions
* Tue Feb 12 2013 ms@suse.de
- suppress cpio blocks message to stderr
* Sat Feb  9 2013 ms@suse.de
- ignore empty directories in the migration report. the migrate
  code checks the unmanaged directories and remove them from the
  data hash if they are empty on the system. Additionally the path
  which ends up in an empty directory is searched backwards to find
  other empty directories in the unmanaged data hash which appears
  due to the removal of deeper empty directories
* Fri Feb  8 2013 ms@suse.de
- use mcopy to create efi structure in vfat image.
* Fri Feb  8 2013 ms@suse.de
- increased the vfat container image to be big enough to hold
  additional efi modules like the shim
* Fri Feb  8 2013 ms@suse.de
- fixed import of shim and grub efi modules. They are packaged
  as links to usr/lib/grub2/xxx-efi thus moving data from this
  directory will destroy the link target. We'd better copy it
- also allow integration of shim-opensuse key. If no Microsoft
  signed key is present we check if an opensuse key exists
* Fri Feb  8 2013 ms@suse.de
- make sure shim package is part of the boot image for iso
  vmx and oem image types starting with openSUSE >= 12.3.
  The sim package contains the Microsoft signed efi module
  which is the entry point for UEFI secure boot
* Fri Feb  8 2013 rjschwei@suse.com
- improved genDevDoc script:
  * improve the file processing routine, use only one loop
  * general code cleanliness improvements
  * implement DAG generation
* Thu Feb  7 2013 ms@suse.de
- fixed search path for UEFI signed shim.efi and grub.efi
* Thu Feb  7 2013 ms@suse.de
- added support for D3 data visualisation for custom files
  in kiwi migration report. The report shows a nice collapsable
  tree view of the unmanaged files/directories
* Thu Feb  7 2013 ms@suse.de
- print warning if installed isohybrid does not support EFI
* Thu Feb  7 2013 ms@suse.de
- search for the grub2 mkimage tool. the tool has been renamed
  in openSUSE 12.3 thus we have to find it and can't rely on
  the name
* Thu Feb  7 2013 ms@suse.de
- make sure module-init-tools is part of the bootstrap list
  for openSUSE 12.3 images. Otherwise kmod-compat ist installed
  which is incompatible with the kernel packages and causes
  a zypper provides error
* Wed Feb  6 2013 ms@suse.de
- fixed search path for grub2 EFI modules. in openSUSE 12.2
  grub2-efi was packaged in a way that the modules were installed
  to /usr/lib/grub2-efi/x86_64-efi. In openSUSE 12.3 the packaging
  has changed and the modules are now installed to
  /usr/lib/grub2/x86_64-efi, really a brilliant idea
* Wed Feb  6 2013 ms@suse.de
- fixed repo setup in KIWIXMLInfo mode, the code there still
  needs the setRepository_legacy() call
* Wed Feb  6 2013 ms@suse.de
- fixed call to undefined function setGlobals(). This was
  renamed into setKiwiConfigData()
* Wed Feb  6 2013 ms@suse.de
- make sure KIWIMigrate writes latest version of the XML schema
* Wed Feb  6 2013 ms@suse.de
- remove autoyastClone function/feature from KIWIMigrate
  this feature did not work well and it's also not
  maintained by yast at the moment
* Wed Feb  6 2013 ms@suse.de
- fixed use of uninitialized value in KIWIMigrate
* Wed Feb  6 2013 ms@suse.de
- added function createCustomHybridPersistent() which allows to
  provide the cmdline variable 'kiwi_cowfile=device:/path/to/cowfile'
  If kiwi get this information it uses the file as container for
  persistent writing for hybrid iso images. If this information is
  not present the standard case applies, which is kiwi tries to
  create a new partition device for persistent writing. In combination
  with the isofrom feature the kiwi_cowfile approach is useful
* Tue Feb  5 2013 rjschwei@suse.com
- generate KIWI Class API documentation and cross references
* Tue Feb  5 2013 ms@suse.de
- v5.05.01 released
* Tue Feb  5 2013 ms@suse.de
- DB: rebuild documentation for version change
* Tue Feb  5 2013 ms@suse.de
- netboot: following is required for (fate #314413) and (fate #314414)
  + add support for SERVERTYPE=local for fetchFile and putFile.
    the SERVER variable then points to a local directory
  + use locally cached MD5 file if it has the same checksum as the
    remote file, this is enabled by setting KIWI_LOCAL_CACHE_DIR
    Setting of these variables will be handled in SLEPOS specific
    hooks.
* Tue Feb  5 2013 ms@suse.de
- v5.04.38 released
* Tue Feb  5 2013 ms@suse.de
- fixed use of uninitialized value in setupBTRFS
* Tue Feb  5 2013 ms@suse.de
- use ext4 filesystem for clic'ed live iso's
* Tue Feb  5 2013 ms@suse.de
- use grub2 as bootloader for xen on openSUSE 12.2 JeOS too
* Tue Feb  5 2013 ms@suse.de
- fixed return value of KIWIImageFormat::createFormat. If no
  format is specified, e.g on xen we need only the format
  configuration, this is just a warning, thus the return
  value of the function should not indicate an error
* Tue Feb  5 2013 ms@suse.de
- fixed update of machine section in case of a xen dom0 setup
  the vmdisk entry is mandatory now thus the section has to
  provide it
* Tue Feb  5 2013 ms@suse.de
- fixed setup of build type in KIWIXML constructor. While testing
  I found that e.g the format conversion failed because there
  was no machine section found. But for the selected type and profile
  there was a machine section specified. The KIWIXML::setBuildType
  function was never called thus the default type applies which was
  of type iso and there no machine section existed.
* Tue Feb  5 2013 ms@suse.de
- fixed use of uninitialized values in KIWIBoot.pm while
  in kiwi's format conversion mode
* Tue Feb  5 2013 ms@suse.de
- added 'skipit' to the list of supported archs. I'm a bit unhappy
  with this change but I didn't see a better way to fix the arch
  check. In fact 'skipit' is not an architecture but for product
  building this architecture flag is used to indicate noarch rpm
  packages. In kiwi we check all arch values by one function
  KIWIXMLFileData::__isSupportedArch(), thus 'skipit' needs to be
  part of the list. The more clean fix would be to have two
  arch checking functions one for image building (real arch check)
  and one for product building (DVD source media). In order to
  keep the risk of regressions low I decided for the fast and
  easy way but we should have in mind that we can do better here.
* Tue Feb  5 2013 ms@suse.de
- make sure dbus machine-id is unique
* Mon Feb  4 2013 ms@suse.de
- update failsafe options (bnc #801973)
* Mon Feb  4 2013 ms@suse.de
- fixed search and call code for editbootconfig and editbootinstall
  evaluation when building iso images, live and install media
* Mon Feb  4 2013 rjschwei@suse.com
- fix the message for the init argument hash presence
  + the log facility is a singleton and is no longer passed
    as argument, thus the initialization hash argument
    is always expected as the first argument.
* Mon Feb  4 2013 rjschwei@suse.com
- remove unused code
  + getTypes_legacy method was no longer called
* Mon Feb  4 2013 ms@suse.de
- fix architecture handling for ProductPackages, allow a
  comma separated list of architectures also in the runtime
  checker function __isSupportedArch()
* Mon Feb  4 2013 rjschwei@suse.com
- add trigger for schema changes
  + run all tests that use an xml file when the schema changes
* Mon Feb  4 2013 ms@suse.de
- check for the existence of a the service file before
  activating/deactivating a systemd service
* Mon Feb  4 2013 ms@suse.de
- fixed creation of KIWI* instances in KIWICollect
* Sun Feb  3 2013 ms@suse.de
- fixed KIWICollect constructor. The code there did not make
  use of the singleton KIWILog object and still expects the
  first parameter to be the log reference
* Sun Feb  3 2013 rjschwei@suse.com
- implement getBootImageDescription method in locator
  + will eventually replace normalizeBootPath in KIWIURL. Implement
    search hierarchy for boot image description search that is more
    easily understood by users.
- implement unit tests for new functionality
* Fri Feb  1 2013 rjschwei@suse.com
- eliminate getOVFConfig_legacy
- remove des_cpu and des_memory attributes
  + des_cpu == ncpus and des_memory == memory we do not need 2
    attributes to describe the same value
  + fix typo of ovfformat name, it is "powervm" not "povervm"
  + the schema version did NOT change thus users must fix the
    config file manually if they used "des_cpu", "des_memory",
    and "povervm"
- implement writing of configured information into the .ovf
  configuration file
  + memory and limits
  + cpu and limits
  + devices
- fix link bug
  + the image file in the .ovf directoy was a dangling link
    as the link created was not pointing to the proper location
- update the tests to account for the removed attributes
- fix typo in method name "...Machine..." not "...Maschine..."
* Fri Feb  1 2013 ms@suse.de
- clean up the kiwi debug mode which collects trace information
  about the perl caller stack. There is now a singleton module
  called KIWITrace which stores the backtrace. Thus this also
  removes the last main:: global variables from the kiwi space
* Fri Feb  1 2013 ms@suse.de
- follow up fix for the use vs. require change in the Singleton
  objects KIWILog and KIWIGlobals. If one of the modules included
  by require contains a use statement of the Singleton object we
  again got warnings about redefined functions
* Thu Jan 31 2013 rjschwei@suse.com
- eliminate getVMwareConfig_legacy
  + incorporate default setting for guestOS
    into XMLVMachineData
  + drop all other mappings for guestOS, this is
    the user's responsibility
- fix VMWare NIC setup bug
  + previously the generated config file (.vmx) did not
    contain information about the specified MAC address.
    The MAC was always set to "generated" ignoring the
    user specified data.
* Thu Jan 31 2013 rjschwei@suse.com
- use require instead of use to include other modules in the
  Singleton classes. when using the "use" syntax for modules
  the perl compiler interrupts the compilation of the current
  module and starts compiling the module declared in the use
  statement. If the included module then includes the singleton
  perl issues 'Subroutine foo redefined' messages. As the
  compilation of of the original module was interrupted it is
  not finished and thus not recorded in the lookup table.
  Delaying the loading to runtime with the require function
  avoids the warning.
* Thu Jan 31 2013 ms@suse.de
- v5.04.37 released
* Thu Jan 31 2013 ms@suse.de
- fixed __checkVMscsiCapable() runtime check, it's ok to have
  no machine section. That one broke the containment builds for
  SUSE Studio
* Thu Jan 31 2013 ms@suse.de
- v5.04.36 released
* Wed Jan 30 2013 ms@suse.de
- v5.04.35 released
* Wed Jan 30 2013 ms@suse.de
- fixed creation of JSON tree in KIWIMigrate
* Wed Jan 30 2013 rjschwei@suse.com
- fix the isohybrid checks
  + previous implementation did not properly account for conditions
    that trigger the isohybrid code path
  + add error condition for architectures that do not support the
    creation of iso hybrids
  + update the tests accordingly
* Wed Jan 30 2013 ms@suse.de
- worked on the visualization of unmanaged data in KIWIMigrate.
  I'd like to use the d3 visualization framework and that requires
  the data as JSON data structure. I implemented a method to
  create that information but ran into JSON max nesting level
  problems
* Wed Jan 30 2013 ms@suse.de
- partially revert (eff68ab8de60). The fstool runtime is ok
  just the test case XML in liveIsoImg/efiOEM/config.xml would
  force the xfs tools to be installed which I think is not
  really necessary for this test
* Wed Jan 30 2013 ms@suse.de
- v5.04.34 released
* Wed Jan 30 2013 ms@suse.de
- fixed use of undefined value in writeImageConfig
* Wed Jan 30 2013 ms@suse.de
- I removed the runtime check for xfs and reiserfs. reiserfs
  is more or less dead and xfs is a pure optional filesystem.
  If we have a mandatory check for xfs kiwi has to require the
  tools package on the package and on the build level which I
  think is not required. imho it would also be better to change
  the fstool runtime check to check only for the selected
  filesystem and not the complete list. We cannot expect our
  users to install all filesystem tools
* Wed Jan 30 2013 rjschwei@suse.com
- build require e2fsprogs to allow unit tests to pass
* Tue Jan 29 2013 rjschwei@suse.com
- remove the getRPM*_legacy methods use the new API
* Tue Jan 29 2013 rjschwei@suse.com
- only require the uefi isohybrid command line option when building
  a EFI/UEFI iso
  + at present the uefi command line option on the isohybrid executable is
    treated as mandatory. This breaks all ISO builds on systems that do not
    have the latest isohybrid tool even if the ISO to be created is not
    designated as an efi/uefi ISO via the firmware attribute. The changes
    treat the uefi command line option as optional. A runtime check ensures
    that kiwi exits if the uefi command line option is required and the
    tool does not support it.
- new runtime check and test cases
* Tue Jan 29 2013 ms@suse.de
- fixed firmware check to allow uefi as well
* Tue Jan 29 2013 ms@suse.de
- grubcd.efi has been moved to grub.efi in the latest grub2
  packages. Thus we have to follow the change
* Mon Jan 28 2013 ms@suse.de
- some cleanup in KIWIMigrate.pm, tested d3 data visualization
* Mon Jan 28 2013 rjschwei@suse.com
- make KIWIGlobals a singleton
  + eliminates another package variable in kiwi.pl
  + add the singleton to the doc
  + allows us to make the remainaing test cases packages, now critic 2 clean
- rename methods getGlobals and setGlobals
  + reflect in name the data that is being returned/set
    getKiwiConfig, setKiwiConfigData
- some general code consistency clean up
* Mon Jan 28 2013 ms@suse.de
- v5.04.33 released
* Mon Jan 28 2013 ms@suse.de
- added support for firmware="uefi" attribute. In contrast to
  the standard firmware="efi" support, kiwi will not create its
  own efi boot images but uses the shim and the signed bootloader
  modules as they are provided by the packages.
* Sun Jan 27 2013 rjschwei@suse.com
- Implement KIWIXMLPXEDeployConfigData
  + <pxedeploy> supports multiple declarations of <configuration>
  + remove confArch, confDest, and confSource from KIWIXMLPXEDeployData
    and encapsulate in this new object
- Integrate KIWIXMLPXEDeployConfigData into XML
  + hold array of KIWIXMLPXEDeployConfigData and enforce child relationship
    to KIWIXMLPXEDeployData indirectly
- Implement proper default processing for partition definitions in
  KIWIXMLPXEDeployData
  + previously the default setting were applied in the XML in the old data
    model. In the new data model all default are known only to the type
    encapsulating the data
- Eliminate all *PXEDeploy*_legacy methods from XML class
  + update client code to use new data model provided objects
- Eliminate all calls to _legacy in the PXE image creation code path
- Implement new tests and update existing tests as necessary
  + new tests for new class
  + update tests for default values
  + new tests for default settings
  + eliminate _legacy tests for PXEDeploy
* Sun Jan 27 2013 ms@suse.de
- fixed hybrid iso search to respect partition devices and
  prefer them over the entire disk device. Additionally don't
  set a loop on the found device anymore which was used to
  workaround the busy state set by the kernel.
* Sat Jan 26 2013 ms@suse.de
- fixed use of undefined value as an ARRAY reference in
  KIWIXML::getUsers() method
* Sat Jan 26 2013 ms@suse.de
- make grub2 search more robust by searching for a flag file
  named like the unique ID used in the ISO header or MBR. This
  completes (bnc #799488)
* Sat Jan 26 2013 ms@suse.de
- make sure grub2/grub2-efi are part of the isoboot initrd
* Fri Jan 25 2013 ms@suse.de
- fixed grub2 prefix and root variable setup (bnc #799488)
- fixed layout of iso's and also make sure fixCatalog()
  is called
* Fri Jan 25 2013 ms@suse.de
- enhanced isohybrid call to know about --uefi option.
  Creating an EFI capable hybrid iso requires the new isohybrid
  tool including patches by Steffen Winterfeldt as well as
  a correctly prepared ISO to write the information. This commit
  is only about calling isohybrid whereas the last commits was
  about preparation of the iso itself
* Fri Jan 25 2013 rjschwei@suse.com
- Remove getEc2Config_legacy method from XML
  + Change client code to use new getEC2Config method and work with the
    returned EC2ConfigData object
- Change getDisplayName implementation in XML
  + Use data from the new data structure to return the name
- Reorder some operations in the EC2 image creation step
  + Facilitate early exit by first checking the architecture
  + Eliminate all _lgacy calls from this code path
  + Move variable initialization closer to the place where the values
    are used
  + Handle all AWS account stuff towards the end of the method,
    when we need the information, as this is not treated as
    an error anyway
- Fix link in documentation
  + The repo for the EC2 tools moved from Virtualization:/Cloud to Cloud:/
* Thu Jan 24 2013 rjschwei@suse.com
- support the profiles attribute for user definitions
  at the "group" level (bnc #77152)
  * implement new tests
  * update consistency checks
* Thu Jan 24 2013 ms@suse.de
- added the firmware type 'vboot' to support creation of
  images for arm based boards using google's chrome OS
  boot style
* Wed Jan 23 2013 ms@suse.de
- prepare ISO images in a way that allows hybrid ISO's which boot
  via EFI. There is some magic involved here and we are still not
  there. In order to make it work it's required to have two iso
  meta data blocks whereas one is used as real iso header providing
  boot entries for syslinux and efi-boot as well as the optional
  legacy bios based partition table for hybrids and the other one
  is used to place a gpt partition table to allow this iso to be
  seen as a disk when booting it as disk over EFI
* Wed Jan 23 2013 ms@suse.de
- removed support for openSUSE 11.4
* Wed Jan 23 2013 ms@suse.de
- added support for openSUSE 12.3
* Wed Jan 23 2013 rjschwei@suse.com
- update the extra examples
  + support 12.2 and 12.3
  + remove 11.4
  + add min-gnome as SLES example
* Tue Jan 22 2013 rjschwei@suse.com
- fix the UserData tests broken by previous update adding merge code
* Tue Jan 22 2013 rjschwei@suse.com
- implement a merge method that supports the merge of user data
* Tue Jan 22 2013 ms@suse.de
- added support for EFI in live ISO images. In order to create
  a syslinux plus EFI (grub2) live ISO use the following type
  <type image="iso" firmware="efi" .../>
  hybrid support for EFI live ISO's requires the new isohybrid
  tool which could also write a gpt into the isoheader.
* Mon Jan 21 2013 rjschwei@suse.com
- fix architecture handling for ProductPackages, allow a
  comma separated list of architectures
* Mon Jan 21 2013 ms@suse.de
- removed __checkNoProfsBootstrapPackages check. It's allowed
  to have profiles specified in the bootstrap packages. There
  are image descriptions which installs the entire system by
  bootstrap packages. Reason for this is if the packagemanager
  in the image is not compatible to the implementation in kiwi
  e.g SLE10. Other than that we officially support bootstrap
  only installation including all features of 'image' typed
  package sections.
* Mon Jan 21 2013 rjschwei@suse.com
- allow archives in the bootsrap section to allow build
  of images of older distributions
* Sun Jan 20 2013 ms@suse.de
- fixed use of sat solvable functions due to the Singleton
  log class changes. There were still some functions calls
  left which passes the $kiwi log object to the functions
* Sun Jan 20 2013 ms@suse.de
- Due to the new Singleton log class and the fix in KIWIQX to make use
  of it, all EXEC calls now lands in the logInfoMsg type of unit test
  framework. Thus I changed the ktLog.pm::loginfo function in the unit
  test functions to ignore EXEC loginfo messages and allow the unit
  tests to work again
* Sun Jan 20 2013 ms@suse.de
- fixed $main::kiwi accesses according to new Singleton log class
- fixed KIWIQX command execution logging with new Singleton log class
- fixed object instantiation of KIWIXMLRepositoryData due to new
  Singleton based log object class
* Sun Jan 20 2013 rjschwei@suse.com
- implement new consistency checks
  + do not allow the assignment of a group ID to known system groups
  + do not allow the profiles attribute on a <packages> section marked
    as bootstrap
  + do not allow the use of archives in a <packages> section marked
    as bootstrap
  + ensure the interface is unique within one <machine> definition
  + ensure the MAC is unique within one <machine> definition
* Fri Jan 18 2013 rjschwei@suse.com
- eliminate the getUsers_legacy method
* Fri Jan 18 2013 ms@suse.de
- fixed wrong filesystem label for the efi jump partition.
  According to the EFI spec it should be EFI not BOOT
- fixed the boot partition setup in case of an EFI system.
  kiwi checks the filesystem type of the jump partition
  and not the boot partition which leads to a missing
  boot -> . link on the boot partition which then prevents
  the grub2 efi core image to find the grub.cfg file
* Fri Jan 18 2013 ms@suse.de
- DB: rebuild documentation
* Fri Jan 18 2013 tom_schr@web.de
- DB: Moved definition of PXE as the first sentence
- DB: Removed linebreak after <screen> and before </screen>
  to avoid layout problems
* Thu Jan 17 2013 rjschwei@suse.com
- turn the logger (KIWILog) into a Singleton
  + eliminates the first argument for every constructor
  + enforces less sloppy testing code for log message checking
- add the logger to the design diagram as a singleton
- start over all design write up
* Wed Jan 16 2013 rjschwei@suse.com
- eliminate some calls to _legacy methods
- moved some "old" accessors to _legacy in XML
  KIWIXMLInfo => getInstallSize_legacy
  KIWIXML     => getImageVersion_legacy
  KIWIXML     => getImageName_legacy
* Tue Jan 15 2013 ms@suse.de
- DB: rebuild documentation
* Tue Jan 15 2013 ms@suse.de
- DB: add documentation about new post hook commands
* Tue Jan 15 2013 ms@suse.de
- added support for post hook commands as requested in (bnc #776535)
* Mon Jan 14 2013 ms@suse.de
- v5.04.32 released
* Mon Jan 14 2013 ms@suse.de
- fixed netboot boot partition setup. In case of a custom boot
  partition the code created the partition and the filesystem
  but the original data from the image was not moved over to the
  boot partition
* Mon Jan 14 2013 ms@suse.de
- fixed updateOtherDeviceFstab to add devices by disk ID
* Mon Jan 14 2013 ms@suse.de
- fixed use of IFS in probeNetworkCard and loadNetworkCard
- try to load hwinfo detected network modules in loadNetworkCard
  but don't fail if there are none detected or the load failed.
  udev normally loads the modules correctly
- ask interfaces for their MAC and IFace name directly instead
  of using hwinfo, that's faster and more reliable
* Mon Jan 14 2013 rjschwei@suse.com
- update XMLVMachineData class to reflect mandatory status of
  <vmdisk> configuration setting in XML. Previously the <vmdisk>
  element was optional and it was possible to construct the
  VMachine object without arguments. Now the <vmdisk> element
  is mandatory and thus the object may no longer be constructed
  without argument.
* Sun Jan 13 2013 ms@suse.de
- make vmdisk a mandatory element in the machine section
* Sat Jan 12 2013 ms@suse.de
- fixed dom0 machine setup to make object init of
  KIWIXMLVMachineData happy
* Sat Jan 12 2013 ms@suse.de
- added oem-swap for all examples which specify a swapsize
* Sat Jan 12 2013 ms@suse.de
- fixed indention, obsolete curly braces from information
  about the structure of the internal XML data types
* Sat Jan 12 2013 rjschwei@suse.com
- store objects in XML instead of raw data
  + change the XML class such that objects are stored instead of
    deeply nested raw data. This results ins simplification of code,
    the internal data structure, and its documentation. Data that
    requires merging (preferences and user data) is not stored as
    objects as it is not obvious that merge delegation to the respective
    objects would be advantageous.
* Fri Jan 11 2013 rjschwei@suse.com
- fix the description
  + RuntimeChecker test failed due to conflicting settings in the config
* Fri Jan 11 2013 rjschwei@suse.com
- fix XMLDescriptionData
  + previously the object construction did not conform to requierements
    of the Schema, it was possible to create an object without author,
    contact, or specification data. Multiple contact definitions were
    ignored
- update unit tests for Description class and XML class
* Fri Jan 11 2013 ms@suse.de
- fixed indention
* Fri Jan 11 2013 ms@suse.de
- update 12.2 examples to use grub2 as bootloader
* Fri Jan 11 2013 ms@suse.de
- moved the os-autoinst test case from the 11.4 JeOS template
  into the SLE11 template. The 11.4 template will be removed
  with the next openSUSE 12.3 distribution but I don't want
  to loose this test case example
* Thu Jan 10 2013 ms@suse.de
- changed zypper call to use one call to install products, patterns
  and packages instead of splitting that up into single calls. This
  has the advantage that zypper can better decide for packages which
  provides similar functionality (bnc #796062)
* Wed Jan  9 2013 ms@suse.de
- update internal data structure in-code documentation
* Tue Jan  8 2013 ms@suse.de
- fixed 'run out of space' problem in LVM setup. use
  a relative 20%% (min 30M) spare space per volume
* Tue Jan  8 2013 ms@suse.de
- fixed LANG setup inside the kiwi initrd. LANG must be correctly
  set before calling fbiterm. Otherwise the multibyte characters
  in the target locale are not displayed correctly
* Thu Jan  3 2013 rjschwei@suse.com
- Start documenting the KIWI design
  + document the new XML design
  + start of high level data-flow/interaction diagram
* Fri Dec 21 2012 ms@suse.de
- added support for resizeMDRaid in kiwi's oemboot code
  when the geometry of the disk changes the raid array
  needs to grow too
* Fri Dec 21 2012 ms@suse.de
- fixed mdraid setup in combination with LVM
* Fri Dec 21 2012 ms@suse.de
- added zeroMDRaidSuperBlock function to make sure an old
  raid array is stopped and the super block is removed prior
  to installing a new system on that disk
* Fri Dec 21 2012 rjschwei@suse.com
- deal with mdraid in the test
  + fix getXMLElement test
  + add unit test for new MDRaid methods
* Fri Dec 21 2012 ms@suse.de
- removed duplicate rt profile
* Wed Dec 19 2012 ms@suse.de
- added support for software raid into disk based appliances
  The feature is based on creating a degraded raid array with
  one disk, thus only mirroring and striping levels can be
  supported. A system build with a degraded raid array allows
  to add custom disks later to the array. In order to set it
  up you only need to specify the mdraid attribute as part of
  the type like the following example:
  <type ... mdraid="mirroring"/>
* Wed Dec 19 2012 ms@suse.de
- removed redundant code from setupInstallCD, this is done
  in the KIWIBoot constructor
* Wed Dec 19 2012 ms@suse.de
- fixed grub2 title setup, spaces were ignored
* Fri Dec 14 2012 ms@suse.de
- v5.04.31 released
* Fri Dec 14 2012 ms@suse.de
- added support for the apt-get/dpkg package manager to kiwi
* Thu Dec 13 2012 rjschwei@suse.com
- allow the id for a vmdisk and vmdvd to be 0
  trapped again by Perl's a string with zero ("0") is false
* Thu Dec 13 2012 ms@suse.de
- update templates and examples to match the schema
* Thu Dec 13 2012 ms@suse.de
- fixed the change of the pwd attribute to be really complete
  also fixed the 5.5 to 5.6 upgrade xsl style sheet
* Wed Dec 12 2012 ms@suse.de
- update templates and examples to latest schema version
* Wed Dec 12 2012 ms@suse.de
- split up KIWIManager object into a base class and the
  corresponding manager sub classes for zypper, ensconce
  yum and smart
* Wed Dec 12 2012 rjschwei@suse.com
- clean up
  + eliminate references to Novell where possible
  + change copyrights from Novell Inc. to SUSE LLC
  + fix spelling OpenSUSE is openSUSE
  + update e-mail address rschweikert@novell.com to rjschwei@suse.com
* Tue Dec 11 2012 rjschwei@suse.com
- implement InstRepositoryData class
  + stores data for <instrepo> element
  + implement RepositoryBaseData class as parent class to share common
    functionality with RepositoryClass
  + implement unit tests
- some clean up for consistency in the RepositoryData class
  + update unit test
- implement ProductPackageData class
  + stores data for <repopackage> element
  + did not implement set* methods as it is not obvious at this time
    if they are needed
- follow up from addition of attributes to <repository> for apt support
  + set the class members
  + check the argument for the set* methods
  + add unit tests for all new methods
- implement ProductOptionsData class
  + stores data for <productoptions> element
  + implement unit tests
- implement ProductArchitectureData class
  + stores data for <arch> element
  + implement unit tests
- implement ProductMetaFileData class
  + stores data for <metafile> element
  + implement unit tests
  + some style clean up in File and Type test
- implement ProductMetaChrootData class
  + stores data for <chroot> element
  + implement unit tests
- integrate all classes related to <instsource> handling into XML
  processing code
  + implement new accessor methods
  + renames all getInstSource* and related methods to _legacy
  + update client code to use _legacy names
  + implement unit tests
* Tue Dec 11 2012 rjschwei@suse.com
- change the pwd attribute of the instrepo element to password
  + be consistent with the attribute name for the repository password
    between the instrepo and repository element
- bump the schema version to 5.6
- implement a 5.5 to 5.6 upgrade style sheet
* Sat Dec  8 2012 ms@suse.de
- make sure plymouth splash is switched off when the progress
  dialog is displayed in the oemboot/suse-dump code (bnc #793260)
* Fri Dec  7 2012 ms@suse.de
- v5.04.30 released
* Fri Dec  7 2012 ms@suse.de
- fixed changelog filter tool to incorporate commits with the
  same timestamp into one changelog entry
* Fri Dec  7 2012 rjschwei@suse.com
- Add tests for the new firmware attribute handling
- Additional changes to new firmware handling in the Type object
  + Encode the firmware type default (bios)
  + Verify that the given value is supported
* Fri Dec  7 2012 ms@suse.de
- v5.04.29 released
* Fri Dec  7 2012 ms@suse.de
- add grub2-efi by default to openSUSE 12.2 oem|vmxboot
  descriptions. Thus just selecting the firmware via
  <type ... firmware="efi"> is enough
* Fri Dec  7 2012 ms@suse.de
- added support for the firmware="bios|efi" type attribute
  before this patch the decision for efi was done by the presence
  of the grub2 efi modules inside the kiwi generated initrd.
  This has turned out to be not flexible and can't be extended
  to the firmware required disk layout on other architectures
  like the arm based chromebook to mention just one example
  This fixes (bnc #792917)
* Fri Dec  7 2012 ms@suse.de
- we should not overwrite the user specified target directory
  in the commandline object with something the user did not set.
  With reference to commit:b6a7e563 the creation of the image
  happened in a subdirectory below the specified target directory
  and kiwi overwrote that user target directory with a new name.
  This should not happen thus I added a new function pair named
  setImageIntermediateTargetDir/getImageIntermediateTargetDir
  to handle that value and don't touch the user specified
  target directory
* Thu Dec  6 2012 ms@suse.de
- finally changed the fragile cleanup code in KIWIBoot.pm
  The code there now builds a stack of commands which set
  the busy devices free if processed in reverse order
* Thu Dec  6 2012 praveen_paladugu@dell.com
- make sure rhelStripInitrd arguments are passed correctly
* Thu Dec  6 2012 rneuhauser@suse.cz
- use mktemp -t to make use of $TMPDIR and do not hardcode
  /tmp in the paramter to mktemp
* Thu Dec  6 2012 ms@suse.de
- Don't use the same inode count for the install stick disk
  compared to the system image disk. If the system image is
  big the inode count is also a big number. But on the install
  disk image there are only a few files including the
  compressed version of the system image. Thus it's smaller
  and has not much files. The system image inode count has no
  relation to the filesystem on the install disk image. Under
  certain circumstances it could happen that the install disk
  filesystem can't be created because the big chunk of inodes
  exceeds the size of the install disk filesystem
* Wed Dec  5 2012 praveen_paladugu@dell.com
- Fedora/RHEL based distros have dhclient instead of dhcpcd.
  Thus the code to ask the DHCP server for an address has been
  splitted into two new functions setupNetworkDHCPCD() and
  setupNetworkDHCLIENT()
* Tue Dec  4 2012 ms@suse.de
- make sure pidof returns only the master pid of udevd
* Tue Dec  4 2012 ms@suse.de
- make sure the splash information doesn't get lost when
  repacking the initrd while building live iso images
* Tue Dec  4 2012 ms@suse.de
- fixed behavior of /etc/init.d/boot.clock which reads a value
  in /dev/shm/warpclock. The value is provided by a mkinitrd
  binary in /lib/mkinitrd/bin/warpclock. It looks like it's
  required to store that information for a proper localtime
  system clock setup. There is not good documentation about
  this magic but to stay compatible the warpclock code from
  mkinitrd was ported over to the kiwi first boot initrd
  This fixes (bnc #786730)
* Tue Dec  4 2012 adrian@suse.de
- instsource: use supportstatus from product descriptions
  instead from PDB (Package Data Base)
* Tue Dec  4 2012 adrian@suse.de
- instsource: avoid usage of translate_packages code, use
  create_package_descr code (patch by rudi)
* Mon Dec  3 2012 ms@suse.de
- don't point stdout to stderr when calling grub2-mkconfig with
  stdout I/O redirection into the configuration file. This just
  leads to an empty file. I should think twice before hitting
  the push button ;)
* Mon Dec  3 2012 ms@suse.de
- workaround a grub2-mkconfig bug which happens if a ' sign is
  used as menuentry title in /etc/default/grub. if called with
  the option -o grub2-mkconfig complains even if the shell
  quoting is perfectly fine. Strange enough it works nicely
  if called as grub2-mkconfig > some-file. As this is only a
  small and maintainable workaround I applied it
* Mon Dec  3 2012 ms@suse.de
- added an architecture check for KIWIIsoLinux::createHybrid()
  on architectures e.g ppc and ia64 the embedding of a partition
  table into the ISO will not work. Thus the check will issue
  a warning but proceed and does not fail
* Mon Dec  3 2012 ms@suse.de
- fixed 64bit path check for lxc base directory
* Sun Dec  2 2012 rjschwei@suse.com
- Implement XMLExceptData class to store <except> data of the
  <split> element
- Modify the get* methods of the XMLSplitData class to return array refs of
  FileData and ExceptData objects
  * this was necessary to avoid duplication of XML generation code across
    class implementations
  * this behavior is now also consistent with other get* methods when
    accessing complex data
- Implement getXMLElement method for all XML*Data classes
  * getXML method returns 1 XML element that represents the data of the
    class
- Update unit tests as needed
* Fri Nov 30 2012 rjschwei@suse.com
- implement consistency check to disallow boot to be setup as
  a volume in <systemdisk> (LVM) configuration
- implement unit tests to verify test
* Fri Nov 30 2012 ms@suse.de
- v5.04.28 released
* Fri Nov 30 2012 ms@suse.de
- removed obsolete and also never reached code
* Fri Nov 30 2012 ms@suse.de
- fixed user/group setup. kiwi used the given group name as a
  supplementary group and not as the main group this user belongs
  to. Together with a group name and a group id which matches
  that group name this could lead to duplicate user views in
  e.g YaST and to basically wrong user configuration (bnc #792058)
* Fri Nov 30 2012 rjschwei@suse.com
- implement handling of additive and unit attributes of the <size>
  element in the imageConfig data structure and the XMLTypeData class
  rename the following methods of the XML class:
  * getImageSize               => getImageSize_legacy
  * getImageSizeAdditiveBytes  => getImageSizeAdditiveBytes_legacy
  * getImageSizeBytes          => getImageSizeBytes_legacy
* Thu Nov 29 2012 ms@suse.de
- fixed legacy grub setup. the partition numbers starts at 0 here
* Thu Nov 29 2012 ms@suse.de
- fixed shell escaping for grub.cfg and /etc/default/grub
- also fixed importFile method to handle single quotes correctly
* Wed Nov 28 2012 rjschwei@suse.com
- implement <strip> data handling in new XML data structure
- rename the following methods:
  * updateTypeList      -> __updateTypeList_legacy
  * updateXML           -> __updateXML_legacy
  * writeXMLDescription -> writeXMLDescription_legacy
  * createURLList       -> __createURLList_legacy
  * getURLHash          -> getURLHash_legacy
  * getURLList          -> __getURLList_legacy
  * getLocale           -> getLocale_legacy
  * getStripDelete      -> __getStripDelete_legacy
  * getStripLibs        -> __getStripLibs_legacy
  * getStripTools       -> __getStripTools_legacy
  * addStrip            -> __addStrip_legacy
- implement new methods to add and get data expressed as <strip>
  in the XML
- update unit tests to use _legacy method names
- implement new unit tests for new methods
  * create new config.xml file for new unit tests
- implement XMLStripData class
* Wed Nov 28 2012 ms@suse.de
- fixes use of custom disk size value via the <size> element
  or the option --bootvm-disksize. In combination with LVM
  volumes the result disk size is much bigger because kiwi
  just added the requested volume sizes to the specified
  disk size which is not the desired behavior
* Wed Nov 28 2012 rjschwei@suse.com
- fix array comparison in the test case
  * at present names that contain "special" characters may not compare
    properly, such that libstdc++ will not match a libstdc++ entry in
    the other array. Use string interpolation to address the issue.
* Tue Nov 27 2012 rjschwei@suse.com
- use numbers for calculations, do not depend on implicit conversion
* Tue Nov 27 2012 ms@suse.de
- DB: rebuild documentation
* Tue Nov 27 2012 ms@suse.de
- DB: update documentation due to the new pxe unionfs mount method
* Tue Nov 27 2012 ms@suse.de
- added mountSystemUnionFS() function which uses fuse-unionfs
  to overlay mount the root system according to the contents
  of UNIONFS_CONFIG. So far this setup is only supported with
  pxe images as requested in (bnc #776505)
* Mon Nov 26 2012 ms@suse.de
- remove searchUSBStickDevice() function. When kiwi was called
  with a target disk device the assumption was made that the
  install media should also be created on a device directly.
  If the install media is a USB stick (installstick="true")
  kiwi searches for stick devices during the process and:
  a) exits with an error if it can't find one
  b) asks which one to use if it finds more than one
  This behavior is a pita for automatic build processes and
  it also fails if the stick media does not set the 'removable'
  state in its meta data correctly. Additionally the assumption
  that the install media is present as a device just because
  the image was created from an existing device also sucks
  This commit removes the search for stick devices and always
  creates the install media through a loop as a file which
  then needs to be dumped on the target device
* Mon Nov 26 2012 ms@suse.de
- fixed spec file, syslinux exists on ix86 and x86_64 only
* Mon Nov 26 2012 ms@suse.de
- cleanup global mount method to use the getPartDevice() function
  to search for partition devices
* Mon Nov 26 2012 ms@suse.de
- cleanup setupInstallStick(), the reference to this->{loop}
  might be undefined depending on the environment better use
  the contents of $haveDiskDevice
* Mon Nov 26 2012 ms@suse.de
- removed obsolete mount code from setupInstallStick()
* Mon Nov 26 2012 ms@suse.de
- fixed setupInstallStick() if called in Studio mode. If this
  function is called with a disk device as reference it expects
  the target USB stick to be plugged in, in order to create the
  install image directly on that stick. For Studio this does
  not work because the target stick is never attached to the
  containment within this call happens. Thus this fix creates
  the install USB stick image in a loop device
* Mon Nov 26 2012 ms@suse.de
- added sanity check for mount() method to fail
  if no source information is passed
* Fri Nov 23 2012 ms@suse.de
- v5.04.27 released
* Fri Nov 23 2012 ms@suse.de
- fixed broken postImage() filesystem check which prevented the
  creation of the system image .md5 file
* Fri Nov 23 2012 ms@suse.de
- v5.04.26 released
* Fri Nov 23 2012 ms@suse.de
- changed behavior of --fat-storage option. Instead of syslinux
  we now use grub2 to boot from the fat partition. It has turned
  out that grub2 is more stable and behaves better when using
  the image on a USB stick. The grub2 theme support also makes
  it easier to use custom branded boot graphics
* Fri Nov 23 2012 ms@suse.de
- fixed cleanup of temporary copy of sysconfig/proxy. If there
  is a fillup template for the file and the file hasn't changed
  as part of the build process the fillup template is restored
  instead of removing the file (bnc #777151)
* Thu Nov 22 2012 ms@suse.de
- fixed logical volume name building in resizeLVMVolumes()
  the function only evaluates volume names at the primary
  level e.g /opt. As soon as you have a volume e.g /opt/bob
  it failed to resize
* Thu Nov 22 2012 ms@suse.de
- added support for a jump partition which is added before the
  actual boot partition. This is used for grub2 efi based disk
  images now. kiwi just put the created grub2 bootx64.efi module
  onto the fat16 based jump partition and let grub2 read all
  data from the second ext3 based boot partition. This allows
  standard linux filesystem based boot partitions and it has
  also turned out that this disk layout might be required for
  arm based images as well. But so far this system is connected
  to the efi setup only
* Thu Nov 22 2012 ms@suse.de
- added parted to openSUSE 12.2 JeOS template
* Thu Nov 22 2012 ms@suse.de
- fixed typo in setupFilesystem() which caused a fat16 filesystem
  even though a fat32 filesystem was requested.
- changed the efi boot partition type to fat16
- added ext2 modules to the bootx64.efi module
* Wed Nov 21 2012 ms@suse.de
- adapt oemboot suse/rhel-repart code to make use of the flexible
  boot partition location in $kiwi_BootPart. The partition ID
  stored there is used as the beginning of the partition layout.
  Instead of a fixed boot partition at 1 the layout handles the
  value of $kiwi_BootPart as the start. If there is no boot
  partition the first partition must be the root partition as
  usual.
* Wed Nov 21 2012 rjschwei@suse.com
- update the driver handling for the imageConfig data structure
  * take advantage of the private helper methods implemented for
    package handling
  * eliminates code duplication
  * simplifies implementation of driver handling methods
- update the unit tests to adjust for minor differences in messages
* Wed Nov 21 2012 praveen_paladugu@dell.com
- fixed perl dependencies in spec file for rhel/centos
- resolve suse version checking to zero if the suse_version
  macro is not defined. This allows the package build going
  easily also in non-suse based distros
* Wed Nov 21 2012 ms@suse.de
- use new partids hash for the bootloader stage setup
  setupBootLoaderStages()
* Wed Nov 21 2012 ms@suse.de
- use new partids hash for the setup and installation of the
  bootloaders, setupBootLoaderConfiguration() / installBootLoader()
* Wed Nov 21 2012 ms@suse.de
- fixed use of filehandle in addAppdata() and collectPackages()
  of the instsource media KIWICollect module
* Tue Nov 20 2012 ms@suse.de
- use new partids hash to create the device map and cleanup
  access to the new device map data
* Tue Nov 20 2012 ms@suse.de
- make sure setupBootFlags also updates the .splash.gz variant of
  the initrd if the function was called with the non splash (.gz)
  variant of the initrd.
* Tue Nov 20 2012 ms@suse.de
- fixed post partition size check and read-write dump if
  split + lvm is used. An undefined device was used for
  the check and the dump in this case
* Tue Nov 20 2012 delgado@pre-sense.de
- allow getExecArgsFormat to parse python optparse/argparse
  output. python uses the form '-o, --option' whereas we
  don't expect a comma between the short and long version
- add unit test for this option format
* Tue Nov 20 2012 ms@suse.de
- check for kiwi_BootPart from new partition IDs meta data
  in setupBootPartition(). This could be used to map the
  boot partition to another than the first partition
* Tue Nov 20 2012 ms@suse.de
- switched oemboot boot code to make use of config.partids
* Tue Nov 20 2012 ms@suse.de
- switched vmxboot boot code to make use of config.partids
* Tue Nov 20 2012 ms@suse.de
- added additional meta data file with suffix .pids. The file
  contains the information about the ID/Name of the root,boot
  readonly/readwrite device according to this appliance if a
  virtual disk based image was requested. The information is
  included as config.partids into the initrd and is used on
  first boot. Rather than guessing the purpose of partitions
  the initrd will now know it exactly
* Tue Nov 20 2012 ms@suse.de
- fixed call of method textContent() on an undefined value
* Tue Nov 20 2012 rjschwei@suse.com
- fix typo and logic error in test cases (bnc #790254)
  * typo cause list comparison to fail
  * logic error caused a name that should have been in he comparison
    list to be omitted
* Mon Nov 19 2012 dvaleev@suse.de
- changed spec file to be quiet on unpacking the source tarball.
  During kiwi build don't list files and directories of tarball.
  This floods build log pretty much.
* Mon Nov 19 2012 ms@suse.de
- don't fail hard if copyBootCode() cannot create e.g symlinks
  on copy of the boot data. Just report that as a warning
* Mon Nov 19 2012 ms@suse.de
- if a bootfilesystem is specified it's required to check its
  type prior to the creation of the partition table because it
  might be required to specify a partition label according to
  the selected filesystem
* Mon Nov 19 2012 rjschwei@suse.com
- fix return values of legacy methods of the XML class, return
  values as string. Older versions of the LibXML perl binding
  do not have an overloaded eq operator for a NodeList where the
  value of the first entry of a node can be used in a comparison.
  There is however a string conversion, thus placing the nodelist
  inside a string "$nl" does the trick. This fixes issues on
  SLES 11 with the unit tests Related to (bnc #790254)
- update the trigger files to fix unit tets execution that was
  broken when ArchiveData, IgnoreData, and ProductData were
  renamed To contain the Package prefix in the name.
  Related to (bnc #790254)
* Mon Nov 19 2012 ms@suse.de
- fixed spec file:
  * update author list for kiwi-instsource
  * make sure at least ext and fat filesystem creation tools
    are required
* Sun Nov 18 2012 ms@suse.de
- fix use of uninitialized variables
* Fri Nov 16 2012 ms@suse.de
- v5.04.25 released
* Fri Nov 16 2012 ms@suse.de
- arm: removed match for image-$VERSION in suseStripKernel
* Thu Nov 15 2012 ms@suse.de
- fixed kernel search in suseStripKernel for armv5 kernel.
  There we have Image-* (with a capital 'I')
* Thu Nov 15 2012 ms@suse.de
- fixed spec file requirements: kiwi has a create mode runtime check
  for the vgs command. Thus the kiwi package should require lvm2 to
  become installed
* Thu Nov 15 2012 ms@suse.de
- make sure possibly left over dhcpcd pid file from a -T (test) call
  is removed before requesting the IP address for the interface. It
  has turned out that the sle10 dhcpcd has this bug and kiwi works
  around this one by actively checking for a pid file after the
  dhcpcd -T (test) call (bnc #787924)
* Thu Nov 15 2012 ms@suse.de
- use baseUpdateSysConfig() function to update variable contents
  of sysconfig files as required in the suseConfig() function.
  This eliminates the various sed statements here and uses one
  common function for all sysconfig updates
* Tue Nov 13 2012 bgeuken@suse.de
- Fixed regular expression for replacing HWCLOCK in clock config file
  This fixes a bug that causes a wrong '--localtime' / '--utc' entry
  in USE_HWCLOCK setting. This setting got introduced first with
  openSUSE 12.2
* Tue Nov 13 2012 ms@suse.de
- fix use of uninitialized variables
* Tue Nov 13 2012 ms@suse.de
- netboot: fixed dhcpcd '-r' option name clash. Older versions of
  dhcpcd use that option in a completely different meaning, thus
  we distinguish the call by the the capability of the '-p' option
  (interface persistency) which was introduced in newer versions
  of dhcpcd only (bnc #787924)
* Tue Nov 13 2012 ms@suse.de
- fix use of uninitialized variables
* Tue Nov 13 2012 rjschwei@suse.com
- add spaces to separate option arguments
* Mon Nov 12 2012 rjschwei@suse.com
- fix use of uninitialized variables
- do not clobber the FS tune settings for ext2,3,4 if fsnocheck and tune
  settings are provided
* Mon Nov 12 2012 ms@suse.de
- fixed use of implicit split to @_ with a temporary variable
* Sun Nov 11 2012 ms@suse.de
- v5.04.24 released
* Sun Nov 11 2012 ms@suse.de
- fixed build of plain bootiso/bootstick from kiwi initrd without
  system image. The call kiwi --bootusb <initrd> failed to work
  because it tried to access the XML description which can't
  work when no system image is specified
* Fri Nov  9 2012 ms@suse.de
- v5.04.23 released
* Fri Nov  9 2012 ms@suse.de
- fixed device name setup in recovery/restore mode. kiwi assumes
  an overlay setup when a second partition exists but this is not
  true if the second partition is the swap space. For the initial
  boot of an appliance the device setup always works but when
  oemboot has created new partitions e.g swap space and the kiwi
  initrd runs again in recovery/restore mode the device setup
  might be broken because of another partition layout compared
  to the initial state
* Fri Nov  9 2012 rjschwei@suse.com
- implement XML data classes for elements that are children of <packages>
  * KIWIXMLPackageArchiveData handle <archive>
  * KIWIXMLPackageIgnoreData <ignore>
  * KIWIXMLPackageCollectData handle <rhelGroup> and <opensusePattern>
  * KIWIXMLPackageData handle <package>
  * KIWIXMLPackageProductData <opensuseProduct>
- update the FileData base class to allow extension by child to support
  additional allowed attributes
- implement unit tests for all new classes
- integrate new data classes into XML class and rename the
  following methods to _legacy
  * getArchiveList
  * addPatterns
  * addImagePatterns
  * getList
  * getTypeSpecificPackageList
  * getPackageNodeListgetPackageAttributes
  * getImageConfig
  * getBaseList
  * getInstallList
  * getDeleteList
  * getBootIncludes
  * addPackages
  * addImagePackages
  * addRemovePackages
- update client code to use *_legacy methods
- removed hasDefaultPackages method
- implement equivalent functionality with the new methods
  * addArchives
  * getArchives
  * addBootstrapPackages
  * addPackages
  * addPackagesToDelete
  * getBootDeletePackages
  * getBootIncludeArchives
  * getBootIncludePackages
  * getBootstrapPackages
  * getPackages
  * getPackagesToDelete
  * getProducts
- the <rhelGroup> and <opensusePattern> are treated equally as a package
  collection
- update unit tests for XML
  * there are some bugs in the _legacy methods, these will not be fixed as
    the bugs will go away when we switch to the new code. The legacy code
    does not respect type specific archives being added.
  * update the test data to re-use same configuration files
    for multiple test cases
  * use _legacy names
  * implement new tests for new methods
- update RuntimeChecker to use new methods in the XML
- implement tnew triggers and update existsing triggers as needed
* Fri Nov  9 2012 rjschwei@suse.com
- some clean up, typos, remove unused code
* Fri Nov  9 2012 ms@suse.de
- added tar to 12.2 JeOS
* Thu Nov  8 2012 ms@suse.de
- add support for grub2 based recovery system
* Thu Nov  8 2012 ms@suse.de
- fixed indention of linux command in grub.cfg
* Thu Nov  8 2012 rjschwei@suse.com
- fix the automatic alias generation to remove '$' from the
  name, this allows users to use SMT repos without having to
  specify an alias in the config.xml file
* Thu Nov  8 2012 ms@suse.de
- use contents of $bootPartitionFSType to check symlink capabilities
* Thu Nov  8 2012 ms@suse.de
- fixed cleanup code in KIWILinuxRC after mkinitrd was called
  in case of arm images not all obsolete data was removed
- pass boot filesystem type as first argument to the pre
  bootloader install script and handle it in the arm JeOS
  template in uboot-image-setup
- export bootPartitionFSType in KIWILinuxRC and handle it
  in the hook script kiwi-hooks/setupUBoot.sh
* Thu Nov  8 2012 ms@suse.de
- DB: rebuild schema documentation
* Thu Nov  8 2012 ms@suse.de
- fixed nic interface runtime check, the value '0' is valid
  for the index of a VMware interface definition, thus it's
  wrong to do a true/false check here.
* Thu Nov  8 2012 ms@suse.de
- fixed use of uninitialized values in the code now reported
  due to the use of warnings at runtime
* Wed Nov  7 2012 ms@suse.de
- make sure var/log/ConsoleKit exists when booting the first time
* Wed Nov  7 2012 ms@suse.de
- fixed cleanKernelFSMount() to use the correct root path
* Wed Nov  7 2012 ms@suse.de
- added support for reading /etc/kiwi/repoalias file in
  KIWIURL.pm. The repoalias definition can be used to
  mirror a repo path to another location (bnc #788536)
* Wed Nov  7 2012 ms@suse.de
- SuSEconfig is gone, call it only if it exists
* Tue Nov  6 2012 ms@suse.de
- fixed schema for bootfilesystem attribute, attribute was not
  set into the attribute list in the RelaxNG schema
* Tue Nov  6 2012 ms@suse.de
- added support for optional type attribute 'bootfilesystem'
  which can be one of ext2,ext3,fat16 or fat32 (bnc #788374)
- added unit test for new attribute
* Tue Nov  6 2012 ms@suse.de
- update pre-commit hook
* Tue Nov  6 2012 ms@suse.de
- fixed use of uninitialized values in the code now reported
  due to the use of warnings at runtime
* Tue Nov  6 2012 ms@suse.de
- removed obsolete and unmaintained dotty graph file
* Tue Nov  6 2012 rjschwei@suse.com
- remove the statistics colector and the generated data
  we never got around to finish the integration of the data collector
  and it is not used. At this point it appears that the code will just
  not be used in the long run, thus it is getting removed
* Tue Nov  6 2012 ms@suse.de
- fixed use of uninitialized values in the code now reported
  due to the use of warnings at runtime
* Tue Nov  6 2012 ms@suse.de
- fixed openSUSE product building
* Mon Nov  5 2012 ms@suse.de
- fixed handling of special characters in grub2 menuentry setup
  single quotes are required for custom names (bnc #786262)
* Mon Nov  5 2012 ms@suse.de
- fixed spec file require for kiwi-tools. kiwi should require
  the same or newer kiwi-tools version compared to the base
  kiwi package
* Mon Nov  5 2012 ms@suse.de
- put tests/unit/*.t to perl critic level 4
- put tests/qa/stats/collector.pl to perl critic level 4
- update pre-commit hook
* Sat Nov  3 2012 rjschwei@suse.com
- clean most test unit driver files to perlcritic level 2
  The remainaing driver files must be cleaned after we have
  migrated the code to use the new internal data structure
* Fri Nov  2 2012 ms@suse.de
- v5.04.22 released
* Fri Nov  2 2012 ms@suse.de
- removed vmxboot respectively image type vmx from arm code
  branch. All arm images are oem's vmx is unused here
* Fri Nov  2 2012 ms@suse.de
- fixed device detection in the oemboot install code. The try to
  remove the boot device from the list of possible install devices.
  The sed statement used here caused a broken list of the substring
  also matches other devices. The fix here changes this to exactly
  match the device string of the boot device and nothing else
* Fri Nov  2 2012 ms@suse.de
- fixed etc/default/grub GRUB_DISTRIBUTOR name setup
* Fri Nov  2 2012 ms@suse.de
- include mdmon to handle raid array status changes if
  a dmraid array is in use
* Fri Nov  2 2012 ms@suse.de
- fixed use of uninitialized values in the code now reported
  due to the use of warnings at runtime
* Fri Nov  2 2012 ms@suse.de
- fixed setup of /etc/default/grub to contain the bootloader
  setup in terms of boot title, timeout, etc... (bnc #786262)
* Fri Nov  2 2012 rjschwei@suse.com
- report an error when a <systemdisk> definition is specified in the
  configuration and we cannot find the necessary command to obtain
  LVM information
- implement consistency check for user settings
  * if a user is specified in two <users> sections all given settings must
    be the same
  * the same user may not be specified twice in the same <users> section
- implement group setting consistency check
  * a group id may only be used once
  * a group name may only be used with one ID
* Thu Nov  1 2012 rjschwei@suse.com
- implement KIWIXMLUserData class to store user data
- implement unit test for new class
- implement unit tests for new methods
- tie new class into XML Class
  * rename the following methods to *_legacy
    __addVolume()
    __populateImageTypeAndNode()
    __updateDescriptionFromChangeSet()
    __populateProfiledTypeInfo()
    getUsers()
    getTypes()
  * add new getUsers method returning an array of UserData objects
  * add new getType method return TypeData object for given type name
- fixup client code to call new _legacy methods
- update unit tests using _legacy
* Wed Oct 31 2012 guillaume.gardet@oliseo.fr
- Added armv5 support
* Wed Oct 31 2012 ms@suse.de
- v5.04.21 released
* Wed Oct 31 2012 ms@suse.de
- fixed unit test, don't use remote URLs for a test they will
  fail inside the buildservice because there is no network
  access allowed
* Wed Oct 31 2012 ms@suse.de
- fixed spec file, added lvm2 to buildrequires. This is
  required to let the unit tests work
* Wed Oct 31 2012 ms@suse.de
- fixed use of uninitialized values in the code now reported
  due to the use of warnings at runtime
* Wed Oct 31 2012 ms@suse.de
- v5.04.20 released
* Tue Oct 30 2012 ms@suse.de
- fixed use of uninitialized values in the code now reported
  due to the use of warnings at runtime
* Tue Oct 30 2012 ms@suse.de
- don't send data to a closed file descriptor
* Tue Oct 30 2012 ms@suse.de
- fixed use of uninitialized values in the code now reported
  due to the use of warnings at runtime
* Tue Oct 30 2012 ms@suse.de
- fixed name for install media:
  * install ISO has suffix: .install.iso
  * install USB has suffix: .install.raw
  * install PXE has suffix: .install.tgz
* Tue Oct 30 2012 ms@suse.de
- update pre-commit hook
* Tue Oct 30 2012 ms@suse.de
- put KIWIXML.pm to perl critic level 4
* Tue Oct 30 2012 ms@suse.de
- put KIWISharedMem.pm to perl critic level 4
* Tue Oct 30 2012 ms@suse.de
- put KIWISatSolver.pm to perl critic level 4
* Tue Oct 30 2012 ms@suse.de
- put KIWIRoot.pm to perl critic level 4
* Tue Oct 30 2012 ms@suse.de
- put KIWIRepoMetaHandler.pm to perl critic level 4
* Tue Oct 30 2012 ms@suse.de
- put KIWIProductData.pm to perl critic level 4
* Tue Oct 30 2012 ms@suse.de
- put KIWIMigrate.pm to perl critic level 4
* Tue Oct 30 2012 ms@suse.de
- put KIWIManager.pm to perl critic level 4
* Tue Oct 30 2012 rjschwei@suse.com
- add consistency check to verify a volume name is unique
  within each <systemdisk> definition
- add unit test
* Tue Oct 30 2012 ms@suse.de
- put KIWILog.pm to perl critic level 4
* Tue Oct 30 2012 ms@suse.de
- put KIWIImage.pm to perl critic level 4
* Tue Oct 30 2012 ms@suse.de
- put KIWIImageFormat.pm to perl critic level 4
* Tue Oct 30 2012 ms@suse.de
- put KIWIConfigure.pm to perl critic level 4
* Mon Oct 29 2012 ms@suse.de
- put KIWICollect.pm to perl critic level 4
* Mon Oct 29 2012 ms@suse.de
- put KIWIArchList.pm to perl critic level 4
* Mon Oct 29 2012 rjschwei@suse.com
- add consistency check for the <packages type="delete"> case
  can only delete packages, thus specifying archives, patterns,
  or a product is not valid
* Mon Oct 29 2012 ms@suse.de
- fixed removal of temporary boot_bind entry in fstab
* Mon Oct 29 2012 ms@suse.de
- make sure proc/cmdline is there when setting up logging
* Mon Oct 29 2012 ms@suse.de
- create LVM volume filesystems with suitable number of inodes
  for filesystems which require this. Occasionally it happens
  that we run out of space when using a custom LVM volume setup.
  The reason for this is that the filesystem cannot allocate
  more inodes because kiwi calculates the inode count for the root
  volume but not for the sub lvm volumes e.g /var, /srv, etc
  according to the volume setup. This commit fixes this in a way
  that kiwi creates a suitable number of inodes for each
  filesystem inside the LVM
* Sat Oct 27 2012 rjschwei@suse.com
- update kiwi manual pages to clarify meaning of set-repo argument
- fix the behavior of the new implementation of setRepository
  * replaceable is considered the default, thus replace a repo if it is
    the first in line and has not status set or the status is marked
    replaceable
  * properly replace the first repo specified in config.xml that is
    not marked "fixed". Previously the default profile would have been
    the first to get a repo replaced, no matter the definition order in
    config.xml
- update the unit tests
- encode the default status of replaceable in the RepositoryData object
* Fri Oct 26 2012 ms@suse.de
- make sure repos marked as imageinclude will preserve its priority
* Fri Oct 26 2012 ms@suse.de
- changed back to clicfs for 12.2 live iso JeOS template.
  I found several problems with btrfs and it's seed implementation
  * the compressed read-only part needs to be bigger than the data
    requires it. if this is not given adding the seed dev will fail
  * when adding a ramdisk seed for the combination read-only loop
    from ISO plus read-write /dev/ram (brd) block device the kernel
    throws a trace from btrfs not being able to relocate sys chunks
    and that 'balancing' it would solve that... which is not true
* Fri Oct 26 2012 ms@suse.de
- make sure edit boot scripts get the executable bit set
* Fri Oct 26 2012 rjschwei@suse.com
- change behavior of boolean in the XML*Data classes
  * undefined attributes in the initialization of an object
    remain undefined
  * defined values are either 'true' or 'false'
  * this change had to be made such that merging and updating
    of preferences in the XML can be supported correctly
* Fri Oct 26 2012 rjschwei@suse.com
- add new runtime check to verify that repo aliases used are unique
  this has to be a runtime check as it is valid to define repos with
  the same alias as long as those repos are never used at the same
  time during a build
- implement setPreferences method in the XML class
  preferences will be assigned to the profile preferences that have
  an existing definition, if no definition exists the setting applies
  to the default preferences
- add unit test for new runtime check
- add unit test for new setPreferences method
- remove all calls to _legacy methods from the RuntimeChecker
  thus the RuntimeChecker is the first using the new internal
  data structure
* Thu Oct 25 2012 ms@suse.de
- fixed getSector to calculate with numeric values
* Thu Oct 25 2012 ms@suse.de
- fixed IPC signal setup
* Thu Oct 25 2012 ms@suse.de
- fixed use of uninitialized values in KIWIBoot.pm. with
  the last cleanup we use warnings for KIWIBoot now thus
  we get informed about perl warnings for this module.
  Along with the ongoing process of cleaning up the code
  by using perl-critic other modules will follow
* Thu Oct 25 2012 ms@suse.de
- make KIWIArch.pm perl critic level 3 clean
* Thu Oct 25 2012 ms@suse.de
- make KIWIBoot.pm perlcritic level 4 clean
* Thu Oct 25 2012 ms@suse.de
- make kiwi.pl perl critic level 4 clean
* Wed Oct 24 2012 ms@suse.de
- update pre-commit hook
* Wed Oct 24 2012 ms@suse.de
- make kiwi.pl perl critic level 5 clean
* Wed Oct 24 2012 ms@suse.de
- make KIWIBoot.pm perlcritic level 5 clean
* Tue Oct 23 2012 ms@suse.de
- DB: rebuild schema documentation
* Tue Oct 23 2012 ms@suse.de
- DB: rebuild documentation
* Tue Oct 23 2012 ms@suse.de
- DB: update documentation concerning the new installpxe attribute
* Tue Oct 23 2012 ms@suse.de
- added support for the <type ... installpxe="true"/> attribute.
  if set kiwi creates a tarball which contains all data required
  to let an oem disk image to become installed via pxe. The
  archive contains: kernel, initrd, system gzimage, md5sum and
  kernel boot options for the append line in the pxe setup
  This fixes bug (bnc #785222)
* Tue Oct 23 2012 ms@suse.de
- added kiwi.pl to pre-commit check
* Tue Oct 23 2012 rjschwei@suse.com
- do not support creation of a TypeData object without keyword
  initialization hash. The image attribute is mandatory on the
  <type> element, thus it should not be possible to construct
  an object representing the element without specifying a value
  for image
- add the new installpxe member to the bool keywords
- update the unit tests to handle the new condition
- add tests for new installpxe member
* Tue Oct 23 2012 rjschwei@suse.com
- change the handling of booleans in the XML*Data classes
  * implement __initializeBoolMembers in the base class to setup
    boolean members
  * modify the __setBooleanValue method such that a boolean value
    is defined as a member only if it is true, this allows us to
    change checks from "if ($bool && $bool eq 'true')" to simply
    "if ($bool)" this is consistent with general language
    conventions
* Mon Oct 22 2012 toganm@opensuse.org
- Emacs mode fix:
  Fix typos in the suse-start-kiwi-xmllocator. Rather than
  blindly adding suffixes to nxml-mode just add kiwi suffix
  to include to the auto-mode-list
* Mon Oct 22 2012 ms@suse.de
- fixed unit test kiwiXML.pm:test_addRepositoriesExistPrefLic.
  The test checks for duplicate preference license indicator but
  adds an invalid bool value for the attribute. Thus kiwi complains
  about the invalid value and not about the duplicate indicator
* Mon Oct 22 2012 ms@suse.de
- added 'imageinclude' to supportedKeywords in KIWIXMLRepositoryData
  to become checked by base class code in KIWIXMLDataBase. Additionally
  removed obsolete and commented out code from KIWIXMLDataBase
  constructor
* Fri Oct 19 2012 ms@suse.de
- v5.04.19 released
* Fri Oct 19 2012 ms@suse.de
- added central deactivateVolumeGroup and activateVolumeGroup
  functions and make sure all udev events are processed before
  activating/deactivating a volume group
* Fri Oct 19 2012 ms@suse.de
- fixed resizeFilesystem() function:
  * don't create INITRD_MODULES list here, this caused multiple entries
  * use separate mount point not /mnt for temporary mount on resize
  * make sure all udev events are processed before resize
* Fri Oct 19 2012 ms@suse.de
- removed __checkKernelVersionToolExists runtime check.
  kiwi provides the tool itself thus it's always there
* Fri Oct 19 2012 ms@suse.de
- v5.04.18 released
* Fri Oct 19 2012 ms@suse.de
- make path check in KIWIURL more robust
* Fri Oct 19 2012 rjschwei@suse.com
- force KIWIXMLFileData to be instantiated with a keyword argument hash
- remove superfluous if test in KIWIXMLDescriptionData and
  KIWIXMLProfileData classes
- update unit tests
* Fri Oct 19 2012 rjschwei@suse.com
- fix up KIWIXMLRepositoryData class
  * do not support un-initialized construction
  * use base class infrastructure for the preferlicense member
- update unit tests accordingly
* Fri Oct 19 2012 rjschwei@suse.com
- implement __hasInitArg in the XMLDataBase class
  * this allows children that should not be constructed without an
    initialization argument to complain in a consistent way it the
    arg is missing
- update ProfileData to use new method in base class
- clean up DescriptionData implementation
  * do not support construction without arg
    : eliminates need for object consistency check
  * make setters consistent in behavior with other *Data class setters
- revamp the DescriptionData unit tests
  * test structure consistent with other tests for XML*Data tests
  * smaller tests, better coverage
* Thu Oct 18 2012 ms@suse.de
- fixed grub2 setup. If the root filesystem is LVM based grub2
  can't read e.g the fonts from this device. Thus this patch
  ensure all required theme data incl. the unicode font is part
  of the boot device
* Thu Oct 18 2012 ms@suse.de
- use the setupFileSystem function to create the boot filesystem
  this is done for code cleanup and also to prepare the code for
  setting up a custom boot partition filesystem. At the moment
  the boot filesystem is bound to which bootloader is in use but
  e.g for arm boxes the same bootloader might require different
  boot filesystems, thus this could become an option in kiwi
* Thu Oct 18 2012 rjschwei@suse.com
- add tests to run when the XML class changes. Previous update
  had an issue that was found by a unit test that was not
  automatically run from the triggers
* Wed Oct 17 2012 ms@suse.de
- fixed copyBootCode to work if no boot partition is used
* Wed Oct 17 2012 rjschwei@suse.com
- implement a ProfileData object
  * while profile data was already included in the new data structure,
    information about this data was not returned as an object. This
    change addresses this outstanding issue
  * implement unit tests for the new object
  * update the XML object to integrate the ProfileData class
  * update the XML unit test
- change all XML*Data classes to be children on XMLDataBase and
  update unit tests to handle new initialization and new error
  conditions and error messages
* Tue Oct 16 2012 rjschwei@suse.com
- change __setDefaultType() to meet the following conditions:
  * if a type is marked primary within the selected profiles
    it is the default type
  * if no type is marked primary then the first type of the default
    <preferences> section (the one not assigned to a specific profile)
    becomes the default type; should the default <preferences> have
    no type than the first type of the first profile bound preferences
    section is the default type
- add test cases to verify this behavior
* Tue Oct 16 2012 ms@suse.de
- added perl-Readonly requirement to spec file
* Tue Oct 16 2012 ms@suse.de
- fixed kernel version tool to work with uImage files
* Tue Oct 16 2012 ms@suse.de
- use kiwi's kversion tool instead of get_kernel_version to
  let other distros also be part of the game
* Mon Oct 15 2012 ms@suse.de
- cleanup volume size calculation to be more readable
* Mon Oct 15 2012 ms@suse.de
- fixed broken symlink when creating tbz images
* Mon Oct 15 2012 ms@suse.de
- DB: update check target to verify docbook build env
* Mon Oct 15 2012 ms@suse.de
- DB: rebuild documentation
* Mon Oct 15 2012 ms@suse.de
- DB: update documentation, add some notes to oem pxe installs
* Fri Oct 12 2012 ms@suse.de
- v5.04.17 released
* Fri Oct 12 2012 ms@suse.de
- arm: fixed JeOS uboot-setup.tgz:setupUBoot.sh. when calling
  code via runHook the first parameter is the name of the hook
  thus I had to shift all params by one
* Fri Oct 12 2012 ms@suse.de
- v5.04.16 released
* Fri Oct 12 2012 ms@suse.de
- fixed reading search path for custom boot config scripts.
  The information of the origin path of the image description
  is read from the image/main::Prepare file stored in the
  unpacked root tree. Within KIWIBoot the reading of that file
  should be done inside the constructor when the XML data
  is read from the unpacked tree. That way the path is consistent
  for the life time of the object and needs to be read only
  once.
* Fri Oct 12 2012 ms@suse.de
- fixed typo in message string, obsolete '\n'
* Fri Oct 12 2012 ms@suse.de
- fixed kiwi --installcd mode and the global mount() method
  in general to know about LVM disks. In this case the mount
  has to activate the volume group in order to access the
  devices inside. The code to do this was in the checkLVMbind
  method in KIWIBoot but it is required before in the mount()
  method in KIWIGlobals
* Thu Oct 11 2012 ms@suse.de
- fixed creation of .profile KIWI_LVM_LV* variables if no
  size is set for the volume
* Thu Oct 11 2012 ms@suse.de
- cleaned up the code which walks through the volumes of an
  LVM setup and calculates the volume sizes and disk size
  increasement
* Wed Oct 10 2012 ms@suse.de
- added boot time correction for kiwi initrd's (bnc #784316)
- removed obsolete disable of hotplug helper when starting udev
- start error logging as early as possible
* Wed Oct 10 2012 ms@suse.de
- removed obsolete comments about deletion of _legacy functions
  Robert already sorted them and added a comment on top of all
  these functions
* Tue Oct  9 2012 ms@suse.de
- fixed repo setup for arm JeOS template
* Mon Oct  8 2012 ms@suse.de
- use simple TERM signal to stop initrd's udevd
* Sun Oct  7 2012 ms@suse.de
- DB: rebuild documentation
* Fri Oct  5 2012 cschum@suse.de
- DB: be more specific about how bootinclude affects the system image.
* Fri Oct  5 2012 ms@suse.de
- v5.04.15 released
* Fri Oct  5 2012 ms@suse.de
- fixed setup of dmraid devices. A new function called
  identifyDMRaid() has been added which searches for
  mapped dmraid disks and also removes the devices which
  belongs to the raid from the list of install disks
* Thu Oct  4 2012 ms@suse.de
- fixed grub2 setup to correctly distinguish the efi and non
  efi config files for dual boot of install iso images
* Tue Oct  2 2012 dvaleev@suse.de
- ppc: fix install iso blessing. In order to have installation
  CD/DVD bootable on PowerMac the suseboot directory must be
  blessed correctly. The situation was that -hfs-bless looks
  for the first directory and tries to bless required subdir.
  But in case required subdir is in the second directry,
  nothing got blessed. So let's switch the order.
* Tue Oct  2 2012 dvaleev@suse.de
- ppc: don't hardcode volume id. The volume ID is hardcoded
  to the value of 'FIXME'. Use createVolumeID function to
  create dynamic volume ID. Something like openSUSE 12.2 1
  where 1 is the media number
* Tue Oct  2 2012 ms@suse.de
- update language translations po/pot files
* Tue Oct  2 2012 ms@suse.de
- added a backtitle information when displaying the language
  dialog saying that the boot will continue in a few seconds
* Tue Oct  2 2012 ms@suse.de
- fixed grub2 'Boot from Hard Disk' chainloader setup
* Tue Oct  2 2012 ms@suse.de
- fixed grub2 root and module setup for bios based ISO boot
* Tue Oct  2 2012 ms@suse.de
- added a 10sec timeout for the language selection (bnc #778570)
* Tue Oct  2 2012 ms@suse.de
- make sure unicode font inclusion for install iso images happens
  when grub2 is used and not only when an efi based image is
  created
* Tue Oct  2 2012 ms@suse.de
- fixed grub2 font, terminal and root configuration
* Tue Oct  2 2012 ms@suse.de
- don't reset the boot_bind system when in GPT/EFI mode
* Mon Oct  1 2012 ms@suse.de
- fixed path for grub.cfg when in efi mode
* Mon Oct  1 2012 ms@suse.de
- fixed repartition and bootloader setup in efi mode
  * make sure the GPT metadata is updated to the real geometry
  * fixed grub2 mkconfig and install calls to match efi
  * make sure no parted call is blocked by user interaction
* Mon Oct  1 2012 ms@suse.de
- fixed grub2 setup for efi based disk images. The grub.cfg file
  was broken, referencing (cd0) instead of the disk root device
* Fri Sep 28 2012 ms@suse.de
- v5.04.14 released
* Thu Sep 27 2012 ms@suse.de
- fixed ISO header Preparer string to point to openSUSE
* Wed Sep 26 2012 ms@suse.de
- make losetup of btrfs cache devices race free
* Tue Sep 25 2012 ms@suse.de
- v5.04.13 released
* Tue Sep 25 2012 ms@suse.de
- cleanup spec file, correctly set Requires for kiwi-desc-*boot
* Tue Sep 25 2012 ms@suse.de
- make check for duplicate volume group name more robust
* Tue Sep 25 2012 ms@suse.de
- v5.04.12 released
* Tue Sep 25 2012 ms@suse.de
- fixed check for duplicate volume group name
* Mon Sep 24 2012 ms@suse.de
- removed unused requirement to perl-File-Stat-Bits
* Fri Sep 21 2012 ms@suse.de
- v5.04.11 released
* Fri Sep 21 2012 ms@suse.de
- make sure images.sh from the boot images checks on
  umounting kernel filesystems aka /proc, /sys, etc before
  exiting
* Wed Sep 19 2012 ms@suse.de
- better way to create uuid loop device in createLoopNode
  we loop setup first and rename the provided device
* Wed Sep 19 2012 ms@suse.de
- make sure to release all mounts if KIWIOverlay fails
* Wed Sep 19 2012 rneuhauser@suse.cz
- make sure /etc/sysconfig/kernel contains the virtio modules
  so that SLE10 mkinitrd picks it up correctly (bnc #747346)
* Tue Sep 18 2012 ms@suse.de
- DB: rebuild documentation
* Tue Sep 18 2012 ms@suse.de
- DB: update cache documentation
* Tue Sep 18 2012 ms@suse.de
- when using the caching system the bootstrap part of the build
  is skipped. Thus profiled bootstrap sections could lead to
  missing data when using a cache. I have moved all profiled
  bootstrap sections to type="image"
* Tue Sep 18 2012 ms@suse.de
- moved from ext2/dm-snapshot cache system to btrfs seed (bnc #764042)
* Mon Sep 17 2012 ms@suse.de
- fixed bootdev setup if no bindloop value is set
* Sat Sep 15 2012 ms@suse.de
- fixed createFormat() to return success when the format
  conversion is skipped in targetstudio mode
* Sat Sep 15 2012 ms@suse.de
- fixed KIWIImageFormat to work with a targetdevice as well
* Sat Sep 15 2012 ms@suse.de
- fixed __clean_loop in KIWIImageFormat. due to mkinitrd mounting
  sys __clean_loop has to take care to release sys before umount
  of the loop
* Sat Sep 15 2012 ms@suse.de
- fixed ec2 setup when only grub2 is installed. The xen loading
  system requires some grub related files to pre present
* Fri Sep 14 2012 ms@suse.de
- allow ec2 format creation when in --targetstudio mode (bnc #779360)
* Fri Sep 14 2012 ms@suse.de
- v5.04.10 released
* Fri Sep 14 2012 ms@suse.de
- cleanup installBootLoader() function. There is one way to setup
  the boot device and not the mess I created before.
- added helper function __getPartDevice() which finds the correct
  block device for a partition if you give it the disk device
  and the partition number
* Fri Sep 14 2012 ms@suse.de
- fixed spec file. Added PreReq for kiwi-pxeboot and kiwi-templates
  to make sure required coreutils are there when the package is
  installed (bnc #780070)
* Fri Sep 14 2012 ms@suse.de
- break long info message into two lines
* Fri Sep 14 2012 ms@suse.de
- arm: make uboot setup scripts verbose
* Fri Sep 14 2012 ms@suse.de
- check exit code from edit boot config script calls
* Fri Sep 14 2012 ms@suse.de
- fixed uboot bootloader script to meet the bash needs
* Fri Sep 14 2012 ms@suse.de
- add x-bit to uboot bootconfig scripts
* Fri Sep 14 2012 ms@suse.de
- call editbootconfig script at the end of setupBootLoaderConfiguration
  and not at the beginning of installBootLoader. That's because there
  is one step in between which could break otherwise. Also make sure
  the script is searched in the original image description path
* Fri Sep 14 2012 ms@suse.de
- arm: kernel-firmware does not exist there
* Fri Sep 14 2012 ms@suse.de
- fixed arch setup for satsolver on armv7l
* Thu Sep 13 2012 ms@suse.de
- use 512MB instead of 128MB for xen domU examples
* Thu Sep 13 2012 ms@suse.de
- fixed __uniqueInPackages() function. It's not a good idea to
  grep via a regexp for duplicate entries. That's because if
  characters which have a special meaning in a regexp are part
  of the name it leads to invalid matching results. I thought I
  could fix this by using the quotemeta call but it has turned
  out that it does not quote with respect to the special meaning
  of characters for regular expressions. What we really want
  here is a dumb string match for duplicate entries.
* Thu Sep 13 2012 ms@suse.de
- finally fixed xen boot with grub2. Problem was the missing
  gzio module which is required to read the signatured from
  the compressed (xen.gz) hypervisor
* Wed Sep 12 2012 ms@suse.de
- arm: moved uboot related code into custom scripts outside
  of the kiwi code. The arm JeOS image template served as
  example for the uboot setup on panda/efika and beagle
  boards
* Wed Sep 12 2012 ms@suse.de
- arm: remove kernel profiles from arm boot image descriptions.
  handle the kernel as bootincluded package from the system
  image description. See the example JeOS image for reference
* Wed Sep 12 2012 ms@suse.de
- added new option '--edit-bootinstall <file>' and the XML
  attribute <type ... editbootinstall="file"/> which allows to
  run a script after the bootloader was installed. This
  allows custom changes to the bootloader installation.
  follow up change for (bnc #667950)
* Tue Sep 11 2012 ms@suse.de
- The fetchFile() return value is broken: it returns status of the
  last command in the pipe. With atftp it works ok, but with curl
  it returns the status of the final dd command, which is always
  zero (bnc #779701)
* Mon Sep 10 2012 ms@suse.de
- fixed check for duplicate packages. The check fails if
  quotable characters are part of the package name e.g
  bonnie++ with bonnie is ok
* Mon Sep 10 2012 ms@suse.de
- fixed cleanup of rpm key tmp dir created for import
* Sun Sep  9 2012 ms@suse.de
- fixed KIWIXML::addPackages() function in a way that it does
  not add packages if they are already added to the list
* Fri Sep  7 2012 ms@suse.de
- v5.04.9 released
* Fri Sep  7 2012 ms@suse.de
- fixed mount point name clash when using the isofrom feature.
* Fri Sep  7 2012 ms@suse.de
- fixed cleanup code in createImageLiveCD
* Fri Sep  7 2012 ms@suse.de
- archive image data with subfolder
* Thu Sep  6 2012 ms@suse.de
- changed processing of build results:
  * build within a subdirectory created below the specified
    destination directory. The name of this subdir is build
    out of the image type and the used profile(s)
  * at the end of the build move the result files to the
    specified destination directory to keep the system
    backward compatible
  * add option --archive-image which allows to pack the
    build results into a tar archive. The name of the archive
    is build out of the image name, type and used profile(s)
    This functionality was requested by (bnc #778787)
  * fixed use of obsolete buildImageName() function and
    change to generateBuildImageName from the global space
* Thu Sep  6 2012 rjschwei@suse.com
- implement new classes for processing imageConfig data structure
  * KIWIXMLEC2ConfigData  => <ec2config>
  * KIWIXMLVMachineData   => <machine>
  * KIWIXMLOEMConfigData  => <oemconfig>
  * KIWIXMLPXEDeployData  => <pxedeploy>
  * KIWIXMLSplitData      => <split>
  * KIWIXMLSystemdiskData => <systemdisk>
  * KIWIXMLTypeData       => <type>
  * KIWIXMLPreferenceData => <preferences>
- rename direct XML accessor functions with _legacy
- integrate all new imageConfig processing classes for use
  in the main XML class
* Wed Sep  5 2012 ms@suse.de
- fixed setupPackageKeys() to work without pubring.gpg
* Wed Sep  5 2012 ms@suse.de
- fixed disk-or-partition check in KIWIGlobals::mount() method
* Tue Sep  4 2012 ms@suse.de
- DB: rebuild documentation
* Tue Sep  4 2012 ms@suse.de
- DB: update documentation, fixing information about flags attribute
* Tue Sep  4 2012 ms@suse.de
- make sure we set the plymouth default theme inside the system
  image to activate it properly. Unfortunately this is not done
  by mkinitrd even thought the configuration files are correctly
  set up
* Tue Sep  4 2012 ms@suse.de
- added warning/info message when using the --target-arch option
* Tue Sep  4 2012 ms@suse.de
- netboot: enable multicast for system image and transfer
  to a block device, respectively disable it for any other
  transfer (bnc #773649)
* Mon Sep  3 2012 ms@suse.de
- added check for duplicate LVM volume groups
* Mon Sep  3 2012 ms@suse.de
- fixed setupBootThemes to create the correct configuration paths
* Mon Sep  3 2012 ms@suse.de
- added two device checks for the list of disks reported by
  hwinfo which are used as possible install targets. First
  check is to read one byte from the device to find out if
  it's really possible to access it. Second check is to find
  the device specific serial number. Devices which are only
  mapped like lvm disks would appear multiple times but there
  is only one origin device which provides a serial string
* Mon Sep  3 2012 ms@suse.de
- added Emacs kiwi XML editing support. For details see:
  http://lizards.opensuse.org/2012/08/31/editing-kiwi-configurations-with-emacs/
  Thanks to Togan for his effort
* Mon Sep  3 2012 ms@suse.de
- don't start plymouth if no framebuffer device is present
* Mon Sep  3 2012 ms@suse.de
- fixed missing done flag for theme information
* Fri Aug 31 2012 ms@suse.de
- v5.04.8 released
* Fri Aug 31 2012 ms@suse.de
- fixed unit test due to changed revision check output
* Fri Aug 31 2012 ms@suse.de
- v5.04.7 released
* Fri Aug 31 2012 ms@suse.de
- fixed kiwirevision check, newline at eol invalidates the match
* Fri Aug 31 2012 ms@suse.de
- v5.04.6 released
* Fri Aug 31 2012 ms@suse.de
- fixed syslinux based boot partition setup. We don't have
  symlinks on fat thus we have to copy the result of mkinitrd
  to the boot/ directory on the boot partition
* Fri Aug 31 2012 ms@suse.de
- adapt suse-live-usbstick example for 12.2, switching to btrfs
  because of bad impressions with persistent writing into clicfs
* Fri Aug 31 2012 ms@suse.de
- allow overwrite of what kiwi thinks is the minimum required size
* Fri Aug 31 2012 ms@suse.de
- fixed evaluation of ramonly attribute for clicfs based images
* Fri Aug 31 2012 ms@suse.de
- fixed checkFileSystem() to correctly detect clicfs filesystems
  also use blkid to detect the filesystem in the first place.
- fixed KIWIGlobal::mount() function to correctly identify a clicfs
  image as filesystem image and not as a disk
* Fri Aug 31 2012 ms@suse.de
- fixed validation of kiwirevision attribute. The kiwi revision
  as it is defined in /usr/share/kiwi/.revision is not a number.
  Thus the XML schema should not require a number
* Fri Aug 31 2012 ms@suse.de
- fixed system theme configuration for plymouth/grub2
  * make sure kiwi writes the plymouth theme setup to
    /etc/plymouth/plymouth.conf. looks like the initrd
    creation tool of the distro uses the information
    from this file
  * make sure kiwi writes the grub2 theme setup to
    /etc/default/grub. when using grub2-mkconfig this seems
    to be required
* Thu Aug 30 2012 ms@suse.de
- removed console-setup.service helper for 12.2 JeOS. The
  final version of 12.2 allows console access after some
  time
* Thu Aug 30 2012 ms@suse.de
- use background_image for grub2 boot message box
* Thu Aug 30 2012 ms@suse.de
- allow to overwrite the architecture when computing
  package dependencies in the KIWISatSolver module. This
  allows to provide package information for other than
  the real architecture. In order to set the value the
  environment variable: KIWI_REPO_INFO_ARCH must be set
* Wed Aug 29 2012 ms@suse.de
- fixed grub2 install if in targetdevice/targetstudio mode
  when using a real disk device the bindloop variable
  was not set because no partition binding is required
* Wed Aug 29 2012 mbarringer@suse.de
- Moving repository to my github:
  http://github.com/mbarringer/imagewriter
* Tue Aug 28 2012 ms@suse.de
- added multiboot support for grub2 setup. This allows Xen
  dom0 appliances booting via grub2
* Tue Aug 28 2012 rjschwei@suse.com
- remove duplicate implementation of profile setting
  * the setSelectionProfiles() and setActiveProfileNames() methods
    implemented the same functionality. The new method
    setSelectionProfileNames() is now the singular implementation of this
    functionality.
  * relocate the new method into the block that separates code using the
    imageConfig data structure (this should avoid duplicate implementation
    in the future).
- fix up the XML unit test to handle the new split for bootsplash and
  bootloader theme settings
* Tue Aug 28 2012 ms@suse.de
- allow to overwrite the architecture when computing
  package dependencies in the KIWIXMLInfo module. This
  allows to provide package information for other than
  the real architecture. In order to set the value the
  environment variable: KIWI_REPO_INFO_ARCH must be set
* Tue Aug 28 2012 ms@suse.de
- DB: rebuild schema documentation
* Tue Aug 28 2012 ms@suse.de
- DB: rebuild documentation
* Tue Aug 28 2012 ms@suse.de
- DB: update documentation due to the boot theme changes
* Tue Aug 28 2012 ms@suse.de
- update XML descriptions to schema version 5.5
* Tue Aug 28 2012 ms@suse.de
- added XSL stylesheet to auto convert former <boot-theme>
  sections into <bootloader-theme> and <bootsplash-theme> sections.
* Tue Aug 28 2012 ms@suse.de
- split <boot-theme> setup into <bootloader-theme> and <bootsplash-theme>
  elements. This allows to have different theme values for splash and
  bootloader as it could appear with the plymouth and grub2.
  Additionally people are more flexible when providing custom
  branding data for either splash or the bootloader (bnc #777599)
* Tue Aug 28 2012 ms@suse.de
- unset *ROOT variables from config.mac if set via cmdline (bnc #777578)
* Mon Aug 27 2012 ms@suse.de
- create a unique application ID for install ISO images
* Mon Aug 27 2012 ms@suse.de
- fixed creation of install media if a target/studio device
  is used which is a disk but requires a mapping section to
  access partitions on this disk. One example is a NBD mapped
  disk which requires kpartx to run before one can access
  partitions on the disk
* Sun Aug 26 2012 ms@suse.de
- fixed restore of kernel splash in setupBootFlags()
* Sun Aug 26 2012 ms@suse.de
- fixed obsolete printout of done flag
* Sun Aug 26 2012 ms@suse.de
- add better user message about used splash system
- prevent stderr output from 'cpio -it' result
* Sat Aug 25 2012 rjschwei@suse.com
- implement setRepository method using the imageConfig data structure
  * this will eventually replace setRepository_legacy()
  * it is not certain thatthis is needed in the long run
  * this completes the Repository handling in the imageConfig data structure
- unit tests for the new implementation
* Fri Aug 24 2012 ms@suse.de
- v5.04.5 released
* Fri Aug 24 2012 ms@suse.de
- fixed unit tests to work in 32bit environment
* Fri Aug 24 2012 ms@suse.de
- fixed 32bit arch check in KIWIXML constructor. For
  32bit systems the generic arch name ix86 is used
* Fri Aug 24 2012 ms@suse.de
- v5.04.4 released
* Fri Aug 24 2012 ms@suse.de
- fixed kiwi --convert mode, no initrd is required for this call
* Fri Aug 24 2012 ms@suse.de
- fixed qcow2 format creation. Invalid options are passed and
  option -c was missing to indicate compression
* Thu Aug 23 2012 rjschwei@suse.com
- implement the ignoreRepositories method using the
  imageConfig data structure
  * this method will replace ignoreRepositories_legacy
* Thu Aug 23 2012 rjschwei@suse.com
- implement new addRepositories method
  * replacing the addRepositories_legacy implementation
- refactor the code that is used to figure out what profile data to
  modify as this code will be needed in any add* implementation
- unit tests for the new addRepositories method
* Thu Aug 23 2012 ms@suse.de
- validate templates and examples
* Thu Aug 23 2012 ms@suse.de
- update openSUSE 12.2 JeOS template. For some reason a dependency
  to kernel-debug exists when building openSUSE 12.2 images. If not
  specified explicitly this is an unwanted package thus I added it
  to the packages marked for deletion
* Wed Aug 22 2012 rjschwei@suse.com
- implement the new getRepositories method
  * will replace getRepositories_legacy()
  * returns array ref of KIWIXMLRepositoryData objects
- implement unit test for new method
- fix up code errors in __populateRepositoryInfo
  * the initial implementation committed prev did not place the
    data in the appropriate profile information.
* Wed Aug 22 2012 rjschwei@suse.com
- change code organization to aid in the transition to the new
  data structure
  * collect all _legacy code in an appropriately marked area of the
    module
  * collect all code using the new data structure in an appropriately
    marked area of the module
  * rename __checkProfiles to __checkProfiles_legacy
  * rename __populateDefaultProfiles to __populateDefaultProfiles_legacy
  * mark the imageConfig data structure dump method as private by prefixing
    __ to the name
* Wed Aug 22 2012 rjschwei@suse.com
- rename all repository related interfaces to *_legacy
  * this is in preparation for the implementation of the replacement
    methods that will access the imageConfig data structure and
    use the KIWIXMLRepositoryData object
* Wed Aug 22 2012 ms@suse.de
- pass --partok option to isohybrid call
* Wed Aug 22 2012 ms@suse.de
- adapt openSUSE 12.2 examples for plymouth and grub2 use
* Wed Aug 22 2012 ms@suse.de
- fixed openSUSE 12.2 JeOS image, added systemd unit script
  to make sure the console login is showed and responsive
* Wed Aug 22 2012 rjschwei@suse.com
- add and implement the __populateRepositoryInfo method
  this method add repository data to the imageConfig data
  structure.
* Tue Aug 21 2012 ms@suse.de
- make sure buildType is set when constructing a new KIWIXML
  object in KIWIImageCreator::prepareImage()
* Tue Aug 21 2012 rjschwei@suse.com
- implement KIWIXMLRepositoryData class
  * this class holds information specified by the <repository> element
    and it's children (<source>) in the configuration file
- implement unit tests for the new module
- add new triggers and adjust existing triggers as appropriate
* Tue Aug 21 2012 ms@suse.de
- cleanup KIWILog module, don't print state flags in log files
* Tue Aug 21 2012 ms@suse.de
- moved imageConfig data dump into a function named
  dumpInternalXMLDescription and add the call as a comment
  to the code. Unfortunately added a loginfo message as
  part of the KIWIXML constructor causes many unit tests
  to fail
* Tue Aug 21 2012 ms@suse.de
- use perl's data dumper to print the new internal
  imageConfig data structure to the log file
* Mon Aug 20 2012 ms@suse.de
- make start of plymouth more quiet and react properly if
  the cmdline value 'quiet' is specified  (bnc #775830)
* Mon Aug 20 2012 ms@suse.de
- cleanup duplicate package entries in SLE10 JeOS
* Wed Aug 15 2012 rjschwei@suse.com
- changed behavior of setActiveProfileNames
  * when called with no argument this now resets that active profiles to
    the setting in the XML file. This type of dual behavior is somewhat
    evil from an OO perspective an dit may prove better to implement a
    resetActiveProfiles() in the future, we'll see how it turns out.
- implement unit test for addDrivers method
* Tue Aug 14 2012 rjschwei@suse.com
- implement getArch/setArch methods
  * allows to have influence on the architecture specific information for
    retrieval and addition of data to the XML object
- refractor the valid profile names check into a private method
  * verification of proper profile names is needed in 2 routines now and
    will be needed in any method that allows addition of profile
    specific information to the XML
- implement new addDrivers method
  * this allows to addDriver data to the XML, this completes the tie-in
    of the KIWIXMLDriverData object into the new structure
- unit tests for get/setArch
* Mon Aug 13 2012 rjschwei@suse.com
- rename addDrivers to addDrivers_legacy
  * this is in preparation for further integration of the new data structure
- implement getActiveProfileNames and setActiveProfileNames
  * with the XML restructure the constructor args will be reduced to just
    the validated XML, thus client code of the XML must have a way to set
    what profiles are active for information retrieval.
- implement unit tests for the {g,s}etActiveProfileNames methods
* Mon Aug 13 2012 rjschwei@suse.com
- fix type for default profile in driver data population code
  * drivers were added to the "wrong" profile due to the type.
    This incorrect profile was not accessed and thus the information
    got lost
- integrate new KIWIXMLDriverData class into KIWIXML implementation
  * rename getDriversNodeList to getDriversNodeList_legacy to
    indicate that this method is deprecated
  * implement getDrivers method to return of XMLDriverData objects
    the objects are created based on information that is contained
    in the imageConfig data structure
- implement unit test for the new getDrivers method
* Mon Aug 13 2012 rjschwei@suse.com
- implement setDescriptionInfo method on XML object
  ~ allow the <description> information to be set programatically,
  this is needed for system migration when the configuration is
  created from scratch
* Mon Aug 13 2012 rjschwei@suse.com
- add a getOopsState method to the test log. This is needed
  to properly handle cases where oops and other message states
  over lap.
* Sun Aug 12 2012 rjschwei@suse.com
- implement a KIWIXMLFileData class
  * this class is intended to be an abstract base class for any xml section
    that uses the <file> element. It stores the name and arch attributes
    of the <file> element. The class provides get and set methods.
- implement a KIWIXMLDriverData class
  * this class is derived from the KIWIXMLFileData class and will be used
    to store the information provided in the <drivers> section.
- implement unit test for KIWIXMLFileData
- implement unit test for KIWIXMLDriverData
- fix-up the pre-commit hook to register the code and set the Perl-critic
  severity levels, all new code (spare the .t files) is level 2 clean
- add the trigger files and adjust existing trigger files to run the test
  on commit
* Sun Aug 12 2012 rjschwei@suse.com
- unit tests for new uniqueness check for archives, packages, and patterns
* Sun Aug 12 2012 rjschwei@suse.com
- add uniqueness checks for packages, archives, and patterns
* Thu Aug  9 2012 ms@suse.de
- use device from device map only if it exists
* Thu Aug  9 2012 ms@suse.de
- removed obsolete internal data $this->{bootpart}. the boot
  partition is always the first partition. Since that change
  this value is no longer useful
* Fri Aug  3 2012 ms@suse.de
- fixed hybrid persistent mode when btrfs seed device is used.
  Unfortunately we are then running into the loop device bug
  mentioned in (bnc #764042). I hope this gets fixed soon in the
  loop and/or btrfs code
* Fri Aug  3 2012 ms@suse.de
- v5.04.3 released
* Fri Aug  3 2012 ms@suse.de
- DB: rebuild documentation
* Fri Aug  3 2012 ms@suse.de
- update dropbear ssh documentation: Since debug_ssh.pub is used as
  the SSH file authorized_keys it is possible to specify serveral
  public ssh keys.
* Fri Aug  3 2012 ms@suse.de
- v5.04.2 released
* Fri Aug  3 2012 ms@suse.de
- DB: rebuild documentation
* Fri Aug  3 2012 ms@suse.de
- DB: update docs about dropbear based ssh access into the boot image
* Fri Aug  3 2012 ms@suse.de
- update rhel-* oemboot code to the current suse-* oemboot code
* Fri Aug  3 2012 ms@suse.de
- changed support for dropbear ssh. we don't provide our own
  keypair but allow to integrate a user public key from the
  pxe server. The key must be stored in <server-root>/KIWI
  and has to be named: debug_ssh.pub. for the default tftp
  download method this would result in the following path
  on the pxe server: /srv/tftpboot/KIWI/debug_ssh.pub
* Thu Aug  2 2012 ms@suse.de
- update size for btrfs filesystem when building JeOS 12.2 iso
* Thu Aug  2 2012 ms@suse.de
- remove cached repos for a new build. The repo setup for the
  package managers smart and yum are cleaned up at the end of
  each build by resetInstallationSource(). For zypper we makes
  an exception here and keep the repo setup for performance
  reasons. Thus at the beginning a a new prepare run we should
  clean up the repo files to rebuild the repos as they are
  specified in the kiwi XML description
* Thu Aug  2 2012 ms@suse.de
- moved startDropBear() prior to the ELOG_BOOTSHELL check
* Thu Aug  2 2012 ms@suse.de
- fixed rpmlint warnings about hidden and empty files
* Thu Aug  2 2012 ms@suse.de
- make sure dropbear keys are installed with correct permissions
* Tue Jul 31 2012 ms@suse.de
- netboot: added function pxePartitionSetupCheck() which is
  used to validate the PART information whether the requested
  partition sizes can be reached according to the size of the
  disk. This implements the request in (bnc #771592)
* Tue Jul 31 2012 ms@suse.de
- changed the suse-12.2 JeOS template provided by kiwi to
  switch from clicfs to the new btrfs seed way (bnc #764042)
* Tue Jul 31 2012 ms@suse.de
- added support for btrfs seed live ISO images. btrfs supports a
  nice COW machinery which allows us to point all write operations
  to a seed device. A similar technique is used with the clicfs
  filesystem but this one works in userspace via fuse. I have
  changed the suse-12.2 JeOS template provided by kiwi to use the
  new btrfs seed way. Of course the clicfs way also still exists.
  In order to use btrfs seed devices your iso type should look
  like the following example:
  <type image="iso" ... flags="seed" fsmountoptions="compress=lzo">
  <size unit="M">400</size>
  </type>
  I got best results with lzo compression. One downside; up to now
  it's not possible to forecast/calculate how much size the btrfs
  image really will need. Thus the calculation kiwi does is in most
  cases too big for small images and for big ones sometimes too
  little. At the moment it's a try and error game to find
  out the minimum required size.
  The implementation add a ramdisk device as seed device to the
  btrfs mount and remount it read-write. This has worked fine
  and stable with the openSUSE 12.2 kernel (bnc #764042)
* Tue Jul 31 2012 ms@suse.de
- fixed getSize and getBlocks functions to calculate with
  integer values. In addition to that the value of getBlocks
  was formerly passed to a dd call but this has changed to a
  qemu-img call. the seek value in the prior dd call was
  offset -1 which is wrong when using qemu-img
* Tue Jul 31 2012 ms@suse.de
- added support for filesystem mount options during image
  build and later to become stored in the fstab file. The
  type attribute <type ... fsmountoptions="..."/> has been
  added, this is related to (bnc #764042)
* Mon Jul 30 2012 ms@suse.de
- don't create an instance of KIWILog other than the
  global one in: KIWILocator,KIWIRuntimeChecker and
  KIWIXMLValidator
* Mon Jul 30 2012 ms@suse.de
- don't create an instance of KIWILog other than the
  global one in KIWIXMLDescriptionData
* Mon Jul 30 2012 ms@suse.de
- v5.04.01 released
* Sat Jul 28 2012 rjschwei@suse.com
- implement the getDescriptionInfo method in the XML object.
  The method uses the new KIWIXMLDescriptionData object, which
  gets created based on the data in the imageConfig datastructure
- implement unit test for the getDescriptionInfo method
* Fri Jul 27 2012 ms@suse.de
- fixed split setup when no persistent data is configured.
  In this case there is no read-write portion which caused
  an error on creation of the split disk
* Thu Jul 26 2012 ms@suse.de
- read reference mbrid file from inside the initrd and not from
  the attached disk devices. The matching of the ID must happen
  by a reference value from the loaded initrd and the data read
  from the MBR of all attached disks
- make sure a new mbrid is written for disk based installation
  images created when installstick="true" is set.
- identify the disk installation device via the same method used
  to identify the bios boot device: searchBIOSBootDevice.
  This allows to put disk install media not only on USB sticks
  but also on e.g SD cards or other disk devices
- fixed grub2 setup for graphics boot of disk based
  installation images
- set kernel log level to 6 by default
- make sure mbrid exists in initrd for disk images.
  This is done by the new setupBootFlags function
* Thu Jul 26 2012 ms@suse.de
- perform a qualified import of KIWIQX in kiwi.pl
* Wed Jul 25 2012 ms@suse.de
- fixed creation of install sticks without system image
* Mon Jul 23 2012 ms@suse.de
- store the mbrid file in /boot and not in /boot/grub. The location
  is misleading if another than the grub bootmanager is used
* Fri Jul 20 2012 ms@suse.de
- add initial new-root directories according to the
  used package manager (bnc #743844)
* Thu Jul 19 2012 rjschwei@suse.com
- add <description> and <drivers> data to the new imageConfig structure
- renamed following functions as legacy code:
  * getProfiles => getProfiles_legacy
  * __populateTypeInfo => __populateTypeInfo_legacy
  * __populateProfiles => __populateProfiles_legacy
* Wed Jul 18 2012 rjschwei@suse.com
- implement unit test for new XMLDescriptionData object
- register new code in the commit-hook
- add new triggers for the new test code and the new object
- add new unit test to existing triggers
* Wed Jul 18 2012 rjschwei@suse.com
- add new object KIWIXMLDescriptionData which provides
  get/set methods for the <description> element
* Wed Jul 18 2012 rjschwei@suse.com
- add an oops method to the test log
  * this implements the oops interface of the KIWILog object to
    allow unit tests to handle this condition
* Wed Jul 18 2012 ms@suse.de
- fixed grub2 chainloader setup
* Wed Jul 18 2012 ms@suse.de
- fixed mkisofs application ID setup when calling kiwi --installcd manually
* Wed Jul 18 2012 rjschwei@suse.com
- New consistency check for package specification
  * At present the user can specify packages to be installed for
    a given image type even if this image type is not defined.
    While the packages get ignored and no harm is done, the
    superfluous specification is confusing and the XML definition
    is for all intent and purposes inconsistent.
- Unit tests for new consistency check
* Wed Jul 18 2012 rjschwei@suse.com
- fix validation test configuration files to meet new stricter
  consistency requirements
* Wed Jul 18 2012 ms@suse.de
- added support for EFI boot with grub2 for install ISO media
  live iso media is still not EFI capable. In order to use
  EFI boot you have to bootinclude the grub2-efi package:
  <packages type="image">
  <package name="grub2-efi" bootinclude="true"/>
  ...
  <packages/>
  kiwi will check if there are efi modules inside the initrd and
  will then setup either a multiboot (iso) or plain gpt based
  image (bnc #771327)
* Wed Jul 18 2012 ms@suse.de
- show ssh login message only if an ip address was assigned
* Wed Jul 18 2012 ms@suse.de
- netboot: fixed use of multicast for compressed images.
  With commit 7a7389f2e3f2b3d92b38c08455b0c6da15569269
  support for multicast based transfer of compressed
  images was added. Thus the checks which disable it
  are obsolete now (bnc #771898)
* Wed Jul 18 2012 ms@suse.de
- added support for EFI boot with grub2 for the disk based
  image types oem and vmx (bnc #771327)
* Tue Jul 17 2012 ms@suse.de
- fixed check for disk in main::mount() function. searching for
  the string 'boot sector' also applies to the file output from
  a boot partition. The patch will call blkid on the given file
  or device and assumes a disk if no block id information exists
* Mon Jul 16 2012 ms@suse.de
- DB: rebuild documentation
* Mon Jul 16 2012 ms@suse.de
- DB: update documentation, add some information about the
  clic_udf feature as well as the support for ssh into the
  boot image. Also removed some obsolete data about aufs
* Mon Jul 16 2012 ms@suse.de
- added support for ssh access into the boot image (initrd). Of
  course this requires an active network connection which is by
  design possible in the netboot and oemboot (in PXE boot mode)
  boot images. So the following is not supported for the isoboot
  and vmxboot boot images because they don't setup a network.
  The feature is based on the dropbear ssh server because it's
  so small to fit into an initrd. In order to have dropbear in
  the boot image you have to add the following to the system
  image configuration:
  <packages type="image">
  <package name="dropbear" bootinclude="true"/>
  </packages>
  and make sure one of your repos provides it. It's required to
  be in debug mode to be able to access the initrd. Thus you
  have to boot with 'kiwidebug=1' enabled. In order to access
  the initrd passwordless via ssh kiwi provides a key pair
  whereas the pubkey is stored in the authorized_keys file
  inside the oem- and netboot images for all supported OS
  versions:
  ssh -i /usr/share/kiwi/keys/id_dropbear root@<ip>
  For openSUSE >= 12.2 rsync is available in the netboot and
  oemboot boot images. For older versions it might be required
  to add tool packages bootincluded to be able to extract
  data from the boot image via ssh easily. In order to copy
  e.g the boot log file the following command can be used
  if rsync exists in the boot image:
  RSYNC_RSH='ssh -i /usr/share/kiwi/keys/id_dropbear -l root'
  rsync -avz <ip>:/var/log/boot.kiwi .
* Mon Jul 16 2012 ms@suse.de
- fixed copy of overlay files for boot images (initrd). make
  sure hidden files like e.g root/.ssh are handled correctly
* Mon Jul 16 2012 ms@suse.de
- avoid double slashes (//) in zypper repo files
* Sat Jul 14 2012 ms@suse.de
- follow up fix for the change of the zypper repo handling. The
  repo meta data will stay on the host again but is going to
  be re-used to prevent unneeded reloading of repo metadata
* Fri Jul 13 2012 ms@suse.de
- fixed spec file to write openSUSE instead of OpenSuSE (bnc #770825)
* Fri Jul 13 2012 ms@suse.de
- changed the way how zypper repos are used. move the repo data
  including cache data into the image root directory instead of
  storing this information in /var/cache/kiwi/zypper on the build
  host. On the build host we only store a shared package cache
  in /var/cache/kiwi/packages. This allows to keep the repo meta
  data per image and thus it can be re-used on operations like
  kiwi --upgrade which speed up the build as this is called as
  part of the the kiwi --create step too
* Fri Jul 13 2012 adrian@suse.de
- map openSUSE 12.3 to 12.2 configs for now
- reformated spec file by current spec_file_formater
* Fri Jul 13 2012 ms@suse.de
- added kernel boot option 'disableProgressInfo=1' which allows
  to deactivate the progress information when the image download
  or install starts (bnc #771104)
* Thu Jul 12 2012 ms@suse.de
- added support for live systems larger than 4G by using the
  udf filesystem. In order to active this make sure you have
  set flags="clic_udf" (bnc #770703)
* Thu Jul 12 2012 ms@suse.de
- fixed use of grub2, with version 2.x there is no grub2-setup
  anymore but a grub2-bios-setup. This change was introduced
  with openSUSE 12.2 RC1
* Thu Jul 12 2012 ms@suse.de
- v5.03.34 released
* Thu Jul 12 2012 ms@suse.de
- follow up spec file fix, list grub2-branding-openSUSE only
  for suse version > 12.1 in the media requires
* Thu Jul 12 2012 ms@suse.de
- v5.03.33 released
* Thu Jul 12 2012 ms@suse.de
- fixed spec file to write openSUSE instead of openSuSE (bnc #770825)
* Thu Jul 12 2012 ms@suse.de
- added grub2-branding-openSUSE to the media requires
* Tue Jul 10 2012 ms@suse.de
- v5.03.32 released
* Mon Jul  9 2012 adrian@suse.de
- fix dependencies on SLES 11 (sed does not support -E, use perl instead)
* Fri Jul  6 2012 ms@suse.de
- v5.03.31 released
* Fri Jul  6 2012 ms@suse.de
- fixed type in spec file, missing %%endif
* Fri Jul  6 2012 ms@suse.de
- v5.03.30 released
* Fri Jul  6 2012 ms@suse.de
- netboot: fixed openSUSE 12.2 boot image description. bootstrap
  was only applied to in diskless profile mode. This leed to missing
  tools like gettext and dialog for all other profiles even the
  default profile
* Fri Jul  6 2012 ms@suse.de
- fixed spec file: netboot and isoboot needs virt-utils
  additionally does isoboot need e2fsprogs
* Wed Jul  4 2012 ms@suse.de
- v5.03.29 released
* Wed Jul  4 2012 ms@suse.de
- don't remove rpm and fonts required in the pxe examples
* Wed Jul  4 2012 ms@suse.de
- added missing fonts and X11 input packages to pxe 12.1 example
* Tue Jul  3 2012 ms@suse.de
- libproxy reads the data from /etc/sysconfig/proxy. Thus it's
  required to hold a temporary copy of that file inside the chroot
  to make use of proxy settings while operating in the chroot
* Mon Jul  2 2012 ms@suse.de
- v5.03.28 released
* Mon Jul  2 2012 ms@suse.de
- make sure possible proxy setting is transfered to the kiwi chroot
* Mon Jul  2 2012 rjschwei@suse.com
- add profile handling in new data structure to handle XML data
  * This is the beginning of the XML object restructuring effort as
    dicussed on the list. This initial commit in the series adds the
    members for the new data structure and ties parts of the profile
    handling code to the new implementation.
* Mon Jul  2 2012 ms@suse.de
- don't call resetBootBind using chroot to workaround (bnc #769634)
* Sat Jun 30 2012 rjschwei@suse.com
- make kiwi_default a reserved profile name
  * for the new data structure for XML processing we need a profile
    name to store unqualified data, this name was chosen to be
    kiwi_default. Therefore this is a reserved name and users may not
    use it as a profile name.
* Fri Jun 29 2012 ms@suse.de
- v5.03.27 released
* Fri Jun 29 2012 ms@suse.de
- fixed hybrid persistent writing with kernel 3.x (bnc #769086)
* Thu Jun 28 2012 ms@suse.de
- netboot: dhcpcd works with timeout 20s, kiwi used 40s, so one half
  of the time it waited with no reason. This patch runs 'dhcpcd -T'
  again after 22s, so the time is used effectively. It also helps in
  situatios when the link needs more time to start, e.g with
  wpa_supplicant and the first dhcp packets are lost.
* Thu Jun 28 2012 rjschwei@suse.com
- fix the getPXEDeployConfiguration unit test on ppc and ppc64
* Wed Jun 27 2012 ms@suse.de
- zypper in 12.2 has been fixed now, so we can change back the
  JeOS image template to the type="image" installation
* Wed Jun 27 2012 ms@suse.de
- v5.03.26 released
* Wed Jun 27 2012 ms@suse.de
- added patterns for removal of unused files/dirs which
  appears along with systemd,grub2,plymouth and are not
  required inside the initrd
* Wed Jun 27 2012 ms@suse.de
- fixed evaluation of glob patterns in kiwi_strip_delete
* Tue Jun 26 2012 ms@suse.de
- remove references to splashy from initrd
* Tue Jun 26 2012 ms@suse.de
- the post install script from grub2-branding-openSUSE creates
  a background.png file in /boot. We have to preserve all data
  created in /boot because the extractKernel() function moves
  out all the data here from the initrd
* Tue Jun 26 2012 ms@suse.de
- hide plymouth splash when throwing an exception
* Tue Jun 26 2012 ms@suse.de
- fixed evaluation of bootincluded packages in type
  specific packages sections
* Tue Jun 26 2012 ms@suse.de
- update openSUSE 12.2 JeOS template. With 12.2 the switch to
  grub2 was made but the grub2-branding-openSUSE package only
  provides grub2 theming information. Thus for building non
  grub2 based images like isolinux based live systems the
  former gfxboot-branding-openSUSE data has to be present.
  Because of this the openSUSE 12.2 JeOS template includes
  now image type specific packages sections to select the
  correct branding package
* Tue Jun 26 2012 ms@suse.de
- make grub2 theming data available in the initrd
* Tue Jun 26 2012 ms@suse.de
- fixed string validation in info message in KIWICollect so
  that it actually shows the content of $metapack
* Tue Jun 26 2012 ms@suse.de
- remove import of graphics boot 'message' file when using grub2
  In order to support custom branding in kiwi for grub it worked
  the way that one provides the theme data and together with
  gfxboot-devel a special formatted 'message' file was created and
  stored inside the initrd. The setupBootLoaderStages() function
  then imported that file to the system image. In grub2 the theme
  data is just fonts and png's and there is no creation of a
  special graphics format required.
* Tue Jun 26 2012 ms@suse.de
- hide plymouth splash when showing a dialog
* Tue Jun 26 2012 ms@suse.de
- switched to grub2-branding-openSUSE for openSUSE 12.2 JeOS template
* Tue Jun 26 2012 ms@suse.de
- grub2 can handle real spaces in menu items, yeah :)
* Tue Jun 26 2012 ms@suse.de
- added grub2 theme support for the openSUSE theme layout
* Tue Jun 26 2012 ms@suse.de
- better info message when --targetstudio option is used
* Tue Jun 26 2012 ms@suse.de
- provide ROOTFS_BLKDEV before calling init/systemd
- don't export variables used by the boot scripts in the
  cleanImage function. This function is called in an extra
  shell process thus exporting back is not possible
* Tue Jun 26 2012 ms@suse.de
- fixed resizeFilesystem to prefer btrfs over btrfsctl
* Tue Jun 26 2012 ms@suse.de
- added variable kiwi_cpio_name which allows to access the name
  of the initrd image from within the initrd. This is currently
  used to distinguish the initrd by the type of the distro
* Mon Jun 25 2012 ms@suse.de
- netboot: improved testing for networks by using -T option
* Mon Jun 25 2012 ms@suse.de
- fixed createOriginSnapshot to prefer btrfs over btrfsctl
* Mon Jun 25 2012 ms@suse.de
- preserve missing btrfs tools
* Mon Jun 25 2012 rjschwei@suse.com
- indicate check failure through return value (undef)
  * we should have it correct now. Previously a 1 was returned,
    indicating success. This change returns no value on failure
    to indicate the failed state of the check.
* Sat Jun 23 2012 ms@suse.de
- v5.03.25 released
* Sat Jun 23 2012 ms@suse.de
- fixed __checkVMscsiCapable() it's a valid setup if no
  machine configuration is specified in the kiwi XML
* Fri Jun 22 2012 toganm@opensuse.org
- fix the suse-live-usbstick config according to the version
* Fri Jun 22 2012 ms@suse.de
- v5.03.24 released
* Fri Jun 22 2012 ms@suse.de
- make sure getExecPath() also works when invoked as non root
  user. It's required that PATH contains /sbin to locate
  binaries used by kiwi with the 'which' tool. This problem
  appeared when calling the unit tests as non root user like
  the buildservice does when building packages, thus this fixes
  the build
* Fri Jun 22 2012 ms@suse.de
- v5.03.23 released
* Fri Jun 22 2012 ms@suse.de
- fixed boot logging, make sure the log continues after
  switching to the real root filesystem
* Fri Jun 22 2012 ms@suse.de
- added runtime check for get_kernel_version binary. This is
  a suse only extension so when running on other build hosts
  it should be checked if it's there.
* Fri Jun 22 2012 ms@suse.de
- added uninstall target to Makefile
* Fri Jun 22 2012 ms@suse.de
- make udevStart() aware of alternative location for udevd binary
* Fri Jun 22 2012 ms@suse.de
- make sure kmod stays in the initrd, with respect to other
  distros which already moved from module-init-tools to kmod
* Fri Jun 22 2012 ms@suse.de
- fixed udevSystemStart / udevSystemStop to check which system
  service manager can be used to run the service
* Fri Jun 22 2012 ms@suse.de
- removed kernel sysconfig template check, that's a suse only
  check and even we change our own names all the time
* Thu Jun 21 2012 ms@suse.de
- v5.03.22 released
* Thu Jun 21 2012 rneuhauser@suse.cz
- kiwi.pl: simpler date(1) use.
  calling 'date -I' is insensitive to locale which means:
  * LANG=POSIX is not needed, thus
  * explicit bash invocation is not needed (it was there
    because the syntax for setting env. vars varies among
    shells
* Thu Jun 21 2012 ms@suse.de
- fixed date call in usage() function to work with native qx
* Thu Jun 21 2012 rjschwei@suse.com
- clean up to perl critic level 4
- disable the brief file open/close check
  * this check is unreliable when using multiple open/close
    constructs in one routine.
* Thu Jun 21 2012 rjschwei@suse.com
- remove duplicate implementation of method to get a list of packages
  marked for boot inclusion. The methods getListBootIncludes() and
  getBootIncludes() used to implement the same functionality. This
  update removes the getListBootIncludes() method.
* Thu Jun 21 2012 rjschwei@suse.com
- add profile handling verification to the package and type unit tests
* Thu Jun 21 2012 rjschwei@suse.com
- add additonal condition to avoid warning
  * At present it is possible to trigger a "uninitialized value" warning
    when calling the addPackages() method, if not all packages that are
    to be added are boot included. This change fixes this issue.
* Wed Jun 20 2012 ms@suse.de
- fixed spec file, require grub2 for >= openSUSE 12.2
* Wed Jun 20 2012 ms@suse.de
- update migration table
* Wed Jun 20 2012 rjschwei@suse.com
- clean to critic level 3
* Wed Jun 20 2012 rjschwei@suse.com
- clean to critic level 4
* Wed Jun 20 2012 rjschwei@suse.com
- do not attempt to normalize a path that has not been defined to begin with
* Wed Jun 20 2012 rjschwei@suse.com
- clean to perlcritic level 4
  * critic exception around the unify function
  * style clean up to more closely resemble the rest of kiwi code
* Wed Jun 20 2012 ms@suse.de
- added get_kernel_version source into kiwi git. We might want
  to install this tool on distros which doesn't provide it
* Wed Jun 20 2012 rjschwei@suse.com
- modify the default critic policy for brief open
  * by default a close() is expected within 9 lines of an open call.
    Accounting for potential kiwi logging information and other coding
    constructs we use this is ofetn insufficient. Therefore a line limit of
    15 is a bit more reasonable for the kiwi code base
* Wed Jun 20 2012 rjschwei@suse.com
- add XML unit tests for type handling
* Wed Jun 20 2012 ms@suse.de
- use strip section in RHEL JeOS template to remove some
  unneded data not required in the initrd
* Tue Jun 19 2012 ms@suse.de
- v5.03.21 released
* Tue Jun 19 2012 ms@suse.de
- remove bootsplash from the delete section in the openSUSE 12.2
  boot image descriptions, bootsplash is no longer installed thus
  it doesn't make sense to list it in the delete sections
* Tue Jun 19 2012 ms@suse.de
- make sure JeOS for 12.2 installs glibc-locale
* Tue Jun 19 2012 ms@suse.de
- small cleanup for info message
* Tue Jun 19 2012 ms@suse.de
- update JeOS 12.2 image description, install in bootstrap because
  zypper in 12.2 is so flaky and bugy throwing segfaults all the
  time and nobody cares about it :(
* Tue Jun 19 2012 ms@suse.de
- added grub2 to openSUSE 12.2 boot image descriptions
* Tue Jun 19 2012 ms@suse.de
- use bootstrap only installation for openSUSE 12.2 boot images
* Tue Jun 19 2012 ms@suse.de
- s390: make sure we wait for udev to finish after fdasd is done
* Tue Jun 19 2012 ms@suse.de
- use grub2 as bootloader for openSUSE 12.2 JeOS except for xenFlavour
* Tue Jun 19 2012 ms@suse.de
- fixed grub2-mkimage call, target format of core image must be set
* Tue Jun 19 2012 ms@suse.de
- add plymouth to JeOS image description
* Tue Jun 19 2012 ms@suse.de
- cleanup list of image packages selected in the openSUSE 12.2
  boot image descriptions. The ones removed here were already
  installed by the selection/requirements of the bootstrap
  packages section
* Tue Jun 19 2012 ms@suse.de
- switched from bootsplash to plymouth splash screen in the
  openSUSE 12.2 JeOS template
* Tue Jun 19 2012 ms@suse.de
- added required plymouth packages to boot descriptions
  for openSUSE 12.2
* Tue Jun 19 2012 ms@suse.de
- added support for plymouth splash system
* Mon Jun 18 2012 ms@suse.de
- netboot: added more sophisticated partition table check. The
  partition table is analyzed to check if it's possible to
  run the update check and also to verify partition order, types
  and sizes with some tolerance (so for example the change to 4k
  sectors would not cause repartitioning). Additionally in a
  RAID setup the checks would check both disks.
* Mon Jun 18 2012 ms@suse.de
- remove references to splashy
* Fri Jun 15 2012 ms@suse.de
- v5.03.20 released
* Fri Jun 15 2012 ms@suse.de
- fixed unit test due to changes in the logging
* Fri Jun 15 2012 ms@suse.de
- v5.03.19 released
* Fri Jun 15 2012 rjschwei@suse.com
- additional unit tests for package handling in the XML object
* Fri Jun 15 2012 ms@suse.de
- added lxc as a recommended package to the spec file
* Fri Jun 15 2012 rjschwei@suse.com
- rename the getTypeList method to getTypeSpecificPackageList
  * the method returns a list of packages for the given image build
    type. This was not obvious from the previous method name.
* Fri Jun 15 2012 ms@suse.de
- call images.sh and config.sh scripts in a contained environment
  using LXC. The function callContained() will use lxc if it is
  installed on the build host machine. If it is not there or
  lxc-execute cannot be called the function switches to the legacy
  chroot method. Using a container to call custom scripts provides
  more protection against the nasty things one can do in a script
  with root permission
* Thu Jun 14 2012 ms@suse.de
- don't umount dev and sys filesystems in umountSystemFileSystems
  this is done by kiwi in the cleanup phase
* Thu Jun 14 2012 ms@suse.de
- fixed logging, use only one global log object which is used
  by all objects to make sure all messages end up in the same
  log file
* Thu Jun 14 2012 rjschwei@suse.com
- more unit tests for XML
* Thu Jun 14 2012 ms@suse.de
- v5.03.18 released
* Thu Jun 14 2012 ms@suse.de
- v5.03.17 released
* Thu Jun 14 2012 ms@suse.de
- s390: sleep for a while after recreating the vtoc table
* Thu Jun 14 2012 rjschwei@suse.com
- clean KIWICommandLine.pm and KIWIQX.pm to perlcritic level 4
  * all other file changes to properly import the symbols from KIWIQX
* Thu Jun 14 2012 rjschwei@suse.com
- exclude additional unit tests in OBS as they need network access
* Wed Jun 13 2012 ms@suse.de
- reread partition table after recreation of the VTOC table
* Wed Jun 13 2012 ms@suse.de
- s390: initialize loader variable with zipl by default
* Wed Jun 13 2012 ms@suse.de
- s390 netboot: recreated the vtoc table with option 'r'
  instead of 'u' which includes the deletion all partitions
* Wed Jun 13 2012 ms@suse.de
- added function umountSystemFileSystems() which is used
  to umount system filesystems like proc within the given
  root tree. This is called after a custom script call to
  cleanup the environment
* Wed Jun 13 2012 ms@suse.de
- s390: fixed normalizeRepartInput to work with fdasd
* Wed Jun 13 2012 ms@suse.de
- provide a pointer to the xml to createImageFormat() which
  allows to only create the machine configuration without
  direct access to the image file for reading the xml data
* Wed Jun 13 2012 rjschwei@suse.com
- clean the unit test implementations to perlcritic level 4
* Wed Jun 13 2012 rjschwei@suse.com
- switch back to perl-Test-Unit
  * the package has been fixed and is back in factory/oS 12.2
* Wed Jun 13 2012 rjschwei@suse.com
- set the db45-utils package as recommend for openSUSE 12.1 and later
  * at present a user running into a rpm db incompatibility issue may get
    an error message that the db45_load tool is not available. This leaves
    the user with no idea where the tool may be found. Unfortunately the
    command-not-found utility does not turn up the command either. Setting
    the package as recommends increases the chance that it will be installed
    when KIWI packages get installed.
* Tue Jun 12 2012 ms@suse.de
- overlooked one format conversion call and make them skip
  if in --targetstudio mode
* Tue Jun 12 2012 ms@suse.de
- fixed building of md5 sum and compressed image when
  in --targetstudio mode. In this mode we don't dump
  an image from the generated target device, thus the
  building of the md5 sum and the compressed version of
  the image must access the device
* Tue Jun 12 2012 adrian@suse.de
- require u-boot-tools for oem images on arm
* Tue Jun 12 2012 ms@suse.de
- instead of skipping the entire format conversion when in
--targetstudio mode we only skip the creation of the format
  but not the meta data which belongs to it
* Tue Jun 12 2012 ms@suse.de
- skip format conversion when in --targetstudio mode
* Tue Jun 12 2012 rjschwei@suse.com
- remove duplicate implementation of buildImageName method
  * the buildImageName was implemented in the XML and the Image
    object. This change removes the duplicate implementation and
    moves the method with the generateBuildImageName into the
    Global object. It is expected that a better place will be
    found eventually.
* Tue Jun 12 2012 ms@suse.de
- don't use value of --targetstudio when building iso images
* Tue Jun 12 2012 ms@suse.de
- fixed --targetdevice mode to work with NBD/AoE devices as well.
  if a network block device receives a partition table there is
  no automatic creation creation of devices per partition. Thus
  it's required to call kpartx to bind those devices prior to
  using it
* Tue Jun 12 2012 rjschwei@suse.com
- additional unit tests for package handling
- skip tests that require network access
- fix up tests to verify network resolve for local test runs
* Tue Jun 12 2012 rjschwei@suse.com
- add Environment variable to allow tests that require network access to
  be skipped in OBS
* Tue Jun 12 2012 rjschwei@suse.com
- make resolveLink and resolveArchitecture "private"
  * these methods should not be called from outside of the XML object,
    and most likely this should not be here to begin with
* Mon Jun 11 2012 ms@suse.de
- added option --targetstudio which is used to specify a program
  which creates the target device node to create the image on.
  In contrast to the targetdevice option there will be no image
  file dumped from the specified device. This option is mainly
  used in SuSE Studio
* Mon Jun 11 2012 ms@suse.de
- don't use dd when reading data from a disk block device
  use qemu-img convert instead which takes care for sparse
  information
* Mon Jun 11 2012 ms@suse.de
- setupEncoding ist not called if a targetdevice is specified
  instead of the standard loop device operations. Thus luks
  extension together with --targetdevice did not work. This
  patch fixes it
* Mon Jun 11 2012 ms@suse.de
- call fdasd relatively and not with absolute path
* Mon Jun 11 2012 ms@suse.de
- remove logging of hijacked studio commands
* Mon Jun 11 2012 ms@suse.de
- allow createImageXFS to work with a target device
* Mon Jun 11 2012 rjschwei@suse.com
- unit tests for XML object verifying package, pattern, and archive handling
* Fri Jun  8 2012 ms@suse.de
- v5.03.16 released
* Fri Jun  8 2012 ms@suse.de
- removed the ZYPP_ARIA2C=0 'hack' which is there only because
  of a bug in aria2c we'd better fix aria2c instead of maintaining
  a workaround for that inside kiwi.
* Fri Jun  8 2012 ms@suse.de
- make sure timezone package is installed as part of the bootstrap
  installations. zypper in openSUSE 12.2 crashes if it can't
  find /etc/localtime. A bug for this problem has been opened.
  As it seems zypper requires a timezone we should make sure
  to install one from within bootstrap
* Fri Jun  8 2012 ms@suse.de
- v5.03.15 released
* Fri Jun  8 2012 ms@suse.de
- Revert "- the env setting ZYPP_ARIA2C=0 caused a segmentation fault"
  problem is that this change caused other unexpected behavior in
  zypper :( I will investigate more here
  * This reverts commit 31e0d0cadfdc9f678e9675754e83674054d29d83
* Fri Jun  8 2012 ms@suse.de
- just found out that also obs:// URL's doesn't work for
  plain package building inside the buildservice. So I had
  to change the unit tests again
* Fri Jun  8 2012 ms@suse.de
- the env setting ZYPP_ARIA2C=0 caused a segmentation fault
  for zypper in openSUSE 12.2. I think if there is a bug in
  aria2c we'd better fix aria2c instead of work around that
  inside kiwi. Therefore I removed this 'hack'
* Fri Jun  8 2012 ms@suse.de
- don't use remote URL's other than obs:// in the unit tests
  the buildservice refused to resolve them so the unit tests
  works locally but not during build, thus the package build
  fails
* Fri Jun  8 2012 ms@suse.de
- v5.03.14 released
* Thu Jun  7 2012 rjschwei@suse.com
- unit test for prefer-license attribute setting unique requirement
* Thu Jun  7 2012 dmajda@suse.cz
- Fixed deleting of /usr/lib/gconv content in baseStripLocales
  The "find" command in baseStripLocales finds not only files
  in /usr/lib/gconv, but also the directory itself which cannot
  be removed by the call of 'rm' in that case
* Thu Jun  7 2012 rjschwei@suse.com
- check that the prefer-license attribute is set to true only once
  * if the attribute is set to true multiple times it results in an
    ambiguity that cannot be resolved. As the outcome of the image build
    is indeterminate in this case we need to error out of the process.
* Wed Jun  6 2012 ms@suse.de
- cleanup kernel profiles: For openSUSE -base is a subset of !-base
* Wed Jun  6 2012 ms@suse.de
- netboot: allow multicast TFTP for compressed images (fate #313083)
  * the predownload hook detects that it is possible to use service
    partition for intermediate files and exports the temp dir path
    in $FETCH_FILE_TEMP_DIR
  * the fetchfile() method uses the temp directory and exports the
    intermediate file path in $FETCH_FILE_TEMP_FILE if it was created
  * the postdownload hook deletes $FETCH_FILE_TEMP_FILE. Later we can
    extend it to manage a cache of several image files.
* Wed Jun  6 2012 ms@suse.de
- netboot: added robust detection of the active network interface
  * call dhcpcd on all available network interfaces and select
    either BOOTIF from pxe or one of the interfaces which got
    a dhcp reply (fate #313338)
* Wed Jun  6 2012 ms@suse.de
- DB: rebuild schema documentation
* Wed Jun  6 2012 ms@suse.de
- adapt schema version from 5.3 to 5.4 for unit test data
* Wed Jun  6 2012 rjschwei@suse.com
- unit test for getRepoNodeList
* Wed Jun  6 2012 rjschwei@suse.com
- unit tests related to driver handling
* Wed Jun  6 2012 ms@suse.de
- apply stylesheet conversion from schema 5.3 to 5.4
* Wed Jun  6 2012 ms@suse.de
- added xsl stylesheet which removes the type attribute
  from the <drivers> sections and also increases the
  schema version from 5.3 to 5.4
* Wed Jun  6 2012 rjschwei@suse.com
- rename addRepository to addRepositories
  * the method may be used to add multiple repositories, this should
    be reflected in the method name.
* Wed Jun  6 2012 ms@suse.de
- DB: rebuild documentation
* Wed Jun  6 2012 ms@suse.de
- DB: update documentation due to removal of the drivers type attribute
* Wed Jun  6 2012 ms@suse.de
- remove type attribute from drivers section entirely
* Tue Jun  5 2012 ms@suse.de
- DB: rebuild schema documentation
* Tue Jun  5 2012 ms@suse.de
- DB: rebuild documentation
* Tue Jun  5 2012 ms@suse.de
- update documentation due to change in the type
  attribute in the drivers sections
* Tue Jun  5 2012 ms@suse.de
- don't evaluate type of drivers sections. There is only
  type 'drivers' now available
* Tue Jun  5 2012 ms@suse.de
- remove use of netdrivers,scsidrivers,usbdrivers typed
  drivers sections and merge them into one section
* Tue Jun  5 2012 ms@suse.de
- limit type attribute of drivers section to 'drivers'
* Tue Jun  5 2012 rjschwei@suse.com
- add unit tests for repo handling in the XML object
* Tue Jun  5 2012 rjschwei@suse.com
- add argument check to addRepository() method
  at present it is possible to attempt to add a repository with
  an invalid type. This may lead to unpredictable behavior during
  build. While the type is verified when given on the command line,
  the additional validation is needed for migration when we add
  repos from a running system.
* Tue Jun  5 2012 rjschwei@suse.com
- add log message for repository replacement
  at present no message is issued if a replacable
  repository is replaced with a new repository
* Tue Jun  5 2012 rjschwei@suse.com
- add info message when repositories are being ignored
* Tue Jun  5 2012 rjschwei@suse.com
- add doc string to the prefer-license attribute in the
  schema documentation. Previously there was no documentation
  and the name was not necessarily obviously implying the
  intension of the attribute.
* Tue Jun  5 2012 rjschwei@suse.com
- added unit tests for:
  * getStripNodeList() method of XML object
  * getConfigName() method of XML object
* Tue Jun  5 2012 rjschwei@suse.com
- comment out variable that is only used for debug printing
* Tue Jun  5 2012 rjschwei@suse.com
- rename of functions:
  * getNodeList() to getRepoNodeList()
    the getNodeList name is too generic and does not indicate by name
    what can be expected about the information returned by the method
  * getRepository() method to getRepositories()
    the method returns all repository information, thus this should be
    reflected in the method name
* Tue Jun  5 2012 ms@suse.de
- DB: update schema documentation
  include info about new <defaultprebuilt> XML element
* Mon Jun  4 2012 rjschwei@suse.com
- do not call the test log internal __reset() method.
  calling __reset() would ignore any potential other states and
  therefore would ignore potential error conditions. Calling
  getState() instead and ignoring the returned value ensures
  that only one state is set in the log as expected after
  calling the getErrorState() method.
* Mon Jun  4 2012 rjschwei@suse.com
- remove unused variable pblt
* Mon Jun  4 2012 rjschwei@suse.com
- unit test for new <defaultprebuilt> element
* Mon Jun  4 2012 rjschwei@suse.com
- DB: rebuild documentation:
  include info about new <defaultprebuilt> XML element
* Mon Jun  4 2012 rjschwei@suse.com
- add new element <defaultprebuilt>
  * allow users to specify a default location for pre-built boot images
    in the configuration file.
* Mon Jun  4 2012 rjschwei@suse.com
- re-sort the attributes of the type element into alpha order
* Mon Jun  4 2012 ms@suse.de
- make sure return value from cleanupRPMDatabase() is passed
  correctly and handled
* Mon Jun  4 2012 ms@suse.de
- v5.03.13 released
* Mon Jun  4 2012 ms@suse.de
- really fixed cleanupRPMDatabase() by using the db_dump|db45_load method
* Mon Jun  4 2012 ms@suse.de
- v5.03.12 released
* Sun Jun  3 2012 ms@suse.de
- fixed test_invalidProfileRequest(), it modifies the
  message data thus it needs a reset to prevent after
  effects in subsequent tests
* Sun Jun  3 2012 ms@suse.de
- perl Test::Unit doesn't work for 12.2 anymore. Other than
  that is's unmaintained since 2005. Therefore we switch to
  Test::Unit::Lite which is also not really maintained but at
  least still works
* Sat Jun  2 2012 rjschwei@suse.com
- unit tests for profile handling
  * these do not test the usage of profiles, only the storage of
    profile data in the XML object and the consistency check upon
    profile request, usage will be integrated into other test at a later
    date
* Sat Jun  2 2012 rjschwei@suse.com
- make the checkProfiles method of the XML object "private"
  * this is an XML internal helper method and should not be
    called by other modules
* Sat Jun  2 2012 rjschwei@suse.com
- unit test for XML object user data storage
* Sat Jun  2 2012 rjschwei@suse.com
- make the getVMConfigOpts method on the XML object "private"
  * this is an internal helper method and should not be called
    from other modules
* Sat Jun  2 2012 rjschwei@suse.com
- make the getPreferencesNodeByTagName XML method "private"
  * this is an XML object internal method and should not be called
    by other modules
* Fri Jun  1 2012 adrian@suse.de
- kernel-pae does only exists on i586/i686 architecture
* Fri Jun  1 2012 rjschwei@suse.com
- eliminate getXenDomain method from XML
  * the domain is part of the Xen config and can be accessed
    via getXenConfig we should not have multiple methods to
    get the same data
* Fri Jun  1 2012 ms@suse.de
- v5.03.11 released
* Thu May 31 2012 rjschwei@suse.com
- unit test for XML validation of the volume element
  test to verify that the combination of "size" and "freespace"
  on the <volume> element is rejected.
* Thu May 31 2012 rjschwei@suse.com
- do not allow the use of the "size" and "freespace" attributes
  in combination. At present a user can specify both the "size"
  and "freespace" attributes on the <volume> element. In this
  case the setting of the "freespace" attribute is ignored,
  therefore allowing the combination of the attributes is
  misleading and should be disallowed
* Thu May 31 2012 rjschwei@suse.com
- XML object unit tests for LVM related methods
* Thu May 31 2012 ms@suse.de
- arm: renamed boot and JeOS images from suse-Factory to suse-12.2
* Thu May 31 2012 ms@suse.de
- removed rt kernel profile, there is no kernel-rt for openSUSE
* Thu May 31 2012 ms@suse.de
- fixed handling of obs URL path within KIWIURL. if the
  created obs path does not exist proceed and check again
  as opensuse URL type. This was done only in KIWIRoot but
  belongs to the URL module
* Thu May 31 2012 adrian@suse.de
- remove packages which do not exist in 12.2 anymore
* Wed May 30 2012 ms@suse.de
- add empiric code to calculate size for btrfs images... not nice
* Wed May 30 2012 ms@suse.de
- make sure btrfs based images provide a common subvolume
  setup as explained in (bnc #764703)
* Wed May 30 2012 rjschwei@suse.com
- unit test for addStrip method of XML object
  * verify error condition of improper call
  * verify proper addition for delete, libs, and tools
* Wed May 30 2012 rjschwei@suse.com
- fix addStrip method of XML object
  * when adding new strip information we need to check if an element
    with the given type already exists, if yes the information needs
    to be added to the existing type. If a new element is added with
    the same type as an existing element the getStrip*()
    implementations will not return the correct information.
    This is a latent bug.
  * also added a consitency check to ensure the method only adds
    strip elements of supported types.
* Wed May 30 2012 rjschwei@suse.com
- add unit tests for XML getStrip* methods
* Wed May 30 2012 rjschwei@suse.com
- make the getStripFileList of the XML object "private", this is
  an internal helper method and should not be called from other
  KIWI modules
* Wed May 30 2012 ms@suse.de
- v5.03.10 released
* Wed May 30 2012 ms@suse.de
- Revert "- eliminate getXenDomain method from XML"
  This breaks kiwi in KIWIXML.pm:getImageConfig()
  This reverts commit a2a9509c6ef44f09cdf2b8a271387de4bec071dc.
* Wed May 30 2012 ms@suse.de
- v5.03.9 released
* Tue May 29 2012 ms@suse.de
- allow direct root tree access for btrfs and xfs when creating
  the virtual disk. For those two filesystem we had the intermediate
  step to create a filesystem image first which is then dumped
  via dd on the virtual disk.
* Tue May 29 2012 adrian@suse.de
- enable PXE on arm platform, untested but PXE exists
  there and it is fixing building kiwi
* Tue May 29 2012 adrian@suse.de
- create additional -requires packages for each boot
  description to track dependencies automatically in
  the openSUSE buildservice
* Tue May 29 2012 ms@suse.de
- eliminate the use of expr and use shell's $((..)) expression instead
* Sat May 26 2012 ms@suse.de
- DB: rebuild documentation
* Sat May 26 2012 rjschwei@suse.com
- eliminate getXenDomain method from XML
  the domain is patr of the Xen config and can be accessed
  via getXenConfig we should not have multiple methods to
  get the same data
* Sat May 26 2012 rjschwei@suse.com
- unit test for OVF data storage in the XML object
* Fri May 25 2012 ms@suse.de
- DB: rebuild documentation
* Fri May 25 2012 ms@suse.de
- v5.03.8 released
* Fri May 25 2012 ms@suse.de
- make sure resizeLVMVolumes unsets FSTYPE before fsresize
* Fri May 25 2012 rjschwei@suse.com
- add a reference to the online and local schema documentation
  * a recent discussion on the mailing list revealed that there is
    no reference to the complete schema documentation in the docbook
    doc and not all available elements are listed in the docbook
    documentation
* Fri May 25 2012 ms@suse.de
- apply oem dump and repart patches from x86 arch
  to ppc/s390 and arm. Reference commits are:
  * e3cb127676f636b71d2a07acd7fdd4bc0bb6f332
  * 8d15e715dcb156bf0b101c87e28ceb810d0f4eed
* Fri May 25 2012 rjschwei@suse.com
- DB: update documentation chapter 3
  * update the chapter w.r.t. content, spelling, grammar
  * add section to chapter 3 explaining the use of pre-built boot images
    in a recent discussion on the mailing list it was pointed out that
    the use of pre-built boot images is not documented
* Fri May 25 2012 ms@suse.de
- fixed OEM partition selection for LVM images. If there
  are exactly two partitions suitable for the install process
  it's possible to assign boot and root partition according
  to the partition ID's from the OEM image partition table.
  Thus we can prevent a selection dialog in this case.
  Additionally this commit added more information about
  the reason why partitions are rejected
* Fri May 25 2012 ms@suse.de
- make sure 'rev' tool stays inside the initrd
* Fri May 25 2012 ms@suse.de
- fixed OEM partition install mode for LVM images
* Fri May 25 2012 ms@suse.de
- don't install unnecessary doc meta data
* Thu May 24 2012 ms@suse.de
- added sync of schema docs to doc.opensuse.org
* Wed May 23 2012 ms@suse.de
- added sync of docs to doc.opensuse.org
* Tue May 22 2012 ms@suse.de
- v5.03.7 released
* Tue May 22 2012 ms@suse.de
- make sure systemctl stay inside the initrd. That's because
  the reboot tool is now a link to systemctl
* Tue May 22 2012 ms@suse.de
- v5.03.6 released
* Tue May 22 2012 ms@suse.de
- fixed baseStripUnusedLibs to work with library links
  pointing to library links (bnc#753574)
* Tue May 22 2012 ms@suse.de
- fixed baseStripUnusedLibs to work with library links
  pointing to an absolute path (bnc#753574)
* Mon May 21 2012 ms@suse.de
- changed the way how the size request of LVM volumes in an oem image
  is processed. Before this patch the volumes were created with the
  requested size and stored in the image. Thus we store a lot of null
  bytes inside the image and also dump those null bytes when running
  the code of an oem install image. As the oem image by design expands
  itself on first boot according to the target disk and oem image
  configuration parameters, it's more clean and also faster to resize
  the volumes on first boot and not keep them with their requested
  size inside the image (bnc#761993)
* Mon May 21 2012 ms@suse.de
- fixed fstab flags for non root device entries
* Mon May 21 2012 ms@suse.de
- apply suse-repart patch for ppc, s390 and arm architecture
  reference commit: a621b4e715ac18e1daabb644a9b3b8af2e316d24
* Mon May 21 2012 ms@suse.de
- make controller and id attributes optional in the vmdisk section
* Mon May 21 2012 ms@suse.de
- added support for openSUSE 12.2 / removed 11.3
  * added JeOS openSUSE 12.2 image template descriptions
  * update spec file to support openSUSE 12.2 and remove 11.3
  * added 12.2 boot image descriptions
  * added openSUSE 12.2 examples
* Fri May 18 2012 ms@suse.de
- DB: rebuild schema documentation
* Fri May 18 2012 ms@suse.de
- DB: rebuild schema due to latest changes in .rnc
* Thu May 17 2012 rjschwei@suse.com
- remove superfluous () for variable declaration
* Thu May 17 2012 rjschwei@suse.com
- remove controller and id attribute settings from Xen example
  The controller and id attributes are not evaluated in the XML object
  for the Xen configuration, showing these settings in the examples
  is misleading to the user.
* Thu May 17 2012 rjschwei@suse.com
- add qualifiers to attribute description of the machine and vmdisk
  elements. At present it is not obvious which of the attributes are
  evaluated for a given Virtual Machine image format when looking at
  the Schema documentation. The qualifiers address this situation.
* Thu May 17 2012 rjschwei@suse.com
- added unit tests:
  * unit test for getEc2Config method of XML object
  * unit test for getVMwareConfig method of XML object
  * unit test for getXenConfig method of XML object
* Wed May 16 2012 rjschwei@suse.com
- add the proper IP address to the Web-UI (sunstone) configuration file
  ~ presently the user has to manually change the configuration file
  and restart the server. This change eliminates this need, after the
  cloud is up and running the user can just access the Web-UI as the
  server is listening on the appropriate address.
* Wed May 16 2012 ms@suse.de
- DB: update schema documentation
* Wed May 16 2012 ms@suse.de
- added type attribute <type ... bootpartsize="MB-value"/>. This
  allows to set the size of the eventual boot partition. If no
  such size is set 150MB is the minimum size for the boot partition.
  The value has an effect for image types which creates a boot
  partition only, e.g LVM, split
* Wed May 16 2012 ms@suse.de
- changed disk increasement stepsize from 100MB to 10MB
* Wed May 16 2012 rjschwei@suse.com
- fix type in comment
* Wed May 16 2012 ms@suse.de
- cleanup of KIWIBoot constructor, avoid code duplication
- added error check for kiwi --bootvm ... --bootvm-system <file|dir|device>
  if the system is not a root tree, rootfs image or partition device
- prevent dumping the image from a --targetdevice if also the creation
  of an install media was set. This will speedup the build
- make sure to use qemu-img convert to dump image from a targetdevice
* Wed May 16 2012 rjschwei@suse.com
- update the OpenNebula example:
  * Adjustments for OpenNebula version 3.4.1 release
  * Minor script fixes
* Tue May 15 2012 ms@suse.de
- don't use cat when reading data from a disk block device
  use qemu-img convert instead which takes care for sparse
  information
* Mon May 14 2012 ms@suse.de
- fixed getSector() calculation, could be too small aligned
* Mon May 14 2012 ms@suse.de
- added support for the vhd subformat=fixed type
* Sat May 12 2012 ms@suse.de
- added LVM volume information for all specified volumes
  to the profile env of the boot image. This is required
  to cleanly solve (bnc #761993)
* Fri May 11 2012 ms@suse.de
- allow option --recycle-root to be used in a --build process
  If there is a root tree in <destination>/build/image-root
  available it will be used as system image tree. The build
  of the boot image is not affected by this root recycling
* Fri May 11 2012 ms@suse.de
- additionally create md5 sum's for the kernel and the optional
  created splash initrd (fate #313338)
* Fri May 11 2012 ms@suse.de
- changed setupNetwork* functions in a way that they check
  for the presence of the $root device and in case of an
  error and an existing root device LOCAL_BOOT is set and
  the system try to proceed with local boot of the installed
  system (fate #313338)
* Fri May 11 2012 ms@suse.de
- v5.03.5 released
* Wed May  9 2012 ms@suse.de
- fixed bootloader setup if yaboot is used. the boot partition
  id is set to fat (0xc) and we have to make sure to provide
  bootinfo.txt, yaboot.cnf and the yaboot binary at the root
  of the boot partition. We don't distinguish the layout between
  LVM and non LVM setup if yaboot is used in order to have a
  clean state
* Wed May  9 2012 ms@suse.de
- changed function names installBootLoaderLilo and setupBootLoaderLilo
  to installBootLoaderYaboot and setupBootLoaderYaboot. lilo is only
  supported together with yaboot on ppc at the moment. So the function
  names are misleading and would block us if we want to add support
  for real lilo.
* Wed May  9 2012 ms@suse.de
- fixed package check for package scripts. The rpm database from
  the image root system has to be used instead of the build system
  package database
* Tue May  8 2012 ms@suse.de
- Revert "- don't set vga= kernel parameter for lilo bootlader setup"
  This reverts commit 5e815b28c84e805d4777551d67be8da0433e1238.
  lilo on ppc is something complete different than lilo on other
  architectures. The vga value is supported well on 'real' lilo
  so this issue should be fixed in the bootloader
* Mon May  7 2012 ms@suse.de
- don't set vga= kernel parameter for lilo bootlader setup
  I was told this causes trouble when lilo.conf is converted
  to yaboot.conf
* Mon May  7 2012 ms@suse.de
- use correct size for FAT table when yaboot is used
* Mon May  7 2012 ms@suse.de
- we don't need the mbrid information for ppc/yaboot
  the searchOFBootDevice function doesn't request it
* Mon May  7 2012 ms@suse.de
- respect custom boot timeout value for yaboot setup
* Fri May  4 2012 ms@suse.de
- don't remove cpio program from initrd, required for custom splash setup
  follow up fix for the other architectures s390, ppc and arm
* Fri May  4 2012 ms@suse.de
- allow evaluation of $DO_NOT_INSTALL_BOOTLOADER variable in
  netboot suse-preinit to prevent installation of the bootloader
  by a variable (bnc #760502)
* Fri May  4 2012 ms@suse.de
- netboot: use --metadata=0.9 format for raid setup (bnc #760713)
* Fri May  4 2012 ms@suse.de
- v5.03.4 released
* Fri May  4 2012 ms@suse.de
- fixed URL repo check, correctly use is_success method and
  make sure every repo is checked for rpm-md _and_ repodata
* Fri May  4 2012 ms@suse.de
- removed 'in progress' indicators from messages containing a path
  People reported to be confused about the path to be complete :)
* Fri May  4 2012 ms@suse.de
- create rootfs.meta data file which includes information about
  the required min size and (good) inode value for split systems.
  This prevents the initrd code from getting that information out
  of the rootfs.tar tarball and thus speeds up the boot
* Thu May  3 2012 ms@suse.de
- fixed unit test due to the removal of the aufs support
* Thu May  3 2012 ms@suse.de
- remove the urlResponse() method and use the timeout function
  implemented in LWP::UserAgent properly to resolve URL's
* Thu May  3 2012 ms@suse.de
- make sure releaseNetwork() also deconfigures the interface and
  configuration. Meaning don't use the -p option as we already
  check for root over NFS/AOE/NBD it doesn't make sense anymore
- make sure releaseNetwork() unsets the HOSTNAME as it might
  conflict with the later system image network setup
* Thu May  3 2012 ms@suse.de
- allow kiwisplitroot_size=<size-in-MB> which specifies how much
  size is reserved for the tmpfs holding the temporary rootfs
  data in a split image. Also fixed the calculation of the inode
  number for this tmpfs
* Thu May  3 2012 ms@suse.de
- removed support for aufs overlay filesystem. The problem is that
  no overlay filesystem like aufs, unionfs, deltafs and friends
  is accepted by the kernel people. Thus support for them inside
  the distribution(s) is hard to maintain and the system barely
  works. My hope is that some day there will be the mount --overlay
  method implemented in a clean way and supported by the kernel
  until then we live with the fuse based approach (clicfs) and
  the device mapper snapshot method for the caching
  system (bnc #760159)
* Thu May  3 2012 rjschwei@suse.com
- unit tests for preference settings
* Thu May  3 2012 rjschwei@suse.com
- check only for presence and boolean value
  The "additive" attribute is a boolean value, i.e. valid values
  are true or false. We should only check for supported values.
  The removed check for 0 is possibly an artifact from times
  where we alloed 0 to indicate false in the XML.
* Thu May  3 2012 ms@suse.de
- fixed hook call with parameters containing spaces (bnc #760331)
* Wed May  2 2012 ms@suse.de
- fixed redundancy in getElementsByTagName ("...") -> get_nodelist();
  calls. According to the spec getElementsByTagName already returns
  the node list if called in array context.
* Wed May  2 2012 ms@suse.de
- added unit test for XML split settings
* Wed May  2 2012 ms@suse.de
- fixed naming inconsistency: getSplitTmpExceptions/getSplitTempExceptions
* Tue May  1 2012 ms@suse.de
- v5.03.3 released
* Tue May  1 2012 ms@suse.de
- fixed baseStripUnusedLibs() to be more robust and prepared
  for the move of libraries to another location
* Tue May  1 2012 ms@suse.de
- don't remove cpio program from initrd, required for custom splash setup
* Tue May  1 2012 ms@suse.de
- v5.03.2 released
* Fri Apr 27 2012 ms@suse.de
- added optional <type ... installprovidefailsafe="true/false"/>
  attribute which allows to configure if the Failsafe boot menu
  entry for the install media should be displayed or not.
* Fri Apr 27 2012 ms@suse.de
- removed misleading Restore wording in install iso boot menu
* Fri Apr 27 2012 ms@suse.de
- make sure required libs for filesystem tools stay inside the initrd
* Thu Apr 26 2012 ms@suse.de
- v5.03.01 relased
* Thu Apr 26 2012 ms@suse.de
- make sure libext2fs stays inside the initrd, it's required
  for tune2fs on Factory/openSUSE 12.2
* Thu Apr 26 2012 ms@suse.de
- fixed evaluation of --edit-bootconfig. There is either the
  choice for setting the value on the commandline or as attribute
  inside the XML description. Before this fix the code did not
  correctly get the value depending on how kiwi is called
- make sure any iso is created via the KIWIISOLinux provided
  functions. According to this editbootconfig now also works
  for the creation of installs ISO's
* Thu Apr 26 2012 rjschwei@suse.com
- unit tests for the getPXEDeploy* methods
* Thu Apr 26 2012 rjschwei@suse.com
- fix typo in XML OEM settings unit test configuration
* Thu Apr 26 2012 rjschwei@suse.com
- fix typo in explanatory comment
* Wed Apr 25 2012 ms@suse.de
- make sure grub menu.lst is correctly utf-8 encoded
* Wed Apr 25 2012 ms@suse.de
- added __hasValidLVMName() runtime check. This checks if the
  optional LVM group name already exist on the build host.
* Wed Apr 25 2012 ms@suse.de
- fixed typo in error message, $! is empty but we stored the
  messages in $status
* Tue Apr 24 2012 ms@suse.de
- fixed flag state for iso in extras/suse-11.4/suse-min-gnome
* Tue Apr 24 2012 ms@suse.de
- redirect errors from rpm --rebuilddb into the result variable
* Mon Apr 23 2012 ms@suse.de
- v5.02.25 released
* Sun Apr 22 2012 ms@suse.de
- fixed loop in partition size check
* Sun Apr 22 2012 ms@suse.de
- added a check for the split read/write partition size
  when creating the virtual disk.
* Sat Apr 21 2012 rjschwei@suse.com
- add unit tests for the getOEM* methods
  Prior to undertacing the restructuring of the XML object we need to get
  unit tests in place
* Fri Apr 20 2012 ms@suse.de
- v5.02.24 released
* Thu Apr 19 2012 ms@suse.de
- take package section type into account when processing
  bootincluded packages. This means packages added as bootincluded
  into the e.g image section gets added to the image section
  in the boot image too. If the target description doesn't
  provide the section the package will be added to the default
  bootstrap section as before
* Thu Apr 19 2012 ms@suse.de
- remove db4 package from the delete list in the RHEL
  boot image descriptions
* Thu Apr 19 2012 ms@suse.de
- fixed rpm package database rebuild check for RHEL/yum
  this reverts commit: c3e4ac88562074d87cad21e96cfe3d6dde976e48
* Thu Apr 19 2012 ms@suse.de
- moved yum priority installation from the RHEL boot- into the
  system image template and make it a bootincluded package.
  That's because there are name differences like yum-priority
  and yum-plugin-priority
* Thu Apr 19 2012 ms@suse.de
- fixed rebuild of package database when yum is used
* Wed Apr 18 2012 ms@suse.de
- arm: adapt JeOS description for beagle and fixed building in emulated environment
* Tue Apr 17 2012 ms@suse.de
- really fixed boot.script setup according to (bnc #757489)
* Tue Apr 17 2012 ms@suse.de
- arm: On other systems which supports a boot menu we add
  the linux kernel and initrd with its file names. But on
  arm systems there can only be one kernel because uboot
  doesn't support a menu. Thus perl-bootloader also doesn't
  support updating the uboot configuration and that's the
  reason why we use the links created by mkinitrd to point
  to the kernel and initrd in order to support kernel
  updates (bnc #757489)
* Mon Apr 16 2012 ms@suse.de
- s390: fixed recreateVTOCTable() to wait until the volume
  group has settled before deactivating it in a LVM setup
* Mon Apr 16 2012 ms@suse.de
- removed obsolete error console information
* Mon Apr 16 2012 ms@suse.de
- kiwi creates a link with filesystem extension pointing to
  the root filesystem image when created. The function
  compressImage creates a .gz version of that root filesystem
  image and therefore break the link. This fix enhances
  compressImage() in a way that it receives the filesystem
  information in order to repair the link
* Mon Apr 16 2012 ms@suse.de
- added oem type to s390 JeOS image description
* Mon Apr 16 2012 ms@suse.de
- update s390 SLE repo in JeOS template
* Mon Apr 16 2012 ms@suse.de
- v5.02.23 released
* Fri Apr 13 2012 ms@suse.de
- DB: rebuild documentation
* Fri Apr 13 2012 ms@suse.de
- DB: update documentation
* Fri Apr 13 2012 ms@suse.de
- added preCallInit hook to be available for the vmx type too
* Fri Apr 13 2012 ms@suse.de
- fixed partition based oem install method. parsing proc/partitions
  was broken in OEMFindPartitions because the ID device name was
  used as reference instead of the unix device name
* Thu Apr 12 2012 rjschwei@suse.com
- properly pick up splash image for pre-built initrd. At present
  it is not possible to use a splash screen with a prebuilt
  initrd. For a pre-built initrd the splash file is named with
  extension '.spl', but we are loking for the extension '.splash.gz',
  thus the file is not found. With this change we look for the
  file with the appropriate extension.
* Wed Apr 11 2012 ms@suse.de
- update list of allowed VMware guestOS values
* Wed Apr 11 2012 winter@pre-sense.de
- Fix the handling of the --mbrid command line switch
  The value passed to the --mbrid flag is parsed to an integer by
  GetOptions (format is 'o' = extended integer). There is code
  checking whether this integer is within the expected range and
  formats it as hexadecimal value. But commit:
  a5c7ab512dfb02dd99044c1db1cbc46ab05bf221
  introduced a regression in the way the value of the --mbrid flag
  was handled because the value is set using $cmdL -> setMBRID()
  before the range checking and conversion.
* Wed Apr 11 2012 rjschwei@suse.com
- prepare the code for the move of the udev tools to the usr
  tree. At present the location of udevadmin is hardcoded to
  /sbin, once the tools move into the /usr tree and a link
  exists the '-x' test will fail. This would result in broken
  images.
* Mon Apr  9 2012 rjschwei@suse.com
- Do not allow whitespce in the value of the name attribute for the
  <systemdisk> and <volume> elements. At present the user can specify
  a name containing whitespace. This leads to problems that are
  difficult to diagnose in when the user tries to run the resulting
  image, as the image will not properly operate.
* Sun Apr  8 2012 rjschwei@suse.com
- Fix ownership issue with persistent tmpdir
  At present the script fails if /var/tmp does not exist. Although /var/tmp
  should always exist, the new code assures proper handling if this directory
  is missing.
* Sun Apr  8 2012 rjschwei@suse.com
- Fix race condition in launch script for openNebula test
  At present the test script may cause a condition where the openNebula
  infrastructure issues a "[VirtualMachineAllocate] Error allocating a
  new virtual machine. Could not get disk image for VM." message. Giving
  the system some time to copy the image file eliminates this issue.
* Wed Apr  4 2012 ms@suse.de
- v5.02.22 released
* Wed Apr  4 2012 ms@suse.de
- fixed missing filesystem resize operation for LVM based images.
  If oem-systemsize and a freespace=all volume is setup kiwi
  resized only the freespace=all volume and missed to resize the
  root volume
* Tue Apr  3 2012 ms@suse.de
- fixed XSL stylesheet conversion: convert49to50.xsl
  the apply templates recursion is broken by using another mode
  so the fix is to stay in the same mode and select the value by
  a modified xpath expression
* Mon Apr  2 2012 ms@suse.de
- fixed misleading error message when kiwi can't find the
  image file on the pxe download server (bnc #754275)
* Mon Apr  2 2012 ms@suse.de
- fixed oem installation with luks encrypted root filesystem
  during the repartitioning the luks setup has to close down
  otherwise the partition table is busy (bnc #754978)
* Mon Apr  2 2012 ms@suse.de
- fixed test -z expression
* Mon Apr  2 2012 ms@suse.de
- fixed creation of sat job list, eliminate duplicate jobs
* Mon Apr  2 2012 ms@suse.de
- make sure solver failed packages/patterns are evaluated in info module
* Sat Mar 31 2012 ms@suse.de
- make sure libkmod stays in the initrd
* Sat Mar 31 2012 ms@suse.de
- make sure solver problems are evaluated in info module
* Fri Mar 30 2012 ms@suse.de
- v5.02.21 released
* Fri Mar 30 2012 ms@suse.de
- fixed incorrect fstab entry created for read-only systems
* Fri Mar 30 2012 ms@suse.de
- fixed identifyDevice() to calculate the correct index for
  accessing an entry in the deviceArray list
* Fri Mar 30 2012 ms@suse.de
- moved from md5_base64 to md5_hex for the creation of random
  repo alias names. md5_base64 could create names with a '/'
  and that causes trouble when checking for the existence of
  the repo file. In order to avoid to implement the same
  escape code as used by zypper in kiwi for such alias names,
  I'd better moved the code to create hex number based alias
  names
* Thu Mar 29 2012 ms@suse.de
- make sure ZYPP_LOCKFILE_ROOT is set appropriately when zypper
  is used with --root option (bnc #753818)
* Wed Mar 28 2012 ms@suse.de
- fixed updateOtherDeviceFstab() to correctly create missing
  mount points inside the root file system (bnc #754344)
* Wed Mar 28 2012 ms@suse.de
- make sure volume group name doesn't contain white spaces
* Fri Mar 23 2012 ms@suse.de
- v5.02.20 released
* Thu Mar 22 2012 ms@suse.de
- arm: added support for optional ${append} bootargs variable (bnc #752623)
* Tue Mar 20 2012 ms@suse.de
- make sure loader variable is initialized
* Mon Mar 19 2012 ms@suse.de
- don't use -s option for losetup:
  the option -s is in collision with the Loop-AES losetup dialect that
  is used in some distributions. Use the long version (--show) only.
* Mon Mar 19 2012 ms@suse.de
- changed repartition code for LVM concerning the use of
  element '<oem-system-size>' and 'freespace=all' volume:
  * if none of the two is specified, the root will be expanded to
    occupy all available space
  * if only oem-systemsize is specified, the root will be expanded
    as much as specified
  * if only freespace=all is specified (for non-root volume), then
    the root will not be expanded and the other volume will take all
    available space
  * Finally, if both are specified, then the root will be expanded to
    take as much as oem-systemsize requires and any remaining space is
    assigned to the other volume.
* Sat Mar 17 2012 ms@suse.de
- fixed compare of object addresses by using refaddr. This is
  more robust because objects can overload operators like '!='
* Sat Mar 17 2012 ms@suse.de
- fixed pattern names used in examples (bnc #752754)
* Fri Mar 16 2012 ms@suse.de
- v5.02.19 released
* Fri Mar 16 2012 ms@suse.de
- fixed order of files in an ova tar archive per spec
  in http://www.vmware.com/pdf/ovf_spec_draft.pdf (bnc #752581)
* Fri Mar 16 2012 ms@suse.de
- fixed malformed ovf file. the Envelope properties
  xmlns:rasd and xmlns:vssd are split in two lines with
  an extra quote (") (bnc #752580)
* Fri Mar 16 2012 rjschwei@suse.com
- only remove the KIWI created initrd and kernel if mkinitrd run was successful
- remove unused variable haveVMX
* Thu Mar 15 2012 ms@suse.de
- make split building more robust. the read-only partition size
  will be a bit bigger than the actual read-only filesystem image
  to be sure it fits into the partition. Due to the alignment this
  was required and costs a few bytes
* Thu Mar 15 2012 ms@suse.de
- make sure kernelCheck() initializes list of kernels if empty (bnc #752259)
* Wed Mar 14 2012 ms@suse.de
- don't remove libbz2 from isoboot boot images for SLE11
* Wed Mar 14 2012 ms@suse.de
- fixed removePackages() function
  * make sure rpmLibs() is called prior to rpm. if all packages
    are installed by bootstrap only this is required
  * make sure to check for empty $final variable
* Wed Mar 14 2012 ms@suse.de
- added ovf format example to examples/suse-12.1/suse-vm-guest
* Wed Mar 14 2012 ms@suse.de
- better warning message about required machine section data
* Tue Mar 13 2012 rjschwei@suse.com
- run the unit tests in verbose mode during package build
* Mon Mar 12 2012 rjschwei@suse.com
- fix Validator test
  Revert f551128061 and d76e57194c, comparison in question checks for
  equality of objects, thus numerical comparison is appropriate
* Fri Mar  9 2012 ms@suse.de
- v5.02.18 released
* Fri Mar  9 2012 ms@suse.de
- fixed entry for hv_netvsc.ko driver
* Thu Mar  8 2012 ms@suse.de
- fixed rpm database consistency check
* Thu Mar  8 2012 ms@suse.de
- use string comparison operator for strings and not numeric op
* Thu Mar  8 2012 ms@suse.de
- add new kernel module paths for Microsoft HyperV (hv) modules
* Tue Mar  6 2012 ms@suse.de
- fixed use of != operator in KIWIXMLValidator
* Tue Mar  6 2012 ms@suse.de
- removed the rpmLibs() tricks, all that sucks
* Tue Mar  6 2012 ms@suse.de
- fixed typo in KIWICollect.pm
* Tue Mar  6 2012 ms@suse.de
- added which based search for dracut/mkinitrd/depmod
* Tue Mar  6 2012 rjschwei@suse.com
- remove unused function callSUSEInitrdScripts
  The initrd is created by setupRHELInitrd and setupSUSEInitrd, there is no
  call in the code to callSUSEInitrdScripts
* Mon Mar  5 2012 ms@suse.de
- fixed removePackages():
  * use options --noscripts --allmatches
  * respect return code from rpm call
  * make sure proc is mounted
* Mon Mar  5 2012 rjschwei@suse.com
- added function updateModuleDependencies() to update the kernel
  modules dependency list. Call this function prior to creating
  the initrd. This allows the user to add custom kernel modules
  and makes sure these get picked up when mkinitrd runs
* Mon Mar  5 2012 ms@suse.de
- make removePackages() to work with yum
* Mon Mar  5 2012 ms@suse.de
- allow fixup of image min size if given size is too small
- fixed partition size check
* Mon Mar  5 2012 ms@suse.de
- fixed logging of non CR terminated lines when in --logfile mode
* Mon Mar  5 2012 ms@suse.de
- v5.02.17 released
* Mon Mar  5 2012 ms@suse.de
- follow up fix for handling of console in kiwi initrd (bnc #749900)
  * don't start blogd in kiwi initrd, doesn't make much sense
  * fixed console output, stdout was wrongly redirected
  * make sure utimer also works in the preinit code
* Mon Mar  5 2012 ms@suse.de
- v5.02.16 released
* Mon Mar  5 2012 ms@suse.de
- arm: fixed installation of MLO loader, wrong path
* Sun Mar  4 2012 ms@suse.de
- arm: added following boot fixes:
  * To avoid any issues when parted leaves x86 boot code we
    zero out the first 440 bytes (MBR without ptable). The
    mandatory master boot id to identify the device is written
    afterwards
  * make sure MLO is installed after repart again in
    installBootLoaderUBoot. Also make sure the same MBR cleanup
    code is applied in the kiwi boot code
* Fri Mar  2 2012 ms@suse.de
- v5.02.15 released
* Fri Mar  2 2012 ms@suse.de
- fixed handling of console in kiwi initrd (bnc #749900)
  * removed use of klogconsole, we want kernel messages at that stage
  * don't use tty devices, use /dev/console and remove kiwistderr
  * allow debug shell only if tty device for it exists
  * don't use extra terminal to show error information. all that
    is stored in /var/log/boot kiwi
* Fri Mar  2 2012 ms@suse.de
- added ec2region setup to ec2 example image descriptions
* Fri Mar  2 2012 ms@suse.de
- DB: rebuild documentation
* Thu Mar  1 2012 ms@suse.de
- fixed default fstab setup to know about /run for udev
* Thu Mar  1 2012 rjschwei@suse.com
- update EC2 chapter
  Include information about EC2 tools handling of regions, us-east-1 is the
  default if not otherwise specified via EC2_URL, --url, or --region
* Thu Mar  1 2012 ms@suse.de
- fixed initrd module list for ec2 format code
* Wed Feb 29 2012 ms@suse.de
- further cleanup of ec2 examples
* Wed Feb 29 2012 ms@suse.de
- cleanup ec2 examples
* Tue Feb 28 2012 ms@suse.de
- netboot: fixed setup of root device for local boot
* Tue Feb 28 2012 ms@suse.de
- added -base kernel packages for ec2 and xenk boot profiles
* Tue Feb 28 2012 ms@suse.de
- fixed mkinitrd call in ec2 format code:
  * don't use -A also make sure the exit code of mkinitrd is evaluated
  * make sure all required filesystem modules are added to
    /etc/sysconfig/kernel before calling mkinitrd
* Tue Feb 28 2012 ms@suse.de
- respect size setup by user and don't add extra space for
  a possible boot partition
* Mon Feb 27 2012 ms@suse.de
- because the input stream from XML is utf-8 encoded it's required
  to set binmode correctly to utf-8 too when writing the data out.
  This is at least required for the profile file inside the initrd
  because it contains data from the XML like the oem boot title
* Sun Feb 26 2012 ms@suse.de
- changed partition alignment to align start and size of
  partitions to 4096 bytes. The value can be changed with
  the option --disk-alignment
* Fri Feb 24 2012 ms@suse.de
- v5.02.14 released
* Fri Feb 24 2012 ms@suse.de
- added support for grub2 based install iso images
* Thu Feb 23 2012 ms@suse.de
- v5.02.13 released
* Thu Feb 23 2012 ms@suse.de
- follow up and improved fix for basePackBootIncludes to pack
  only items listed in the rpm package filelist but don't
  recursively look them up in the filesystem when tar'ing
  them up (bnc #743159)
* Thu Feb 23 2012 ms@suse.de
- added creation of new meta file appdata.xml for product media
* Thu Feb 23 2012 ms@suse.de
- don't remove opt and selinux from initrd
* Wed Feb 22 2012 ms@suse.de
- added possibility to specify an oem-unattended-id in the
  oemconfig section. The id is evaluated as part of the oem
  install code and can be either the string like it appears
  in dev/disk/by-id or by-path. if the option oem-unattended
  is set to true kiwi will try to assign the install device
  according to the specified id. if the id cannot be found
  a reboot exception is thrown. If no id is specified but
  unattended mode is requested the first entry of the sorted
  device list will be used like before this change
* Wed Feb 22 2012 ms@suse.de
- sort list of devices found for installation in suse-dump
* Tue Feb 21 2012 ms@suse.de
- remove 'fixed' flagged repositories from boot image descriptions.
  As the boot image inherit the repo setup from the system image
  it's more flexible to let the system image decide for the repos
* Tue Feb 21 2012 ms@suse.de
- fixed suseStripModules to return early if no update driver was found
* Tue Feb 21 2012 ms@suse.de
- added staging/hv drivers to SLE11 boot image descriptions.
  Beginning with SLE11-SP2 the drivers are part of the standard
  kernel and thus they should be preserved (bnc #747898)
- with reference to (bnc #747898) a new function called
  suseStripModules() has been added. The function searches
  for update modules and removes the old version which
  might be provided by the standard kernel to prevent
  a load clash
* Tue Feb 21 2012 rjschwei@suse.com
- fix improper call off stripImage()
- fix some cosmetic issues
* Mon Feb 20 2012 ms@suse.de
- v5.02.12 released
* Mon Feb 20 2012 ms@suse.de
- fixed resetBootBind, the function did not properly check for
  the existence of the boot_bind directory
* Fri Feb 17 2012 ms@suse.de
- v5.02.11 released
* Fri Feb 17 2012 ms@suse.de
- deactivate volume groups always with their name as argument
- fixed setDefaultDeviceMap to respect device naming conventions
* Fri Feb 17 2012 ms@suse.de
- finally fixed setupBootPartition in a clean way. kiwi creates
  a volume label named 'BOOT' if a boot partition is used.
  setupBootPartition searches for the label and setup the boot
  partition accordingly. Along with the change the functions
  update*BootDeviceFstab and resetBootBind were also adapted.
  There is now only one updateBootDeviceFstab handling the
  boot partition entry for all modes if required
* Thu Feb 16 2012 ms@suse.de
- v5.02.10 released
* Thu Feb 16 2012 ms@suse.de
- added virtio drivers for sle10 boot image descriptions (bnc #747346)
* Thu Feb 16 2012 ms@suse.de
- arm: make boot.script more robust by checking alternative
  variable names for kernel and initrd addresses
* Thu Feb 16 2012 ms@suse.de
- fixed checkLVMbind so that it directly reads the LVM
  header from the specified disk device
* Thu Feb 16 2012 ms@suse.de
- arm: fixed installation of MLO loader, wrong path
* Thu Feb 16 2012 ms@suse.de
- call resetBootBind before preinit (bnc #747241)
* Wed Feb 15 2012 ms@suse.de
- removed use of suseRemovePackagesMarkedForDeletion
* Wed Feb 15 2012 ms@suse.de
- arm: renamed image descriptions to 'Factory'
- arm: removed use of suseRemovePackagesMarkedForDeletion
* Wed Feb 15 2012 ms@suse.de
- arm: added vram setup to JeOS description
- arm: fixed boot.script setup on first boot
* Wed Feb 15 2012 ms@suse.de
- DB: update documentation, added chapter about image caching
* Wed Feb 15 2012 ms@suse.de
- arm: added mmc sd card drivers to boot image descriptions
* Wed Feb 15 2012 ms@suse.de
- don't call images.sh and config.sh when in --init-cache mode
- don't evaluate packages type="delete" section in --init-cache mode
- added check for rpm binary in cleanupRPMDatabase
* Tue Feb 14 2012 ms@suse.de
- arm: make creation of boot.script more generic by using
  kerneladdr and ramdiskaddr variables
- arm: fixed JeOS console setup for efika, setup baudrate
* Tue Feb 14 2012 ms@suse.de
- added newline for messages waiting for status flag when
  they are written to the kiwi log file. It hurts when
  multiple log messages are written without a newline
* Mon Feb 13 2012 ms@suse.de
- arm: fixed setup of boot.script, missing redirect
* Fri Feb 10 2012 ms@suse.de
- v5.02.9 released
* Fri Feb 10 2012 ms@suse.de
- added support for iso boot process from external loader
  If the boot option isofrom="storage-device:path/to/iso"
  is given the isoboot initrd will try to use the contents
  of this device to boot up the system. This allows to
  externally load the linux kernel and initrd with e.g
  grub2's loopback support and let the iso image exist
  as a file instead of being dumped on a target device
  Details on the use case can be found in (bnc #746351)
* Thu Feb  9 2012 rjschwei@suse.com
- remove superfluous boot.local
* Thu Feb  9 2012 ms@suse.de
- store mbrid for iso images as Application ID and not as Volume ID
* Wed Feb  8 2012 ms@suse.de
- fixed importFile function to export only prefixed version
  of the variable if there is a prefix and not both (bnc #732247)
* Wed Feb  8 2012 ms@suse.de
- fixed import of dhcp info file (bnc #745548)
* Wed Feb  8 2012 ms@suse.de
- migration changes:
  * apply deny files on packaged dir list to speedup File::Find
  * added patternType plusRecommended
  * added comment about package prefer problem
  * added path resolver function
* Wed Feb  8 2012 ms@suse.de
- migration: fixed service setup, use chkconfig
* Tue Feb  7 2012 ms@suse.de
- migration: fixed oemboot prefix setup
* Mon Feb  6 2012 ms@suse.de
- arm: Now that x-loader on OMAP can boot from ext2, let's also
  teach kiwi about that awesome new capability. This gets rid of
  the vfat based boot partition and moves it to an ext2 based
  one. Additionally the 64MB limit on the boot partition is gone
  because the MLO is installed in the first 128kb of the disk
  and is no longer part of the boot partition. Kudos to Alexander
  Graf you added all this.
* Mon Feb  6 2012 ms@suse.de
- s390: fixed bootdevice setup for zipl
* Mon Feb  6 2012 ms@suse.de
- added rootfs check to ec2 format code
* Sat Feb  4 2012 ms@suse.de
- clean up delete lists for 12.1 boot image descriptions
* Sat Feb  4 2012 ms@suse.de
- run xml validation on source tree
* Fri Feb  3 2012 rjschwei@suse.com
- clean up to perlcritic level 5
* Fri Feb  3 2012 ms@suse.de
- fixed typo in flavour name: efikaFlavour
* Fri Feb  3 2012 ms@suse.de
- fixed setup of LOADER_TYPE for /etc/sysconfig/bootloader in
  setupBootLoaderLilo(). Depending on the architecture this
  value is different
* Fri Feb  3 2012 ms@suse.de
- v5.02.8 released
* Fri Feb  3 2012 ms@suse.de
- moved validation of delete section into setup() routine
- dont't use basePackBootIncludes/baseUnpackBootIncludes anymore
  this conflicts with bootincluded packages marked for deletion
* Thu Feb  2 2012 ms@suse.de
- keep only the uBoot initrd representation and remove the
  gzip version of the initrd from the boot partition. This
  saves some space urgently needed because on arm the boot
  partition is fixed 64MB
* Thu Feb  2 2012 rjschwei@suse.com
- add unit test for getExecArgsFormat() method of KIWILocator
- implement helper executables for the test in new bin directory
- fix logic errors in getExecArgsFormat() found by unit test implementation
* Wed Feb  1 2012 ms@suse.de
- migration: fixed repo dir detection
* Wed Feb  1 2012 ms@suse.de
- migration: sort repo list information
* Wed Feb  1 2012 ms@suse.de
- migration: write cache early enough
* Wed Feb  1 2012 ms@suse.de
- migration: added support for svn detection
* Wed Feb  1 2012 ms@suse.de
- fixed use of uninitialized value in the locator
* Wed Feb  1 2012 ms@suse.de
- migration changes:
  * added progress information while creating custom tree
  * make custom files creation much faster
  * make modified files creation faster
* Mon Jan 30 2012 ms@suse.de
- allow use of merged solvable in KIWISatSolver
* Mon Jan 30 2012 ms@suse.de
- migration: ignore weak-update links
* Mon Jan 30 2012 ms@suse.de
- migration changes:
  * create custom tree for unpackaged files/dirs based on hardlinks
  * don't copy entire etc/ directory, doesn't make sense to have all
    especially packages stuff in the overlay tree
  * adapt deny list, ignore bootsplash and bootloader data for
    migration
* Fri Jan 27 2012 rjschwei@suse.com
- fix spec file, version of RPM on SLE does not handle %%else if directives
  thus we get a dependency to qemu-img is created, but this package does
  not exist on SLE.
* Fri Jan 27 2012 ms@suse.de
- v5.02.7 released
* Fri Jan 27 2012 ms@suse.de
- clean KIWICollect.pm to perl critic
* Fri Jan 27 2012 ms@suse.de
- In RHEL/CentOS distributions the qemu-img program is packaged
  in qemu-img not in qemu or virt-utils.
* Fri Jan 27 2012 ms@suse.de
- enhanced RHEL6 JeOS
  * added default ifcfg-eth0 connecting via dhcp
  * switch off firstboot start via sysconfig/firstboot
  * added profiles RedHat and CentOS to build for both targets
* Thu Jan 26 2012 ms@suse.de
- v5.02.6 released
* Thu Jan 26 2012 ms@suse.de
- fixed setupKernelModules and init call for CentOS
* Wed Jan 25 2012 rjschwei@suse.com
- implement method to allow us to handle different command line argument
  implementations, i.e. -longOpt vs --longOpt. This problem is currently
  experienced on different versions of the isohybrid executable
- use newly implemented method to properly determine the argument format
  when calling the isohybrid executable. Really fixes (bnc #742836)
* Wed Jan 25 2012 ms@suse.de
- fixed error console setup in arm JeOS description
* Tue Jan 24 2012 ms@suse.de
- v5.02.5 released
* Tue Jan 24 2012 ms@suse.de
- really fixed basePackBootIncludes to pack only files and don't
  break if packages includes symbolic links (bnc #743159)
* Tue Jan 24 2012 ms@suse.de
- added support for oem image type for the arm architecture
* Tue Jan 24 2012 ms@suse.de
- fixed call of isohybrid, there is no -o option but -offset
* Tue Jan 24 2012 ms@suse.de
- clean ProductData, RepoMetaHandler, and Root modules to perl critic
* Tue Jan 24 2012 ms@suse.de
- eliminate previously removed SatSolverLegacy file from
  check lists in the pre-commit hook
* Mon Jan 23 2012 ms@suse.de
- v5.02.4 released
* Mon Jan 23 2012 ms@suse.de
- check if fbiterm binary really exists and don't assume it's
  there just because a framebuffer device exists. Also cleanup
  the Dialog function to work without a framebuffer
* Mon Jan 23 2012 rjschwei@suse.com
- ignore additional files (emacs backup, localization, temporaries)
* Mon Jan 23 2012 ms@suse.de
- fixed setup of root partition for LVM images
* Mon Jan 23 2012 ms@suse.de
- fixed repo and config setup for RHEL6 JeOS
* Mon Jan 23 2012 rjschwei@suse.com
- create hybrid ISOs at offset 64. This fixes (bnc #742836)
* Fri Jan 20 2012 ms@suse.de
- migration changes:
  * add support for local repo (git) checkout detection
  * search for unpacked symlinks whose origin is packaged
* Fri Jan 20 2012 ms@suse.de
- migration: added support for gem inspection
* Thu Jan 19 2012 ms@suse.de
- make media check more user friendly. check if checkmedia
  returns successfully and print a message. After that wait
  for keypress and don't reboot (bnc #728384)
* Thu Jan 19 2012 ms@suse.de
- migration: fixed creation of unpackaged files information
* Thu Jan 19 2012 ms@suse.de
- fixed basePackBootIncludes to pack only files from boot
  included rpm packages but not entire directories
* Wed Jan 18 2012 ms@suse.de
- make sure rhel oemboot descriptions are packaged
* Wed Jan 18 2012 ms@suse.de
- fixed RHEL6 JeOS used group names
* Wed Jan 18 2012 ms@suse.de
- removed staging/hv drivers from SLE11, they conflict with
  the kmp package provided on SLE11
* Wed Jan 18 2012 ms@suse.de
- fixed error handling in XML info module when sources can't be found
* Tue Jan 17 2012 ms@suse.de
- DB: update schema documentation
* Tue Jan 17 2012 ms@suse.de
- added type attribute devicepersistency which allows to set
  by-uuid, by-label or by-path device names. by default by-id
  device names are used
* Tue Jan 17 2012 ms@suse.de
- update rhel support:
  * incorporate non suse specific kiwi patches to rhel boot code
  * added rhel6 support for vmx image type
  * added rhel6 support for oem image type
  * added rhel6 JeOS image template
* Mon Jan 16 2012 ms@suse.de
- fixed root device name setup due to changed partition layout
* Mon Jan 16 2012 ms@suse.de
- changed the way how kiwi detects live and install ISO media.
  The volume ID of a live and install iso is now a unique ID.
  On boot the devices are searched to match that ID
* Sun Jan 15 2012 ms@suse.de
- follow up fix for last commit. Moved the calculation of
  the seek value into the getBlocks function and also fixed
  the function in terms of non reachable code
* Sat Jan 14 2012 rjschwei@suse.com
- fix "off by 1" error
  The created image is either 1M or 8K larger than the created partition
  for images that require a boot partition (XFS or Btrfs filesystems).
  This triggers a failure when the image is dumped to the partition in the
  disk image. See mailinglist thread
  http://groups.google.com/group/kiwi-images/browse_thread/thread/8988598856aee92d
* Fri Jan 13 2012 ms@suse.de
- added support for setupBootLoaderGrub2 and installBootLoaderGrub2
  in kiwi's initrd code. The functions are called on first deployment
  of the image and create the system bootloader configuration via
  grub2-mkconfig and grub2-install
* Fri Jan 13 2012 ms@suse.de
- make sure default strip type="delete" information from
  KIWIConfig.txt is used even if a custom strip section
  was defined
* Fri Jan 13 2012 ms@suse.de
- deactivate the use of basePackBootIncludes/baseUnpackBootIncludes
  These functions can be used to preserve and restore the contents
  of bootincluded packages/archives. We used it to prevent removal
  of files by the suseStripInitrd function. Due to the change of
  suseStripInitrd we are now more flexible to control what stays in-
  and what should be removed from the initrd which makes the use
  of basePackBootIncludes/baseUnpackBootIncludes obsolete
* Thu Jan 12 2012 ms@suse.de
- v5.02.3 released
* Thu Jan 12 2012 ms@suse.de
- find a way to install grub2 into a partition :)
* Wed Jan 11 2012 ms@suse.de
- first start of supporting grub2 in kiwi, still missing parts are:
  * graphics boot setup, no font or theme is provided by SUSE
  * first boot setup, it's not clear if we use grub2-mkconfig
    or if kiwi has to write the configuration by itself
  * recovery grub2 setup, this normally means install grub into
    a partition. So far I wasn't able to install grub2 at another
    place than the MBR
* Wed Jan 11 2012 ms@suse.de
- increased wait timeout for CDDevice search
* Tue Jan 10 2012 ms@suse.de
- added staging/hv drivers to 12.1 and SLE11 boot images
* Tue Jan 10 2012 ms@suse.de
- allow by-uuid device persistency via the kernel
  commandline option USE_BY_UUID_DEVICE_NAMES=1
* Tue Jan 10 2012 ms@suse.de
- removing references to online repos from the sle boot images (bnc #734887)
  * Virtualization:/Appliances:/suse-sle11
  * Virtualization:/Appliances:/suse-sle10
* Tue Jan 10 2012 ms@suse.de
- clean up spec file, don't require perl-satsolver but recommend it
* Tue Jan 10 2012 ms@suse.de
- removed obsolete repo reference from KIWISatSolver module
- removed obsolete KIWISatSolverLegacy module and satplugin
* Tue Jan 10 2012 ms@suse.de
- added additional data to the XML info module:
  * repository url per package to the packages info
  * adaption of the legacy kiwi SaT binding
* Mon Jan  9 2012 ms@suse.de
- added additional data to the XML info module:
  * checksum and checksum type information to packages info
  * priority, username and password information to sources info
* Mon Jan  9 2012 rjschwei@suse.com
- alphasort the driver and package entries in the boot descriptions
  This aids comparison between base distributions and boot types. It also
  helps in avoiding duplicate entries if changes need to be made (see mistake
  in a recent commit)
* Mon Jan  9 2012 ms@suse.de
- update SLE10/11 JeOS README
* Mon Jan  9 2012 ms@suse.de
- fixed missing btrfs driver entries
* Mon Jan  9 2012 ms@suse.de
- fixed typo: s/btrfsprogrs/btrfsprogs
* Sun Jan  8 2012 ms@suse.de
- netboot: added a check for the boot partition in a LUKS
  setup. if root is LUKS encrypted the local boot setup only
  works with a proper boot partition. If such a partition is
  not found the local boot setup will be skipped (bnc #735112)
* Sun Jan  8 2012 ms@suse.de
- make setup of boot device and updateOtherDeviceFstab
  more robust. This is related to bug (bnc #735112)
* Sun Jan  8 2012 ms@suse.de
- fixed typo, doubled driver entry
* Sat Jan  7 2012 ms@suse.de
- v5.02.2 released
* Sat Jan  7 2012 ms@suse.de
- make sure xfs_growfs and xfs_check stay in the initrd (bnc #740073)
* Sat Jan  7 2012 ms@suse.de
- fixed rebuild of rpm database (bnc #740033)
* Sat Jan  7 2012 ms@suse.de
- fixed possible use of uninitialized value in string comparison
* Sat Jan  7 2012 ms@suse.de
- fixed indention spaces vs. tabs at some code points
* Fri Jan  6 2012 rjschwei@suse.com
- Properly support image builds for SLE with xfs and btrfs filesystem
  The initrd image descriptions previously did not include necessary
  drivers and packages (bnc #740073)
* Fri Jan  6 2012 ms@suse.de
- v5.02.1 released
* Fri Jan  6 2012 ms@suse.de
- fixed typo when calling createPartitionerInput
* Fri Jan  6 2012 ms@suse.de
- fixed __checkTypeConfigConsist to allow valid combinations
* Thu Jan  5 2012 rjschwei@suse.com
- add new XML consistency check to verify that type configuration settings
  are compatible with the specified image type to be built.
- update unit test module for validator and implement test cases
* Wed Jan  4 2012 rjschwei@suse.com
- fix gpg signature import
  The failure is triggered by a behavior changes of /usr/lib/rpm/gnupg/dumpsigs
  on openSUSE 12.1. The updated implementation must be called with a comand
  line argument, i.e. the gpg file. Previous implementations (checked
  openSUSE 11.4 and SLES 11 SP1) of dumpsigs also accept this commandline
  argument, thus the change is backward compatible.
* Wed Jan  4 2012 ms@suse.de
- adapt oem boot/repart code to changed partition layout
* Tue Jan  3 2012 ms@suse.de
- adapt vmx boot code to changed partition layout
* Tue Jan  3 2012 ms@suse.de
- changed partition layout to setup the boot partition
  as first partition in any case not only for LVM
* Mon Jan  2 2012 ms@suse.de
- make sure a new master boot id is written on bootloader install
* Sun Jan  1 2012 rjschwei@suse.com
- clean Log, Manager, and Migrate modules to critic level5
* Fri Dec 23 2011 ms@suse.de
- cleanup partition code in KIWIBoot.pm
* Thu Dec 22 2011 ms@suse.de
- arm: add fixed mac address for panda board which doesn't have an eeprom
* Thu Dec 22 2011 ms@suse.de
- arm: fixed creation of boot.script in setupBootLoaderUBoot
- arm: fixed kernelList() function to work with arm uImages
* Thu Dec 22 2011 ms@suse.de
- added securetty overlay file for arm to allow login on
  serial console ttyO2
* Wed Dec 21 2011 ms@suse.de
- added SnapshotChunk and SnapshotCount to global space
* Wed Dec 21 2011 ms@suse.de
- fixed creation of filelist for cache selection
- fixed creation of cache meta data
* Tue Dec 20 2011 ms@suse.de
- run pretty printer on XML description to create a clean state
* Tue Dec 20 2011 ms@suse.de
- arm: kiwi-tools is required in the initrd. as it builds now we
  can safely add it to the vmxboot description
* Tue Dec 20 2011 ms@suse.de
- arm: if everything is installed in bootstrap, zypper needs to be
  added as an explicit package
* Tue Dec 20 2011 ms@suse.de
- arm: better JeOS description. added less and systemd-sysvinit
  also added a pandaFlavour profile which is imported by default
  and includes the kernel-omap2plus plus u-boot-omap4panda useful
  for panda boards. That way we can easily extend the image
  description to be suitable for other boards
* Tue Dec 20 2011 ms@suse.de
- fixed spec file for arm build, make sure kiwi-templates has
  the correct arm JeOS template and also exclude templates from
  main kiwi package correctly
* Mon Dec 19 2011 ms@suse.de
- arm: better name for the kernel profile on panda boards: omap4panda
- arm: added internal helper repo to the JeOS template as comment
* Mon Dec 19 2011 ms@suse.de
- added support for arm based images with kiwi
  * added vmxboot image description for armv7l
  * added kernel profiles: tegra (tegra boards), omap2plus (panda boards),
    omap3beagle (beagle boards) and imx51 (efika boards).
    Tested only on panda and there are still plenty of problems.
    Don't expect this support to be ready and stable !
  * added JeOS example image for arm, target SLE12
  * added support for uboot loader
* Sun Dec 18 2011 ms@suse.de
- stay compatible with fdisk when using the CHS (cylinder,head,sector) values
* Fri Dec 16 2011 ms@suse.de
- make sure the recovery partition is big enough
* Fri Dec 16 2011 ms@suse.de
- fixed typo in variable naming, a byte value should be in a
  variable whose name makes sure this actually is a byte value
* Fri Dec 16 2011 rjschwei@suse.com
- add writeXMLDiff method stub in test logger implementation to mimick the
  regular log object, this fixes the test failures when running tests as root
* Fri Dec 16 2011 ms@suse.de
- added end partition alignment which needs to be aligned to
  head/sectors (aka 255*63 in the loopback case). The end sector
  needs to end one block before the next cylinder starts.
  Additionally the value for what the kernel thinks about
  the heads sectors and sectorsize can be set via:
  * --bios-heads
  * --bios-sectors
  * --bios-sector-size
* Fri Dec 16 2011 rjschwei@suse.com
- change resource file hierarchy, the resource file in the local directory
  wins over the one in the home directory (Globals.pm)
- clean Globals.pm to level 5 critic
- partial level 5 critic clean of Boot.pm
* Fri Dec 16 2011 ms@suse.de
- DB: rebuild documentation
* Thu Dec 15 2011 rjschwei@suse.com
- add support for the new Amazon EC2 South America (announced as Sao Paulo)
  region
* Wed Dec 14 2011 ms@suse.de
- fixed xen initrd inflate/deflate problem. Xen see the bootsplash
  at the end of the initrd as garbage and refuses to boot. With this
  patch we skip the bootsplash setup if it's xen (bnc #736491)
* Wed Dec 14 2011 ms@suse.de
- fixed detection of clean-root before we remove it (bnc #736003)
* Wed Dec 14 2011 ms@suse.de
- fixed disktype setup in getOVFConfig
* Wed Dec 14 2011 ms@suse.de
- fixed SDK url's in the ppc boot images
* Wed Dec 14 2011 ms@suse.de
- DB: rebuild schema documentation
* Wed Dec 14 2011 ms@suse.de
- fixed/unify spec file license names/setup
* Wed Dec 14 2011 ms@suse.de
- revert commit: 43be86a0aa57fb393e914c03d9c621b1dec0eb31
  moved hook calls pre/postpartition back inside of the block
* Wed Dec 14 2011 ms@suse.de
- removed used of binary only ovftool and added native support
  for creating the ovf machine description. So far only the
  basic information is setup in the ovf but this will be
  enhanced according to user requests. Along with the change
  support for the ova format has been added as well. ova is
  tar container including the actual image plus a manifest
  and the ovf XML description
* Tue Dec 13 2011 rjschwei@suse.com
- fix the OpenNebula example cloud node setup to ensure the cloud admin
  home directory gets properly nfs mounted on reboot for 12.1 using systemd
* Mon Dec 12 2011 ms@suse.de
- fixed BEGIN block evaluation in KIWICollect.pm
* Mon Dec 12 2011 ms@suse.de
- add a 30 second timeout for the LWP:UserAgent
* Mon Dec 12 2011 ms@suse.de
- DB: rebuild documentation
* Fri Dec  9 2011 ms@suse.de
- v5.01.8 released
* Fri Dec  9 2011 ms@suse.de
- fixed udev database transfer. udev stores the database in /run and
  in /dev/.udev. kiwi did not take care for the information in /run
  which has a bad impact on systemd waiting for udev events which did
  not appear. Along with this fix the changes from commit 1a12ad0974ea
  were partially reverted. The obsolete udev rule is gone again and
  we don't use the exit control signal in udevSystemStop. The more
  failsafe udev exit code in the initrd udevKill() function has been
  tested and will stay there (bnc #731457)
* Fri Dec  9 2011 ms@suse.de
- v5.01.7 released
* Fri Dec  9 2011 rjschwei@suse.com
- change the suggested repo for the aoetools package to be server:/ltsp
  the previously suggested project system:/aoetools does not appear to
  be maintained
* Thu Dec  8 2011 ms@suse.de
- fixed split boot. setupBootPartition() behaved incorrectly
  with the split image because the read-write part is also
  used to store the boot configuration in this mode
* Thu Dec  8 2011 ms@suse.de
- fixed --grub-chainload setup. In this mode the mbr from the
  master-boot-code package is used to call the grub installed
  into a partition. The code there was broken in a way that the
  filesystem on that partition was damaged
* Thu Dec  8 2011 ms@suse.de
- fixed boot device setup for split build
* Thu Dec  8 2011 ms@suse.de
- update 12.1 examples
  * there is no default pattern anymore
  * don't use recommended packages, zypper behaves strange here
    and starts to install a kernel-debug and other unwanted
    packages
* Thu Dec  8 2011 ms@suse.de
- fixed 32bit xen domU build for 12.1 JeOS template
  xen and xen-tools only exists on 64bit 12.1 distro
* Thu Dec  8 2011 rjschwei@suse.com
- update example to work with OpenNebula 3.0 packages in OBS
- open nebula example fixes regarding network detection on cloud node
- open nebula example update the 12.1 example to work with systemd
* Thu Dec  8 2011 ms@suse.de
- fixed some typos when displaying schema validation error messages
* Wed Dec  7 2011 ms@suse.de
- fixed repo file check if alias names with '/' content is used
* Wed Dec  7 2011 ms@suse.de
- fixed handling of dm devices in udev database of the
  kiwi initrd to prevent systemd to block on boot (bnc #731457)
  * try to shutdown udev with 'udevadm control --exit'
  * try to cleanup udev database with 'udevadm info --cleanup-db'
  * add persistent udev rule for dm devices
* Wed Dec  7 2011 ms@suse.de
- fixed rpmLibs() baselibs setup to use a tmp copy of
  ldconfig from the host system to allow to work with
  the other library tmp copies
* Mon Dec  5 2011 ms@suse.de
- clean up build process
  * moved swig to libsatsolver-devel. Only required if kiwi builds
    the legacy satsolver module if no perl-satsolver exists
  * removed trang to get rid of java dependency. trang is used to
    transform kiwi's rnc schema code into the rng syntax. If the
    rng is up to date the build doesn't have to create it though
  * removed obsolete Qt requirement. The tool which needed this
    is not packaged/required anymore
  * make the build work for the arm architecture
* Mon Dec  5 2011 ms@suse.de
- remove obsolete code and speedup removal of files in suseStripInitrd
* Fri Dec  2 2011 ms@suse.de
- v5.01.6 released
* Fri Dec  2 2011 ms@suse.de
- fixed changelog creation tool:
  * date string is not recognized if not from a +X timezone
  * indention of sub entries not correctly set
* Fri Dec  2 2011 rjschwei@suse.com
- fix the systemctl command for inserting and removing services for systemd
  the command is systemctl enable/disable NAME.service not service_NAME.service
* Fri Dec  2 2011 ms@suse.de
- v5.01.5 released
* Thu Dec  1 2011 ms@suse.de
- fixed suseInsertService and suseRemoveService to use
  systemctl if systemd is installed
* Wed Nov 30 2011 rjschwei@suse.com
- remove systemd specific check, systemd is the default for
  12.1, no specific entry is required in menu.lst
- add quiet commandline option in menu.lst to avoid having
  kernel message show up in the console for 12.1
* Tue Nov 29 2011 ms@suse.de
- fixed setLoopDeviceMap() to work with yaboot
* Tue Nov 29 2011 ms@suse.de
- fixed setLVMDeviceMap() to work with yaboot
* Tue Nov 29 2011 ms@suse.de
- cleanup device map setup for ppc and integrate yaboot bootloader
  setup into the setupBootLoaderStages and setupBootLoaderConfiguration
  functions like all others
* Mon Nov 28 2011 ms@suse.de
- added support for plain tar image type named 'tbz'. This image
  type just builds a bz2 compressed tarball from the prepared tree
  as requested in report (bnc #732797)
* Mon Nov 28 2011 ms@suse.de
- fixed unit test for valid arch check
* Fri Nov 25 2011 ms@suse.de
- before adding a repo check if it already exists.
  if yes remove it prior to add it
* Fri Nov 25 2011 ms@suse.de
- v5.01.4 released
* Fri Nov 25 2011 ms@suse.de
- fixed parameter quoting of setupBootLoader() functions (bnc #729315)
* Thu Nov 24 2011 ms@suse.de
- fixed unused declaration of result variable
* Thu Nov 24 2011 ms@suse.de
- sed -ie behaves differently than sed -i -e, weird
* Thu Nov 24 2011 ms@suse.de
- fixed zypper repo setup. Don't let --raw-cache-dir point to
  cache-dir. Redirecting raw-cache-dir to cache-dir makes packages/
  and solv/ appear to be orphaned raw metadata caches for ex-repos
  packages and solv. Also don't re-add the repo if it's already
  there. Just update the path for local repos to work with the
  bind mounted path inside the chroot. (bnc #731090)
* Thu Nov 24 2011 ms@suse.de
- fixed spec file to build on RHEL as well
* Thu Nov 24 2011 ms@suse.de
- added s390 pxeboot client configuration examples
* Wed Nov 23 2011 ms@suse.de
- clean up ppc code. make sure loader variable is passed to the
  yaboot configuration. Also handle partition layout and bootloader
  setup according to the bootloader value and not according to
  the architecture value
* Wed Nov 23 2011 rjschwei@suse.com
- properly handle specification of "scsi" controller type for VMWare images
  This requires the "-o scsi" option to be present for the qemu-img command
  on the build machine.
- implement new check in RuntimeChecker to verify that qemu-img supports proper
  option if controller="scsi" is specified and a vmdk image is being built
- clean KIWIRuntimeChecker to critic level 4
* Tue Nov 22 2011 ms@suse.de
- fixed --info/packages output to respect image typed packages
  sections. getInstallSize() now behaves the same like when the
  system is actually prepared
* Tue Nov 22 2011 ms@suse.de
- v5.01.3 released
* Tue Nov 22 2011 ms@suse.de
- allow initrd variable NON_PERSISTENT_DEVICE_NAMES. If set
  to a non empty string it will cause getDiskID() to return
  the non persistent kernel device node name like /dev/sda.
  This is to support storage devices with name conflicts
  when using the udev generated node names.
* Mon Nov 21 2011 ms@suse.de
- wait a second before rereading the partition table in initGeometry
* Mon Nov 21 2011 ms@suse.de
- apply quoting of .profile contents during build (bnc #729315)
* Mon Nov 21 2011 ms@suse.de
- fixed inode count calculation. Since vmmbytes is the image
  size in MB, we need to mutiply it to get the count right
  because inode ratio is in bytes/inode
* Mon Nov 21 2011 ms@suse.de
- update repo paths for kiwi specific rhel6 packages
* Mon Nov 21 2011 ms@suse.de
- fixed call of checkmedia (bnc #730763)
* Mon Nov 21 2011 ms@suse.de
- v5.01.2 released
* Mon Nov 21 2011 ms@suse.de
- fixed creation of useless udev tmpfs in udevStart() because this
  is created as devtmpfs/tmpfs properly in createInitialDevices()
  which is called in udevStart
* Mon Nov 21 2011 ms@suse.de
- in LVM case on ppc the boot partition should be fat16 (part type c)
* Sun Nov 20 2011 ms@suse.de
- shorten verification message in suse-dump
* Sun Nov 20 2011 ms@suse.de
- cleanup run-init code, prevent redundant calls
* Sun Nov 20 2011 ms@suse.de
- make sure /sbin/ifup stays in the initrd
* Fri Nov 18 2011 ms@suse.de
- prevent umount of fstab listed subvolumes before calling systemd.
  The former sysvinit did not like if another than the root filesystem
  was mounted at call time but systemd handles this differently and
  times out when processing the fstab listed entries
* Thu Nov 17 2011 ms@suse.de
- make sure fat16 is used for boot partition on ppc
* Thu Nov 17 2011 ms@suse.de
- adapt common changes in the x86 oem boot code to the ppc code
  also make sure partition table layout on ppc is the same than
  on all other architectures
* Thu Nov 17 2011 ms@suse.de
- adapt common changes in the x86 oem boot code to the s390 code
* Wed Nov 16 2011 ms@suse.de
- use $pID instead of fixed number
* Wed Nov 16 2011 ms@suse.de
- DB: rebuild documentation
* Wed Nov 16 2011 ms@suse.de
- DB: update documentation, added section about boot image customization
- DB: update documentation, added list of hook names and their meaning
* Tue Nov 15 2011 ms@suse.de
- added isoboot description for rhel/centos 6.0
* Tue Nov 15 2011 ms@suse.de
- fixed getDeleteList() to take care if a package was added as
  bootincluded that it is not removed by an entry in the delete
  type packages section. A warning message is added to the log
  file that this package is ignored in the delete list, thus it
  will be installed. This problem often appear if one added a
  package to be included in the initrd but the initrd image
  description marked this package as to be deleted
* Tue Nov 15 2011 ms@suse.de
- make sure the default strip tools and libs are appended if
  one has specified such a strip section in the system image
  description (bnc #720933)
* Tue Nov 15 2011 ms@suse.de
- added lvm2 to 12.1 JeOS
* Tue Nov 15 2011 ms@suse.de
- added support for dracut in setupRHELInitrd
* Tue Nov 15 2011 ms@suse.de
- allow strip sections to be part of the system image. This provides
  full control over the initrd striping code for items to delete and
  tools and libraries to stay (bnc #720933)
* Tue Nov 15 2011 ms@suse.de
- removed fixed strip lists from suseStripInitrd() and provide a
  default strip table in KIWIConfig.txt. There is now the strip section
  which can be of type 'delete', 'libs' or 'tools' the delete typed
  section specifies files to remove from the initrd. The tools typed
  section specifies the tool names in /bin|/sbin|/usr/bin/|/usr/sbin
  which should stay whereas all other tools in that directories are
  removed. And the libs typed section specifies those libraries which
  has to stay whereas all other libraries without any ldd reference
  are removed. (bnc #720933)
* Tue Nov 15 2011 ms@suse.de
- save some space in the initrd by removing licenses and iptables
  packages. Added them in the type="delete" sections
* Mon Nov 14 2011 ms@suse.de
- fixed typo in error message
* Sun Nov 13 2011 ms@suse.de
- fixed spec file: rhel vmxboot available on x86 and x86_64 only
* Fri Nov 11 2011 rjschwei@suse.com
- add collection of perlcritic exceptions to the statistics collector
- change collector such that only the next scan time is written and
  not he whole "old" content that does not change. New data is added to the
  file at the end
- add the doc stats collector provided by Thomas, this is not yet integrated,
  but I thought we shouldn't loose the code
- register the collector code in the hook
* Fri Nov 11 2011 ms@suse.de
- DB: rebuild documentation, mention Microsoft HyperV (vhd) format
* Fri Nov 11 2011 ms@suse.de
- update kiwi --help output to show supported vhd format
* Fri Nov 11 2011 ms@suse.de
- renamed image format vpc to vhd. vhd seems to be the well
  known name for Microsoft HyperV images (bnc #729857)
* Fri Nov 11 2011 ms@suse.de
- v5.01.1 released
* Fri Nov 11 2011 ms@suse.de
- make sure IFS is restored in fdasdGetPartitionID
* Fri Nov 11 2011 rjschwei@suse.com
- integrate unit test run into the pre-commit hook
  * if a file is changed that has an associated unit test and the
    test has not been executed after the changes were made the test is
    run prior to commit
- fix the runTest code to generate a timestamp file when a test is run and
  it succeeds
- clean up kiwiCommandLine.pm, kiwiLocator.pm, and KIWIXMLValidator.t to
  critic level 4
  * clean up used to test new hook functionality
- clean up KIWISharedMem.pm to critic level 5
  * clean up used to test new hook functionality
* Fri Nov 11 2011 ms@suse.de
- fixed type in runTests, also set execution bit on the script
* Fri Nov 11 2011 ms@suse.de
- fixed creation of initial aligned partition table in KIWIBoot.pm
  In SuSE studio the loop device which is normally the target for
  parted is relinked behind the scene to a virtio device. As result
  parted now sees a real disk geometry and that induced the bug in
  kiwi which is not visible if it operates on the file mapped loop
  device only. Looking at that partition code has turned out that
  the alignment is broken which in the end broke the repartition
  process in the first boot of an oem install image. The code is
  now fixed to work properly on any storage device (bnc #729636)
* Thu Nov 10 2011 rjschwei@suse.com
- modify Makefile to create timestamp files when tests are run
- add .gitignore file to ignore timestamp files and timestamp directory
- implement trigger files
  * each trigger file contains a list of tests that should be run when
    the module with the equivalent name is changed. For example if KIWIXML.pm
    changes, the tests listed in KIWIXML.trig will be run
- implement runTests
  * contains the logic to execute tests as needed based on the trigger files
    and dependent on the timestamps
  * this script needs to be integrated into the pre-commit hook to assure the
    appropriate tests get run prior to commit
* Thu Nov 10 2011 ms@suse.de
- update rng schema due to last change in rnc
* Thu Nov 10 2011 ms@suse.de
- fixed fdasdGetPartitionID() it was completely broken.
  The function evaluates the wrong information and was
  also syntactically wrong... I should tell myself each
  day 'never code in a hurry'
* Thu Nov 10 2011 rjschwei@suse.com
- add Perl module compile check to pre-commit hook
  * any Perl file (ending in .t, .pl, .pl that is changed is run through
    "perl -wc" prior to commit to assure the code at least builds
- clean the KIWIArchlist module to critic level 5 and fix the style
  to match the rest of the code
* Thu Nov 10 2011 ms@suse.de
- fixed parameter quoting in setupBootLoader (bnc #729315)
* Thu Nov 10 2011 rjschwei@suse.com
- fix unit tests
  * earlier update of ktLog broke the tests due to initialization problem
    with q{ } vs q{}, the later producing an empty string, the former a
    string with one space character, thus not empty. Empty string
    initialization is required in other parts of the code.
* Thu Nov 10 2011 rjschwei@suse.com
- include new EC2 region (US-West2), update the EC2 kernel IDs to the newly released v1.02 IDs, update code and docs, also fix the regular expression in hook to properly deal with .txt extension, i.e. ignore those files
* Thu Nov 10 2011 rjschwei@suse.com
- fix compile error (errant character g at EOL)
* Wed Nov  9 2011 ms@suse.de
- make sure partedSectorInit() comes up with an initial value for
  the start sector if the partition table is empty (bnc #729251)
* Wed Nov  9 2011 ms@suse.de
- turn all fixed flaged http:// URI's in the x86 boot images into
  more flexible obs:// URI's
* Wed Nov  9 2011 ms@suse.de
- if an obs:// path can't be resolved, turn it into an opensuse path
  and try again. That way you can use one URI to build the image
  inside the buildservice and also outside with network access
* Wed Nov  9 2011 ms@suse.de
- changed cache creation. the cache is created from the image
  description referenced by --init-cache and we prevent the
  split into packages and patterns and the weird cache template
  in modules/KIWICache.kiwi. This allows to create cache only
  image descriptions whose only purpose is to create caches
* Wed Nov  9 2011 ms@suse.de
- fixed doubled my declaration of the same variable
* Wed Nov  9 2011 rjschwei@suse.com
- level 5 critic clean up, fix up the level 5 list in the hook
* Wed Nov  9 2011 rjschwei@suse.com
- level 5 clean up of Collect and style clean up to make it match the style of the rest of the KIWI code
* Tue Nov  8 2011 ms@suse.de
- remove tmpdir directory only if it exists
* Tue Nov  8 2011 ms@suse.de
- fixed setLogFile path writable check (bnc #728885)
* Tue Nov  8 2011 ms@suse.de
- removed dead code in iso boot code due to the removal of
  the swap file support (bnc #728645)
* Tue Nov  8 2011 ms@suse.de
- added options --xattrs and --acls when using rsync
* Tue Nov  8 2011 ms@suse.de
- fixed importFile to filter out empty lines and also match
  comment lines starting with space/tab before '#' (bnc #728357)
* Tue Nov  8 2011 ms@suse.de
- use mktemp to create tmp dir in setupInstallFlags
* Tue Nov  8 2011 ms@suse.de
- v4.99.1 released
* Tue Nov  8 2011 ms@suse.de
- fixed importFile to allow '\' characters (bnc #728357)
* Tue Nov  8 2011 rjschwei@suse.com
- work on critic level 5 clean up, this is mostly low hanging fruit.
  Also cleaned up the level 5 list in the hook for files that were
  already level 5 clean
* Tue Nov  8 2011 rjschwei@suse.com
- include test code in perlcritic checks, clean ktTestCase to level 3
* Mon Nov  7 2011 ms@suse.de
- critic: ktLog.pm now at level 2
- critic: KIWIXMLValidator.pm now at level 5
- critic: added .perlcriticrc with following settings:
  * allow mixed case naming
  * no check for module VERSION
  * disable check for RCS strings
* Mon Nov  7 2011 ms@suse.de
- fixed importFile() to correctly match variable names and
  make it more robust against quoting issues (bnc #728357)
* Mon Nov  7 2011 ms@suse.de
- make sure importFile() stays backward compatible and ensures
  proper quoting. Also make sure the prefixed variable copy is
  only created if a prefix was set (bnc #728357)
* Mon Nov  7 2011 ms@suse.de
- switch from tar to rsync based copies. Reason for the change is
  because tar doesn't support file attributes like xattr,acls
  and fscaps (bnc #728312)
* Mon Nov  7 2011 ms@suse.de
- removed left over debug message from KIWIXMLValidator.pm
* Mon Nov  7 2011 ms@suse.de
- DB: rebuild documentation
* Mon Nov  7 2011 ms@suse.de
- DB: update documentation, correct quoting for config.<MAC>
* Mon Nov  7 2011 ms@suse.de
- DB: rebuild documentation
* Mon Nov  7 2011 ms@suse.de
- DB: update documentation, correct quoting for config.<MAC>
* Mon Nov  7 2011 ms@suse.de
- don't create a swap file if no swap partition can be found in
  the live iso boot code. people complained about the creation
  of swap files while this is not expected.
* Sun Nov  6 2011 ms@suse.de
- fixed setupNetworkInterfaceS390 qeth_configure execution
- added setupNetworkInterfaceS390 to s390 netboot preinit
  to create the relevant udev rules
* Sun Nov  6 2011 rjschwei@suse.com
- initial implementation of code statistics collector
* Sat Nov  5 2011 rjschwei@suse.com
- added git pre-commit hook to check the code with perlcritic
  git hooks are placed as source in the git in '.git-hooks'
- put KIWIURL module to level 5
- put KIWILocator module to level 4
* Sat Nov  5 2011 rjschwei@suse.com
- clean up to level 5 perlcritic, also found some syntax errors
* Fri Nov  4 2011 rjschwei@suse.com
- added new chapter providing basic installation instructions
* Thu Nov  3 2011 ms@suse.de
- v4.98.14 released
* Thu Nov  3 2011 ms@suse.de
- fixed check for empty variable in shell code
* Thu Nov  3 2011 ms@suse.de
- v4.98.13 released
* Thu Nov  3 2011 ms@suse.de
- setupDefaultGateway uses route but route was not part of the initrd
* Thu Nov  3 2011 ms@suse.de
- fdasdGetPartitionID uses awk but awk was not part of the initrd
* Thu Nov  3 2011 ms@suse.de
- moved hook calls pre/postpartition outside of the block
  which allows to skip the partition code via the hook
  script
* Wed Nov  2 2011 ms@suse.de
- fixed repartition code to create an aligned table (bnc #721580)
* Mon Oct 31 2011 ms@suse.de
- setup PXE_IFACE interface only if PXE_IFACE exists in the
  environment. When using zPXE this variable does not exist
* Mon Oct 31 2011 ms@suse.de
- fixed setupNetworkStatic to write correct interface file
* Mon Oct 31 2011 ms@suse.de
- removed static inittab and securetty overlay files from s390
  JeOS template. The setup is done by setupConsole() in preinit
* Mon Oct 31 2011 ms@suse.de
- call runPreinitServices in s390 netboot suse-preinit
* Mon Oct 31 2011 ms@suse.de
- turn pxe PART info tranformation functions into a generic
  and a fdasd specific function
* Mon Oct 31 2011 ms@suse.de
- added pxePartitionInputS390 suitable for use with fdasd
* Mon Oct 31 2011 ms@suse.de
- added pxeRaidPartitionInputS390 suitable for use with fdasd
* Mon Oct 31 2011 ms@suse.de
- v4.98.12 released
* Mon Oct 31 2011 ms@suse.de
- s390 netboot:
  * make sure the VTOC table is created prior to any fdasd call
  * make sure searchBusIDBootDevice is called to set the device
    in $DISK online by a custom DEVICE_INIT command
* Mon Oct 31 2011 ms@suse.de
- added support for custom s390 device init command in the
  searchBusIDBootDevice function. This is required if the s390
  client was not booted by an ipl command but e.g. via zPXE
* Sun Oct 30 2011 ms@suse.de
- fixed migration code:
  * fixed creation of URL list from zypper information
  * write current schema version (5.3) XML
  * fixed creation of KIWISatSolver objects
* Sat Oct 29 2011 ms@suse.de
- added support for Microsoft Hyper-V machine image format
  <type ... format="vpc"/>. This requires a qemu version
  which supports the vpc format conversion (fate# 309765)
* Sat Oct 29 2011 ms@suse.de
- fixed migration module to work again. Added 11.4 and 12.1 paths
  and make sure the global object pointer is there when it is
  accessed
* Fri Oct 28 2011 ms@suse.de
- v4.98.11 released
* Fri Oct 28 2011 ms@suse.de
- make sure the seq command is part of the initrd
  used in convertCIDRToNetmask()
* Thu Oct 27 2011 ms@suse.de
- make sure pxeSetupDownloadServer() uses a deadline of 30sec
  in the ping check. Otherwise it might happen that the server
  online check fails even though the machine is online
* Thu Oct 27 2011 ms@suse.de
- v4.98.10 released
* Thu Oct 27 2011 ms@suse.de
- removed __checkNameValid() checker function and make sure
  that an arch string as part of the name attribute doesn't
  cause any trouble (bnc #716992)
* Thu Oct 27 2011 ms@suse.de
- v4.98.9 released
* Thu Oct 27 2011 ms@suse.de
- arch check in __checkNameValid is too restrictive
* Thu Oct 27 2011 ms@suse.de
- v4.98.8 released
* Thu Oct 27 2011 ms@suse.de
- fixed quoting of parameters in config.isoclient
* Thu Oct 27 2011 ms@suse.de
- DB: update documentation
* Thu Oct 27 2011 ms@suse.de
- reverted commit 620e4e65d05b257e4fc8c6017908e6ba9f75e28e
  this was a parted bug which is now fixed
* Thu Oct 27 2011 rjschwei@suse.com
- add unit test to the locator for the createTmpDirectory
  method, change one of the messages from info to error in
  the locator, update my e-mail address
* Thu Oct 27 2011 rjschwei@suse.com
- change URL in spec file to point to the new homw of the source, github vs. berlios
* Thu Oct 27 2011 rjschwei@suse.com
- generated html doc
* Wed Oct 26 2011 ms@suse.de
- v4.98.7 released
* Wed Oct 26 2011 ms@suse.de
- fixed appliance name escaping. One can use any string for
  the displayname attribute which is now properly escaped
  via perl's quotemeta(). Along with this change the image
  name attribute must match the pattern [a-zA-Z0-9_\-\.]
  and is not allowed to have the architecture string
  as part of the name (bnc #716992)
* Wed Oct 26 2011 rjschwei@suse.com
- add section about cross platform build, expand the introductory section of chapter 4
* Wed Oct 26 2011 ms@suse.de
- v4.98.6 released
* Wed Oct 26 2011 ms@suse.de
- libcrc32 module depends on crc32c, but it does not state this dependency
  explicitely (modules.dep does not contain this information). Since KIWI
  relies od modules.dep to clean up unused modules in the initrd, this can
  break module loading. This patch ensures that the module is kept in the
  initrd and not purged.
* Wed Oct 26 2011 ms@suse.de
- revert back to parted hex id's, this reverts commits:
  47f8bf758861a3d8cdbc2c188024f423e6ee45db
  47f8bf758861a3d8cdbc2c188024f423e6ee45db
* Wed Oct 26 2011 ms@suse.de
- v4.98.5 released
* Wed Oct 26 2011 ms@suse.de
- fixed creation of XML diff in log file
* Wed Oct 26 2011 ms@suse.de
- fixed parted flag setup in KIWILinuxRC code, 12.1 and upstream
  parted doesn't support the hex id's like 'set type 0x..'
* Wed Oct 26 2011 ms@suse.de
- fixed KIWIXMLInfo unit test due to last --info changes
* Wed Oct 26 2011 ms@suse.de
- call createURLList() only on demand. Also provide accessor
  methods for xml->{urllist} and xml->{urlhash}, don't access
  these object data directly anymore. createURLList() was called
  in the KIWIXML constructor but changes to the XML might happen
  at a later point in time. So it makes sense to build the final
  URL list when access to it is requested
* Tue Oct 25 2011 ms@suse.de
- call setupNetworkStatic in suse-preinit for s390. With this
  change we write the network configuration as received by
  the initrd into the system config files below /etc/sysconfig
* Tue Oct 25 2011 ms@suse.de
- added function convertCIDRToNetmask() which allows the interpretation
  of the CIDR extension like 192.168.1.1/24 to create a standard netmask
  255.255.255.0 out of it.
* Tue Oct 25 2011 ms@suse.de
- fixed use of uninitialized value $free in KIWIXML.pm
* Tue Oct 25 2011 ms@suse.de
- make the info module write the imagescan XML into a tmpfile (bnc #726337)
* Tue Oct 25 2011 ms@suse.de
- added log information about cylinder size and count
- fixed parted flag setup, 12.1 and upstream parted doesn't
  support the hex id's like 'set type 0x..'
* Mon Oct 24 2011 ms@suse.de
- fixed default boot label selection in syslinux mode
* Mon Oct 24 2011 ms@suse.de
- added support for overlay file and archive listing in info module
* Fri Oct 21 2011 ms@suse.de
- fixed escaping of chown parameters (bnc #725706)
* Thu Oct 20 2011 ms@suse.de
- added update repo path for 11.4 images due to grub bug (bnc #717836)
* Wed Oct 19 2011 ms@suse.de
- check for FSTYPE == btrfs in createOriginSnapshot()
* Wed Oct 19 2011 ms@suse.de
- fixed creation of btrfs origin snapshot. This is now done
  on first boot of the appliance and not after kiwi prepare
* Wed Oct 19 2011 ms@suse.de
- added baseSetupBtrfsOrigin() function which allows to add
  an origin snapshot for the image root filesystem contents
* Tue Oct 18 2011 ms@suse.de
- moved README to mkd style
* Tue Oct 18 2011 ms@suse.de
- adapt README style
* Tue Oct 18 2011 ms@suse.de
- v4.98.4 released
* Tue Oct 18 2011 ms@suse.de
- fixed disk device setup in USB stick install mode
* Tue Oct 18 2011 ms@suse.de
- added init=... bootloader setup if systemd is used
* Tue Oct 18 2011 ms@suse.de
- v4.98.3 released
* Tue Oct 18 2011 ms@suse.de
- update German translation .po file
* Tue Oct 18 2011 ms@suse.de
- make sure locale .mo files are created
* Tue Oct 18 2011 ms@suse.de
- update locale headers
* Tue Oct 18 2011 ms@suse.de
- added support for setting up which volume should get the
  rest free space assigned in a LVM setup. Example:
  <systemdisk>
  <volume name="/var" freespace="all"/>
  </systemdisk>
  This will assign the rest space available in the volume
  group to the LVvar logical volume. rest space means either
  the size of the 'oem-systemsize' element or if not set
  the entire rest space of the disk. If no 'all' freespace
  attribute is set in the volume setup, the default volume
  LVRoot is used as before (bnc #724489)
* Mon Oct 17 2011 ms@suse.de
- added clicfs COW file check prior to mounting it via clicfs_fsck
  if the check fails we disable persistent writing
* Mon Oct 17 2011 ms@suse.de
- v4.98.2 released
* Mon Oct 17 2011 ms@suse.de
- renamed suse-live-stick to suse-live-usbstick to allow package
  upgrade again. Details in (bnc #722452)
* Mon Oct 17 2011 ms@suse.de
- prefer systemd over sysvinit if installed
* Mon Oct 17 2011 ms@suse.de
- don't use --ignore-cow-errors when using a cow _file_
* Mon Oct 17 2011 ms@suse.de
- make sure setupHybridPersistent() is called before the
  boot device is busy
* Mon Oct 17 2011 ms@suse.de
- added missing __checkImageIntegrity() calls
* Mon Oct 17 2011 ms@suse.de
- v4.98.1 released
* Mon Oct 17 2011 ms@suse.de
- update XML data to new schema version 5.3
* Mon Oct 17 2011 ms@suse.de
- fixed kiwiRuntimeChecker unit tests
* Mon Oct 17 2011 ms@suse.de
- added a 30 sec timeout to searchBIOSBootDevice
* Sat Oct 15 2011 ms@suse.de
- make searchBiosBootDevice more robust. The function probes
  for the boot device until found and does not expect all
  storage devices to be present at call time. There is still
  a problem in install mode where we need a list of all
  potential installation devices to be present at a certain
  point in time. The function waitForIdleEventQueue tries
  to address this but it's not race free
* Sat Oct 15 2011 rjschwei@suse.com
- revamp the EC2 chapter, include instructions for using EBS, restructure organization
* Sat Oct 15 2011 rjschwei@suse.com
- change ec2region values to match reported regions from ec2-describe-regions comand, AP-Japan -> AP-Northeast, AP-Singapore -> AP-Southeast, change schema version to 5.3 to reflect the value change, implement xml convert from 5.2 to 5.3, update the tests and validation
* Fri Oct 14 2011 ms@suse.de
- xen dom0 support exists only for x86_64 architecture in
  SLE11 SP2. Therefore we check for this arch in the boot
  image descriptions
* Fri Oct 14 2011 ms@suse.de
- run 'make valid' and store XML style changes
* Fri Oct 14 2011 rjschwei@suse.com
- fix repository path for EC2 repo in 11.3 EC2 example
* Fri Oct 14 2011 ms@suse.de
- v4.97.5 released
* Thu Oct 13 2011 ms@suse.de
- xen dom0 support exists only for x86_64 architecture in
  SUSE 12.1. Therefore we check for this arch in the boot
  image descriptions
* Thu Oct 13 2011 ms@suse.de
- fetchFile does not handle special characters consistently.
  fetchFile "some%%20file" with atftp correctly downloads 'some%%20file'.
  but with ftp curl converts the file name to 'some file', which is
  not expected. This patch fixes this and makes the behavior
  consistent
* Wed Oct 12 2011 ms@suse.de
- fixed use of uninitialized $count variable (bnc #455990)
* Wed Oct 12 2011 ms@suse.de
- don't ignore size setup even if the size is smaller than the min size
  kiwi's min size is safe but includes spare space. people who want to
  overwrite that size can do it but on their own risk
* Wed Oct 12 2011 ms@suse.de
- allow drivers section in the system image which will be
  added to the drivers section of the selected boot image.
  This allows to add custom driver information additional
  to the existing driver selection as part of the boot
  image (bnc #720933)
  Author: Marcus SchÃ¤fer <show>
* Wed Oct 12 2011 ms@suse.de
- fixed size calculation, use 4%% overhead
* Wed Oct 12 2011 ms@suse.de
- removed function waitForUSBDeviceScan and added new function
  waitForIdleEventQueue which waits for a specific amount of time
  to check whether new device nodes settle or not. if not the
  function will return
* Tue Oct 11 2011 ms@suse.de
- removed obsolete files from the suse-11.3 examples
* Tue Oct 11 2011 ms@suse.de
- added preException hook which runs inside the systemExcpetion
  function to allow further tasks before the exception message
  is printed and the shell/reboot/wait action happens
* Tue Oct 11 2011 ms@suse.de
- fixed the check for the installed system in the netboot code
  if the luks encryption is used. The check calls luksOpen with
  luks_open_can_fail=yes. This means if the wrong passphrase is
  given the check will proceed with 'update is required' and
  does not fail with a reboot exception in luksOpen
* Tue Oct 11 2011 ms@suse.de
- added hooks preswap/postswap which run before the check and
  creation of the imageSwapDevice. This allows to setup your
  own swap device handling.
* Tue Oct 11 2011 ms@suse.de
- allow luksOpen to fail if luks_open_can_fail is set
- allow map name to be specified in luksClose
* Tue Oct 11 2011 ms@suse.de
- fixed updateOtherDeviceFstab to make use of the prefix argument
* Mon Oct 10 2011 ms@suse.de
- don't show the LUKS passphrase as part of the boot log
* Mon Oct 10 2011 ms@suse.de
- fixed vgchange calls to take the volume group name as argument
* Mon Oct 10 2011 ms@suse.de
- fixed multiple display of the same info messages when
  creating the virtual disk file
* Mon Oct 10 2011 ms@suse.de
- added a workaround for the cylinder counting bug in parted.
  parted lists two different numbers for the amount of cylinders
  only one is correct. This patch uses the correct value displayed
  here. parted only shows different values if called on a loop
  device
* Sun Oct  9 2011 ms@suse.de
- make suse-live-stick a real image example directory and not
  a link to the live iso description. This also fixes the upgrade
  problem between versions were suse-live-stick was a directory
  and the one were it is provided as a link (bnc #722452)
* Fri Oct  7 2011 ms@suse.de
- v4.97.4 released
* Fri Oct  7 2011 ms@suse.de
- make sure updateOtherDeviceFstab creates the mount point
* Fri Oct  7 2011 ms@suse.de
- activate only volume group stored in $VGROUP, prevent vgscan
* Fri Oct  7 2011 ms@suse.de
- fixed luksOpen to generate unique name for luksroot
- fixed luksOpen to stop asking for the passphrase after 3 times
- fixed updateOtherDeviceFstab to work in luks and/or RAID env
- fixed luksOpen to wait until the mapper created the device
- allow luks_pass to be set on the kernel commandline
* Thu Oct  6 2011 ms@suse.de
- DB: rebuild documentation
* Thu Oct  6 2011 ms@suse.de
- fixed race conditions in LOCAL_BOOT=yes code, we have to
  wait for the $disk device to appear before acting on it
* Thu Oct  6 2011 ms@suse.de
- removed %%pre section from spec, does not work with older distros
* Thu Oct  6 2011 ms@suse.de
- fixed %%pre script and filelist
* Thu Oct  6 2011 ms@suse.de
- fixed doc upgrade, added pre-install script for kiwi-doc
  and also reverted the spec changes for the commits 275a601c
  and ced64858
* Thu Oct  6 2011 ms@suse.de
- v4.97.3 released
* Thu Oct  6 2011 rjschwei@suse.com
- correct attribute name error, some word smithing around <systemdik> description
* Wed Oct  5 2011 ms@suse.de
- added support for detecting multiple occurrences of the same
  MBR ID in searchBIOSBootDevice. Also make sure that this does
  not happen by writing a default MBR ID of 0xffffffff into
  the MBR when the bootloader is installed
* Wed Oct  5 2011 ms@suse.de
- rewrote function CDMount into more clear parts, also fixed
  the waitForUSBDeviceScan which only checks dmesg for a string
  which doesn't appear anymore on newer kernels
* Wed Oct  5 2011 ms@suse.de
- DB: update documentation, better intro page and contributor list
* Wed Oct  5 2011 ms@suse.de
- added support for creating luks encoded squashfs images
* Tue Oct  4 2011 ms@suse.de
- make sure luks devices are evaluated first
* Tue Oct  4 2011 ms@suse.de
- added level sorting for LVM volumes to make sure e.g /opt is
  mounted before /opt/bob
* Tue Oct  4 2011 ms@suse.de
- fixed spec file, make sure doc files get the %%doc macro assigned
* Tue Oct  4 2011 ms@suse.de
- fixed spec file, wrong use of %%doc on directory causes
  the kiwi-doc package to fail the installation on upgrade
  with 'cpio: rename failed - Is a directory'
* Tue Oct  4 2011 ms@suse.de
- fixed typo, missing eol
* Tue Oct  4 2011 ms@suse.de
- added mailing list info to README file
* Tue Oct  4 2011 ms@suse.de
- fixed typo and wrote Linus correctly, Oh Oh sorry Linus
* Thu Sep 29 2011 ms@suse.de
- make setupConsole code more clear
* Thu Sep 29 2011 ms@suse.de
- let kiwi exit if a package setup script returns with ecode != 0
* Wed Sep 28 2011 ms@suse.de
- DB: update documentation, new showlicense element
* Wed Sep 28 2011 ms@suse.de
- added support for the new <showlicense>name</showlicense> element as
  part of the preferences section. This element allows to specify the
  base name of a license file which is displayed in oem images before
  the installation happens. It's possible to add more <showlicense>
  sections to display more licenses one after the other. If no such
  element is specified the default 'license' and 'EULA' files are
  searched to keep the system backward compatible
* Wed Sep 28 2011 ms@suse.de
- added runtime check which makes sure that there are no bogus
  files included in archives. So far we check for YaST2 license
  files in /etc/YaST2/licenses
* Tue Sep 27 2011 ms@suse.de
- added support for RHEL splashimage (redhat-logos)
* Fri Sep 23 2011 ms@suse.de
- v4.97.2 released
* Fri Sep 23 2011 ms@suse.de
- fixed RHEL authentication setup
* Fri Sep 23 2011 ms@suse.de
- fixed typo in perl to bash list dereferencing
* Thu Sep 22 2011 ms@suse.de
- use generic vgchange -an in cleanLoop to make sure the loop maps
  can be cleaned up even if we can't read the name of the volume
  group from the image
* Thu Sep 22 2011 ms@suse.de
- fixed sysconfig template check to work on RHEL too
- fixed init call for RHEL, does not work with run-init program
* Thu Sep 22 2011 ms@suse.de
- added kernel to be installed in rhel-05.4-JeOS template
* Thu Sep 22 2011 ms@suse.de
- fixed use of uninitialized value
* Thu Sep 22 2011 ms@suse.de
- make sure mpath_wait program exists in initrd for RHEL
* Thu Sep 22 2011 ms@suse.de
- fixed missing done flag for info message
* Thu Sep 22 2011 ms@suse.de
- make sure loop module is loaded
* Thu Sep 22 2011 ms@suse.de
- applied following changes to the ppc boot code
  * fixed download of md5 file in oem pxe install mode
  * make sure iputils is there in oemboot for pxe based installation
  * allow installation via the kiwi install image into a ramdisk.
* Thu Sep 22 2011 ms@suse.de
- fixed s390 netboot code:
  * make sure there is also a lowercase version of cmdline params
  * make sure cleanPartitionTable is called before setup
  * make sure setupNetworkStatic also brings up the network
* Thu Sep 22 2011 ms@suse.de
- applied following changes to the s390 boot code
  * fixed download of md5 file in oem pxe install mode
  * make sure iputils is there in oemboot for pxe based installation
  * allow installation via the kiwi install image into a ramdisk.
* Wed Sep 21 2011 ms@suse.de
- fixed download of md5 file in oem pxe install mode
* Wed Sep 21 2011 ms@suse.de
- make sure iputils is there in oemboot for pxe based installation
* Tue Sep 20 2011 ms@suse.de
- use ext3 filesystem for the boot partition
* Tue Sep 20 2011 ms@suse.de
- make sure system filesystems like proc and friends
  are umounted in rhel-preinit
* Mon Sep 19 2011 ms@suse.de
- allow long names in install iso images (-joliet-long)
  This is related to (bnc #716149)
* Mon Sep 19 2011 adrian@suse.de
  [product] unpack themes in defined order
* Fri Sep 16 2011 ms@suse.de
- v4.97.1 released
* Fri Sep 16 2011 ms@suse.de
- fixed baseSetRunlevel() to work with systemd as well
* Fri Sep 16 2011 ms@suse.de
- don't use fuser -k to kill the debug shell, that could cause
  the kill of other important processes like the fuse clicfs
* Fri Sep 16 2011 ms@suse.de
- allow default path search for --init-cache too
* Fri Sep 16 2011 ms@suse.de
- removed local s390 suse repo
* Fri Sep 16 2011 ms@suse.de
- added SLE11 SP2 SDK repo for s390 boot images in order to receive
  the kiwi-tools package from there
* Tue Sep 13 2011 ms@suse.de
- allow installation via the kiwi install image into a ramdisk.
  In order to activate this feature one has to specify the
  following on the kernel commandline: 'ramdisk=1' The size
  of the ramdisk can be set by ramdisk_size=<value-in-byte>
  This fixes bug (bnc #717499)
* Mon Sep 12 2011 ms@suse.de
- removed local x86 suse and rhel repo
* Mon Sep 12 2011 ms@suse.de
- added 11.4 remote repo for oemboot
* Mon Sep 12 2011 ms@suse.de
- moved RHEL5 repo from local to remote
* Mon Sep 12 2011 ms@suse.de
- moved SLE11 repo from local to remote
* Mon Sep 12 2011 ms@suse.de
- removed local kiwi repo from ppc boot images. There are
  no ppc packages provided in a repo by kiwi
* Mon Sep 12 2011 ms@suse.de
- moved SLE10 repo from local to remote
* Mon Sep 12 2011 ms@suse.de
- fixed __getPartID reg exp (bnc #716718)
* Sun Sep 11 2011 ms@suse.de
- more colorful list image output
* Fri Sep  9 2011 ms@suse.de
- v4.96.1 released
* Thu Sep  8 2011 ms@suse.de
- DB: update documentation
* Thu Sep  8 2011 ms@suse.de
- fixed addPackages. Only if the requested packages type
  was 'image' it's allowed to add to 'bootstrap' if there
  is no 'image' typed packages section
* Thu Sep  8 2011 ms@suse.de
- consistency fix for the vmxboot boot image descriptions.
  all kernels should belong to the same typed packages section
* Thu Sep  8 2011 ms@suse.de
- added new option '--edit-bootconfig <file>' and the XML
  attribute <type ... editbootconfig="file"/> which allows to
  run a script before the bootloader is actually written.
  This allows custom changes to the bootloader setup files
  as requested in (bnc #667950)
* Wed Sep  7 2011 ms@suse.de
- make use of devtmpfs if available
* Wed Sep  7 2011 adrian@suse.de
- This breaks multi arch medias, we need more complex solution here
  Revert "- priorize repositories over fallback architectures"
  This reverts commit ce611d35662473365cebdc41172653d287bcaa0e.
* Wed Sep  7 2011 ms@suse.de
- fixed addPackages() function. In case the requested section
  type cannot be found the function will switch back to the
  bootstrap section.
* Wed Sep  7 2011 ms@suse.de
- put isoboot kernel-rt package to bootstrap section.
* Wed Sep  7 2011 ms@suse.de
- don't show output of pushd / popd in updateMTAB
* Wed Sep  7 2011 ms@suse.de
- create mtab link in kiwi's chroot instead of touching an empty file
* Wed Sep  7 2011 ms@suse.de
- fix updateMTAB() to create a /etc/mtab symlink if /proc/self/mounts
  exists. Otherwise leave /etc/mtab untouched
* Mon Sep  5 2011 ms@suse.de
- use the same version of suse-dump for ppc and s390 arch
* Mon Sep  5 2011 ms@suse.de
- the by-id device names can contain the ':' sign which causes
  trouble when kiwi uses the same sign as data separator. This
  patch solves the problem for the evaluation of the instItems
  array in the suse-dump code
* Mon Sep  5 2011 ms@suse.de
- add priority to the repository to the boot config of RHEL iso
  images. This will resolve the conflicts with the kiwi-tools
  package while creating the boot image.
* Mon Sep  5 2011 ms@suse.de
- added support for vmxboot for RHEL 5.4. Thanks to Praveen
* Fri Sep  2 2011 ms@suse.de
- v4.95.4 released
* Fri Sep  2 2011 ms@suse.de
- fixed warning when checking for rpc_pipefs (bnc #711389)
* Fri Sep  2 2011 ms@suse.de
- fixed checkLVMbind() to search for the lvm flag on the disk
  first. Only if the disk has that flag we search for the LVM
  devices.
* Thu Sep  1 2011 ms@suse.de
- last commit causes a regression for non split types.
* Thu Sep  1 2011 ms@suse.de
- fixed bootloader setup for split images
* Thu Sep  1 2011 ms@suse.de
- added missing done() flag
* Wed Aug 31 2011 adrian@suse.de
- product build: avoid multiple handling of debug packages
* Wed Aug 31 2011 adrian@suse.de
- priorize repositories over fallback architectures
* Tue Aug 30 2011 ms@suse.de
- more readable 'kiwi --list' output
* Tue Aug 30 2011 ms@suse.de
- make sure $prio variable is initialized empty for
  each repo validation (bnc #714927)
* Tue Aug 30 2011 ms@suse.de
- fixed inline description of addRepository() function
* Sat Aug 27 2011 ms@suse.de
- v4.95.3 released
* Sat Aug 27 2011 ms@suse.de
- fixed BuildArch setup for sle11 build
* Sat Aug 27 2011 ms@suse.de
- v4.95.2 released
* Sat Aug 27 2011 ms@suse.de
- DB: rebuild schema documentation
* Sat Aug 27 2011 ms@suse.de
- DB: rebuild documentation
* Sat Aug 27 2011 ms@suse.de
- DB: update documentation concerning the new imageinclude attribute
* Sat Aug 27 2011 ms@suse.de
- added a new attribute to the <repository> element called
  'imageinclude', a boolean. The code treats the attribute
  as having a "false" default value. When set to true (for
  using zypper package manager only at this point) the specified
  repository is added to the image being created, thus the
  repo is available to install additional packages or upgrade
  existing packages from within the running image.
* Sat Aug 27 2011 ms@suse.de
- cleanup XML data from example image descriptions by the
  result of the kiwi XML pretty printer
* Sat Aug 27 2011 ms@suse.de
- added RHEL/CentOS 5.x. compatible repodata for rhel-repo
* Sat Aug 27 2011 ms@suse.de
- fixed %%post for kiwi-templates. %%post has to use the
  same ifarch selection as used by the %%package section
* Fri Aug 26 2011 ms@suse.de
- v4.95.1 released
* Wed Aug 24 2011 ms@suse.de
- better version of baseSetupBootLoaderCompatLinks()
  which hardlinks the files to be able to access them
  from within the cpio archive
* Wed Aug 24 2011 ms@suse.de
- make sure to have some spare space in filesystem images
* Wed Aug 24 2011 ms@suse.de
- don't remove data from initial boot partition
* Wed Aug 24 2011 ms@suse.de
- call setupBootPartition() only if systemIntegrity is != fine
- clean up setupBootPartition, create mount points inside the initrd
- clean up netboot code, setup bootid before mountSystem and let
  setupBootPartition do the setup of the boot contents
* Wed Aug 24 2011 ms@suse.de
- added support for pxe luks encrypted images
* Wed Aug 24 2011 ms@suse.de
- break up long code line into two
* Wed Aug 24 2011 ms@suse.de
- added compat link menu.lst -> grub.conf, required by RHEL
- added function baseSetupBootLoaderCompatLinks() which can
  be used to create the /usr/share/grub link to the stage
  files which kiwi expects in /usr/lib/grub. RHEL installs
  them in /usr/share/grub
* Tue Aug 23 2011 ms@suse.de
- added parted 1.8.7 to RHEL5.4 repo
* Tue Aug 23 2011 ms@suse.de
- fixed boot code: explicitly wait until the background
  job showing the progress information has finished
* Tue Aug 23 2011 ms@suse.de
- let atftpProgress() read output directly so there is just one job
- fixed fetchFile(): enable progress only for block devices, without
  this it showed the progress for md5 and other files when the first
  image download failed.
- fixed fetchFile(): fbiterm does not work with serial console, added
  fallback when it fails
- fixed fetchFile(): loadCode value from the background job is
  returned correctly now
* Tue Aug 23 2011 ms@suse.de
- changed the image size calculation to leave not too much of
  free space. In case of a filesystem based image as less free
  space as possible is added. In case of a disk image we make
  sure to have ~100MB of free space. If a single boot partition
  is required we make sure to have min 150M to allow proper
  kernel updates
* Tue Aug 23 2011 ms@suse.de
- make sure atftpProgress() finishes _after_ the atftp process has
  concluded the download, related to (bnc #713167)
* Tue Aug 23 2011 ms@suse.de
- use $imageBlkSize as parameter for atftpProgress()
- take care for handling of re-sent blocks in atftpProgress()
- fixed atftp error output handling $TRANSFER_ERRORS_FILE vs. /tmp/atftp_trace
- fixed atftp blocksize detection - with multicast the block number 1
  does not have to be at the beginning
* Tue Aug 23 2011 ms@suse.de
- added kiwi-media-requires meta package which recommends all
  packages which should be part of the distribution DVD
* Tue Aug 23 2011 ms@suse.de
- rpmlint doesn't like empty files
* Tue Aug 23 2011 ms@suse.de
- added atftpProgress() function which implements the progress
  information for atftp by watching the atftp trace output.
  atftp seeks in the output stream which forbids the use of
  pipes for the progress information (bnc #713167)
* Mon Aug 22 2011 ms@suse.de
- make sure fribidi stays installed in netboot. It's required for
  the fbiterm based progress information (bnc #713173)
* Mon Aug 22 2011 ms@suse.de
- don't use pipes in combination with atftp (bnc #713167)
* Mon Aug 22 2011 ms@suse.de
- fixed typo, missing '\n' in info output
* Fri Aug 19 2011 ms@suse.de
- v4.94.3 released
* Fri Aug 19 2011 ms@suse.de
- don't remove netcfg from boot images. This would remove the
  etc/hosts file which might be required. Along with this change
  also fixed the cleanupResolvConf() function which has to
  reset the needResolvConf and needHosts flags in order to prevent
  a deletion at a later point in time (bnc #713158)
* Fri Aug 19 2011 ms@suse.de
- don't call restoreCDRootData() and restoreSplitExtend()
  inside the global destructor of the KIWIImageCreator.
  If the functions are applied to the creation of a boot
  image it leads to errors because they are designed to
  operate on the system image root tree
* Fri Aug 19 2011 ms@suse.de
- removed broken state setup in KIWILog which was used to detect
  whether we need a CR when printing the line or not. All that
  sucked and caused mystery empty lines in the log
* Fri Aug 19 2011 ms@suse.de
- make sure loop maps are closed before installing grub. Also
  changed the way grub is called. We are creating a file with
  the commands first and then call grub ... --batch < file.
  It makes the code more readable and also allows to include
  the commands as part of the log file
* Thu Aug 18 2011 ms@suse.de
- fixed zero timeout value handling in syslinux. A value of zero
  disables the timeout so we set the smallest possible value in
  that case which is 1/10sec
* Thu Aug 18 2011 ms@suse.de
- increased amount of spare space 1.1 -> 1.5
* Thu Aug 18 2011 ms@suse.de
- fixed evaluation of which output
* Thu Aug 18 2011 ms@suse.de
- apply check for partitioner capabilities only for boot image
  types which actually use a partitioner; netboot and oemboot
* Wed Aug 17 2011 ms@suse.de
- added pxe image type for s390 JeOS template
* Wed Aug 17 2011 ms@suse.de
- added more useful repo path for s390 netboot
* Wed Aug 17 2011 ms@suse.de
- added support for netboot on s390, still _experimental_ !
* Wed Aug 17 2011 ms@suse.de
- changed ddn() function to also check for the '_' separator
  between the device and partition name
* Wed Aug 17 2011 ms@suse.de
- fixed this path evaluation in build operation mode
* Wed Aug 17 2011 ms@suse.de
- allow boottimeout of 0sec, also set the same default timeout
  of 10sec for the ext|syslinux setup
* Tue Aug 16 2011 ms@suse.de
- reduced amount of spare space 1.5 -> 1.1
* Tue Aug 16 2011 ms@suse.de
- fixed suse-11.4/suse-min-gnome package list
* Fri Aug 12 2011 ms@suse.de
- v4.94.2 released
* Thu Aug 11 2011 ms@suse.de
- fixed default label text for ext|syslinux setup
* Thu Aug 11 2011 ms@suse.de
- fixed vfat boot partition id lookup in setupBootPartition()
* Thu Aug 11 2011 ms@suse.de
- make sure the text message file isolinux.msg is created in
  case of a sys|extlinux based virtual disk image
* Thu Aug 11 2011 ms@suse.de
- make sure loader variable is initialized as early as possible
  also make sure .profile is loaded inside the initialize()
  function. This allows to setup loader by the value of the
  kiwi_bootloader variable in an early phase
* Wed Aug 10 2011 ms@suse.de
- make sure the which command is part of the initrd
* Wed Aug 10 2011 ms@suse.de
- don't configure a graphics boot screen in grub if no
  bootscreen picture data is available
* Wed Aug 10 2011 ms@suse.de
- allow init=/path/to/program option for kiwi images
* Tue Aug  9 2011 ms@suse.de
- in 12.1 the sysconfig.kernel file has been changed into a
  sysconfig.kernel-mkinitrd file.
* Tue Aug  9 2011 ms@suse.de
- suppress error message on stat evaluation for rpc_pipefs
* Mon Aug  8 2011 ms@suse.de
- use getExecPath() to locate parted binary, also allow
  alternative location of parted inside the linuxrc code
* Mon Aug  8 2011 ms@suse.de
- When the Boot image's repositories are updated/reconfigured,
  the priority and alias information is chopped off. This patch
  makes sure the priority information is retained.
* Mon Aug  8 2011 ms@suse.de
- use getExecPath() to find the grub binary. Along with this
  change the extraction of the grub binary from the initrd has
  been removed. That binary never was called.
- allow alternative location for the grub binary inside the
  linuxrc boot code
* Fri Jul 29 2011 ms@suse.de
- cleanup splash directory in case of call interruption
* Fri Jul 29 2011 ms@suse.de
- v4.94.1 released
* Fri Jul 29 2011 ms@suse.de
- added support for download and verification progress
  information for pxe (netboot) images (bnc #708711)
* Thu Jul 28 2011 ms@suse.de
- setup INITRD_MODULES for ppc correctly as ipr module is not
  included there by default.
- includes only needed scsi and network modules for ppc based
  boot images
* Thu Jul 28 2011 ms@suse.de
- setup serial console on JS21 ppc blade with correct baud rate
* Thu Jul 28 2011 ms@suse.de
- added support for dmraid fake-raid controllers (bnc #708712)
* Thu Jul 28 2011 ms@suse.de
- use the udev by-id path as device for the installation in suse-dump
  instead of the the standard unix device names (bnc #708712)
* Thu Jul 28 2011 ms@suse.de
- added support for repo priority for the yum package manager backend
* Wed Jul 27 2011 ms@suse.de
- fixed splash setup on recreation of the splash.install.gz initrd
* Wed Jul 27 2011 ms@suse.de
- added function to check for boot image creation and call
  setupSplash only if we are building a boot image
- fixed splash creation for iso images
* Wed Jul 27 2011 ms@suse.de
- allow bootwait post dump action in combination with other post dump action
* Tue Jul 26 2011 ms@suse.de
- increased performance of the splash creation. Instead of
  ripping the splash information out from the created initrd
  cpio archive, the splash files are now obtained from the
  unpacked tree and stored in a .spl file for appending it
  later to the final initrd (bnc #708357)
* Tue Jul 26 2011 ms@suse.de
- fixed xsl 3.8 to 3.9 conversion, oem-align-partition,oem-dumphalt
  and oem-inplace-recovery were not handled correctly
* Tue Jul 26 2011 ms@suse.de
- DB: fixed schemaversion value in documentation
* Tue Jul 26 2011 ms@suse.de
- don't remove zypper cache dir unconditionally
* Mon Jul 25 2011 ms@suse.de
- v4.93.3 released
* Mon Jul 25 2011 ms@suse.de
- fixed deviceDisks setup in suse-dump. The code there should
  check if imageDiskDevice has a value otherwise the sed call
  will fail with an invalid expression
* Fri Jul 22 2011 ms@suse.de
- v4.93.2 released
* Thu Jul 21 2011 ms@suse.de
- fixed config dir path serach in --build mode
* Thu Jul 21 2011 ms@suse.de
- added patch for genName creation. The generated name is now
  unique according to the repository name. This allows to use
  the cache zypper creates per repository again
* Wed Jul 20 2011 ms@suse.de
- DB: rebuild documentation
* Wed Jul 20 2011 ms@suse.de
- DB: use the 2 part version number for the documentation
* Wed Jul 20 2011 ms@suse.de
- fixed .newrelease to just increase the release part of the new
  kiwi version string by one
* Wed Jul 20 2011 ms@suse.de
- DB: rebuild images only if the .fig has changed
* Tue Jul 19 2011 ms@suse.de
- fixed evaluation of @UmountStack. There were some mount points
  still active if $main::global->mount() is called multiple times
  each mount() call causes a reset to the @UmountStack which means
  some umount information got lost
* Mon Jul 18 2011 adrian@suse.de
- fix catalog handling failure on apple style medias
* Mon Jul 18 2011 adrian@suse.de
- do not try to run boot loader setup code when no boot loader exists
* Fri Jul 15 2011 ms@suse.de
- v4.93.1 released
* Fri Jul 15 2011 ms@suse.de
- fixed installstick creation if sys|extlinux bootloader is
  used. Also fixed size setup of install stick. Problem here
  was that the uncompressed size of the raw install file was
  used and not the compressed size which ends up in a too big
  installstick image
* Fri Jul 15 2011 ms@suse.de
- added support for hybrid installiso media. In order to create
  the hybrid the attribute bootloader must be either set to
  syslinux or extlinux
* Thu Jul 14 2011 ms@suse.de
- moved zypper version check outside of the loop. It's enough
  to check this one time
* Thu Jul 14 2011 ms@suse.de
- improve the OpenNebula example. I recently created a separate
  package for the OpenNebula Web-UI server (sunstone) and with
  the package "cleanup/separation" from the main opennebula package
  showing how to use the Web-UI is easier now.
* Thu Jul 14 2011 ms@suse.de
- use the --one-file-system option for tar when copying the
  system image tree. This prevents the copy of files existing
  beyond the local filesystem (bnc #705717)
* Thu Jul 14 2011 ms@suse.de
- added log information if a hijacked command is called.
  That check only works inside the studio environment were
  a hijacked command has 'cmd'_real replacement.
* Thu Jul 14 2011 ms@suse.de
- fixed use of uninitialized value $ENV{'HOME'} (bnc #705717)
* Thu Jul 14 2011 ms@suse.de
- added %%post script for kiwi-templates which removes old JeOS
  template directories for distros we no longer support a JeOS
  image from.
* Wed Jul 13 2011 ms@suse.de
- cleaned up relocateCatalog calls which does not receive
  a parameter anymore. Also fixed return value of fixCatalog
  function
* Wed Jul 13 2011 ms@suse.de
- make sure relocateCatalog and fixCatalog is called
  for SuSE installation media (bnc #705208)
* Wed Jul 13 2011 ms@suse.de
- added README file to make github happy
* Mon Jul 11 2011 ms@suse.de
- use predefined set of configuration settings if a bootcd
  without system image was requested. The initrd itself doesn't
  contain further XML information so we set vga to normal and
  disabled the boot menu along with a boot timeout of zero
  seconds (immediate boot)
* Mon Jul 11 2011 ms@suse.de
- fixed --bootcd creation mode
* Fri Jul  8 2011 ms@suse.de
- v4.92.2 released
* Wed Jul  6 2011 ms@suse.de
- activate NFS locking for nfsroot systems. This means the
  mount call doesn't use -o nolock anymore
* Wed Jul  6 2011 ms@suse.de
- make sure rpc_pipefs is mounted if /var/lib/nfs/rpc_pipefs exists
- force NFS version 3 for NFSROOT setup. In that case v4 features
  are not required
* Tue Jul  5 2011 ms@suse.de
- added check if reading the md5 file was successful (bnc #703829)
* Tue Jul  5 2011 ms@suse.de
- don't remove /etc/netconfig for nfsroot setup (bnc #672172)
* Tue Jul  5 2011 ms@suse.de
- changed order of resize/check operation to check/resize
* Fri Jul  1 2011 ms@suse.de
- v4.92.1 released
* Thu Jun 30 2011 ms@suse.de
- added sle10 backward compatibility patches for losetup calls
  and partedGetPartitionID function. losetup in sle10 doesn't
  know about the --find option and parted in sle10 has a different
  machine (-m) output
* Thu Jun 30 2011 ms@suse.de
- make sure to unset the cacheDir if selectCache failed
* Thu Jun 30 2011 ms@suse.de
- removed -t option when mounting the squashfs image
  container in suse-dump. let libuuid decide that
* Thu Jun 30 2011 ms@suse.de
- fixed typo, check for dialog program happened twice
* Wed Jun 29 2011 ms@suse.de
- fixed and cleaned up disk size setup. There are two new
  functions __initDiskSize() and __updateDiskSize() which are
  used to create an initial disk size value and an update
  function if there are conditions which requires to increase
  the disk size. That actions are now also part of the kiwi
  log file
* Wed Jun 29 2011 ms@suse.de
- fixed setupOverlay() in KIWIImage.pm to write back possible
  XML changes into the overlay tree to stay persistent in the
  cow file
* Wed Jun 29 2011 ms@suse.de
- fixed cleanup of KIWIBoot instances in KIWIImageCreator
* Wed Jun 29 2011 ms@suse.de
- increased chunk size in createSnapshotMap(). This increased
  the performance of image caches a lot
* Tue Jun 28 2011 ms@suse.de
- allow firstboot and autoyast service to be enabled together (bnc #700105)
* Tue Jun 28 2011 ms@suse.de
- remove use of hardcoded path for the mksquashfs program by
  using the KIWILocator::getExecPath() method
* Tue Jun 28 2011 ms@suse.de
- added quoting of special characters for kiwi_oemtitle (bnc #702044)
* Mon Jun 27 2011 ms@suse.de
- added support for pxe buffered write on destination device in
  fetchFile() function used for netboot images. By default a
  chunk size of 4k is used
* Mon Jun 27 2011 ms@suse.de
- added network functions for s390 pxeboot. New functions are
  setupNetworkInterfaceS390, setupNetworkStatic, setupDefaultGateway
  setupDNS. Normally the pxe boot on x86 expects a DHCP server to
  provide all the required network services but on s390 pxe boot
  works together with a parm file containing that information
  which is evaluated by the new functions.
* Fri Jun 24 2011 ms@suse.de
- fixed evaluation of buildtype in createImage(). There were
  some places which did not reference the build type as it
  is stored in the XML object. This could lead to the use of
  an uninitialized value if no primary type was set in the
  XML description and no type was explicitly selected
* Wed Jun 22 2011 ms@suse.de
- changed 01-network.sh preinit script for s390 templates to use
  the same variable names as provided by the parm file when using
  the standard yast based installation
* Tue Jun 21 2011 ms@suse.de
- added function includeKernelParametersLowerCase() which
  converts all cmdline paramters to lowercase variables
* Mon Jun 20 2011 ms@suse.de
- systemd-sysvinit creates a symlink from '/bin/systemd' to
  '/sbin/init'. Unfortunately kiwi linuxrc tries to check
  for the file permissions which leads to a false positive
  rebootException (bnc #700603)
* Mon Jun 20 2011 ms@suse.de
- changed __getBootSize() function so that it multiplies the
  calculated minimum boot space by 3 to allow proper kernel
  updates (bnc #698161)
* Mon Jun 20 2011 ms@suse.de
- fixed thisPath() evaluation. When in create or upgrade mode the
  function did not use the value of the main::Prepare lookup file
* Mon Jun 20 2011 ms@suse.de
- Apply some clean up to the recently submitted OpenNebula example.
  I made some changes to the packaging in OBS which allows me to
  simplify the image configuration.
* Thu Jun 16 2011 ms@suse.de
- fixed build on Centos/Redhat, recommended packages like
  jing or zypper does not exist there so we had to check
  the distro in that case
* Thu Jun 16 2011 ms@suse.de
- fixed the patternType validation bug reported by John Lund
  on the users list. The patch also adds a new test case xml
  file for the KIWIXMLValidator unit test.
* Thu Jun 16 2011 ms@suse.de
- added a new example for 11.3, 11.4, and 12.1. This example
  demonstrates the use of Kiwi to create cloud setup images
  and a guest images for clouds based on the OpenNebula
  infrastructure.
* Sun Jun 12 2011 ms@suse.de
- v4.91.2 released
* Sun Jun 12 2011 ms@suse.de
- DB: fixed typo in URI documentation
* Fri Jun 10 2011 adrian@suse.de
- we need to go back to SHA1 for SLE 11 for now, zypp is not working with 256 yet.
* Fri Jun 10 2011 ms@suse.de
- use hardlink instead of copy to create the init file
  in the initrd cpio archive
* Thu Jun  9 2011 adrian@suse.de
- make sure options for LogFile and RootTree are handled
  before createInstSource() is called
* Thu Jun  9 2011 adrian@suse.de
- switch to 11.1 PDB branch
* Thu Jun  9 2011 adrian@suse.de
- fix plugin to become usable with current kiwi code
* Wed Jun  8 2011 ms@suse.de
- remove the call to sax2 in the 11.3 vm guest example, sax2 is no
  longer part of 11.3 and later as the X-server is self configuring.
  Also added code to allow the firstboot sequence to be initiated.
  While this particular example does not use the firstboot mechanism,
  someone basing their build of the example and trying to get firstboot
  to work would be hard pressed to find why it is not working.
* Tue Jun  7 2011 ms@suse.de
- changed kiwi version number from a two part version
  into a three part version number: v4.91.1. The major
  and minor part of the version will not change with
  bugfix releases. The following rules should apply to
  the version number: major.minor.release. major change
  might include incompatible changes. minor change
  includes features and schema version updates. release
  change includes any kind of bugfixes
* Tue Jun  7 2011 ms@suse.de
- update LICENSE file to latest version of GPLv2
* Tue Jun  7 2011 ms@suse.de
- don't package empty file euca-setup
- update license GPLv2, rpmlint complained about outdated address
* Tue Jun  7 2011 adrian@suse.de
- new perl complains about implicit parentheses
* Mon Jun  6 2011 ms@suse.de
- added appliances that are not referenced in docbook and are
  intended to demonstrate image building and appliances in a
  broader view into the doc/examples/extras directory
* Mon Jun  6 2011 ms@suse.de
- don't use a fixed value for the size of the boot partition. The
  size among others depends on how many kernels were installed. Thus
  a fixed value is always wrong. The new function __getBootSize()
  is used to check the actual size of the boot/* area and this value
  is used to create the boot partition if required. In case of an
  oem image the re-creation of the boot partition happens based on
  the original boot partition size (bnc #698233)
* Mon Jun  6 2011 ms@suse.de
- drop RPMQ dependency, package does not exist, but module is
  provdided already by inst-source-utils.
* Mon Jun  6 2011 ms@suse.de
- DB: update documentation
* Mon Jun  6 2011 ms@suse.de
- added openSUSE 12.1 template and boot image descriptions
- removed openSUSE 11.1 and 11.2 docs plus template and boot
  image descriptions
* Mon Jun  6 2011 ms@suse.de
- fixed location of squashfs in drivers section for sle10
* Mon Jun  6 2011 ms@suse.de
- fixed ELOG_* setup for ppc architecture. We use the hvc
  console for ppc and tty for all others
* Sat Jun  4 2011 ms@suse.de
- activate build of kiwi-desc-netboot for ppc in spec file
* Sat Jun  4 2011 ms@suse.de
- added support for pxe images on ppc architecture
* Fri Jun  3 2011 ms@suse.de
- added squashfs in drivers section of SLE10 boot image descriptions
* Fri Jun  3 2011 ms@suse.de
- v4.91 released
* Wed Jun  1 2011 ms@suse.de
- added option -f to 'prove' in order to show failed unit tests
* Wed Jun  1 2011 ms@suse.de
- call the XML pretty printer when kiwi writes back the
  XML description to the unpacked image tree. The result
  is easier to read
* Wed Jun  1 2011 ms@suse.de
- moved requirement back to genisoimage, after checking the code
* Wed Jun  1 2011 ms@suse.de
- fixed build: unit testing requires iso and filesystem tools
  to be present in the buildsystem
- fixed spec file: genisoimage is set as required but kiwi uses
  growisofs in the code which is provided by dvd+rw-tools
* Wed Jun  1 2011 ms@suse.de
- fixed unit testing ktLog.pm, some functions from the real
  KIWILog module were missing in ktLog.pm
* Tue May 31 2011 ms@suse.de
- allow username and password to be transfered via
  updateDescription / __updateDescriptionFromChangeSet
* Tue May 31 2011 ms@suse.de
- added option --start-sector to kiwi. This allows to influence
  the default start sector 2048 to be another value e.g. 32 for
  the old style disk layout.
* Tue May 31 2011 ms@suse.de
- fixed call of cleanup functions for KIWIBoot objects
* Tue May 31 2011 ms@suse.de
- really fixed setupConsole to remove the ttyS0 console if no
  ttyS0 device exists (bnc #695948)
* Tue May 31 2011 ms@suse.de
- fixed build: Added zypper to BuildRequires. This is needed in
  order to make the unit test run happy
* Fri May 27 2011 ms@suse.de
- v4.90 released
* Fri May 27 2011 ms@suse.de
- DB: update documentation, typo in ec2 docs
* Fri May 27 2011 ms@suse.de
- eliminate use of global variable: XMLChangeSet
* Fri May 27 2011 ms@suse.de
- DB: update documentation
* Thu May 26 2011 ms@suse.de
- don't store DOM tree references in XML changeset
- don't create a new KIWICommandLine object in KIWICache
* Thu May 26 2011 ms@suse.de
- eliminate use of global variable: OverlayRootTree
* Thu May 26 2011 ms@suse.de
- eliminate use of global variables:
  * BootVMSystem
  * BootVMSize
  * StripImage
  * ProfilesOrig
  * PrebuiltBootImage
  * ISOCheck
  * CheckKernel
  * LVM
  * GrubChainload
  * FatStorage
* Thu May 26 2011 ms@suse.de
- fix the problem with an improper exit status on test failure.
  We now use prove (part of Perl) to execute the unit tests.
  Prove generates the proper exit status upon test failure.
* Wed May 25 2011 ms@suse.de
- fixed spec file: The functionality provided with the
  kiwi-desc-usbboot package has moved into a new technology
  which is not provided by another package. Therefore the
  wrong provides entry was removed.
* Wed May 25 2011 ms@suse.de
- enhanced setupConsole to remove the ttyS0 console if no
  ttyS0 device exists (bnc #695948)
* Wed May 25 2011 ms@suse.de
- fixed setupConsole() if search string appears as comment
* Wed May 25 2011 ms@suse.de
- use -t squashfs to mount the installation image. This works
  around the problem if libuuid doesn't know the squashfs
  signature
* Wed May 25 2011 ms@suse.de
- eliminate use of global variables: ListXMLInfoSelection and RootTree
* Wed May 25 2011 adrian@suse.de
- minor cleanup: remove -C parameter for 12.1 style medias, -D is enough
* Wed May 25 2011 ms@suse.de
- fixed bootloader setup if split image type is used
* Wed May 25 2011 ms@suse.de
- eliminate use of global variable: LogFile
- cleaned up init() function, removed redundant code and moved
  the listXMLInfo code into the main operations block
* Wed May 25 2011 ms@suse.de
- adapt unit tests due to last KIWIXML ctor code changes
* Tue May 24 2011 ms@suse.de
- eliminate global variable: Destination
- fixed backtrace() output in debug mode, show only latest trace level
  the other trace levels are kept for further debugging
* Tue May 24 2011 ms@suse.de
- eliminate use of global variable: ImageDescription
- pass commandline object reference (cmdL) to KIWIXML objects
  and from there to KIWIURL objects.
* Tue May 24 2011 ms@suse.de
- eliminate use of global vars: ImageCache and RecycleRoot
- added check for global object in constructors
- added perl-RPMQ as requirement for kiwi-instsource
* Tue May 24 2011 ms@suse.de
- eliminate global variables used by main()
* Mon May 23 2011 ms@suse.de
- eliminate use of global variables: main::FS* and main::SetImageType
* Mon May 23 2011 ms@suse.de
- cleanup kiwiExit calls
* Mon May 23 2011 ms@suse.de
- s390: fixed disk online code, wait for disk device to appear (bnc #693031)
* Sun May 22 2011 ms@suse.de
- fixed boot included archive installation in prepareBootImage
* Fri May 20 2011 ms@suse.de
- moved .kiwirc into the tests/unit directory
* Fri May 20 2011 ms@suse.de
- v4.89 released
* Fri May 20 2011 ms@suse.de
- allow unit tests to run standalone without kiwi
  installed in /usr/share/kiwi
* Fri May 20 2011 ms@suse.de
- DB: update schema documentation
* Fri May 20 2011 ms@suse.de
- fixed obsoletes in spec file
* Fri May 20 2011 ms@suse.de
- build arch of master kiwi can't be noarch if other
  arch specific sub packages will be created
* Fri May 20 2011 ms@suse.de
- make rpmlint happy:
  * don't package empty files
  * don't package non unix file (dos2unix)
  * don't package scripts without executable flag
  * don't use unversioned obsoletes
  * provide man pages with the master kiwi package
  * make the master kiwi package noarch if possible
  * require kiwi-tools version from the same master
* Fri May 20 2011 ms@suse.de
- fixed stylesheet bugs: Thanks to Tom for looking at it
  * A xsl:call-template cannot contain a mode attribute. Only
    xsl:apply-templates can have it. The affected files are
    convert39to41.xsl and convert41to42.xsl
  * A <xsl:copy select="@"/> is incorrect in two ways: First
    a xsl:copy needs to have something to copy in its _content_,
    second the select attribute is syntactically wrong; @ means
    attribute, but which one? I guess, it should mean
    <xsl:copy-of select="@*"/>. However, in this case it's
    totally useless as it copies *all* attributes, regardless
    of the for-each loop. So the for-each loop can never act
    as it was supposed to be.
* Fri May 20 2011 ms@suse.de
- get unit test working again, due to restructuring changes
- provide config and target location as arguments to
  prepareBootImage() and createBootImage(). Retrieving those from
  the CommandLine object is not following our functional
  separation model as the config dir and target dir for the
  initrd cannot be given on the command line and therefore
  should not be stored on the command line argument
- refactor setting of XML parameters into methods for re-use
* Thu May 19 2011 ms@suse.de
- run unit tests during package build if SUSE > 1130
* Thu May 19 2011 ms@suse.de
- limit the validation of config.xml files in the Kiwi tree to files
  located outside the tests tree. config.xml files in the tests tree
  are not necessarily expected to be valid as we also need to do
  negative unit testing.
* Thu May 19 2011 ms@suse.de
- fixed version update script
* Thu May 19 2011 ms@suse.de
- cleanup situation around global variables. There is now a
  KIWIGlobals object which contains all global variables and
  functions. There are still some global variables in use
  which references options. Those should be handled by a
  KIWICommandline accessor
* Wed May 18 2011 ms@suse.de
- fixed unit test kiwiImageCreator.pm
- fixed *.kiwi search in getControlFile
* Wed May 18 2011 ms@suse.de
- moved the image create step into the KIWIImageCreator code
  There is now a function createImage / createBootImage which
  is also used by the build step. Along with this change I
  removed all occurences of the main::Survive variable and
  thus removed all recursive kiwi calls now from the code.
* Wed May 18 2011 adrian@suse.de
- do not enforce the need of a meta package, driver update disk is not needing one (on command from cwh)
* Tue May 17 2011 ms@suse.de
- cleanup fix; don't create instances of KIWICommandLine
  if it's not necessary. Also removed redundant code in
  prepareBootImage
* Tue May 17 2011 ms@suse.de
- make the user password optional; It is valid to have a user on
  a system that cannot login via password authentication. Therefore
  kiwi should not force a password assignment in the <user> element
* Tue May 17 2011 ms@suse.de
- fixed caching if used for boot images. Also fixed the check
  between the initial prepare with cache and the remount of a
  prepared tree with cache
* Tue May 17 2011 adrian@suse.de
- add SLE 11 SP 2 media style plugin, using sha256 sums for meta data
* Tue May 17 2011 adrian@suse.de
- fix installation directory of 12.1 plugin
* Tue May 17 2011 adrian@suse.de
- add openSUSE 12.1 media style, using sha256 meta data sums
* Tue May 17 2011 ms@suse.de
- removed global variables CacheRoot and CacheRootMode and
  cleaned up the KIWICache code. Also added a new runtime
  check: __checkRootRecycleCapability which makes sure that
  a cache based root tree cannot be used in --recycle-root
  mode
* Tue May 17 2011 ms@suse.de
- last fix using --numeric-owner was still broken. Robert has
  added a better and more robust patch to fix this
* Tue May 17 2011 ms@suse.de
- use --numeric-owner option in tar to prevent the table layout
  to break if the user/group field in the tar -t output exceeds
  the field length
* Tue May 17 2011 ms@suse.de
- don't strip vgrename command from initrd
* Mon May 16 2011 ms@suse.de
- moved the following operation modes into the KIWIImageCreator:
  also fixed the unit tests and get rid of some recursive calls
  * --setup-splash  => createSplash()
  * --bootusb       => createImageBootUSB()
  * --bootcd        => createImageBootCD()
  * --installcd     => createImageInstallCD()
  * --installstick  => createImageInstallStick()
  * --bootvm        => createImageDisk()
  * --convert       => createImageFormat()
* Mon May 16 2011 ms@suse.de
- make sure XML validation happens in each processing mode
- fixed environment cleanup, added cleanup function in main
* Mon May 16 2011 ms@suse.de
- fixed logging. Added function resetRootChannel which allows
  to split up the log at a certain point. This is used when
  one --init-cache call creates multiple caches and each one
  has a dedicated log file
* Mon May 16 2011 ms@suse.de
- moved the upgrade code into the KIWIImageCreator object
  also removed the recursive upgrade call inside the create
  step and call the new function upgradeImage() instead
* Fri May 13 2011 ms@suse.de
- fixed fixupOverlayFilesOwnership(), remove leading
  spaces from file names
* Fri May 13 2011 ms@suse.de
- added unit tests for testing the KIWIImageCreator code
* Fri May 13 2011 ms@suse.de
- added new KIWICache object and move out the cache code
  from the main kiwi.pl file into the new object code
* Thu May 12 2011 ms@suse.de
- added new KIWIImageCreator object which will encapsulate
  the major kiwi processing modes like prepare, create, upgrade
  and others into module functions. So far the prepare step
  has been moved out and others will follow. The goal is to
  get rid of the global variable stack in kiwi as well as to
  remove the recursive kiwi calls
* Thu May 12 2011 ms@suse.de
- unit test fixes:
  * move test repo to sharable location, adjust XMLInfo test
  * fixed removal of test directory, remove only if no mounts exists
  * fixed test directory cleanup, remove only if no mount exists
  * fixed broken unit test due to commit: c9c797b47cb4
* Wed May 11 2011 ms@suse.de
- changed name of enableRootRecycle to setRootRecycle, better
  following the style of the KIWICommandLine functions
* Wed May 11 2011 ms@suse.de
- fixed use of glob-type for filehandle in KIWIRoot.pm
* Wed May 11 2011 ms@suse.de
- DB: fixed some typos in schema inline documentation
* Wed May 11 2011 ms@suse.de
- expand command line object to handle more options. Also expand
  the unit tests for this options. This happened in preparation to
  the new KIWIImageCreator object which will encapsulate the kiwi
  build, prepare and create modes
* Wed May 11 2011 ms@suse.de
- move knowledge about the default cache directory path
  into the KIWILocator module: getDefaultCacheDir()
* Wed May 11 2011 ms@suse.de
- update unit test infrastructure in preparation for the new
  KIWIImageCreator object which will encapsulate the kiwi
  build, prepare and create modes
* Wed May 11 2011 ms@suse.de
- remove outdated undocumented prechrootcall option
* Tue May 10 2011 ms@suse.de
- fixed this:// path evaluation if used in --info mode (bnc #692813)
* Tue May 10 2011 ms@suse.de
- enhanced the ddn() function to work correctly if a
  udev /dev/disk/<name> device name is specified as disk
  parameter (bnc #692629)
* Mon May  9 2011 ms@suse.de
- integrate end-to-end testsuite written by Bernhard Wiedemann
  into kiwi. There is a kiwi --test-image ... mode now, and I
  added an example test to the 11.4 JeOS description. It's
  required to have the os-autoinst package installed in order
  to run a test (bnc #677789)
* Fri May  6 2011 ms@suse.de
- v4.88 released
* Fri May  6 2011 ms@suse.de
- fixed build for ia64 architecture
* Fri May  6 2011 ms@suse.de
- added hook preNetworkRelease (bnc #691249)
* Wed May  4 2011 ms@suse.de
- fixed the problem where the <size> element is being dropped
  during XML file upgrade if the <size> element is specified as
  a child of <preferences>. The <size> element is moved to
  every <type>
* Wed May  4 2011 ms@suse.de
- fixed xsl style sheets, apply changes only if the
  schema version of the input data is smaller than the
  style sheet version
* Wed May  4 2011 ms@suse.de
- fixed typo in kiwi_bootloader evaluation (bnc #691424)
- fixed hvc/xvc console setup, add entry only if missing (bnc #691424)
* Tue May  3 2011 root@s390a06.suse.de
- fixed disk offset calculation for zipl.conf creation, also
  fixed the lookup of the boot partition and the cleanup of the
  loop devices if the zipl bootloader is used (bnc #687927)
* Tue May  3 2011 ms@suse.de
- switch back to by-id device name schema (bnc #691199)
  This reverts commit: f1e31c85689d6925b9c3069a845f5e252c838936
* Tue May  3 2011 ms@suse.de
- fixed first type selection for a subset of types selected
  by profiles. This is a follow up fix for (bnc #690554)
* Tue May  3 2011 ms@suse.de
- DB: update documentation, FORCE_KEXEC feature (bnc #691247)
* Tue May  3 2011 ms@suse.de
- added support for FORCE_KEXEC in kernelCheck function which
  allows to force the kexec call even if the kernel versions
  are the same (bnc #691247)
* Mon May  2 2011 ms@suse.de
- removed pxeNotifyNewImage function. This is done inside the
  slepos specific code hooked in (bnc #691249)
* Mon May  2 2011 ms@suse.de
- make sure bootincluded_archives.filelist contains only files
* Mon May  2 2011 ms@suse.de
- move the createTmpDirectory code from the XML object to the Locator.
  Creating a directory really has nothing to do with XML processing,
  the Locator now handles local file system interaction, thus this
  is a better place.
* Mon May  2 2011 ms@suse.de
- fixed reboot call in kernelCheck function (bnc #689294)
* Mon May  2 2011 ms@suse.de
- fixed type selection if not type was specified and no primary
  attribute is set to any type. In that case the first type written
  in the XML description should be used (bnc #690554)
* Thu Apr 28 2011 ms@suse.de
- also allow NFSROOT and AOEROOT to be set on the
  commandline (bnc #536309)
* Thu Apr 21 2011 ms@suse.de
- v4.87 released
* Thu Apr 21 2011 ms@suse.de
- fixed initial variable setup for haveDASD|ZFCP
* Thu Apr 21 2011 ms@suse.de
- changed searchBusIDBootDevice() for the s390 architecture.
  All required information is now obtained from /sys/firmware/ipl
  According to this no additional kernel parameters are
  required to set the boot device online (bnc #689004)
* Thu Apr 21 2011 ms@suse.de
- added alternative location for kiwi hooks scripts which
  is FHS compliant: /lib/kiwi/hooks/ (bnc #688792)
* Wed Apr 20 2011 ms@suse.de
- added URL mapping table for the opensuse:// url type. When
  resolving this the regular expression based mapping table is
  used to create a valid location from the specified URI data.
  It's possible to extend the existing KIWIURL.txt table
  according to the needs of the user or service.
* Wed Apr 20 2011 ms@suse.de
- changed xsl 51 to 52 conversion. The obsolete usb image type
  is removed from the XML input. this image type can be either
  replaced by an iso hybrid type or by an oem type. As there is
  a choice for the user the stylesheet will not make a decision
  here.
* Wed Apr 20 2011 ms@suse.de
- netboot: added preLoadConfiguration hook:
  preLoadConfiguration: is called before the client.<MAC> is
  loaded by kiwi and thus can be used to inject alternative code
  for loading the client configuration.
- netboot: added postLoadConfiguration hook:
  postLoadConfiguration: is called after the client configuration
  has been loaded and imported and can be used for any action
  after the client configuration has exported its variables into
  the boot environment
- netboot: renamed the default register file which is put on
  the pxe boot server if there is client configuration found.
  kiwi now put a file called: upload/client.$DHCPCHADDR
  which doesn't conflict with the files SLEPOS uses for
  registration
- netboot: removed SLEPOS related code, posbios calls and
  the evaluation of the WORKSTATION_LDAP_IP variable. All
  this will be part of product specific hook scripts
* Wed Apr 20 2011 ms@suse.de
- allow parameters to be passed to hook scripts
* Tue Apr 19 2011 ms@suse.de
- added setupBootLoaderTheme() function which is called
  after the bootloader configuration has been written. The
  function adapts/sets the THEME variable in the
  /etc/sysconfig/bootsplash file according to the boot
  theme set in the kiwi XML configuration
* Mon Apr 18 2011 ms@suse.de
- fixed suseStripFirmware to match in subdirectories below
  /lib/firmware/ too. firmware installed by the kernel packages
  for example were removed
* Fri Apr 15 2011 ms@suse.de
- v4.86 released
* Fri Apr 15 2011 ms@suse.de
- DB: update documentation. Added chapter about hook scripts
* Thu Apr 14 2011 ms@suse.de
- merge in relevant changes from x86 boot image descriptions
  into the ppc and s390 boot images
* Thu Apr 14 2011 ms@suse.de
- fixed build
* Thu Apr 14 2011 ms@suse.de
- fixed boot partition id in suse-repart if syslinux is
  used as bootloader. We are using fat32 now (c)
* Thu Apr 14 2011 ms@suse.de
- using sfdisk --id now, thus require sfdisk in spec file
* Thu Apr 14 2011 ms@suse.de
- fixed getStorageID function and the evaluation of the return
  value of this function. The assumption that the partition id
  is a decimal value is wrong, thus calling int() on the result
  is not a good idea. man I really shouldn't code at midnight
* Thu Apr 14 2011 ms@suse.de
- fixed setupSUSEInitrd function. We create imho poinless
  links named linux.vmx and initrd.vmx which are not used
  at all if the initrd could be generated by mkinitrd.
  Additionally the links are broken if the running kernel
  is not the same as the installed kernel. Therefore I
  removed the creation of that link files
- fixed kernelList function. the code searching for installed
  kernels if the running kernel can't be found was never
  reached. Additionally the function did not search for other
  than the running kernel which seems to be wrong if multiple
  kernels are installed
* Thu Apr 14 2011 ms@suse.de
- update config.sh scripts for the ec2 examples to ensure
  the ssh policy and inittab console settings are correct
* Thu Apr 14 2011 ms@suse.de
- added new consistency check to enforce that ec2 formatted images are
  created as file system types. This required an update to a number of
  other config files used for Validator unit testing. Added new unit
  tests for the EC2 requirement.
* Wed Apr 13 2011 ms@suse.de
- fixed parted type setup, use the form 'set [nr] type 0x[id]'
  this is used to workaround a parted bug happening if you
  type 'set [nr] swap on'. parted refuses to set this even
  though the help page in batch mode tells the user to do it
  exactly that way
* Wed Apr 13 2011 ms@suse.de
- removed fat 8+3 kernel/initrd renaming code. This is no longer
  required when using a fat32 / vfat partition / filesystem
- fixed kernelCheck() function: rewrote the code
* Wed Apr 13 2011 ms@suse.de
- fixed fstab setup in ec2 format setup (bnc #687211)
* Tue Apr 12 2011 ms@suse.de
- fixed syslinux kernel/initrd setup in resetBootBind()
* Tue Apr 12 2011 ms@suse.de
- added syslinux to package list of JeOS images
* Tue Apr 12 2011 ms@suse.de
- fixed partition id setup if parted is used
* Tue Apr 12 2011 ms@suse.de
- added lvm2 to ix86 SLE11 JeOS template
* Mon Apr 11 2011 ms@suse.de
- fixed the --lvm option. The option now adds a systemdisk
  element and behaves the same as if the users would have
  modified the XML accordingly
* Mon Apr 11 2011 ms@suse.de
- make sure installBootLoader() is called for vmxboot
  image if a root overlay filesystem structure is used
- move resetBootBind() into installBootLoader()
* Mon Apr 11 2011 ms@suse.de
- call setupBootPartition() only on first boot
* Mon Apr 11 2011 ms@suse.de
- added evaluation of kiwi_ramonly element for vmx too
- added evaluation of kiwi_ramonly element for ppc and s390 arch
- added evaluation of kiwi_ramonly element for non LVM setup
* Mon Apr 11 2011 ms@suse.de
- fixed subsequent mount procedure of a clicfs based image.
  The resize2fs call has to happen in any case if the image
  is a ramonly system
* Fri Apr  8 2011 ms@suse.de
- v4.85 released
* Fri Apr  8 2011 ms@suse.de
- in KIWIRoot.pm the fixupOverlayFilesOwnership() function
  fails to quote the filaname which results in problems with
  files/directories with spaces in their names.
* Thu Apr  7 2011 ms@suse.de
- Added a new consistency check and unit tests to ensure that
  config.xml files specifying an image type that requires an
  initrd set the boot attribute on the <type> element.
* Wed Apr  6 2011 mbarringer@suse.de
- Fixing a problem with imagewriter's makefile
* Wed Apr  6 2011 mbarringer@suse.de
- Minor fix to the command line help output in Imagewriter
* Wed Apr  6 2011 mbarringer@suse.de
- Fixing Imagewriter compilation w/ HAL support enabled
* Wed Apr  6 2011 ms@suse.de
- don't use the result of a getExecPath() call happened outside
  of the chroot, for a command call inside the chroot. It might
  happen that the path to the binary is different inside the
  chroot and thus can't be found
* Wed Apr  6 2011 mbarringer@suse.de
- Fixing bnc#679099 - Imagewriter still requires HAL
* Wed Apr  6 2011 root@s390a06.suse.de
- added support for ZFCP devices
* Wed Apr  6 2011 ms@suse.de
- added repodata information for s390 suse-sle11-repo
* Tue Apr  5 2011 ms@suse.de
- if the target-device option is used kiwi normally doesn't
  create a disk image file until the image file is created
  by a dump off from the target device. SuSE studio requires
  the size information of the target disk before the dump off
  happens, because it creates that target device internally.
  Therefore this patch makes sure that a image disk file is
  created before the dump off happens
* Tue Apr  5 2011 ms@suse.de
- moved from fat16 (0x6) to fat32 (0xc) for syslinux setup
* Tue Apr  5 2011 ms@suse.de
- alpha sort the option parser
* Tue Apr  5 2011 ms@suse.de
- fixed kiwiCommandLine unit test according to the changes
  done in commit: 7954bf3bed5845f4ece4991ef17f8f2978c8fbee
* Mon Apr  4 2011 ms@suse.de
- created a repo to support new tests for size query and package
  install query. Additionally the common test case base class
  gets new methods to create a writable directory and to clean
  it up after the test
* Mon Apr  4 2011 ms@suse.de
- fixed KIWICommandLine::setLogFile, it breaks for 'terminal' logging
- fixed KIWICommandLine::setAdditionalRepos, it breaks if
  numAlias and or numPrios is zero
* Mon Apr  4 2011 ms@suse.de
- fixed solvable creation for old distros (sle10) providing
  uncompressed versions of suse/setup/descr/packages file
* Mon Apr  4 2011 ms@suse.de
- fixed init(), creation of global kiwi log object is
  required for KIWIQX execution logging
* Mon Apr  4 2011 ms@suse.de
- added repodata to kiwi provided suse-* repos and move the
  repotype to rpm-md in all referencing XML descriptions
* Mon Apr  4 2011 ms@suse.de
- removed test_cmdReplaceRepo_noRepoType test, it's valid
  to overwrite first repo without specifying a type
* Mon Apr  4 2011 ms@suse.de
- renamed the test implementation and data base directory to be
  consistent with other tests, i.e. start with kiwi
* Sun Apr  3 2011 ms@suse.de
- update spec file, added jing as recommended package
* Sun Apr  3 2011 ms@suse.de
- added unit tests for the new KIWIXMLInfo object. Also
  break up the bigger tests into smaller test cases
* Sun Apr  3 2011 ms@suse.de
- added a new KIWIXMLInfo object and eliminate the
  listXMLInfo() function from kiwi.pl
* Fri Apr  1 2011 ms@suse.de
- v4.84 released
* Fri Apr  1 2011 ms@suse.de
- added normalizeBootPath() function which allows to use
  the following boot attribute source locator prefixes:
  * this://    => pointing to the image description directory
  * system://  => pointing to /usr/share/kiwi/image
  * dir://     => pointing to a directory
    if no source locator is set kiwi uses the path if it is an
    absolute path and in case of a relative path it checks if
    the path relative to the called directory exists and if not
    it also checks if the path exists below /usr/share/kiwi/image
* Fri Apr  1 2011 ms@suse.de
- fixed repository setup for cache creation
* Thu Mar 31 2011 ms@suse.de
- fixed LVM repartition code. if no recovery partition is
  requested just us the default end sector suggested by the
  partition tool
* Wed Mar 30 2011 ms@suse.de
- fixed s390 LVM repartition code [2]
* Wed Mar 30 2011 ms@suse.de
- fixed s390 LVM repartition code
* Wed Mar 30 2011 root@s390a06.suse.de
- fixed zipl setup if used with LVM images
* Wed Mar 30 2011 ms@suse.de
- suse 11.4 doesn't provide the by-id disk paths anymore.
  Because of that change kiwi switches to the by-path method
  with this commit
* Wed Mar 30 2011 adrian@suse.de
- do not replace @ to . in package names when building products
* Wed Mar 30 2011 ms@suse.de
- fixed xen examples for suse 11.4, xen-tools-domU doesn't
  exist anymore. xen-tools is used instead
* Tue Mar 29 2011 ms@suse.de
- dont't start udev using startproc (bnc #683126)
* Tue Mar 29 2011 ms@suse.de
- fixed boot path lookup if boot attribute contains an
  absolute path (bnc #683135)
* Mon Mar 28 2011 ms@suse.de
- added fixupOverlayFilesOwnership() function which handles
  all files from the overlay root tree and the image archives.
  The function changes the ownership of all that files to
  root:root if they don't belong to a user in the passwd file.
  files which belongs to passwd users are not touched and
  therefore must be added with the correct owner:group setup
  in the overlay tree and/or archive
* Mon Mar 28 2011 ms@suse.de
- fixed perl warning (uninitialized variable) and a checker error
  when building an ISO image without setting the 'flags' attribute.
* Fri Mar 25 2011 ms@suse.de
- v4.83 released
* Fri Mar 25 2011 ms@suse.de
- option -s for qemu-img convert hast changed its meaning
* Thu Mar 24 2011 ms@suse.de
- fixed pxeRaidCreate() function. Use --run option when creating
  the array and write a more reliable mdadm.conf file (bnc #678076)
* Wed Mar 23 2011 ms@suse.de
- fixed format string of hexdump. If the mbrid has leading
  zero's the hexdump call removes them which leads to an
  error when string matching the mbrid
* Wed Mar 23 2011 ms@suse.de
- DB: update documentation, new option --mbrid
* Wed Mar 23 2011 ms@suse.de
- added support for a custom mbr disk label with
  the option --mbrid. The default is to create a random
  mbr disk label.
* Tue Mar 22 2011 ms@suse.de
- DB: update documentation, new info module 'version'
* Tue Mar 22 2011 ms@suse.de
- added info 'version' selection to obtain the appliance
  name and version information
* Tue Mar 22 2011 ms@suse.de
- fixed start of udev and blogd
* Tue Mar 22 2011 ms@suse.de
- enable loading of agp modules before udev is started (bnc #659843)
* Tue Mar 22 2011 ms@suse.de
- reverts commit 8f5df54fd23cc6c16e7d72fe5954e62fd70bb458
  busybox is distributed with 11.4 (bnc #679660)
* Mon Mar 21 2011 ms@suse.de
- added suseStripFirmware() which removes all firmware files
  which are not referenced by any module (bnc #681234)
* Mon Mar 21 2011 ms@suse.de
- fixed use of uninitialized value in __checkPatternTypeAttrrValueConsistent
* Mon Mar 21 2011 ms@suse.de
- DB: update documentation, new attribute prefer-license
* Mon Mar 21 2011 ms@suse.de
- added support for the repository attribute 'prefered-license'
  The repository providing this flag will be used to install
  the license tarball due to request in bnc #633664. If no repo
  with a prefered license flag exists the search happens over
  all repos but it's not guaranteed in that case that the search
  order follows the repo order like they are written into
  the XML description (bnc #680886)
* Mon Mar 21 2011 ms@suse.de
- DB: update documentation and examples, new element oem-silent-boot
* Mon Mar 21 2011 ms@suse.de
- added support for the configuration of a silent OEM boot mode
  Normally the oem boot process switches the splash screen off.
  With <oem-silent-boot>true</oem-silent-boot> as part of the
  oemconfig section, the splash stays on top
* Fri Mar 18 2011 ms@suse.de
- fixed examples, added boot.local script to the suse-live-stick
  example which allows to mount the fat boot partition as data
  container below /media/stickstorage
* Fri Mar 18 2011 ms@suse.de
- fixed kiwirevision check. In case of a git revision it's
  invalid to check for less than a number. The check must
  match the revision
* Fri Mar 18 2011 ms@suse.de
- DB: update documentation, kiwirevision specifies a git commit id
* Fri Mar 18 2011 ms@suse.de
- v4.82 released
* Fri Mar 18 2011 ms@suse.de
- fixed exit code handling:
  * kiwi --version     => exit 0
  * kiwi --help | -h   => exit 0
  * unknown option     => exit 1
  * no root privileges => exit 1
  * processsing error  => exit 1
* Fri Mar 18 2011 ms@suse.de
- move the knowledge about the default package manager from
  the KIWIManager object into the XML object. This is a configuration
  value and thus the default should be in the part of the code
  that processes the configuration
* Fri Mar 18 2011 ms@suse.de
- added a new target to the Makefile to allow the execution of a
  single unit test, i.e. support 'make KIWIXMLValidator.t'
  This is useful when working on unit tests as it allows to
  execute only the test being worked on.
* Thu Mar 17 2011 ms@suse.de
- fixed spec file. perl-satsolver from the 11.4 distro doesn't
  contain the code changes Klaus made during the Studio workshop
  Therefore kiwi provides the required version now in the
  Virtualization:Appliances repo for 11.4 (bnc #680549)
* Thu Mar 17 2011 ms@suse.de
- fixed 11.3 and 11.4 JeOS templates. openssl-certs doesn't exist
  there anymore. I replaced it by ca-certificates
* Thu Mar 17 2011 ms@suse.de
- increased size of boot partition from 60M to 100M. If
  mkinitrd is called it might happen that /boot runs
  out of space
* Wed Mar 16 2011 ms@suse.de
- The ISO generation code allows for either genisoimage or mkisofs.
  The checker does not support this. The patch addresses this problem
  and the checker no will be happy if either genisoimage or mkisofs
  is found (bnc #680148)
* Wed Mar 16 2011 ms@suse.de
- fixed typos in ppc boot scripts (spaces at end of line, tab mismatches)
  and adapt latest noarch code changes from x86 boot scripts to ppc
- removed 01-console.sh from ppc JeOS template. That's done by the
  setupConsole() function in suse-preinit
* Wed Mar 16 2011 ms@suse.de
- fix the VMware image example. The example does not contain
  necessary packages for a graphical user interface, thus
  setting window manager and runlevel in config.sh to imply
  that a GUI environment is present is misleading
* Tue Mar 15 2011 ms@suse.de
- fixed device map cleanup. The cleanup happened to early
  because the installBootLoader() code accesses the device
  map under certain circumstances but the original device
  was already freed. In that case the installBootLoader()
  code re-adds the mapping but that could lead to a different
  device name compared to the one stored in the device
  mapping table
* Tue Mar 15 2011 ms@suse.de
- prevent the use of File::Path qw(make_path remove_tree) because
  it's not compatible to File::Path qw(mkpath rmtree) in older
  perl versions
* Tue Mar 15 2011 ms@suse.de
- fixed race condition in CD device search, missing udevPending
- fixed wrong mountCalled variable setup, the return code of the
  mount call was not checked. So even if the mount failed the
  variable was set to 'yes' which leads to an umount of the root
  filesystem before the root filesystem was activated
* Tue Mar 15 2011 ms@suse.de
- removed local sle11 repo assigned to 11.4 net|oemboot boot image
  description. This was to pull in busybox but I don't want sle
  busybox in 11.4 to avoid compatibility problems (bnc #679659)
* Tue Mar 15 2011 ms@suse.de
- removed busybox from boot image descriptions for 11.4. It's
  not distributed with the 11.4 media anymore (bnc #679660)
* Tue Mar 15 2011 ms@suse.de
- added new consistency check to assure that all credentials
  used with any specified "https" repository are the same. Further
  the consistency check verifies that the username and password
  attributes are always used together.
* Tue Mar 15 2011 ms@suse.de
- added support for https repositories for zypper with username
  and password. Here is an example specification:
  <repository type="rpm-md" username="UNAME" password="PASS">
  <source path="https://..."/>
  </repository>
  kiwi now writes a credentials file and takes advantage of
  the zypper support for this file. This patch also addresses
  the problem that in the current implementation we end up using
  the build system zypper configuration file "zypper.conf"
  as zypper is called without the "--config" option.
* Tue Mar 15 2011 ms@suse.de
- DB: update documentation, https support added for zypper
* Mon Mar 14 2011 ms@suse.de
- fixed the udev trigger call which must only be called
  one time after the udev daemon has started (bnc #668014)
* Mon Mar 14 2011 ms@suse.de
- fixed setup of the loader initrd variable. Normally this variable
  is set via the kernel commandline but in case of a PXE setup it
  might be missing. In that case we check if the bootloader is
  present as .profile variable in kiwi_bootloader and set loader
  appropriately
* Mon Mar 14 2011 ms@suse.de
- fixed OEM PXE installation code. Wrong function name, checkServer
  was renamed into pxeCheckServer and the image file in case of a
  pxe installation is gzip compressed not squashfs embedded
* Mon Mar 14 2011 ms@suse.de
- DB: update documentation, fixed typos
* Mon Mar 14 2011 ms@suse.de
- fixed spec file, kiwi-desc-usbboot was dropped
* Mon Mar 14 2011 ms@suse.de
- added netboot root configuration check. The NFSROOT setup in
  combination with clicfs is not allowed. It doesn't make sense
  because it requires the clicfs process to run on the NFS server
  which would allow to connect only one station safely. AOEROOT
  or NBDROOT should be used in combination with clicfs instead
* Mon Mar 14 2011 ms@suse.de
- added kernel-firmware package to boot images
* Mon Mar 14 2011 ms@suse.de
- DB: update documentation, added a section about OEM -> pxe install
* Fri Mar 11 2011 ms@suse.de
- v4.81 released
* Fri Mar 11 2011 ms@suse.de
- added function resetBootBind() which turns the bind mounted
  boot path into a standard distro path which allows kernel
  updates. resetBootBind() is only called if mkinitrd can
  be used according to the image root filesystem setup. Along
  with the resetBootBind change we also had to fix the setup
  of the fat boot partition if the syslinux bootloader is used.
  Normally there is a link named boot -> . but on fat we can't
  have links so the data has to be moved. (bnc #678159)
* Fri Mar 11 2011 ms@suse.de
- adapt recent changes to x86 linuxrc to the s390 code stream
* Fri Mar 11 2011 ms@suse.de
- fixed typo in motd message of 11.4 JeOS
* Fri Mar 11 2011 ms@suse.de
- DB: update documentation for ramonly attribute
* Thu Mar 10 2011 ms@suse.de
- fixed syslinux boot partition setup, links on fat does not exist
* Thu Mar 10 2011 ms@suse.de
- added optional type attribute ramonly="true" which forces
  the COW device in a overlay filesystem setup to point to the
  main RAM memory
* Thu Mar 10 2011 ms@suse.de
- DB: update schema documentation
* Thu Mar 10 2011 ms@suse.de
- fixed evaluation of $main::FatStorage. I put it too late
  in the code so that the overall disk size wasn't adjusted
* Thu Mar 10 2011 ms@suse.de
- removed usbboot boot image and usb image type from kiwi. The
  obsolete usb image type has been replaced by the hybrid iso
  image type or by the oem image type.
* Thu Mar 10 2011 ms@suse.de
- DB: update documentation and removed the suse-live-stick examples.
- DB: suse-live-stick are now handled by the hybrid iso examples
* Thu Mar 10 2011 ms@suse.de
- added more careful grub install check
* Wed Mar  9 2011 ms@suse.de
- When mounting the hybrid boot drive, select the partition
  marked as bootable instead of blindly mounting the first one.
  This change makes it possible to update the system if the
  image has been written to a writable medium.
* Wed Mar  9 2011 ms@suse.de
- DB: update documentation, man page update (new options)
* Wed Mar  9 2011 ms@suse.de
- fixed syslinux boot device setup if LVM is used
* Wed Mar  9 2011 ms@suse.de
- make the creation of USB sticks more Windows friendly.
  For a detailed description how this is done watch the
  bug report: (bnc #677246)
* Tue Mar  8 2011 ms@suse.de
- fixed spec file for s390 build
* Tue Mar  8 2011 ms@suse.de
- fixed spec file for ppc build
* Fri Mar  4 2011 ms@suse.de
- netboot: allow network boot in degraded raid mode (bnc #668014)
- netboot: remove superblocks from raid disks if RAID
  has been dectivated in config.<MAC> (bnc #668014)
* Fri Mar  4 2011 ms@suse.de
- added support for the ncpus attribute on the <machine>
  element. It is used to set the number of virtual cpus for a
  VM and written to .vmx and .xenconfig
* Thu Mar  3 2011 ms@suse.de
- fixed xsl stylesheet convert47to48.xsl. existing lvmvolumes
  section wasn't translated into systemdisk section
* Thu Mar  3 2011 ms@suse.de
- added KIWICommandLine and KIWIRuntimeChecker modules. The command
  line module is a storage container for the commandline options
  passed to kiwi. It's used to transport the data into other objects.
  One successor of KIWICommandLine is the KIWIRuntimeChecker module
  which does some checks while kiwi runs. This means kiwi reads in
  the image description and after that the runtimer checker checks
  if it is possible to build the desired image according to the
  specified information. If that tests are passed kiwi enters the
  actual processing mode which is either the image prepare or create.
  This is useful to exit early if some option combination or data
  set is valid according to the XML schema but can't be build due
  to other reasons.
* Thu Mar  3 2011 ms@suse.de
- update RNG schema ec2region comment
* Thu Mar  3 2011 ms@suse.de
- added support for the new EC2 Japan region
* Thu Mar  3 2011 ms@suse.de
- assure that the given memory size given for a Vm is an integer
* Wed Mar  2 2011 ms@suse.de
- removed python-elementtree package required by smart
  which was removed in an earlier commit
* Wed Mar  2 2011 ms@suse.de
- make sure size parameter is used without adding kernel
  and initrd space if the given size is big enough.
* Wed Mar  2 2011 ms@suse.de
- removed smart packages
- export PBL_SKIP_BOOT_TEST=1 to allow mkinitrd to install
- changed SLE10 JeOS example:
  * all packages in bootstrap to allow the use of zypper
  * remove installiso option which doesn't work because no squashfs
- added an updated version of parted for SLE10
- added a zypper version check for the kiwi upgrade mode
- changed all SLE10 boot image descriptions to put packages
  into the bootstrap section to allow the use of zypper
- adapt README of SLE10 JeOS, smart is not required
- adapt kiwi.spec to recommend zypper only
* Wed Mar  2 2011 ms@suse.de
- v4.80 released
* Wed Mar  2 2011 adrian@suse.de
- export meta data location content keys for ftp tree medias
* Wed Mar  2 2011 adrian@suse.de
- ftp medias beside first one should not provide the product
* Mon Feb 28 2011 ms@suse.de
- don't ignore blocksize value from config.<MAC> (bnc #675004)
* Fri Feb 25 2011 ms@suse.de
- added support for --recycle-root option which allows to use
  and modify an existing root tree while in the kiwi prepare
  step.
* Fri Feb 25 2011 ms@suse.de
- v4.79 released
* Fri Feb 25 2011 ms@suse.de
- The default tftp block size chosen by kiwi is too small and
  not aligned to page size (4096), so it causes unnecessary
  overhead. This patch improves loading performance a lot
* Thu Feb 24 2011 adrian@suse.de
- just compare the major version of squashfs kernel module and squashfs tools (bnc #674653)
* Thu Feb 24 2011 adrian@suse.de
- parse all available product file not just the first one
* Thu Feb 24 2011 ms@suse.de
- fixed -z test for RELOAD_CONFIG variable in netboot
* Thu Feb 24 2011 ms@suse.de
- added unit testing for the KIWILocator object
* Thu Feb 24 2011 ms@suse.de
- added ensconce parameter -i imagename which contains
  the contents of the name attribute. ensconce requires this
  to distinguish between system image and initrd image
* Wed Feb 23 2011 ms@suse.de
- Using here documents with tabs in front of the limit
  string works but is not recommended. Tabs are ignored
  when searching for the limit string but spaces are not,
  in which case the here document ends at the next occurence
  of the limit string or at the end of the file with some
  shells not even issuing a warning
* Wed Feb 23 2011 ms@suse.de
- fixed use of uninitialized value if an improper
  configuration directory is specified
* Tue Feb 22 2011 ms@suse.de
- move warning messages about shm and semaphores into logfile
* Tue Feb 22 2011 ms@suse.de
- v4.78 released
* Tue Feb 22 2011 ms@suse.de
- added check to enforce the "no whitespace" rule for profile names
* Tue Feb 22 2011 ms@suse.de
- enhanced patternType check which now allows the use of the patternType
  attribute for all <packages> specifications that add packages to the
  image
* Tue Feb 22 2011 ms@suse.de
- fixed suse-min-gnome example, empty vmx package section doesn't make sense
* Tue Feb 22 2011 ms@suse.de
- fixed cleanup of shared memory segments and semaphores
  by a valid destructor in KIWISharedMem.pm
* Tue Feb 22 2011 ms@suse.de
- fixed regexp in __checkPatternTypeAttrConsistent()
* Tue Feb 22 2011 ms@suse.de
- fixed locale Makefile, wrong use of equals operator
* Mon Feb 21 2011 ms@suse.de
- v4.77 released
* Mon Feb 21 2011 ms@suse.de
- call isohybrid only once according to caller environment
* Mon Feb 21 2011 adrian@suse.de
- add optional support for hybrid iso for product medias
* Mon Feb 21 2011 ms@suse.de
- v4.76 released
* Mon Feb 21 2011 ms@suse.de
- added support for config-cdroot.tgz and config-cdroot.sh in
  OEM install media (CD and stick) (bnc #673566)
* Mon Feb 21 2011 ms@suse.de
- removed obsolete TestSuite check in KIWIURL
* Mon Feb 21 2011 ms@suse.de
- moved check for ec2-bundle-image after the check for the
  Amazon AWS credentials
* Sun Feb 20 2011 ms@suse.de
- setup owner/group permissions only if the user home
  directory exists (bnc #658172)
* Sun Feb 20 2011 ms@suse.de
- DB: update documentation for netboot config files update feature
* Sun Feb 20 2011 ms@suse.de
- added support for netboot config files update. The update
  happens according to the value of an optional md5sum hash
  specified per file
* Sat Feb 19 2011 ms@suse.de
- rebuild rng schema from rnc data
* Sat Feb 19 2011 ms@suse.de
- cosmetic changes to the unit tests
  * fixed the repo specification to point to online repo
  * updated the description to indicate what the test does
- improve the error message when an undefined profile is referenced
- added check for a consistent setting of the patternType
  attribute value
* Fri Feb 18 2011 ms@suse.de
- v4.75 released
* Fri Feb 18 2011 ms@suse.de
- fixed default behavior for oem-swap. If not specified the default
  should be to create a swap partition. This was accidently changed
* Fri Feb 18 2011 ms@suse.de
- DB: fixed description about default partitions created
* Fri Feb 18 2011 ms@suse.de
- allow creation of ec2 format even without credentials. In that
  case only the adaptions to the root image will be made but the
  ec2-bundle process will be skipped
* Fri Feb 18 2011 ms@suse.de
- fixed use of uninitialized value in squashfs version check
* Fri Feb 18 2011 ms@suse.de
- DB: update documentation according to the pxe raid feature change
* Fri Feb 18 2011 ms@suse.de
- changed raid 1 support for pxe images. The former implementation
  can only use raid for the root partition. This implementation
  allows a custom partition table to be mapped in one raid 1 per
  partition
* Wed Feb 16 2011 ms@suse.de
- fixed linuxPartition() to be fine with a raid partition too
* Wed Feb 16 2011 ms@suse.de
- fixed raid partition setup. The wrong id was set. If there
  is only one raid partition on the disk fdisk doesn't require
  a number for the 't' command
* Wed Feb 16 2011 ms@suse.de
- DB: update documentation
* Tue Feb 15 2011 ms@suse.de
- restore copy of temporary files only if they are not provided
  by the overlay tree. This affects /etc/hosts and /etc/resolv.conf
* Tue Feb 15 2011 ms@suse.de
- fixed createSnapshotMap() to be able to setup snapshot tables
  multiple times in a row. this requires unique table names
* Tue Feb 15 2011 ms@suse.de
- fixed yast2 firstboot startup for old (sle10) init script
  based startup sequence (bnc #660770)
* Tue Feb 15 2011 ms@suse.de
- fixed build, unfortunately perl-Test-Unit doesn't exist in BS
* Tue Feb 15 2011 ms@suse.de
- added unit test framework and some XML validation tests
* Tue Feb 15 2011 ms@suse.de
- fixed typos in XMLValidator output. This is
  important for the unit test results
* Tue Feb 15 2011 ms@suse.de
- removed testsuite from kiwi. The current --testsuite mode
  has been removed because it has turned out that's it's unused
  code. With this testsuite it was possible to run scripts
  inside the kiwi created root tree and check their results.
  Basically this is only useful for testing the root tree
  integrity which can always be done outside of kiwi like
  studio and slepos does. Along with the change we will add
  unit tests for testing the XML error handling and I plan
  to integrate an end-to-end testng framework which allows to
  realy make sure the appliance works as expected
* Mon Feb 14 2011 ms@suse.de
- fixed location of radeon.ko (typo: missing drivers/)
* Mon Feb 14 2011 ms@suse.de
- added graphics cards direkt rendering modules for
  i915, nouveau and radeon for openSUSE 11.4
* Fri Feb 11 2011 ms@suse.de
- v4.74 released
* Thu Feb 10 2011 ms@suse.de
- removed split sections from oem examples, use the kiwi
  default split section for this examples
* Thu Feb 10 2011 ms@suse.de
- changed the filesystem type to ext3 for 11.2 oem example
  because we found issues with ext4 on 11.2
* Thu Feb 10 2011 ms@suse.de
- fixed __addDefaultSplitNode() function. A cloneNode() call
  is required if you add children from another DOM tree
* Wed Feb  9 2011 ms@suse.de
- speedup prepare step with caches by skipping the bootstrap
  installation. If there is a cache available we add the
  bootstrap packages into the image package section and run
  the rest of the installation procedure in one image
  installation step
* Wed Feb  9 2011 ms@suse.de
- make use of zypper's autorefresh feature and don't call
  zypper refresh manually anymore
* Wed Feb  9 2011 adrian@suse.de
- offer options to ignore specified but missing packages for product generation
* Wed Feb  9 2011 adrian@suse.de
- make a difference between arch modifiers (addarch and removearch) and
  usage of a package (no modifier). This solves the last problem for openSUSE
  biarch medias.
* Wed Feb  9 2011 ms@suse.de
- fixed netboot disk device check. In case of a ramdisk only
  configuration there is no DISK set but the image download
  should happen into the ramdisk device. Therefore the disk
  device check was enhanced to check the ramdisk setup too
* Tue Feb  8 2011 adrian@suse.de
- fix arch= statement for real for multi arch medias, use only the subset
  of global required archs and filtered one by arch= statement
* Tue Feb  8 2011 ms@suse.de
- moved caching system over from clicfs to a device mapper
  snapshot table. This seems to be more stable and leaves more
  room for improvements
* Mon Feb  7 2011 adrian@suse.de
- Revert wrong commit overriding package attributes on multi arch medias
  This reverts commit 1ef1a8b62df61899480285051c9b725990685113.
* Mon Feb  7 2011 adrian@suse.de
- avoid error message about undefined $manager variable when building a product
* Mon Feb  7 2011 adrian@suse.de
- ignore missing debug packages, they may not get generated (esp on noarch packages).
* Mon Feb  7 2011 adrian@suse.de
- handle autodetected src packages with correct arch (src or nosrc)
* Mon Feb  7 2011 ms@suse.de
- DB: update documentation and examples due to new ec2region element
* Mon Feb  7 2011 ms@suse.de
- added support for the <ec2region> child element for
  <ec2config>. With this a user can specify one or multiple
  target regions for the EC2 image. Specifying multiple <ec2region>
  elements creates multiple AMIs. The main convenience is that one
  does not have to look for the aki-... cryptic name for the PVGrub
  boot kernel as the value gets embedded in the generated manifest.
  Supported values are: AP-Singapore, EU-West, US-East, US-West
* Mon Feb  7 2011 adrian@suse.de
- support blacklisting of packages via onlyarch=""
* Mon Feb  7 2011 adrian@suse.de
- report about all missing packages and abort afterwards, not at the first missing package.
* Mon Feb  7 2011 adrian@suse.de
- take care about arch= package statement for product required architectures
* Fri Feb  4 2011 ms@suse.de
- v4.73 released
* Fri Feb  4 2011 ms@suse.de
- DB: update ec2 documentation
* Fri Feb  4 2011 ms@suse.de
- fixed typo in ec2 format creation (missing /)
* Thu Feb  3 2011 ms@suse.de
- fixed ec2 examples
* Thu Feb  3 2011 ms@suse.de
- DB: update ec2 docs and examples per request in (bnc #667303)
* Thu Feb  3 2011 ms@suse.de
- improved ec2 format creation per request in (bnc #667303)
* Wed Feb  2 2011 ms@suse.de
- provide partition info in MB instead of KB
* Tue Feb  1 2011 ms@suse.de
- update s390 boot code according to generic changes in the x86 boot code
* Tue Feb  1 2011 ms@suse.de
- added support for ppc images:
  * added oemboot boot code
  * added vmxboot boot code
  * adapt kiwi for creation of ppc disk images
  * adapt kiwi for creation of ppc install iso
  * added suse-SLE11-JeOS template for ppc
  * added support for lilo boot loader used for ppc
  * changed spec file to build ppc packages
* Tue Feb  1 2011 ms@suse.de
- DB: update documentation: Added information about plain:// source
- DB: update documentation: Improved smb:// paragraph
* Tue Feb  1 2011 ms@suse.de
- fixed squashfs version check
* Tue Feb  1 2011 ms@suse.de
- DB: update documentation, removed wrong version information
* Tue Feb  1 2011 ms@suse.de
- added support for plain:// url types. They forward the URL
  (everything following "plain://") unmodified to the package
  manager. This can be used if kiwi does not support a special
  URL but the package manager does
* Tue Feb  1 2011 ms@suse.de
- fixed smb mount. Leave // to indicate the share name and make
  sure we create a unique mount point with mktemp instead of using
  the share name as base
* Tue Feb  1 2011 ms@suse.de
- DB: update documentation from review
* Mon Jan 31 2011 ms@suse.de
- use -o guest option to mount a samba share without
  username and password specified
* Mon Jan 31 2011 ms@suse.de
- fixed use of profiled repository sections
* Mon Jan 31 2011 ms@suse.de
- DB: fixed typo: cifs-utils is required in bootstrap section
* Mon Jan 31 2011 ms@suse.de
- DB: added documentation about smb:// repo source type
* Mon Jan 31 2011 ms@suse.de
- added support for username and password in repository elements
- enhanced cifs mount (smb://) to be able to use credentials
* Mon Jan 31 2011 adrian@suse.de
- Fail hard on missing packages during product build.
  This is requested with high prio from coolo, we need to make this
  an option later on.
* Fri Jan 28 2011 ms@suse.de
- v4.72 released
* Fri Jan 28 2011 ms@suse.de
- run parted capability checks only if parted exists
* Thu Jan 27 2011 ms@suse.de
- fixed build for 11.4
* Thu Jan 27 2011 ms@suse.de
- added filesystem mktool vs. kernel module version check for the
  squashfs filesystem. The check has been added in the checkType()
  function
* Thu Jan 27 2011 ms@suse.de
- add support for smb:// type urls by supporting cifs mount
* Wed Jan 26 2011 ms@suse.de
- DB: fixed typo
* Wed Jan 26 2011 ms@suse.de
- DB: added patch from Franz Leitl, fixing some typos
* Wed Jan 26 2011 ms@suse.de
- added partition ID information into progress information when
  installing the system in partition install mode
* Wed Jan 26 2011 ms@suse.de
- fixed lvresize calls in kiwi which are all missing the '+' prefix
- fixed createSnapshotMap() to know about LVM volumes
- fixed partition based installation with LVM image. The dialog for
  boot and root partition selection was broken and there is also a
  small fix improving the progress information when installing the
  image partitions to the disk partitions
* Tue Jan 25 2011 ms@suse.de
- reverted the following commits:
  eeecf05d029e7e75abfc44a5c2c600263838c50e
  438e83976cbd12dde20511ea5d000620082fa066
  They broke the yast autoyast and firstboot setup. The provided
  config-yast-autoyast.xml or config-yast-firstboot.xml were not
  handled anymore
* Mon Jan 24 2011 ms@suse.de
- removed fdisk support entirely except for changing the
  partition table created by the isohybrid tool. parted can't
  handle that table and therefore we use fdisk inside the
  function createHybridPersistent() but nowhere else anymore
* Mon Jan 24 2011 ms@suse.de
- update schema and kiwi documentation
* Mon Jan 24 2011 ms@suse.de
- fixed mdadm --stop call for pxe raid(1) boot
* Sun Jan 23 2011 ms@suse.de
- check the return code for the image container mount call
* Fri Jan 21 2011 ms@suse.de
- v4.71 released
* Fri Jan 21 2011 ms@suse.de
- fixed partition selection in OEMFindPartitions(). Don't
  take any other than 0x83 partition types into account
* Fri Jan 21 2011 ms@suse.de
- change the layout of the install ISO / USB stick. The raw
  disk image on the install media was compressed using gzip. The
  downside is that it's not possible to loop mount the compressed
  file. But for partition based installations this is required.
  Therefore the raw disk image is now packed into a squashfs
  filesystem (bnc #665888)
* Fri Jan 21 2011 ms@suse.de
- fixed typos in kiwi_oemunattended and kiwi_oemswap evaluation
  which caused wrong content in the oemconfig file
* Thu Jan 20 2011 ms@suse.de
- added support for gparted in partition based oem installation
  If the partition table does not provide the correct layout
  we start a X session with some descriptive message window
  and the gparted tool to be able to change the partition
  table
  Author: Bernhard M. Wiedemann <bernhard+smartdiffgit lsmod.de>
* Thu Jan 20 2011 ms@suse.de
- fix approx 109 typos
* Thu Jan 20 2011 ms@suse.de
- added check for $imageDiskDevice and the existence of
  $imageBootDevice to the setupBootPartition() function in
  order to prevent unused mount actions for /boot
  Author: Bernhard M. Wiedemann <bernhard+smartdiffgit lsmod.de>
* Thu Jan 20 2011 ms@suse.de
- fixes from review
* Thu Jan 20 2011 ms@suse.de
- fixed skip check for firstboot and autoyast descriptions
* Wed Jan 19 2011 ms@suse.de
- added check which disallows white space in the value for
  the displayname attribute
* Wed Jan 19 2011 ms@suse.de
- fixed use of undefined value in KIWIXML.pm validation
* Tue Jan 18 2011 ms@suse.de
- added support for raid 1 (mirroring) for pxe images
* Tue Jan 18 2011 ms@suse.de
- fixed insertion of repo alias and priority commandline options
  into the correct section of the XML description.
* Tue Jan 18 2011 ms@suse.de
- dont't overwrite firstboot.xml or autoconf.xml if they
  exist as overlay files in the overlay root tree
* Mon Jan 17 2011 ms@suse.de
- create private __expandFS() function and eliminate some code
  duplication by this new function
* Mon Jan 17 2011 ms@suse.de
- added check for the PatternType attribute which may only be
  used for image and bootstrap packages. Check that this is
  set appropriately.
* Sat Jan 15 2011 ms@suse.de
- fixed typo in use of oem-shutdown element
* Fri Jan 14 2011 ms@suse.de
- fixed evalutation of patternType attribute
* Thu Jan 13 2011 ms@suse.de
- make sure fixupFDiskSectors() only fixes the first partition
  start sector and doesn't touch the others (bnc #664236)
* Thu Jan 13 2011 ms@suse.de
- make sure fixupFDiskSectors() is called on a non busy table (bnc #664236)
* Thu Jan 13 2011 ms@suse.de
- fixed fdisk setup in alignment mode. fdisk is not able
  to suggest the correct next sector if called with the
  option "-u". Therefore only one partition is created in
  that mode and the rest is created in fdisk cylinder
  based mode (bnc #664236)
* Thu Jan 13 2011 ms@suse.de
- added new module KIWILocator which perform operations to
  locate objects needed by Kiwi in the filesystem. Along with
  the new module other code parts which did that before has
  been replaced
* Thu Jan 13 2011 ms@suse.de
- added support for satsolver bindings provided with the
  perl-satsolver package
* Mon Jan 10 2011 ms@suse.de
- fixed syslinux/isolinux configuration for disk based
  images. Several problems like missing branding files,
  write checks in not existing directories and file checks
  in wrong directories were found
* Mon Jan 10 2011 ms@suse.de
- fixed syslinux/isolinux config for non graphics boot setup
* Mon Jan 10 2011 ms@suse.de
- minor clean up, remove match for yes
* Fri Jan  7 2011 ms@suse.de
- v4.70 released
* Fri Jan  7 2011 ms@suse.de
- fixed evaluation of kernelcmdline in createImageLiveCD()
* Wed Jan  5 2011 adrian@suse.de
- Make SUSE meta data compression rsyncable (partly transferable).
* Wed Jan  5 2011 ms@suse.de
- fixed setupKernelModules() in a way that it doesn't overwrite
  settings from /etc/sysconfig/kernel but append to them
* Tue Jan  4 2011 ms@suse.de
- revert last commit, broken patch
* Tue Jan  4 2011 ms@suse.de
- fix sed expression which removes the architecture suffix
  from the image name. The expression failed if the architecture
  is also part of the name so it changed to match the suffix
  at the end of the name string only
* Tue Jan  4 2011 ms@suse.de
- don't call setupConsole twice if systemIntegrity is fine
  in kiwi netboot code. Also make sure unsetFile(), called
  on the dhcp info file, is called before the interface is
  released
* Tue Jan  4 2011 ms@suse.de
- fixed releaseNetwork() to cleanup /dev/.sysconfig as well
  as unset the variables from the dhcp info file which has been
  exported into the root shell environment. Those variables
  caused conflicts with the network scripts in /etc/init.d
* Tue Jan  4 2011 ms@suse.de
- removed obsolete config file from suse-11.3/suse-live-stick
* Mon Jan  3 2011 ms@suse.de
- cleanup netboot code. moved some functions into the KIWILinuxRC.sh
  pool and fixed bootloader setup when using clicfs images
* Mon Jan  3 2011 ms@suse.de
- removed old and unmaintained ppc code
* Wed Dec 22 2010 ms@suse.de
- added check for first sector start after repartitioning via
  fdisk. The start sector must be the same before and after the
  repartitioning (bnc #659865)
* Tue Dec 21 2010 ms@suse.de
- make sure bootincluded packages and archives are not
  removed by the initrd strip down functions. This is done
  by introdudcing two new functions in KIWIConfig.sh:
  * basePackBootIncludes
  * baseUnpackBootIncludes
    whereas the first one packs the bootinclude files and the
    second one unpacks them again. The standard boot image
    descriptions provided by kiwi uses that functions to make
    sure all bootincluded files can be restored at the end of
    the strip down functions called in image.sh (bnc #660743)
* Fri Dec 17 2010 ms@suse.de
- v4.69 released
* Wed Dec 15 2010 ms@suse.de
- if ensconce is used the pattern/package list is already solved.
  In that case it doesn't make sense to do solving with satsolver
  again. We are using the list provided by ensconce as solved list
  directly in that case.
* Wed Dec 15 2010 ms@suse.de
- fixed ensconce call and parameters:
  * ensconce now resides in /usr/bin, so we can call it that way
  * pass -b parameter to ensconce, since bootstrap is obsolete
  * pass proper root parameter to ensconce
* Wed Dec 15 2010 ms@suse.de
- fixed profile request handling when kiwi invokes itself
* Wed Dec 15 2010 ms@suse.de
- fixed functions ignoreRepositories() and addRepository to
  correctly update the DOM tree and not only the internal
  hash structures
* Wed Dec 15 2010 ms@suse.de
- fixed SLE11 template which did not include gfxboot branding
  packages if xenFlavour was selected
* Mon Dec 13 2010 ms@suse.de
- fixed warning message when using int() on empty string
* Mon Dec 13 2010 ms@suse.de
- fixed use of .buildenv
* Fri Dec 10 2010 ms@suse.de
- renamed modprobe.conf.local to modprobe.d/99-local.conf on
  systems which doesn't support the old conf file anymore
* Fri Dec 10 2010 ms@suse.de
- v4.68 released
* Thu Dec  9 2010 ms@suse.de
- fixed location of local modprobe configuration file.
  The new place is in /etc/modprobe.d/99-local.conf. Only if this
  doesn't exist we will use /etc/modprobe.conf.local
* Wed Dec  8 2010 ms@suse.de
- make baseSetupInPlaceGITRepository more useful
* Wed Dec  8 2010 ms@suse.de
- fixed initial value (set it to empty) for INITRD_MODULES
* Wed Dec  8 2010 ms@suse.de
- removed obsolete setImageType() function from KIWIXML
* Wed Dec  8 2010 ms@suse.de
- make use of the --check-config modus in kiwi to validate
  and check the kiwi provided XML configurations within the
  Makefile.
* Wed Dec  8 2010 ms@suse.de
- fixed suse-SLE11-JeOS to validate correctly. It's not
  allowed to have multiple import="true" attributes set.
  Therefore the profile setup for this JeOS XML changed
* Wed Dec  8 2010 ms@suse.de
- added Option --check-config which validates the XML using the
  new KIWIXMLValidator module. Along with the new module validation
  from KIWIXML has been moved into the KIWIXMLValidator object
* Wed Dec  8 2010 ms@suse.de
- fixed use of createImageUSB() which has changed its name
  into createImageRootAndBoot()
* Tue Dec  7 2010 ms@suse.de
- fixed boot partition setup for non mkinitrd supported setups
* Tue Dec  7 2010 ms@suse.de
- added updateTypeList() function in KIWIXML which is required
  if an accessor function changes the XML tree the internal data
  structures needs to be updated too
* Tue Dec  7 2010 ms@suse.de
- don't overwrite the zypp repo data when in recovery mode (bnc #657922)
* Tue Dec  7 2010 ms@suse.de
- fixed cache creation
* Mon Dec  6 2010 adrian@suse.de
- fix build for factory (openSUSE 11.4)
* Mon Dec  6 2010 ms@suse.de
- added KIWIXML methods __populateProfiles() and __populateTypeInfo
  which are gathering the profile and type information as they are
  set by the XML description. Along with this change the following
  methodes have changed: __populateDefaultProfiles
  and __populateProfiledTypeInfo. They both read the data structures
  created by the first two and assign a new data structure
  according to the selected profiles.
* Mon Dec  6 2010 ms@suse.de
- removed unneeded KIWIXML instance from KIWIBoot. The KIWIBoot
  constructor creates one instance of KIWIXML which is sufficient
  for all operations
* Mon Dec  6 2010 ms@suse.de
- fixed parameter list in 'new KIWIXML' instances
* Sat Dec  4 2010 ms@suse.de
- fixed repository update in __updateDescriptionFromChangeSet()
* Fri Dec  3 2010 ms@suse.de
- v4.67 released
* Fri Dec  3 2010 ms@suse.de
- make addDefaultSplitNode() a private helper method
  called __addDefaultSplitNode(). Also fixed that function to
  work correctly. It should add the default split mode for all
  relevant types (iso and split) and add the section only if
  those types doesn't already implement a split section
* Thu Dec  2 2010 ms@suse.de
- cleanup KIWIImage and main kiwi code. The global variables
  ForeignRepo and ImageName has been removed. Additionally the
  KIWIXML constructor doesn't have the ForeignRepo hash in
  its parameter list. Inside KIWIXML the entire foreign data
  setup has been changed into methods creating and applying
  a changeset. Therefore a temporary global hash XMLChangeSet
  has been introduced. After apply of the changeset it will
  be removed directly. Along with the cleanup the creation
  and check for boot and prebuilt images has been moved into
  functions. The preparation step of kiwi now also writes back
  the internal XML changes into the XML file. Last but not
  least the global variable ImageDescription has been introduced
  which stores in prepare and create mode the path to the
  base image description which is required to know the location
  of bootincluded archives and this:// repos
* Wed Dec  1 2010 ms@suse.de
- removed xml inheritance. This feature was never used
* Tue Nov 30 2010 ms@suse.de
- restructured XML data processing by adding the following
  KIWIXML methods: __populateTypeInfo() and __populateImageTypeAndNode()
  The first method creates the %%typeInfo hash which contains all
  possible <type> elements according to the selected profiles. The
  second method operates on the %%typeInfo hash and initializes
  those part of the hash which represents the requested image type
  or the primary type or the first type read in. Both methodes are
  called only _once_ inside the object constructor. The existing method
  getImageTypeAndAttributes() has changed to simply return the selected
  part of the %%typeInfo hash and does _not_ change any object data
  as done before.
* Tue Nov 30 2010 ms@suse.de
- added check that only one type with image="myName" exists
  per <preferences section>
* Tue Nov 30 2010 ms@suse.de
- fixed use of uninitialized value in KIWIXML processing
* Mon Nov 29 2010 ms@suse.de
- if logfile option is specified along with --init-cache set the
  logfile to the 'terminal' mode. That's because in that mode
  multiple logfiles per cache are created and it wouldn't make
  much sense to have them in one file. If the output is on the
  terminal the user can decide himself for the redirection
* Mon Nov 29 2010 ms@suse.de
- require clicfs >= 1.3.9 due to major bugs in former versions
* Mon Nov 29 2010 ms@suse.de
- fixed __checkReferencedProfDefined to work with sections
  defining more than one profile like netboot does
* Mon Nov 29 2010 ms@suse.de
- fixed invalid numeric expression in reqProfiles
- added __populateDefaultProfiles according to XML restructuring
  and removed setDefaultProfiles
* Mon Nov 29 2010 ms@suse.de
- fixed use of uninitialized value in KIWIXML.pm
* Fri Nov 26 2010 ms@suse.de
- v4.66 released
* Fri Nov 26 2010 ms@suse.de
- fixed use of undefined value as an ARRAY reference
* Fri Nov 26 2010 ms@suse.de
- removed unused cleanInitrd() function
* Fri Nov 26 2010 ms@suse.de
- make sure bootstrap packages are handled when using a cache
- fixed time when KIWIImage.pm mounts the overlay and provide
  a function getImageTree() which returns the currently used
  root tree. Move the recovery creation, profile update, and
  cleanup after the KIWIImage module creation
* Fri Nov 26 2010 ms@suse.de
- fixed overlay setup for KIWIBoot modules. Only if a cow
  file exists in the given system image path it's required to
  setup the overlay mount
* Fri Nov 26 2010 ms@suse.de
- don't create new kiwi object if there is already one available
* Thu Nov 25 2010 ms@suse.de
- check image type only if a preferences section is present
* Thu Nov 25 2010 ms@suse.de
- fixed profile check in create mode
* Thu Nov 25 2010 ms@suse.de
- cleanup xenconfig setup by removing conditions that no longer apply
  due to the removal of the xen image type which is now handled
  by the vmx/oem type flavoured with xen and xenk profiles
* Thu Nov 25 2010 ms@suse.de
- make sure the package manager is added only once to the
  list when in --info mode
* Thu Nov 25 2010 ms@suse.de
- fixed dumpsolv regexp which searches for pattern names
* Thu Nov 25 2010 ms@suse.de
- fixed creation of boot image caches. It's required to prevent
  the kernel extraction from the cache because this is done in
  the preparation process which uses the cache
- don't allow logfile option when in init-cache mode. This is
  because each cache has its own logfile living in the cache
  directory
* Thu Nov 25 2010 ms@suse.de
- fixed minor code duplication inside the RNC schema
* Thu Nov 25 2010 ms@suse.de
- deactivate compression for clicfs caches (faster)
- fixed and cleaned up profile evaluation and use
* Thu Nov 25 2010 adrian@suse.de
- make "mk_listings" call during product generation optional
* Thu Nov 25 2010 ms@suse.de
- explicitly call SuSEconfig --module permissions. This module
  is no longer called by the default SuSEconfig call so we need
  to call it directly
* Wed Nov 24 2010 ms@suse.de
- added the following consistency checks:
  * only 1 profile may be marked as default via import="true"
  * only 1 type per <preference> spec may be set as default via primary="true"
  * only 1 <preference> spec may reference 1 <profile>
  * only 1 <preference> specification without a profiles=... attribute
  * check that all references used via profiles="aName" attribute have
    a definition of <profile name="aName".../>
* Wed Nov 24 2010 ms@suse.de
- require specific clicfs version because the version before
  has severe problems when writing to a cow file
* Tue Nov 23 2010 ms@suse.de
- don't preserve rpm database on recovery. This could cause
  an inconsistent rpm database. Not preserving it could cause
  an incomplete but consistent database which is better. For
  reference a copy of the old database is stored in
  /var/lib/rpm.backup
* Mon Nov 22 2010 ms@suse.de
- follow up: make sure system filesystems and mount options corresponds
  with the default settings we use in a standard installation with yast
* Mon Nov 22 2010 ms@suse.de
- fixed cleanImage() function to cleanly umount partitions before
  calling init. Also make sure cleanImage reports its actions
  as part of the boot.kiwi logfile
- make sure system filesystems and mount options corresponds with
  the default settings we use in a standard installation with yast
* Mon Nov 22 2010 ms@suse.de
- fixed typo in option description
* Fri Nov 19 2010 ms@suse.de
- v4.65 released
  * rebuild documentation
  * rebuild schema documentation
* Fri Nov 19 2010 ms@suse.de
- added an oem hook named: preCallInit which runs right before
  init is called or in case of a reboot/halt request right before
  that reboot (bnc #654404)
* Fri Nov 19 2010 ms@suse.de
- make sure /dev is bind mounted when installing the very
  first bootstrap packages.
* Thu Nov 18 2010 ms@suse.de
- DB: update documentation
* Wed Nov 17 2010 ms@suse.de
- put package manager into solver list when calling
  kiwi --select ... --info packages
- fixed clicfs mount in cache mount code:
  * we don't want reserved blocks
  * we don't want automatic filesystem check
  * we don't want to use --ignore-cow-errors
- deactivate automatic cache creation and introduce a new
  operation mode called kiwi --init-cache. Caches needs to
  be created in a separate call. This has turned out to be
  more flexible and prevent customer confusion
- add default cache image location: /var/cache/kiwi/image
  which can be overwritten by the --cache option. If one want
  to use caches in prepare or create mode it's required to
  select the cache location with this option.
- removed baseroot attribute and defaultbaseroot element
  from XML description. baseroot has been replaced by the
  clicfs based caching process
- don't leave .broken inside the tree if it is not broken
- cleanup the overlay preparation code. The code is in
  KIWIOverlay.pm exclusively. At each code point which
  requires it we create a KIWIOverlay object and let it
  control the overlay mount
* Wed Nov 17 2010 ms@suse.de
- DB: add documentation about PXE hardware maps
* Wed Nov 17 2010 ms@suse.de
- update documentation for oem-unattended mode
* Wed Nov 17 2010 ms@suse.de
- if in oem-unattended mode and we found more than one disk for
  installation, use the first disk found by hwinfo
* Wed Nov 17 2010 ms@suse.de
- fix bug in the format conversion from raw to qcow2.
  The 'convert' command to qemu-mig was missing.
* Wed Nov 17 2010 ms@suse.de
- move the two consistency checks (kiwirevision and
  version format) out of the KIWIXML constructor and into
  their own methods
- Implement a new consistency check, __checkFilesysSpec().
  This method assures that the 'filesystem' attribute is used
  for image types that require the attribute
* Tue Nov 16 2010 ms@suse.de
- fixed creation and use of kiwi caches for boot images
  also make sure the same clicfs cache is mounted only once
  and is released in case of an exception
* Tue Nov 16 2010 ms@suse.de
- netboot: fixed incorporation of hardware maps
- netboot: evaluate additional VENDOR_CONF value
* Tue Nov 16 2010 ms@suse.de
- fixed use of uninitialized variable @configNodes
- fixed solvable setup for susetags
* Tue Nov 16 2010 ms@suse.de
- update RNG schema due to last change to the RNC schema
* Tue Nov 16 2010 ms@suse.de
- added new element <vmconfig-entry>text</vmconfig-entry> which
  allows the user to specify raw text that ends up in the .vmx
  or .xenconfig file. Certain default options currently written by
  Kiwi may be over written by these settings. Therefore the use
  of this option happens on your own risk. No validation of the
  raw text is performed.
* Mon Nov 15 2010 ms@suse.de
- verify format used for the mac address when specifying
  the attribute on the vmnic element.
* Mon Nov 15 2010 ms@suse.de
- fixed logging for listXMLInfo()
* Mon Nov 15 2010 ms@suse.de
- move the XML validation and loading to it's own methods
- added image consistency checks into KIWIXML as addition to
  the XSLT stylesheet processor. The function __validateConsistency
  provides a place to add consistency checks:
  * Added check: __checkPostDumpAction which ensures that only
    one of oem-bootwait, oem-reboot, oem-reboot-interactive,
    oem-shutdown or oem-shutdown-interactive is specified.
* Mon Nov 15 2010 ms@suse.de
- added return string to partitionSize() function even in case of error
* Mon Nov 15 2010 ms@suse.de
- added bc tool to netboot image descriptions
* Thu Nov 11 2010 ms@suse.de
- allow boottimeout setup for image="iso" too
* Wed Nov 10 2010 ms@suse.de
- added xsl stylesheet to convert images which uses the image="xen"
  type into an appropriate image="vmx" type because the xen image
  type was removed. Additionally increased schema version to v5.0
  with this change
* Tue Nov  9 2010 ms@suse.de
- netboot: added support for hardware maps. Hardware maps are
  configuration files for a given range of MAC addresses. If a client
  of the specified range boots up the corresponding hardware map
  file will be loaded and merged with the default configuration.
  That way you can specify in one config file configurations dedicated
  to different machines. Example config.<MAC>
  ...
  HARDWARE_MAP="vendor1, vendor2, vendor3"
  vendor1_HARDWARE_MAP="xx:xx:xx:xx:xx:x1, xx:xx:xx:xx:xx:x2"
  ...
  if client xx:xx:xx:xx:xx:x1 boots up the file hardware_config.vendor1
  is additionally loaded from the pxe boot server
* Mon Nov  8 2010 ms@suse.de
- fixed doit OBS script to work with branch names different from 'kiwi'
* Mon Nov  8 2010 ms@suse.de
- more flexible post dump behavior:
  * Fix misnomer of oem-dumphalt, now called oem-bootwait
    xslt included, no change in functionality from oem-dumphalt
  * Add oem-reboot-interactive
    post a message before rebooting the system after image expansion
    wait for user interaction
  * Add oem-shutdown
    power the system off after dump and image expansion are complete
  * Add oem-shutdown-interactive
    post a message before system power off, wait for user interaction
* Sun Nov  7 2010 ms@suse.de
- word-smithing for images.sh and config.sh doc
* Fri Nov  5 2010 ms@suse.de
- v4.64 released
- rebuild documentation
- rebuild schema documentation
* Fri Nov  5 2010 ms@suse.de
- added a command line argument to sepecify the default 'yes'
  answer for questions which could come up during the build process
* Fri Nov  5 2010 ms@suse.de
- changed partition layout of LVM based vmx/oem images. The boot
  partition is now the first partition and we will use only one
  partition for the entire LVM as second partition (bnc #651331)
* Fri Nov  5 2010 ms@suse.de
- fixed compare statement, in perl 'eq' for strings must be used
* Thu Nov  4 2010 ms@suse.de
- fixed rpmlint warning: kiwi.src:434: W: macro-in-comment %%config
* Thu Nov  4 2010 ms@suse.de
- added 11.4 JeOS to spec file
* Thu Nov  4 2010 ms@suse.de
- added templates and boot image descriptions for SuSE 11.4
- removed doc/examples/suse-11.1
* Thu Nov  4 2010 ms@suse.de
- fixed format conversion checks. iso type can't be converted
* Thu Nov  4 2010 ms@suse.de
- fixed checkLVMbind() function to activate volume groups before
  checking the device mapper nodes
* Wed Nov  3 2010 ms@suse.de
- fixed check for xvc/hvc consoles (bnc #650667)
* Tue Nov  2 2010 ms@suse.de
- keeping old boot files in /boot and trying to copy
  in newly generated initrd + kernel during image startup
  could result in not enough space on /boot partition for LVM
  enabled builds. This patch fixes that by removing the old
  kernel + initrd, before copying in the new one.
* Tue Nov  2 2010 ms@suse.de
- added languages nb_NO,da_DK,pt_PT and en_GB to the
  selection list
* Tue Nov  2 2010 ms@suse.de
- support multiple vmnic elements for VMware
* Mon Nov  1 2010 ms@suse.de
- added support for the XFS filesystem
* Mon Nov  1 2010 ms@suse.de
- fixed the schema inplace dochint for the oem-dumphalt element
- rebuild documentation
* Mon Nov  1 2010 ms@suse.de
- don't let the recovery partition grow to the rest disk space
  available. This is not intended as the recovery partition should
  only be of the min size required to store the recovery data
* Fri Oct 15 2010 ms@suse.de
- v4.63 released
- rebuild documentation
- rebuild schema documentation
* Fri Oct 15 2010 ms@suse.de
- fixed repartition code, out of bounds partitioning
* Thu Oct 14 2010 ms@suse.de
- added setupConsole() function to activate xvc and/or hvc consoles
  if their device nodes are present
* Wed Oct 13 2010 ms@suse.de
- fixed xenconfig creation, virtual framebuffer line wasn't written
* Wed Oct 13 2010 ms@suse.de
- fixed suse-11.3/suse-xen-guest example by removing some
  old static sysconfig files. Also remove the boot.xen service
  script it's no longer required as we can use the xvc device
  for the console
* Wed Oct 13 2010 ms@suse.de
- added support for targetdevice option for filesystem images
- if the targetdevice option is used check if the device
  exists before proceeding
* Tue Oct 12 2010 ms@suse.de
- make sure volume is active again if no LVM repartition takes
  place. This is because recreateVTOCTable has deactivated the
  volume group before
* Tue Oct 12 2010 root@s390a06.suse.de
- fixed LVM based repartition code for s390 and DASD, it's required to
  recreate the VTOC table here before you can create new partitions
* Tue Oct 12 2010 ms@suse.de
- fixed creation of VTOC table; close active device maps first
* Mon Oct 11 2010 ms@suse.de
- fixed spec file requirements, grub and clicfs only exists
  on ix86 and x86_64
* Mon Oct 11 2010 ms@suse.de
- fixed use of satsolver if ensconce is used together with
  pattern names. ensonce uses an already resolved manifest file
  and thus it's not required to solve the patterns via
  satsolver (bnc #643442)
* Mon Oct 11 2010 ms@suse.de
- changed the lvmvolumes section into systemdisk like the
  following example shows:
  <systemdisk name="system">
  <volume name="/home" freespace="1G"/>
  ...
  </systemdisk>
- update to new schema version 4.8 due to the systemdisk change
- if systemdisk is specified a lvm setup is implicitly requested.
  Therefore also the attribute 'lvm' from the type section was removed
- Also the oem-home element was removed with this change. A volume
  instead of a single partition should be used.
- wrote a xslt stylesheet for the following conversions:
  * remove lvm attribute
  * move lvmvolumes element into systemdisk
  * move lvmgroup attribute into name
  * if oem-home is set create a systemdisk setup with a home volume
- update documentation due to the systemdisk change
* Fri Oct  8 2010 ms@suse.de
- v4.62 released
- rebuild documentation
* Thu Oct  7 2010 ms@suse.de
- added vfb (virtual framebuffer configuration) to the xenconfig file
  written by kiwi. This allows easy graphics console access with
  the virt-viewer program. If you want to run the xen domU in text
  mode you have to manually pass the option xencons=tty in the pygrub
  boot menu
* Thu Oct  7 2010 ms@suse.de
- added egrep for dasd_configure to initrd
- fixed the creation of the boot partition if a real targetdevice
  is used to prevent using the entire rest space for the boot image
* Thu Oct  7 2010 root@s390vm05.suse.de
- fixed boot device detection for zipl on dasd devices with LVM
* Thu Oct  7 2010 ms@suse.de
- removed xencons boot option for domU creation in .xenconfig
  and from the bootloader kernel options (bnc #644138)
* Thu Oct  7 2010 ms@suse.de
- update and rebuild documentation
* Thu Oct  7 2010 ms@suse.de
- added support for setting up the boottimeout value prior
  to the default value in the config.xml <type> section.
  the unit for the timeout value is seconds if grub is used
  as the boot loader and 1/10 seconds if syslinux is used
  <type ... boottimeout="20">
  ...
  </type>
* Thu Oct  7 2010 ms@suse.de
- fixed fdasd input creation, wrong 't' command setup
* Thu Oct  7 2010 ms@suse.de
- call udevPending before checking /sys/bus/usb/devices
* Mon Oct  4 2010 ms@suse.de
- DB: Deleted kiwi-doc-intro.xml and moved content to kiwi-doc-workflow.xml
- DB: Removed xinclude of kiwi-doc-intro.xml from kiwi-doc.xml
* Fri Oct  1 2010 ms@suse.de
- v4.61 released
- rebuild documentation
* Fri Oct  1 2010 ms@suse.de
- fixed creation of install CD if syslinux is used.
- fixed syslinux dosfs boot partition setup by adding the
  dosfstools package to the oemboot image descriptions
* Thu Sep 30 2010 ms@suse.de
- fixed OEMRepartStandard(). Additionally to the last commit, fixed
  the use of the suggested last cylinder for swap and recovery only
  if no oem-systemsize is set
* Thu Sep 30 2010 ms@suse.de
- fixed OEMRepartStandard() to use the suggested last cylinder for
  the last partition to become created instead of a fixed value.
  Also use the suggested last cylinder for the resize of the root
  partition if there is no other partition to become created and
  no oem-systemsize was specified
* Wed Sep 29 2010 root@s390vm05.suse.de
- fixed boot device detection for s390 KVM target
* Mon Sep 27 2010 ms@suse.de
- fixed typo in DHCPCD option test
* Mon Sep 27 2010 ms@suse.de
- added support for partition alignment with fdisk. Thus support
  for 4k-sector size disks (logical 512 byte) with fdisk was added
  when using parted the -align option is used in any case though.
  In order to use the alignment when fdisk is used the oemconfig
  element oem-align-partition must be set to 'true' (bnc #637333)
* Thu Sep 16 2010 ms@suse.de
- v4.60 released
- rebuild documentation
* Thu Sep 16 2010 ms@suse.de
- removed umount -a call to prevent a read-only remount (bnc #635159)
* Thu Sep 16 2010 ms@suse.de
- fixed searchGroupHardwareAddress() parameter list. mac_list must be
  a quoted string otherwise only the first entry is evaluated
* Wed Sep 15 2010 ms@suse.de
- use $main::Gzip for compressing the recovery tarball
* Wed Sep 15 2010 ms@suse.de
- moved hooks directory to kiwi-hooks
- added and documented new hooks for oemboot
  preHWdetect,preImageDump,postImageDump
* Wed Sep 15 2010 ms@suse.de
- DB: Fixed typo in xsl:import: instead xsl-ns it should be xsl in the URI
- DB: Added option --nonet for xmllint and xsltproc to avoid opening a
  network connection (should be done through XML catalogs)
* Tue Sep 14 2010 ms@suse.de
- fixed foreign lvm attribute setup, a value must be set
- fixed setForeignTypeAttribute() to display the attribute value
* Tue Sep 14 2010 root@s390vm05.suse.de
- added support for s390 DASD repartitioning
* Tue Sep 14 2010 ms@suse.de
- added 'rt' kernel-rt profile for isoboot, netboot, usbboot
  and vmxboot too (bnc #639217)
* Tue Sep 14 2010 ms@suse.de
- DB: rebuild documentation
- DB: Enhanced manpages with more tags, unified spelling of KIWI,
  splitted para in separate paragraphs
- DB: fixed callout lists for PDF creation
* Tue Sep 14 2010 ms@suse.de
- DB: added callout lists below pictures
* Tue Sep 14 2010 ms@suse.de
- fixed --bootstick creation. Don't dump an image file when
  writing to the stick. Fixed image type setup when usbboot
  is used
* Mon Sep 13 2010 ms@suse.de
- According to the documentation [1], parted uses SI prefixes when
  reporting sizes. Cylinder size is thus reported in 1000 Bytes,
  not 1024 Bytes. This caused partitions which were created using
  cylinder offsets to have a wrong size. This patch fixes that by
  correcting constants in offset calculation. It also removes the
  magic multiplication constant used when creating LVM volumes.
* Mon Sep 13 2010 ms@suse.de
- DB: added callout graphics
* Mon Sep 13 2010 ms@suse.de
- DB: fixed figure callout lists
* Mon Sep 13 2010 ms@suse.de
- DB: changed figure text type to Helvetica
* Mon Sep 13 2010 ms@suse.de
- DB: changed figures to use call-out list items
* Fri Sep 10 2010 ms@suse.de
- fixed check for fdasd partitioner
* Fri Sep 10 2010 ms@suse.de
- added 'rt' profile for oemboot pointing to kernel-rt (bnc #638512)
* Fri Sep 10 2010 ms@suse.de
- DB: added doc hint about the use of multiple DVD's
* Fri Sep 10 2010 ms@suse.de
- fixed disk increase per LVM volume (bnc #587361)
* Fri Sep 10 2010 ms@suse.de
- v4.59 released
* Fri Sep 10 2010 ms@suse.de
- DB: fixed Makefile to update Revision.txt from spec file version
* Fri Sep 10 2010 ms@suse.de
- DB: Added <indexentry>s > ... and similar entries
* Thu Sep  9 2010 ms@suse.de
- allow the qeth parameters to be set via the kernel
  commandline too for the s390/suse-SLE11-JeOS image.
  Detailed information about kernel parameters for this
  image can be found in the s390/suse-SLE11-JeOS/README
* Thu Sep  9 2010 ms@suse.de
- fixed mount() function to work with disk files too
* Thu Sep  9 2010 ms@suse.de
- if the --targetdevice option is set, create the image file
  by dumping bytes from the targetdevice. Also make sure the free
  space of the filesystem on the targetdevice is filled with
  zero bytes to gain a better compression result of the image
  file. --targetdevice is currently used for s390 DASD devices
* Thu Sep  9 2010 ms@suse.de
- fixed suseSetupProduct looking for a SUSE_ prefix too (bnc #637996)
* Thu Sep  9 2010 ms@suse.de
- rebuild documentation
* Thu Sep  9 2010 ms@suse.de
-DB: pxe: fixed some spelling and gramatical errors
-DB: Enabled mini tocs for chapters and appendices
-DB: Chapter and appendix titles are in the format "Number Title" now
-DB: Removed "Appendix" from kiwi-doc-appendix.xml
-DB: Added more comments in fo/docbook.xsl
* Wed Sep  8 2010 ms@suse.de
- fixed qeth setup in s390 template
* Wed Sep  8 2010 ms@suse.de
- rebuild documentation
* Wed Sep  8 2010 ms@suse.de
- DB: Reduced size of description.png image
- DB: Converted informaltable to table, added xref
- DB: Improved toc: Make chapters and appendices bold
- DB: Activated numbering of sections
- DB: Make <refentry>s title consistent with HTML
* Wed Sep  8 2010 ms@suse.de
- removed unused root.tar.gz files in JeOS descriptions
- added dasd_configure and qeth_configure to initrd
- fixed check for kiwi_lvm variable
- added functions isVirtioDevice and isDASDDevice to
  check for these devices.
- added runPreinitServices to call scripts in
  /etc/init.d/kiwi/$service/*.sh
- adapt s390 JeOS template to use preinit service
  scripts. This system should can be used to setup the
  hvc console for kvm as well as the network setup on
  a s390 guest system
* Tue Sep  7 2010 ms@suse.de
- moved documentation from LaTeX to DocBook, PDF and HTML provided
* Tue Sep  7 2010 root@s390vm05.suse.de
- fixed s390 support for DASD devices. The main problem here is
  the detection of the disk. kiwi stores the busid value from the
  disk it used to create the image on in the kernel cmdline.
  We also had to add a function which set this disk online before
  we can access it via the device node
* Tue Sep  7 2010 root@s390vm05.suse.de
- added hint about hvc console usage in README of s390 JeOS template
* Tue Sep  7 2010 ms@suse.de
- fixed fdasd input to use partition id=1 if LVM=8e was requested
* Tue Sep  7 2010 ms@suse.de
- pxe: added support for non-contiguous MAC/IP grouping (bnc #636692)
- pxe: added documentation for MAC/IP grouping
* Tue Sep  7 2010 ms@suse.de
- fixed s390 vmxboot and oemboot boot images to contain the
  drivers/s390 kernel modules which are required for DASD and
  other s390 specific devices
* Tue Sep  7 2010 ms@suse.de
- DB: added make check target to docbook Makefile
* Mon Sep  6 2010 root@s390vm05.suse.de
- added support for fdasd partitionier
- fixed installation of zipl.conf when writing into real device
* Mon Sep  6 2010 ms@suse.de
- allow the kernelCheck function to reboot via kexec (bnc #636406)
* Mon Sep  6 2010 ms@suse.de
- DB: added missing dashes, resp. replaced with correct option dashes
- DB: added set monospace.properties attribute for fo creation
- DB: added common table id's
* Fri Sep  3 2010 ms@suse.de
- DB: added fop configuration for PDF font setup
* Fri Sep  3 2010 ms@suse.de
- allow boot disk creation to work from real devices too
  * setupBootDisk(),setupInstallCD and setupInstallStick()
    can operate on real disk devices too
  * changed setupBootStick to call setupBootDisk with the
    selected stick device as parameter
  * added a destructor function in KIWIBoot to cleanup all
    created tmp directories after the object is no longer in
    use. Prevent all clean* function to remove and tmp dir
  * cleanup KIWIBoot: removed cleanTmp function
  * cleanup KIWIBoot: moved kpartx calls into function
  * cleanup KIWIBoot: moved stick search into function
  * cleanup KIWIBoot: added checkLVMbind function
* Fri Sep  3 2010 ms@suse.de
- DB: added ref counter for pictures
* Fri Sep  3 2010 ms@suse.de
- DB: added IDs for all sect{1,2,3}, procedures, tables and figures
* Fri Sep  3 2010 ms@suse.de
- DB: added 'man' target to create man pages
* Fri Sep  3 2010 ms@suse.de
- DB: changed all <screen>: options from -bob to --bob
- DB: added new stylesheet for html: xslt/html/docbook.xsl
- DB: adapt Makefile according to new stylesheet
- DB: update CSS from Andy
- DB: fixed kiwi-man-*.xml: added id-Attribut, common
  name kiwi,Kiwi -> KIWI used, added <sgmltag>s for
  filenames
* Thu Sep  2 2010 ms@suse.de
- DB: fixed some commandline parameter dashes
- DB: added title page for PDF
* Thu Sep  2 2010 ms@suse.de
- DB: fixed man page template titles
- DB: fixed Makefile, add kiwi-doc.xml to source files
- DB: enabled index page creation
* Thu Sep  2 2010 ms@suse.de
- DB: update documentation, pictures and the DocBook README file
* Thu Sep  2 2010 ms@suse.de
- DB: fixed creation of picture files
* Thu Sep  2 2010 ms@suse.de
- use $SERVER server ip for NFS or NBD root server if not
  specified in NBDROOT/NFSROOT
* Thu Sep  2 2010 ms@suse.de
- added check for dhcpcd options. On sle10 we don't have
  the options -p or --noipv4ll
* Thu Sep  2 2010 ms@suse.de
- DB: added index page to docbook source
- DB: fixed Makefile for building book
* Wed Sep  1 2010 ms@suse.de
- better Makefile for docbook book creation. Added pictures
  which are currently embedded as PNG's. This needs to be
  improved though
* Wed Sep  1 2010 ms@suse.de
- started conversion of the documentation from LaTeX to DocBook.
  This first version is still missing a few things, therefore the
  LaTeX source is still in place and preferred
* Tue Aug 31 2010 ms@suse.de
- make sure the lvm attribute is part of the .profile environment
  of the kiwi boot images. The value is exported as $kiwi_lvm. The
  searchVolumeGroup() function only operates if kiwi_lvm is set
  to true
- moved the message text 'Searching for $VGROUP volume group'
  into the searchVolumeGroup() function and remove it from all
  boot image linuxrc's
* Tue Aug 31 2010 ms@suse.de
- LVM: added 1%% spare space for each volume to store the metadata
* Mon Aug 30 2010 ms@suse.de
- prevent dd output on stderr when checking the boot sector
* Mon Aug 30 2010 ms@suse.de
- fixed check for boot sector inclusion
* Mon Aug 30 2010 ms@suse.de
- update documentation
* Mon Aug 30 2010 ms@suse.de
- copy license files into the system if found on one of the
  specified repos. The first repo which provides a license.tar.gz
  is the one which is used (bnc #633664)
* Mon Aug 30 2010 ms@suse.de
- added sync call before umounting the filesystems. Reasons
  for this workaround is the kernel problem in (bnc #15906)
* Fri Aug 27 2010 ms@suse.de
- don't call the grub binary from the image this could lead
  to problems when the grub binary is linked against a library
  which doesn't exist on the build machine. Therefore we use
  the grub binary installed on the build machine (kiwi requires
  grub for vmx and oem now) and bind mount the grub stage
  files in boot/grub from the image to the build machine
  while grub is called
* Fri Aug 27 2010 ms@suse.de
- v4.58 released
* Fri Aug 27 2010 ms@suse.de
- make use of the mkfs.$FS toolset instead of mk2fs with parameters
  This is more compatible and also prevents us from dealing with
  the changed meanings of some mk2fs parameters (bnc #635052)
* Thu Aug 26 2010 ms@suse.de
- fixed convert39to41.xsl to insert xenconfig and vmwareconfig
  sections also for iso image type
* Thu Aug 26 2010 ms@suse.de
- added parted as requirement for kiwi-desc-oem|vmxboot
* Wed Aug 25 2010 ms@suse.de
- fixed yum package check. the 'list available' command is not
  suitable for already installed packages. Therefore we use 'list all'
  which also works for already installed packages
* Wed Aug 25 2010 ms@suse.de
- changed iso image type for RHEL template to use clicfs
  instead of squashfs
* Wed Aug 25 2010 ms@suse.de
- added clicfs for RHEL 5.4 to kiwi rhel repo
* Wed Aug 25 2010 ms@suse.de
- fixed clicfs mount by not using losetup on the clicfs file
  before mounting it via the clicfs command. The clicfs command
  now get the clicfs file directly. Problem here was that with
  a loop clicfs is no longer able to read the size of the clicfs
  file which results in unexpected behavior (bnc #629543)
- Related to that fix clicfs based caching now works stable
* Wed Aug 25 2010 ms@suse.de
- call dhcpcd with the option --noipv4ll to be able to check the
  return code of dhcpcd and to prevent the interface from an ip address
  if there was a DHCP timeout (bnc #634057)
* Wed Aug 25 2010 ms@suse.de
- added package/group check before yum is called to install
  packages/groups. This is done because there are yum versions
  which silently ignore missing items and proceed installing
  the rest.
* Tue Aug 24 2010 ms@suse.de
- fixed message about package installation when using ensconce
  The problem was that it prints always the same message about
  installing bootstrap packages even in non-chroot mode
* Tue Aug 24 2010 ms@suse.de
- don't check the return code of dhcpcd it's always zero.
  Therefore the check has been changed to check for the creation
  of the /var/lib/dhcpcd/dhcpcd-$PXE_IFACE.info file (bnc #634057)
* Mon Aug 23 2010 ms@suse.de
- added <hwclock> setup to templates. Use utc by default
* Mon Aug 23 2010 ms@suse.de
- allow setup of HWCLOCK in /etc/sysconfig/clock via the
  preferences element <hwclock>utc|localtime</hwclock>
* Mon Aug 23 2010 ms@suse.de
- RHEL: fixed URL quoting when building with yum
- RHEL: added alternative search path for isolinux.bin
* Mon Aug 23 2010 ms@suse.de
- v4.57 released
* Fri Aug 20 2010 ms@suse.de
- fixed etc/motd for suse-11.3-JeOS. It was still saying this
  is a 11.2 system, cut&paste bug :-)
* Fri Aug 20 2010 ms@suse.de
- fixed suse-11.3/suse-min-gnome. Gnome is not working no
  session and desktop information was installed
* Fri Aug 20 2010 ms@suse.de
- don't use mkclicfs from image root tree. That will fail in
  any case where the image buildsystem libraries doesn't match
  the ones required by the mkclicfs binary inside the root tree
* Fri Aug 20 2010 ms@suse.de
- fixed suse-11.3/suse-min-gnome example. Some X11 packages
  where missing in order to boot up with a working X
* Wed Aug 18 2010 ms@suse.de
- fixed convert39to41.xsl schema conversion. The attributes
  for the conversion from <deploy> to <pxedeploy> were missing
* Wed Aug 18 2010 ms@suse.de
- fixed shell exception handling after the move mount of
  devices. In that cases the tty devices are in /mnt/dev and
  therefore any shell exception failed because the setctsid
  call can't find the device. This is now fixed (bnc #608620)
* Wed Aug 18 2010 ms@suse.de
- fixed netboot building by providing atftp for SLE11 (bnc #632203)
* Tue Aug 17 2010 ms@suse.de
- update schema documentation
* Tue Aug 17 2010 ms@suse.de
- added support for selecting the default boot entry for a
  kiwi install image. The optional <type> attribute called
  installboot can take the values 'install' for standard
  installation, 'failsafe-install' for installation with
  failsafe kernel parameters and 'harddisk' which is the
  default anyway if no installboot attribute was
  given (bnc #624228)
* Tue Aug 17 2010 ms@suse.de
- update documentation. XML elements and attributes are
  now listed in the index
* Tue Aug 17 2010 ms@suse.de
- update documentation. Better index page
* Tue Aug 17 2010 ms@suse.de
- update documentation
* Mon Aug 16 2010 ms@suse.de
- removed unused variable $device in mountSystem()
* Mon Aug 16 2010 ms@suse.de
- put the code which deactivates the filesystem check
  by resetting the mount counter into a function called
  resetMountCounter(). Let resetMountCounter also check
  the filesystem type to be able to distinguish different
  filesystem tools (bnc #627021)
* Fri Aug 13 2010 ms@suse.de
- update documentation, fixed Makefile and changed box frame
  layout into two horizintal lines
* Fri Aug 13 2010 ms@suse.de
- update documentation. Some style changes for code boxes
  which now allows also cut&paste
* Fri Aug 13 2010 ms@suse.de
- disable filesystem check for kiwi managed partitions
  using tune2fs -c -1 -i 0 $device (bnc #627021)
* Wed Aug 11 2010 ms@suse.de
- v4.56 released
* Wed Aug 11 2010 ms@suse.de
- fixed permissions and ownership setup of read-write part in
  split images. The problem here was that the read-write part is
  created as new directory structure belonging to root. Therefore
  it's required to update permissions and ownership from the original
  tree afterwards in the same as it's done for the read-only and
  temporary parts
* Tue Aug 10 2010 ms@suse.de
- make use of the --recursive feature of insserv and remove
  my own recursice insserv implementation which has to parse
  the insserv output and therefore always fail if that output
  changes (bnc #627480)
* Tue Aug 10 2010 ms@suse.de
- added acpi modules to kiwi's oemboot initrd. This is required
  mostly for fan control on laptops and therefore very important
  for the preload images running on laptops to prevent overheating
  of the devices
* Tue Aug 10 2010 ms@suse.de
- fixed hybrid persistent feature. The check for the bios
  protection was broken which caused the creation of the
  persistent write partition to be skipped.
- added support for the kernel option wipecow=1. This option
  allows to wipe an eventually existing cow file on a hybrid
  iso image to start from scratch
* Tue Aug 10 2010 ms@suse.de
- changed suse-11.3/suse-live-stick example to use the hybrid
  iso technology
* Tue Aug 10 2010 ms@suse.de
- fixed coding style for driverupdate support in inst-sys mode
  also fixed DB comments in schema for driverupdate section
* Tue Aug 10 2010 ms@suse.de
- update documentation and man pages. some formal and
  consistency changes over the entire document
* Mon Aug  9 2010 ms@suse.de
- update documentation. Thanks to Thomas Schraitle
* Mon Aug  9 2010 ms@suse.de
- pxe: make sure the CONF contents are evaluated even if
  the image is downloaded to RAM only instead of a persistent
  device.
* Mon Aug  9 2010 ms@suse.de
- added missing xml object reference to foreign repo hash
  when building a split image
* Mon Aug  9 2010 ms@suse.de
- setup overlay mount method in create mode if the file
  $Create/kiwi-root.cache exists
* Mon Aug  9 2010 ms@suse.de
- update documentation. Thanks to Thomas for providing the patch
* Fri Aug  6 2010 ms@suse.de
- v4.55 released
* Fri Aug  6 2010 ms@suse.de
- fixed typo in config.xml search in overlay mount function
* Fri Aug  6 2010 ms@suse.de
- turn main::Prepare into an abspath
* Fri Aug  6 2010 ms@suse.de
- make sure the cache holds the correct copy of the base image
  and not the cache image XML
* Fri Aug  6 2010 ms@suse.de
- added arch information into caches
* Fri Aug  6 2010 ms@suse.de
- update documentation, patch by Thomas Schraitle
* Fri Aug  6 2010 ms@suse.de
- moved cache creation into functions initializeCache()
  selectCache() and createCache()
- added meta information into root tree if cow cache is used.
  It's required to have the name of the cache clicfs available
  when running kiwi create on a root tree created with a
  clicfs based cache
* Thu Aug  5 2010 ms@suse.de
- improve caching by creating clicfs files from
  the single caches and mount them with a cow file for
  further operations.... still experimental
* Thu Aug  5 2010 ms@suse.de
- fixed xen/ec2 examples to clone services into runlevel 4
  which is required by EC2
* Thu Aug  5 2010 ms@suse.de
- changed ec2 account number back to default
* Thu Aug  5 2010 ms@suse.de
- fixed boot image checksum creation in Makefile
* Thu Aug  5 2010 ms@suse.de
- EC2: changed the way how ec2 images are created. We now bundle
  the ami from a raw disk Xen image using the ec2 kernel. Along
  with this change the xenboot boot image became obsolete and was
  removed in a previous commit. Support for Xen is now only availabe
  via disk image and Xen must support PVgrub in order to boot it
* Thu Aug  5 2010 ms@suse.de
- EC2: update documentation about EC2 and Xen support
* Thu Aug  5 2010 ms@suse.de
- EC2: removed support for xenboot boot images, xen/ec2 is disk based now
* Thu Aug  5 2010 ms@suse.de
- EC2: removed suse-ec2-guest examples
- EC2: added ec2Flavour into suse-xen-guest examples
- EC2: changed suse-xen-guest examples image type to vmx with xen/ec2 kernel
* Wed Aug  4 2010 ms@suse.de
- fixed changelog creation tool. Don't include information about
  branch merges or commits which just copied a changelog entry for
  a previos commit into the kiwi.changes file. We also don't include
  the svn to git conversion information as I think it's not required
* Wed Aug  4 2010 ms@suse.de
- added xen guest example for 11.3
* Wed Aug  4 2010 ug@taylor.suse.de
- fixed respect write protection for Live medium (SD-card)
  bnc#623038
* Wed Aug  4 2010 ms@suse.de
- fixed MBR rewrite call in installBootLoader()
* Wed Aug  4 2010 ms@suse.de
- fixed check for foreign packages. The problem here was that the
  correct packages sections were checked for matching the profiles
  of the boot image but they should be checked against the profiles
  of the system image.
* Wed Aug  4 2010 ms@suse.de
- don't check the return value of the e2fsck call. If the
  filesystem check was forced for example by a wrong system
  clock the check runs successfully but the return value is
  not zero.
* Wed Aug  4 2010 ms@suse.de
- fixed license display problem when no localized license files
  exist but a license.txt file does
* Wed Aug  4 2010 ms@suse.de
- add the vm guest example to openSUSE 11.3
* Tue Aug  3 2010 ms@suse.de
- create the kiwi.changes file from the git log information
* Tue Aug  3 2010 ms@suse.de
- add the live stick example to openSUSE 11.3
* Tue Aug  3 2010 ms@suse.de
- write back masterBootID (MBR ID) to the master boot record
  after it has been changed by installBootLoader()
* Tue Aug  3 2010 ms@suse.de
- added suse-euca-cloud examples for 11.3
* Tue Aug  3 2010 ms@suse.de
- reverted last change:
  don't call root filesystem check for images (bnc #627021)
  this causes the fs to remount read-only on newer versions
  if suse; what a crappy reaction
* Tue Aug  3 2010 ms@suse.de
- fixed repartition code for fdisk (SLE10) (bnc #627807)
* Tue Aug  3 2010 ms@suse.de
- don't call root filesystem check for images (bnc #627021)
* Tue Aug  3 2010 ms@suse.de
- if a fixed xml size was set for a filesystem image we use if
  even if kiwi's calculation says it's too small. This allows users
  to create the image with less or no free space but also could
  cause the image to fail because of no space left on device.
  We don't use the fixed xml size if it's too small for a virtual
  disk based image though because this could cause the image to
  be created successfully but then failed on boot which is a bad
  user experience (bnc #627031)
* Tue Aug  3 2010 ms@suse.de
- v4.54 released
* Tue Aug  3 2010 ms@suse.de
- fixed evaluation of PARTED_... variables (bnc #627593)
* Mon Aug  2 2010 ms@suse.de
- added entire usb stack to initrd for SLE11 oemboot (bnc #627439)
* Mon Aug  2 2010 ms@suse.de
- v4.53 released
* Mon Aug  2 2010 ms@suse.de
- again fixed the check for specific parted versions. I now
  changed it to directly check for the available options in
  parted instead of the parted version number
* Mon Aug  2 2010 ms@suse.de
- when creating a new cpio image make sure an eventually
  existing old version of .splash.gz will be removed
* Fri Jul 30 2010 ms@suse.de
- put patterns into image package section instead of bootstrap
  I discovered strange errors with older zypper versions when
  building newer images
* Fri Jul 30 2010 ms@suse.de
- v4.52 released
* Fri Jul 30 2010 ms@suse.de
- added log information about used boot-theme
* Fri Jul 30 2010 ms@suse.de
- clarify user creation and group association documentation
- some alpha ordering inside the schema
* Thu Jul 29 2010 ms@suse.de
- support add-pattern option in upgrade mode too
* Thu Jul 29 2010 ms@suse.de
- add changelog entry for last commit
- recreate documentation
* Thu Jul 29 2010 ms@suse.de
- again fixed parted version setup
* Wed Jul 28 2010 ms@suse.de
- again fixed PARTED_VER setup. older version strings looks different
  than the new ones. We had to standardize those too
* Tue Jul 27 2010 ms@suse.de
- fixed PARTED_VER setup and tests. If the parted version
  is below or equal 1.8.8 we switch to fdisk. This applies for
  sle10 where parted doesn't have some options which we require
* Tue Jul 27 2010 ms@suse.de
- added support for image caching. With this feature you can
  provide a cache directory along with the option --cache.
  kiwi in prepare step looks into the directory if it finds
  a cache serving as the base-root for the system image.
  If it can't find one it creates caches based on the
  patterns used in the image description which speeds
  up subsequent prepare calls for this and other images
* Tue Jul 27 2010 ms@suse.de
- fixed solvable cache if only one solvable is created it
  was removed and not cached
* Tue Jul 27 2010 ms@suse.de
- fixed use of uninitialized value for $dir
* Tue Jul 27 2010 ms@suse.de
- fixed suse-11.3/suse-min-gnome example, added missing
  icewm and a terminal :)
* Tue Jul 27 2010 ms@suse.de
- don't create splash initrd if it already exists
* Tue Jul 27 2010 ms@suse.de
- fixed use of uninitialized value for $overlay
* Mon Jul 26 2010 ms@suse.de
- fixed SLE10 boot images using gettext-runtime. This package
  doesn't exist there, it was gettext only (bnc #625392)
* Mon Jul 26 2010 ms@suse.de
- accidently removed an important return statement in
  setupBootPartition
* Mon Jul 26 2010 ms@suse.de
- v4.51 released
* Mon Jul 26 2010 ms@suse.de
- fixed setupBootPartition() to return with a bootid
  export in _any_ case. Default bootid is 1 (bnc #625379)
* Fri Jul 23 2010 ms@suse.de
- v4.50 released
* Fri Jul 23 2010 ms@suse.de
- fixed URL quoting, we have to distinguish the quoting
  for local path URL's and network protocol URL's
* Thu Jul 22 2010 ms@suse.de
- fixed xenconfig creation for vmx if no format was set
* Thu Jul 22 2010 ms@suse.de
- fixed oem-partition-install for LVM images
* Thu Jul 22 2010 ms@suse.de
- fixed use of uninitialized value and test -z usage in bash code
* Thu Jul 22 2010 ms@suse.de
- fixed locale validation and documentation as well as
  some template examples provided by kiwi. The locale value
  in kiwi is always a UTF-8 locale therefore it's not
  allowed to add the encoding type to the locale string.
  We also support the xx_XX locale style only which is
  now all checked by the schema (bnc #620789)
* Thu Jul 22 2010 ms@suse.de
- fixed documentation about the evaluation of the locale information
* Thu Jul 22 2010 ms@suse.de
- fixed locale setup for some examples
* Wed Jul 21 2010 ms@suse.de
- added 11.3 as migration target
* Wed Jul 21 2010 ms@suse.de
- fixed suse-11.3/suse-pxe-client/config.xml
* Tue Jul 20 2010 ms@suse.de
- fixed changelog chronology
* Tue Jul 20 2010 ms@suse.de
- fixed oem recovery for LVM based images. It's required
  to backup the LVM metadata in order to restore it
* Tue Jul 20 2010 ms@suse.de
- added main::isize function to replace the use of
  the -s operator. This is done because of SUSE Studio
  which maps a file to a block special under certain
  circumstances which causes -s to not work anymore
* Mon Jul 19 2010 ms@suse.de
- v4.49 released
* Sat Jul 17 2010 root@linux.(none)
- install bootloader for vmx and usb after initial deployment
  to make sure reboot works
* Fri Jul 16 2010 root@linux.(none)
- added suport for the btrfs filesystem (bnc #596205)
* Fri Jul 16 2010 cwh@suse.de
- Finally added driverupdate stuff to schema
* Fri Jul 16 2010 ms@suse.de
- update ppc netboot image (copy of x86 version)
* Fri Jul 16 2010 root@linux.(none)
- fixed Makefile boot image md5 creation time
* Fri Jul 16 2010 ms@suse.de
- v4.48 released
* Fri Jul 16 2010 ms@suse.de
- fixed recovery cleanup code
- fixed umountSystem call to check proc/mounts and umount
  a list of possible system mount paths in the right order
- netboot: fixed creation of read-write partition
- netboot: fixed boot partition setup, IFS restore required
- netboot: imageDiskDevice was not set but used
* Thu Jul 15 2010 ms@suse.de
- v4.47 released
* Thu Jul 15 2010 ms@suse.de
- fixed parted sector init if the disk has no partitions
  we need to set startSectors to 1
* Wed Jul 14 2010 ms@suse.de
- v4.46 released
* Wed Jul 14 2010 ms@suse.de
- fixed kernelList and xenServer functions:
  * xenServer checks via kernel systemMap and kiwi_xendomain
    if a xen server bootloader setup is required
  * kernelList is fixed to store the running kernel as first
    entry in the kernel list
* Wed Jul 14 2010 ms@suse.de
- do not fail when image files are symlinks to a device
* Wed Jul 14 2010 ms@suse.de
- fixed race condition resulting at times in message of not
  finding the MBR and other times not finding the CD drive.
* Tue Jul 13 2010 ms@suse.de
- put the information about the xen domain setup into the
  initrd as variable kiwi_xendomain
* Tue Jul 13 2010 ms@suse.de
- remove unneeded initrd.vmx and linux.vmx files _before_
  calling mkinitrd. This saves space to not run into a space
  problem on the boot partition (bnc #621859)
* Tue Jul 13 2010 ms@suse.de
- usb attribute in vmwareconfig doesn't exist anymore with
  the new machine section. usb is always present for vmware
  fixed xslt stylesheet for this case
* Fri Jul  9 2010 ms@suse.de
- v4.45 released
* Fri Jul  9 2010 ms@suse.de
- recovery tarball: tar is intelligent enough to find hard link references.
  This causes the archive to be smaller. But when kiwi installs the root
  tree into the image all hard link references will solve into a new inode.
  According to this the recreation of the tarball in combination with an
  inplace setup will always be bigger than the reference tarball from the
  root tree and this causes the recovery partition and/or the free space
  inside the root partition to be too small. I fixed this with the
  following tar option: --hard-dereference
* Fri Jul  9 2010 ms@suse.de
- fixed convert38to39.xsl stylesheet
* Fri Jul  9 2010 ms@suse.de
- fixed use of uninitialized value in fs tool check
* Thu Jul  8 2010 ms@suse.de
- fixed evaluation of bool oem-inplace-recovery value
* Thu Jul  8 2010 ms@suse.de
- moved in-place recovery file creation into suse-dump
  directly after the install verification (bnc #620777)
* Thu Jul  8 2010 ms@suse.de
- don't put the recovery meta information into the recovery tarball
  when creating them dynamically
* Wed Jul  7 2010 ms@suse.de
- clean up setupFirstBootYaST() function
* Wed Jul  7 2010 ms@suse.de
- fixed build for s390
* Wed Jul  7 2010 root@s390vm05.suse.de
- improved s390 template
* Wed Jul  7 2010 ms@suse.de
- add some sanity checks
* Wed Jul  7 2010 ms@suse.de
- fixed loop cleanup after zipl install
* Wed Jul  7 2010 ms@suse.de
- operate on loop mounted boot partition when writing zipl
* Wed Jul  7 2010 ms@suse.de
- fixed zipl.conf creation
* Wed Jul  7 2010 ms@suse.de
- zipl requires block device to operate
* Wed Jul  7 2010 ms@suse.de
- fixed zipl.conf creation
* Wed Jul  7 2010 ms@suse.de
- fixed zipl.conf creation
* Wed Jul  7 2010 ms@suse.de
- leave tmpdir in case of an error while writing the bootloader
* Wed Jul  7 2010 ms@suse.de
- added zipl install into disk image file code
* Tue Jul  6 2010 ms@suse.de
- fixed build
* Tue Jul  6 2010 ms@suse.de
- don't let it diverge too much between x86 and s390 suse-preinit
* Tue Jul  6 2010 ms@suse.de
- don't let it diverge too much between ix86 and s390 linuxrc code
* Tue Jul  6 2010 ms@suse.de
- fixed zipl.conf, typo when writing image line
* Tue Jul  6 2010 ms@suse.de
- fixed zipl.conf, forgot to add image
* Tue Jul  6 2010 ms@suse.de
- fixed zipl.conf parameters setup
* Tue Jul  6 2010 ms@suse.de
- fixed zipl.conf creation (invalid chars [], using () instead)
* Tue Jul  6 2010 ms@suse.de
- zipl doesn't read the configuration from a filesystem
  so any change triggers a new bootloader install command
* Tue Jul  6 2010 ms@suse.de
- fixed kernel search for s390 (image-...)
* Tue Jul  6 2010 ms@suse.de
- fill setupBootLoaderS390() with live
* Tue Jul  6 2010 root@s390vm05.suse.de
- added kernel package to s390 JeOS
* Tue Jul  6 2010 root@s390vm05.suse.de
- fixed product name
* Tue Jul  6 2010 ms@suse.de
- simplify s390 JeOS
* Tue Jul  6 2010 ms@suse.de
- added README files in arch directories
* Tue Jul  6 2010 ms@suse.de
- added support for the creation of the zipl.conf file
  the installation of zipl into the MBR from a loop file is
  still an open issue. We need to talk to IBM here first
- restructure source tree a bit. make templates and repos
  architecture dependent because of the s390 implementations
* Tue Jul  6 2010 ms@suse.de
- make sure virtio_blk is loaded
* Tue Jul  6 2010 ms@suse.de
- match MBR id for little and big endian machines
* Tue Jul  6 2010 ms@suse.de
- don't exit with an error if 'zypper rm' can't find the package
- check for profiles when searching for foreign packages also
  search in type=image and type=bootstrap package sections
* Mon Jul  5 2010 root@s390vm05.suse.de
- removed SLE10 target for s390, we are starting with SLE11 SP1
- added support for s390 kernel extraction from initrd (image file)
- fixed vmxboot/oemboot boot image descriptions for s390
- added kiwi-tools for s390/s390x
* Mon Jul  5 2010 adrian@suse.de
- fix syntax error from my last commit :/
* Fri Jul  2 2010 ms@suse.de
- v4.44 released
* Fri Jul  2 2010 ms@suse.de
- fixed this path evaluation (bnc #619482)
* Fri Jul  2 2010 ms@suse.de
- fixed use of uninitialized iso object reference
* Thu Jul  1 2010 ms@suse.de
- fixed repartition problem with new and old parted. The
  code has been changed in a way that it uses a sector
  based start value and a cylinder based end value
* Thu Jul  1 2010 ms@suse.de
- call conversion module automatically but only if a format
  was set in config.xml. Exception: the xen image type, which
  requires a machine configuration but without a format conversion
* Thu Jul  1 2010 adrian@suse.de
- Make volume id labels nicer on coolos request:
  * Always strip -Media
  * Do not add dots when stripping
  * Do add media number .XXX suffix only when multiple medias exist
* Thu Jul  1 2010 ms@suse.de
- added volume label for recovery partition (bnc #618276)
* Thu Jul  1 2010 ms@suse.de
- use format from xml if specified and not set on the commandline
  for the conversion into another image format
* Wed Jun 30 2010 ms@suse.de
- fixed minor ovf creation bugs. Note old versions of ovftool will
  not work with this version of kiwi because VMware changed the
  option set of their own tool completely
* Wed Jun 30 2010 ms@suse.de
- update image descriptions via xslt
* Wed Jun 30 2010 ms@suse.de
- added xslt stylesheet to convert from schema v4.6 to v4.7
  the conversion moves the vmwareconfig and xenconfig sections
  into the common machine sections and also changes
  format="iso" into installiso="true" and format="usb" into
  installstick="true"
* Wed Jun 30 2010 ms@suse.de
- update documentation according to the new KIWIImageFormat
  module and the changes in the type and VM configuration
  XML setup
* Tue Jun 29 2010 ms@suse.de
- Cleanup formats in kiwi:
  * create new KIWIImageFormat.pm module for the conversion
    into different image formats like vmdk,ovf and friends.
    Also added function for creating the machine configuration
    into this new module
  * create common XML specification for vmware|xen config
    starting with <machine>
  * added new option --convert to kiwi.
  * recursively call kiwi with $main::Convert set to convert
    into the specified format and/or configuration
  * added bool attributes installcd and installstick replacing
    the old format="iso" and format="usb" setup
* Mon Jun 28 2010 ms@suse.de
- moved the XML validation ahead of the first data extraction
- changed the way validation errors are reported. If the xml
  file was converted via XSL the error will be reported
  against the converted file. This makes the error reporting
  more meaningful as otherwise validation errors are reported
  that are due to the use of an older schema version.
- fixed typo in convert45to46.xsl. Do not swallow attributes
  on packages of the vmware section
- Thanks to Robert who did the last three ones, great work :)
* Fri Jun 25 2010 ms@suse.de
- v4.43 released
* Fri Jun 25 2010 ms@suse.de
- fixed copy of root tree into final image. We used
  cp -a $source/* $dest which did not match the dot files
  in $source/.* Therefore I changed this to use a tar
  based copy
* Thu Jun 24 2010 ms@suse.de
- added oem-inplace-recovery option which allows creation
  of the recovery tarball at first deployment instead of
  creating the tarball and store it inside the image
* Wed Jun 23 2010 ms@suse.de
- add bugid to changelog entry
* Wed Jun 23 2010 ms@suse.de
- update the min gnome example to 11.3
* Wed Jun 23 2010 ms@suse.de
- use cylinder based alignment with new parted version
  2.2.x. This fixes the oem repartition code for systems
  which uses parted >= 2.2.x build on a parted 1.9.x build
  system. Also removed unused functions: partedGetSectors
  and partedStartCylinder
* Wed Jun 23 2010 ms@suse.de
- fixed <image name="..."/> attribute validation, space
  and / is not allowed for this attribute
* Wed Jun 23 2010 ms@suse.de
- started support for s390 imaging:
  * zipl support in kiwi. This is still work in progress only
    the skeleton at the required code points has been added.
  * adapted the JeOS sle11 template to provided a profile
    for x86 and s390 packages
  * also added vmxboot and oemboot bootimages to be build
    The code there will work as initrd for an s390 guest
    within kvm
* Tue Jun 22 2010 ms@suse.de
- added alpha-ordering patch from Robert
* Tue Jun 22 2010 ms@suse.de
- added SLE11 target for migration
* Tue Jun 22 2010 ms@suse.de
- strict and warning should be loaded first
* Tue Jun 22 2010 ms@suse.de
- fixed broken patch :(
* Tue Jun 22 2010 ms@suse.de
- fixed use of global file handles
* Tue Jun 22 2010 ms@suse.de
- changed spec file requirement: require virt-utils for
  distro versions >= 11.3
* Tue Jun 22 2010 ms@suse.de
- cleaned up split image code:
  * unneeded directory checks
  * multiple functions calls where one would be ok
* Tue Jun 22 2010 ms@suse.de
- migration: added version to cache file
* Mon Jun 21 2010 ms@suse.de
- fixed split section evaluation (bnc #615121)
* Fri Jun 18 2010 ms@suse.de
- exit kiwi directly if the possible question to create
  the destination directory was canceled by the user
* Fri Jun 18 2010 ms@suse.de
- v4.42 released
* Fri Jun 18 2010 ms@suse.de
- avoid a Perl runtime error message from being
  printed if the XML file parsing fails.
- changed findExec to return undef if the executable
  cannot be found. If as previously the execName is returned
  the caller has no way to differentiate whether or not the
  desired executable actually exists on the system.
* Thu Jun 17 2010 ms@suse.de
- migration:
  * fixed distro detection
  * added support for harware dependent package information
* Thu Jun 17 2010 ms@suse.de
- redesigned and restructure the kiwi migration module
  we were working in a small workgroup this week to
  establish a new version of the migration module. Thanks
  to everybody in my team.
* Thu Jun 17 2010 ms@suse.de
- added distro tags to orphant package list
* Thu Jun 17 2010 ms@suse.de
- allow plaindir repo for solvable creation
* Thu Jun 17 2010 ms@suse.de
- migration:
  * fixed deny list, service links must stay
  * apply deny links on overlay tree
* Wed Jun 16 2010 ms@suse.de
- fixed attr access
* Wed Jun 16 2010 ms@suse.de
- fixed file/directory search for migration
* Wed Jun 16 2010 ms@suse.de
- fixed Makefile
- don't follow symlinks to directories in migration
* Tue Jun 15 2010 ms@suse.de
- fixed spec file to provide /var/cache/kiwi
- fixed migration to be faster in searching non packaged
  files / directories
* Tue Jun 15 2010 ms@suse.de
- migration:
- fixed filesystem scan
- copy /etc entirely to root/
- don't setup services
- use product file to add system repository
* Mon Jun 14 2010 cwh@suse.de
- DriverUpdateDisk support
* Mon Jun 14 2010 ms@suse.de
- Remove some code duplication by using a new
  getDefaultBaseRoot() function
* Mon Jun 14 2010 ms@suse.de
- Remove some code duplication by using a new
  createDirInteractive() function
* Fri Jun 11 2010 ms@suse.de
- v4.41 released
* Thu Jun 10 2010 ms@suse.de
- added oem-unattended element which allows unattended
  installation if possible
* Thu Jun 10 2010 ms@suse.de
- use dialog program to show dump reboot message
* Thu Jun 10 2010 ms@suse.de
- added oem-dumphalt element which reboots the system after
  the image was dumped (installed) on the target device. A message
  appears and the system waits for a key event before reboot
* Wed Jun  9 2010 ms@suse.de
- reduce the scope of the eval around the config.xml file parsing.
  The only operation that may fail with an exception is the parsing,
  while accessing the resulting document does not generate
  exceptions, thus the eval (exception handling) should only
  enclose the code that actually may trigger an exception
- improve the XML validation error reporting if jing
  is installed on the system
* Wed Jun  9 2010 ms@suse.de
- also search for pattern file name in repomd.xml
* Wed Jun  9 2010 ms@suse.de
- fixed repo-patterns info module
* Wed Jun  9 2010 ms@suse.de
- add selinux hint for RHEL example template
* Wed Jun  9 2010 ms@suse.de
- fixed README for rhel image creation
* Tue Jun  8 2010 ms@suse.de
- v4.40 released
* Tue Jun  8 2010 ms@suse.de
- fixed luks + lvm boot if no re-partition code is called
* Tue Jun  8 2010 ms@suse.de
- update documentation, added kiwirc manual page. Fixed
  manual page creation to contain correct version info
* Tue Jun  8 2010 ms@suse.de
- check that the specified log server port is numeric in nature
* Mon Jun  7 2010 ms@suse.de
- setup xencons only for domU setup (bnc #561635)
* Fri Jun  4 2010 ms@suse.de
- v4.39 released
* Fri Jun  4 2010 ms@suse.de
- removed dbsulock from kiwi, hal is deprecated
* Wed Jun  2 2010 ms@suse.de
- fixed CDMountOption() to use blkid type check (bnc #610649)
* Wed Jun  2 2010 ms@suse.de
- use vmxboot linuxrc for usbboot too, make sure --bootstick
  deployment does a cleanup of the write partition if used
* Wed Jun  2 2010 ms@suse.de
- changed ovtool call, they don't understand -oq but -o -q
* Tue Jun  1 2010 ms@suse.de
- use "kernel chain" syntax for syslinux chain loader
* Mon May 31 2010 ms@suse.de
- don't touch modules in updates and weak-updates (bnc #609879)
* Mon May 31 2010 ms@suse.de
- v4.38 released
* Sun May 30 2010 ms@suse.de
- added findExec() function to check for tools
- fixed unneeded kpartx call in installBootLoader
* Fri May 28 2010 ms@suse.de
- check if the rootEFD is defined before attempting to
  write to the file handle
* Fri May 28 2010 ms@suse.de
- fixed usb stick creation for sys|extlinux
* Thu May 27 2010 ms@suse.de
- make fbiterm work in vmx images too
- fixed setup of initrd/kernel links, because of the change
  from a link to a bind mount we can now make that code
  simpler
* Thu May 27 2010 ms@suse.de
- make sure boot image has enough space
* Thu May 27 2010 ms@suse.de
- fixed boot configuration if overlay filesystem is used
* Thu May 27 2010 ms@suse.de
- added support for extlinux based recovery (bnc #606651)
- make recovery work with separate boot partition
- use bind mount instead of link to boot partition
* Thu May 27 2010 mbarringer@suse.de
- Very minor cleanups to the imagewriter
* Tue May 25 2010 ms@suse.de
- fixed install cd boot parameters if ext|syslinux is used
- fixed ext|syslinux setup in initrd code (KIWILinuxRC.sh)
* Tue May 25 2010 ms@suse.de
- changed ovftool options according to latest version
* Tue May 25 2010 ms@suse.de
- use isolinux for install CD's if sys|extlinux was requested
  as bootloader for an oem image plus install media (bnc #606651)
- fixed clicfs resize operation. The command is now based
  on a 512 byte sector size value instead of a 4k filesystem block
  size value which might be wrong depending on the size of the
  filesystem (bnc #604646)
* Fri May 21 2010 ms@suse.de
- v4.37 released
* Fri May 21 2010 ug@taylor.suse.de
- fixes endless building problem if function
  suseInsertService() is calling in config.sh and system/chroot contains a broken
  /etc/init.d/ script.
  (bnc #605981)
* Fri May 21 2010 ms@suse.de
- oem: fixed creation of clicfs over LVM images
- oem: fixed home device setup for LVM
- oem: fixed fstab setup for LVHome
* Fri May 21 2010 ms@suse.de
- update documentation and schema documentation due to last
  change (dmsquash support removed)
* Fri May 21 2010 ms@suse.de
- fixed setLVMDeviceMap() function. The contents of
  $result{dmapper} were wrong if the device was a loop
  destination
* Fri May 21 2010 ms@suse.de
- removed support for dmsquash filesystem. This implementation
  was replaced by clicfs. dmsquash was a combination of a
  squashfs filesystem together with a device mapper snapshot
  as copy-on-write part. There was no way to properly react
  if we run out of cow space which also makes this feature
  more or less useles in a production environment
* Fri May 21 2010 ms@suse.de
- fixed size check for repart operation
- make sure home has a min size of 500 MB if home partition
  was requested
* Thu May 20 2010 ms@suse.de
- removed plusSuggested attribute, update documentation
  and added sort patch by Robert
* Thu May 20 2010 ms@suse.de
- rewrote the oem partition code for better maintenance
  and to support syslinux/extlinux bootloader (bnc #606651)
* Wed May 19 2010 ms@suse.de
- update documentation
* Wed May 19 2010 ms@suse.de
- fixed packages type value "net" which should be pxe
- added documentation update from Robert
* Tue May 18 2010 ms@suse.de
- fixed typo in comment
* Tue May 18 2010 ms@suse.de
- use tar command to copy overlay files which is more
  error prune than the cp command (bnc #476117)
* Tue May 18 2010 ug@taylor.suse.de
- fix for Bug 604705 - kiwi overwrites /etc/sysconfig/firstboot
* Tue May 18 2010 ms@suse.de
- fixed replace package handling and update JeOS templates
  accordingly. This allows to bind multiple package actions
  bound to one package
* Tue May 18 2010 ms@suse.de
- added support for type specific package sections
  <packages type="iso|net|usb|oem|xen|vmx">. Along with this
  change a new Schema version 4.6 was introduced which
  automatically converts the type="vmware" section into
  a type="vmx" section
* Mon May 17 2010 ms@suse.de
- added support for extlinux bootloader for vmx and usbboot.
  support for extlinux and oemboot will follow later. The
  repartition code of the oem images causes a more complex
  implementation for sys|extlinux.
* Mon May 17 2010 ug@taylor.suse.de
- check RPM version of autoyast
* Fri May 14 2010 ms@suse.de
- added support for displayname for vmx type (bnc #605939)
* Fri May 14 2010 ms@suse.de
- v4.36 released
* Fri May 14 2010 ms@suse.de
- fixed in place search field text
* Fri May 14 2010 ms@suse.de
- fixed some typo in migration js
* Fri May 14 2010 ms@suse.de
- activate javascript in migration report
* Fri May 14 2010 ms@suse.de
- added search field for unpackaged file list on the
  generated migration report page
* Fri May 14 2010 ms@suse.de
- update schema documentation, schema doc hint fix
* Wed May 12 2010 ms@suse.de
- better changelog entry for last fix
* Wed May 12 2010 ms@suse.de
- revert last change to Dialog function and fixed luksOpen
  function to use the runInteractive() method for dialogs with
  input fields
* Wed May 12 2010 ms@suse.de
- update translations from suse svn
* Wed May 12 2010 ms@suse.de
- fixed Dialog function work with input fields
* Wed May 12 2010 ms@suse.de
- fixed probeFileSystem function for luks detection.
  blkid returned crypto_LUKS which was missing in the
  case section
* Wed May 12 2010 ms@suse.de
- v4.35 released
* Wed May 12 2010 ms@suse.de
- disabled autoyastClone() temporarly, we need to find a way to
  call that only on >= 11.3 systems
* Wed May 12 2010 ms@suse.de
- update migration css code
* Wed May 12 2010 ms@suse.de
- fixed cleanup of xmlused/xmlorig files
* Wed May 12 2010 ms@suse.de
- added .info file for cached solvables
- fixed solvable pattern creation. It's required to lookup susetags
  even if there is a repodata meta data information to be able to
  create a full featured solvable including all pattern names
* Tue May 11 2010 ms@suse.de
- migration changes:
  * automatically copy the packaged but modified files
    into the overlay section and don't put them into the report
  * create a HTML file list for the unpackaged files
    to browse through and update the text.
* Tue May 11 2010 ms@suse.de
- deactivate splash screen for initial deployment
  in kiwi OEM boot images (bnc #600710)
* Tue May 11 2010 ms@suse.de
- start sshd for SLE10 JeOS
* Tue May 11 2010 ms@suse.de
- fixed rpmLibs() function, need ldconfig after cleanup
* Tue May 11 2010 ms@suse.de
- some code cleanup in KIWIImage.pm, unused variables
- call mkclicfs from the installed root tree instead of the
  build system to prevent version conflicts. If no clicfs
  is installed by the image description a warning message is
  displayed and the build system mkclicfs is used as
  before (bnc #604646)
* Mon May 10 2010 ms@suse.de
- fixed min inode count when creating the virtual disk
  from a root directory instead of a root image file
* Mon May 10 2010 ms@suse.de
- set fixed journal size to 12 MB, fixed size calculation
  in KIWIBoot.pm which did not take the journal size into
  account (bnc #587361)
* Fri May  7 2010 ms@suse.de
- umountSystemFilesystems at the end of isoboot pre-init
* Fri May  7 2010 ms@suse.de
- v4.34 released
* Fri May  7 2010 ms@suse.de
- fixed old live iso type (no flags set) to work again.
  The problem was that we prevent --follow-symlinks in this
  mode but then we also have to copy the fixed read-write
  part as file to the iso structure instead of linking it.
  This fix is related to (bnc #599712)
* Fri May  7 2010 ms@suse.de
- typo in changelog
* Fri May  7 2010 ms@suse.de
- removed check for utimer program, it's not a mandatory
  requirement for the system to be able to boot correctly
- fixed mkinitrd call, check if the option -B exists and
  don't pass it if it doesn't first (bnc #603338)
* Thu May  6 2010 ms@suse.de
- beautify migration report and fixed html code
* Wed May  5 2010 ms@suse.de
- fixed warning message if URL can't be resolved
- fixed space problem when setting up boot partition for
  images which requires a separate boot partition which is
  the case for filesystems like clicfs. This caused a wrong
  copy of the initrd and prevents the system from being
  able to reboot
* Tue May  4 2010 ms@suse.de
- package scripts change: use File::lchown qw( lutimes ); for
  changing the a|mtime of the symlinks inside the source tarball.
  This means all people who use "make build" from the kiwi source
  need to make sure they have the File::lchown module installed
  from CPAN
* Tue May  4 2010 ms@suse.de
- preserve timestamps of source tarballs if not change has
  happened. I'm still searching for a way to preserve timestamps
  of symlinks (cp -a has a bug and does not preserve it)
* Tue May  4 2010 ms@suse.de
- fixed pxeSwapDevice to create the correct device node
  name using ddn function
* Tue May  4 2010 ms@suse.de
- v4.33 released
* Tue May  4 2010 ms@suse.de
- support partition type 8e (V) in pxePartitionInput()
* Mon May  3 2010 ms@suse.de
- fixed build
* Mon May  3 2010 ms@suse.de
- split up kiwi source into: source, repository and
  documentation tarballs to be more OBS friendly (bnc #601908)
* Mon May  3 2010 ms@suse.de
- removed netboot specific partition code and replace
  it by the common partition functions used for oem
  and other tasks, related to (bnc #601890)
* Mon May  3 2010 ms@suse.de
- added support for Xen dom0 over netboot (bnc #601890)
* Fri Apr 30 2010 adrian@suse.de
- Add cciss driver: make blade center with HP smart array controller supported
* Fri Apr 30 2010 ms@suse.de
- added cyrus-sasl to netboot images (bnc #600951)
* Thu Apr 29 2010 ms@suse.de
- moved the PARTITIONER change for hybrid into the CDMount function
* Thu Apr 29 2010 ms@suse.de
- fixed createHybridPersistent: wait for new storage device
  before creating a filesystem. Also make sure imageDiskDevice
  is set before calling callPartitioner()
* Thu Apr 29 2010 ms@suse.de
- added parted to isoboot images this is required for
  the hybrid persistent feature. also increased min space
  for clicfs embedded ext3 filesystem. Also fixed the
  createHybridPersistent() function to use fdisk instead
  of parted. The problem here is that parted doesn't accept
  the partitiont able written by the isohybrid tool.
* Thu Apr 29 2010 ms@suse.de
- v4.32 released
* Wed Apr 28 2010 ms@suse.de
- fixed repartition code for overlay systems (clicfs)
* Wed Apr 28 2010 ms@suse.de
- fixed clicboot contents (kernel, initrd was missing)
* Wed Apr 28 2010 ms@suse.de
- fixed repartition code for overlay systems (clicfs)
* Tue Apr 27 2010 ms@suse.de
- fixed satplugin hash creation
- sort package list in migration mode
* Tue Apr 27 2010 ms@suse.de
- support new createrepo repomd.xml metadata information.
  kiwi now reads the repomd.xml if it exists and parses the
  primary data section in order to get all metadata file names
* Tue Apr 27 2010 ms@suse.de
- don't create empty /var/lib/YaST2 directory during migration
* Tue Apr 27 2010 ms@suse.de
- don't create install.inf and runme_at_boot in migration code
  we are creating the config-yast-autoyast.xml file and during
  kiwi prepare all required files to start autoyast are created
  by KIWIConfigure.pm
* Tue Apr 27 2010 ms@suse.de
- fixed skip package detection in migration
* Tue Apr 27 2010 ms@suse.de
- more file checks in migration autoyast clone code
* Tue Apr 27 2010 ms@suse.de
- added file check before moving
* Tue Apr 27 2010 ms@suse.de
- fixed regexp
* Mon Apr 26 2010 ms@suse.de
- automatically skip the gpg-pubkey packages during migration
* Mon Apr 26 2010 ms@suse.de
- removed kiwi's own pattern solving module. The satsolver
  approach is the preferred solution to implement this
* Fri Apr 23 2010 ms@suse.de
- added alarm timer for HTTP requests. If a URL can't be
  resolved due to problems on the remote side the request
  will be canceled after 5 seconds
* Fri Apr 23 2010 ms@suse.de
- v4.31 released
* Thu Apr 22 2010 ms@suse.de
- removed atftp from SLED oem|netboot (bnc #598899)
* Thu Apr 22 2010 ms@suse.de
- better changelog message for last fix
* Thu Apr 22 2010 ms@suse.de
- use -t instead of -T for mke2fs
* Wed Apr 21 2010 ms@suse.de
- update schema docs
* Wed Apr 21 2010 ms@suse.de
- added support for OEM partition based install (bnc #597679)
* Tue Apr 20 2010 wfeldt@opensuse.org
- use gfxboot.c32 if gfxboot.com does not exist
  Signed-off-by: Steffen Winterfeldt <wfeldt@opensuse.org>
* Tue Apr 20 2010 ms@suse.de
- fixed function dn(), added function nd()
  dn -> disk device name from device node
  nd -> device node number from device node
* Mon Apr 19 2010 ms@suse.de
- removed SAP related code from boot images.
  This was only for a proof of concept and never lead to anything useful
* Sun Apr 18 2010 adrian@suse.de
- fix product building for current factory
* Fri Apr 16 2010 ms@suse.de
- v4.30 released
* Fri Apr 16 2010 ms@suse.de
- fixed kiwi -l output
* Thu Apr 15 2010 ms@suse.de
- changed info module to print XML output
* Thu Apr 15 2010 ms@suse.de
- fixed info module patterns selection
- fixed info module repo-patterns output (prevent empty lines)
* Thu Apr 15 2010 ms@suse.de
- fixed the --select types info module
- fixed the info module to respect the XML profile setup
* Thu Apr 15 2010 ms@suse.de
- nicer info output
* Thu Apr 15 2010 ms@suse.de
- added package version and architecture information when
  requesting the solved packages list via --info
* Wed Apr 14 2010 ms@suse.de
- remove 0 in partition ID detection
* Wed Apr 14 2010 ms@suse.de
- fixed partedGetPartitionID() function to return correct ID
* Wed Apr 14 2010 ms@suse.de
- added parted to vmxboot images
* Wed Apr 14 2010 ms@suse.de
- reverted last change in default split section
* Wed Apr 14 2010 ms@suse.de
- fixed split boot, cleanImage is not allowed to umount
  the required but non busy symlinked read-write part
* Wed Apr 14 2010 ms@suse.de
- cleaned up unused variables in KIWIImage.pm
* Wed Apr 14 2010 ms@suse.de
- enhanced KIWILinuxRC create/resize filesystem functions
  to be able to return only the command without actually
  invoking it
* Mon Apr 12 2010 ms@suse.de
- version v4.29
* Mon Apr 12 2010 ms@suse.de
- speedup prepare step by not removing the repository
  when the chroot switch happens
* Mon Apr 12 2010 ms@suse.de
- restart utimer in pre-init stage, also put the time
  information into /dev which is a bind mounted location
* Mon Apr 12 2010 ms@suse.de
- Don't update bootloader when calling mkinitrd. The bootloader
  setup in the first place was done by kiwi (bnc #595073)
* Fri Apr  9 2010 ms@suse.de
- activate verbose mode for --info module
* Fri Apr  9 2010 adrian@suse.de
- fix skipping of not wanted release packages, because they are not on media. (#594808)
* Fri Apr  9 2010 ms@suse.de
- fixed info module to work with loop media like iso://
* Thu Apr  8 2010 ms@suse.de
- v4.28
- fixed typo in repo prio message
* Thu Apr  8 2010 ms@suse.de
- make ppc netboot suse-linuxrc the same as for ix86
* Thu Apr  8 2010 ms@suse.de
- removed SAP related code. This was only for a proof
  of concept and never lead to anything useful
* Thu Apr  8 2010 ms@suse.de
- added common functions resizeFilesystem() and
  createFilesystem() in KIWILinuxRC.sh
* Thu Apr  8 2010 ms@suse.de
- added suse-11.3 boot and image templates. Also removed
  suse-11.0 boot and image templates
- cleaned up spec file, removed prebuild code and package
  which is not used by anybody
* Wed Apr  7 2010 ms@suse.de
- fixed bootnext boot from harddrive feature (bnc #583212)
* Wed Apr  7 2010 ms@suse.de
- forgot to add probeFilesystem bevore restoring home filesystem
  because of this only the default action (ext3) applies
* Wed Apr  7 2010 ms@suse.de
- also use the root filesystem type for the optional home
  filesystem while in a OEM deployment process (bnc #594202)
- make the recovery filesystem an ext2 filesystem
- fixed createPartedInput() to always have a partition ID
* Tue Apr  6 2010 ms@suse.de
- added missing "done" status
* Tue Apr  6 2010 ms@suse.de
- ovftool will create junks of data according to the image size
  to allow better download performance. Because of this I changed
  the call to create new files in a separate directory
* Tue Mar 30 2010 ms@suse.de
- added iputils package to 11.2 JeOS
* Mon Mar 29 2010 ms@suse.de
- v4.27
- fixed --build option, glob check did not work (bnc #591889)
* Fri Mar 26 2010 ms@suse.de
- leave /mnt directory before calling umountSystem
- fixed bc division by zero
* Fri Mar 26 2010 ms@suse.de
- leave libnss_dns inside the boot images for name resolution
- don't print usage message for inst-source module, works suse
  internally only at the moment
* Thu Mar 25 2010 ms@suse.de
- fixed cloud examples, use rsyslog in 11.2 example
* Thu Mar 25 2010 ms@suse.de
- use bootnext 'boot from hard disk' for ISO's too (bnc #583212)
* Thu Mar 25 2010 ms@suse.de
- added uncompressed tar size information for OEM recovery
* Thu Mar 25 2010 ms@suse.de
- update changelog
- cleanup the yast clone config code a bit
* Thu Mar 25 2010 ug@taylor.suse.de
  * autoyast cloning code added to migration
* Thu Mar 25 2010 ms@suse.de
- update XML catalog and format of suse-euca-cloud example
* Tue Mar 23 2010 ms@suse.de
- switched to parted as default partition tool
* Tue Mar 23 2010 ms@suse.de
- removed destdir check for migration
* Tue Mar 23 2010 ms@suse.de
- force base destination directory for image migration and
  update documenation about migration
* Tue Mar 23 2010 ms@suse.de
- added /mnt/var/cache/recovery/oem-trigger to be written
  after the kiwi recover/restore process in order to allow
  scripts to do something on boot of the recovered/restored
  system (bnc #586529)
* Mon Mar 22 2010 ms@suse.de
- v4.25
- added bootnext program which implements a small boot loader
  needed for the 'boot from hard disk' menu entry on usb media.
  It basically loads the mbr from the first drive that is
  not the usb stick. Thanks to Steffen Winterfeldt who
  implemented this (bnc #583212)
* Sun Mar 21 2010 mbarringer@suse.de
- Fixing the imagewriter desktop file and spec file
* Sun Mar 21 2010 mbarringer@suse.de
- Add a helpful message when there are no USB keys present
* Fri Mar 19 2010 ms@suse.de
- added example to create cloud infrastructure
  images based on Eucalyptus
* Fri Mar 19 2010 ms@suse.de
- fixed error which is triggered if the overlay root directory
  of the image description exists but is empty.
* Fri Mar 19 2010 ms@suse.de
- added dialog based OEM install verification UI
* Fri Mar 19 2010 ms@suse.de
- fixed runInteractive() exit code handling
* Fri Mar 19 2010 ms@suse.de
- added "Select disk for installation" to getText (bnc #589667)
* Thu Mar 18 2010 ms@suse.de
- only recommend squashfs don't require it
* Thu Mar 18 2010 ms@suse.de
- added setterm -powersave off -blank 0 for boot images
* Thu Mar 18 2010 ms@suse.de
- fixed udevKill in pre-init by udevSystemStop()
* Thu Mar 18 2010 ms@suse.de
- fixed pattern/product evaluation
* Thu Mar 18 2010 ms@suse.de
- set /tmp to be a write path in KIWISplit.txt
* Thu Mar 18 2010 ms@suse.de
- fixed build
* Thu Mar 18 2010 ms@suse.de
- added support for RHEL 5.4 in kiwi. This includes:
  * custom rhel-repo with hwinfo, gfxboot and friends
  * support for yum package manager backend
  * JeOS template for RHEL 5.4
  * isoboot boot image description for RHEL 5.4
  * NOTE: only the iso type has been implemented so far
* Wed Mar 17 2010 ms@suse.de
- fixed long startup time because of ldconfig running when
  KIWILinuxRC is sourced from the shell
- don't use killproc,killall inside the boot images. All procs
  are written to /iprocs and are handled when required
* Tue Mar 16 2010 ms@suse.de
- added Xen dom0 hypervisor check if domain="dom0" is set
- fixed Xen dom0 bootloader configuration
* Tue Mar 16 2010 ms@suse.de
- fixed --build option in kiwi
* Mon Mar 15 2010 ms@suse.de
- fixed getSize, +5M journal size
- fixed install stick free space setup
* Mon Mar 15 2010 ms@suse.de
- leave libresolv inside the initrd to allow name resolution
- fixed default pxeboot file, use kiwiserver
* Mon Mar 15 2010 ms@suse.de
- v4.23
- fixed getSize() function taking journal size into account
- fixed getSize() function round values not truncate them
* Fri Mar 12 2010 ms@suse.de
- fixed typo in documentation
* Thu Mar 11 2010 ms@suse.de
- fixed quoting in baseUpdateSysConfig (bnc #587132)
- turn destdir into absolute path directly after
  the option parser (bnc #584200)
* Wed Mar 10 2010 ms@suse.de
- remove empty dirs in rpmLibs ("clean") (bnc #536256)
* Wed Mar 10 2010 ms@suse.de
- allow LWP proxy setting from environment (bnc #586655)
* Tue Mar  9 2010 adrian@suse.de
- support architectures for products, which are not specified
  in fallback lists
  (fixes glibc.i686 case)
* Tue Mar  9 2010 mbarringer@suse.de
- Adding two new command flags:
-l, which lists USB devices
-k, which sets the imagewriter in "kiosk mode" (it won't list drives > 200GB)
* Mon Mar  8 2010 ms@suse.de
- v4.22
- fixed missing xen package in oemboot/suse-11.2 boot
  image description (bnc #561635)
* Mon Mar  8 2010 adrian@suse.de
- use fallback handling to LABEL for readme.beta string
* Fri Mar  5 2010 ms@suse.de
- removed nsswitch conf from being copied before the packagemanager
  is called the first time. that was a bad idea. Imagine you have
  configured ldap for passwd or something. It should use nsswitch.conf
  coming with the glibc installation in the chroot.
* Fri Mar  5 2010 ms@suse.de
- fixed root tree creation build inconsistencies because of
  missing libraries at the beginning of the root tree creation.
  The first fix for this bug did not work in mixed arch
  environments (bnc #536256)
* Thu Mar  4 2010 adrian@suse.de
  * make them bootable and yast working again, fixing linked packages
    for all archs
* Thu Mar  4 2010 adrian@suse.de
- change string in README.BETA to "SUMMARY + BETA_VERSION"
* Thu Mar  4 2010 ms@suse.de
- added better log information about size calculation
* Thu Mar  4 2010 adrian@suse.de
  * fix multiarch medias, when using metapackages with onlyarch
  * sync arch fallback handling between repo and meta packages
* Wed Mar  3 2010 ms@suse.de
- v4.21
- ext4 (currently) should be mounted with 'nodelalloc';
  else we might run out of space unexpectedly...
* Wed Mar  3 2010 ms@suse.de
- added 'boot from harddrive' as default menu selection for
  the installation images (CD+USB). Thus remove the request to
  remove the media after the image dump to the hard drive is
  complete. (bnc #583212)
* Wed Mar  3 2010 ms@suse.de
- rebuild documentation
* Wed Mar  3 2010 ms@suse.de
- renamed Xen kernel profile 'nex' to 'xenk'. The original name
  causes confusion to some people. Also removed xen support from
  netboot (pxe) images and adapted JeOS image descriptions.
* Tue Mar  2 2010 ug@taylor.suse.de
  * fixed a quoting bug (bnc#584651)
* Tue Mar  2 2010 adrian@suse.de
- support arch= statements for metapackages correctly
- make missing metapackage for a required arch a warning
  (we missuse onlyarch atm)
* Mon Mar  1 2010 ms@suse.de
- allow empty lvmvolumes section, if one only wants to set
  the volume group name but no volumes except for root
* Mon Mar  1 2010 ms@suse.de
- some message cosmetics :-)
* Mon Mar  1 2010 ms@suse.de
- more visible message to check the migration report file
* Mon Mar  1 2010 ms@suse.de
- update migration table, sources are taken from zypper
* Mon Mar  1 2010 ms@suse.de
- v4.20
- migration: fixed operating system detection
- fixed getLVMGroupName() not accessing an undefined value
- fixed LVM cleanup code
* Fri Feb 26 2010 ms@suse.de
- use $FSInodeSize instead of fixed value
* Fri Feb 26 2010 ms@suse.de
- add spare 1.1 for vmsize
* Fri Feb 26 2010 ms@suse.de
- fixed getSize() function. The size of the inodes are
  part of the size calculation now
* Fri Feb 26 2010 ms@suse.de
- added trang as a build requirement to the spec
- tighten up the XML checking a bit thus that some
  errors in the XML are detected at validation rather than
  later during processing.
- cleanup: remove the matching of "yes" as a supported
  value for boolean types
* Fri Feb 26 2010 ms@suse.de
- allow profiled repository sections
* Thu Feb 25 2010 ms@suse.de
- don't log commands used to create the XML diff in the log file
* Thu Feb 25 2010 ms@suse.de
- v4.19
- added a JFYI headline in the log file and print only
  relevant information in the log excerpt in case of errors.
  This increases the chance to see the error (bnc #583125)
* Thu Feb 25 2010 adrian@suse.de
- redo my last commit, still fail if metapackage was not found for any architecure
* Thu Feb 25 2010 adrian@suse.de
- missing metapackages are no error anymore, since we need fallback
  to noarch (but we still warn)
- remove obsolete code
* Thu Feb 25 2010 adrian@suse.de
- KIWICollect: fix links for packages below /boot (bnc#579936)
  (done by Rudi)
* Wed Feb 24 2010 ms@suse.de
- fixed documentation example section
* Wed Feb 24 2010 ms@suse.de
- fixed spec file noarch, allowed with > 11.2 only
* Wed Feb 24 2010 ms@suse.de
- migration: update schema version to 4.4
- migration: update skip list
* Tue Feb 23 2010 ms@suse.de
- migration: exclude lock files
* Tue Feb 23 2010 ms@suse.de
- removed imagewriter from kiwi packages, it is provided as
  separate package now maintained by mbarringer@novell.com
* Tue Feb 23 2010 ms@suse.de
- migration: fixed report messages, better English :)
* Mon Feb 22 2010 ms@suse.de
- migration: use pre tag to display zypper solutions
* Mon Feb 22 2010 ms@suse.de
- migration:
  * added detection for packages installed multiple times
  * improvement report explanations
* Mon Feb 22 2010 ms@suse.de
- v4.18
- fixed display of EULA messages
* Sat Feb 20 2010 mbarringer@suse.de
- Fixing bug with non-hybrid ISO files
* Fri Feb 19 2010 ms@suse.de
- fixed duplicate kernel options
* Fri Feb 19 2010 ms@suse.de
- fixed use of kiwi_cmdline in initrd
* Fri Feb 19 2010 ms@suse.de
- removed commandline from pxedeploy section. kernel
  commandline parameters are set by the kernelcmdline
  attribute now (bnc #577720). Update schema version to 4.4
  and add an XSLT to remove commandline when required
* Fri Feb 19 2010 mbarringer@suse.de
- Bumping the imagewriter version
* Thu Feb 18 2010 mbarringer@suse.de
- Set the .desktop file for the imagewriter correctly
* Thu Feb 18 2010 mbarringer@suse.de
- Add icons for the imagewriter
* Thu Feb 18 2010 mbarringer@suse.de
- Cleaning the imagewriter up and also adding an "about" box
* Thu Feb 18 2010 mbarringer@suse.de
- Add COPYING file to comply with GPL
* Thu Feb 18 2010 ms@suse.de
- fixed function comments in runInteractive()
* Thu Feb 18 2010 ms@suse.de
- added support for additional kernel commandline options
  specified as kernelcmdline <type> attribute (bnc #577720)
* Wed Feb 17 2010 mbarringer@suse.de
- Increase the imagewriter version
* Wed Feb 17 2010 mbarringer@suse.de
- Detect non-hybrid ISOs
* Wed Feb 17 2010 adrian@suse.de
- add changelog entry for last commit
* Wed Feb 17 2010 adrian@suse.de
- fix arch condition handling for meta package collection
* Wed Feb 17 2010 ms@suse.de
- test
* Wed Feb 17 2010 mbarringer@suse.de
- Added USB key insertion/removal detection
* Wed Feb 17 2010 ms@suse.de
- added support for additional kernel commandline options
  specified in the new <commandline> section (bnc #577720)
* Wed Feb 17 2010 ms@suse.de
- don't remove ldap and sasl in oemboot it's required for
  curl based downloads
* Tue Feb 16 2010 ms@suse.de
- moved lvmgroup attribute into the lvmvolumes section
* Tue Feb 16 2010 ms@suse.de
- v4.17
- update documentation
- changed migration to use root path directly and don't mount
  the root device before. As we can't mount it read-only because
  it's already mounted read-write I decided to prevent the mount
  at all and exclude any remote mounted location by searching
  through /proc/mounts
* Tue Feb 16 2010 ms@suse.de
- don't remove libidn it's required for curl based downloads
* Mon Feb 15 2010 ms@suse.de
- v4.17
- fixed xen building with empty or no type=xen packages
* Mon Feb 15 2010 adrian@suse.de
- do not fail on creating directory which might be there already.
  (fixes openSUSE:Factory ftp tree generation)
* Mon Feb 15 2010 adrian@suse.de
- runtime fix from Rudi to process Eula.txt correctly without error
* Mon Feb 15 2010 adrian@suse.de
- do not die on not used release package
* Mon Feb 15 2010 ms@suse.de
- fixed cleanup of hosts file (bnc #579852)
* Fri Feb 12 2010 ms@suse.de
- update migration chapter
* Thu Feb 11 2010 ms@suse.de
- v4.16
- make setupSplash() to operate in a temp dir (bnc #579134)
* Thu Feb 11 2010 ms@suse.de
- fixed name resolution inside chroot if curl backend is used
  zypper uses libcurl for ftp transfers (bnc #578687)
* Thu Feb 11 2010 mbarringer@suse.de
- Adding a TODO file for the imagewriter
* Wed Feb 10 2010 ms@suse.de
- migration: fixed file find function
- migration: fixed broken link search / removal
* Wed Feb 10 2010 ms@suse.de
- migration: added zypper repos to config.sh if not local
* Wed Feb 10 2010 mbarringer@suse.de
- Minor imagewriter text changes
* Wed Feb 10 2010 ms@suse.de
- update documentation
* Wed Feb 10 2010 ms@suse.de
- migration: fixed version lookup
- migration: fixed report creation
* Wed Feb 10 2010 ms@suse.de
- fixed typo
* Wed Feb 10 2010 ms@suse.de
- fixed repo metadata download, cleanMount was called too early
- fixed error handling in report file creation
* Tue Feb  9 2010 ms@suse.de
- enable noarch subpackages
* Tue Feb  9 2010 ms@suse.de
- update documentation
* Mon Feb  8 2010 ms@suse.de
- added bug ID
* Mon Feb  8 2010 ms@suse.de
- handle reboot request only if we are not in recovery mode
* Mon Feb  8 2010 ms@suse.de
- moved EC2 options into a new ec2config section (bnc #577883)
* Mon Feb  8 2010 ms@suse.de
- v4.15
- fixed default split section usage for iso type
* Fri Feb  5 2010 ms@suse.de
- added XSL transformation for latest XML changes
  Thanks to Robert for doing this
* Fri Feb  5 2010 ms@suse.de
- prevent double / in activateImage
* Fri Feb  5 2010 ms@suse.de
- v4.14
- update documentation due to latest XML changes
- don't probeFileSystem if FSTYPE is nfs
- mounting sys devices with -o nolock doesn't make much sense
- use rpcbind as an alternative to portmap
* Fri Feb  5 2010 ms@suse.de
- update documentation
* Thu Feb  4 2010 ms@suse.de
- removed unneded xenconfig information from templates if dom0 setup is used
* Thu Feb  4 2010 ms@suse.de
- fixed migration mount setup and clean code allow
  zypper types dvd:// and iso:// to be used
* Thu Feb  4 2010 ms@suse.de
- fixed templates, Xen based OEM image should be a dom0
- Xen dom0 images doesn't require a xenconfig file
* Wed Feb  3 2010 ms@suse.de
- fixed migration mount setup and clean code
* Wed Feb  3 2010 ms@suse.de
- v4.13
- prevent XML pretty printer from swallowing comments
* Wed Feb  3 2010 adrian@suse.de
- enforce the "print" logging again for KIWICollect for significant speedup.
  However, we should rework the KIWICollect logging, but using
  KIWILog module would require significant speedup there.
* Tue Feb  2 2010 ms@suse.de
- fixed build
* Tue Feb  2 2010 ms@suse.de
- allow image="product" for inst-source module
- fixed NBD setup, make swap and RW an option
* Tue Feb  2 2010 ms@suse.de
- don't ask questions on oemboot pxe based install
* Tue Feb  2 2010 ms@suse.de
- added support for OEM installation via PXE. To setup your
  PXE boot server do the following:
  1) create an OEM install ISO (format="iso")
  2) loop mount the created .iso file to /mnt and copy the following
  files to the PXE boot server:
  * copy /mnt/boot/initrd  => /srv/tftpboot/boot
  * copy /mnt/boot/linux   => /srv/tftpboot/boot
  * copy /mnt/image.gz     => /srv/tftpboot/image
  * copy /mnt/image.gz.md5 => /srv/tftpboot/image
    3) set the kernel commandline parameter
    pxe=1
    via the append line in your PXE configuration.
    Alternatively the image can be stored on a FTP,HTTP server
    specified via the kiwiserver and kiwiservertype append
    information
* Mon Feb  1 2010 ms@suse.de
- added bug ID
* Mon Feb  1 2010 ms@suse.de
- v4.12
- don't move overlay mounts to real-root if NFS-root is used
  additionally prevent the ROOT_FSCK in case of NFS-root
- allow NFSROOT and NBDROOT to be overlayed with a remote
  read-write location
* Mon Feb  1 2010 ms@suse.de
- fixed incorrect handling of unit="G" values (bnc #574660)
* Mon Feb  1 2010 ms@suse.de
- v4.11
- added kernel/initrd update hotfix mechanism based on kexec
  It is possible to put the kernel file named linux.kexec and
  the initrd file named initrd.kexec on the first partition of
  a USB stick. If you plugin the stick and boot with the kernel
  option hotfix=1 it allows you to replace the existing kernel
  and initrd with the one on the stick
- increased wait time for dhcp lease file up to
  20sec (bnc #575561)
* Mon Feb  1 2010 adrian@suse.de
- create 11.3 fork, which is current factory.
  We basically need this to destinguish between kiwi 4.1 and 3.74 to write
  correct kiwi xml again.
* Thu Jan 28 2010 ms@suse.de
- update schema documentation
* Thu Jan 28 2010 ms@suse.de
- fixed inode calculation (bnc #574660)
* Thu Jan 28 2010 ms@suse.de
- fixed backtrace de-/activation functions
* Thu Jan 28 2010 ms@suse.de
- make XSL diff more readable
* Wed Jan 27 2010 ms@suse.de
- set XML element only if it's not already set with that value
- better XML diff output in logfile
* Tue Jan 26 2010 ms@suse.de
- fixed build
* Mon Jan 25 2010 ms@suse.de
- v4.10
- applied XML changes with the following effects
  * the image type is no longer an element content but an
    attribute called image="type" inside the type element
  * all oem elements are now part of the new oemconfig section
  * the sections oemconfig,pxedeploy,split,vmwareconfig,xenconfig,lvmvolumes
    are now type specific and have to be specified inside a type
  * migration code has been adapted to 4.1 schema
  * documentation has been adapted to 4.1 schema
- added clicfs as spec file requirement (bnc #573357)
* Mon Jan 25 2010 ms@suse.de
- added pretty xsl
* Mon Jan 25 2010 ms@suse.de
- fixed boot type check
* Mon Jan 25 2010 ms@suse.de
- print a jing helper message if schema validation failed
* Mon Jan 25 2010 ms@suse.de
- update to XML version 4.1
- update documentation
* Fri Jan 22 2010 ms@suse.de
- update migration XML creation
* Fri Jan 22 2010 ms@suse.de
- fixed XML parsing
- fixed XML diff
* Fri Jan 22 2010 ms@suse.de
- fixed XML parsing
* Fri Jan 22 2010 ms@suse.de
- fixed XML parsing
* Fri Jan 22 2010 ms@suse.de
- fixed XML parsing
* Fri Jan 22 2010 ms@suse.de
- fixed XML parsing
* Fri Jan 22 2010 ms@suse.de
- fixed XML parsing
* Fri Jan 22 2010 ms@suse.de
- changed parser function according to new XML layout
* Thu Jan 21 2010 ms@suse.de
- first start of better XML description
  moving pxedeploy split vmwareconfig xenconfig lvmvolumes into type
  adding new oemconfig section
* Thu Jan 21 2010 cwh@suse.de
- Added missing requires for sysopen constants
* Wed Jan 20 2010 ms@suse.de
- fixed missing ddn call to solve the device node
  in vmxboot too (bnc #571948)
* Wed Jan 20 2010 ms@suse.de
- v3.95
- fixed missing ddn call to solve the device node (bnc #571948)
* Wed Jan 20 2010 ms@suse.de
- removes sax2 and let the 11.2 based example use
  the X11 auto configuration feature in the suse-min-gnome example
  image description
* Tue Jan 19 2010 cwh@suse.de
- Integrated KIWIIsoLinux-gen-s390-cd-kernel.pl into KIWIIsoLinux.pm
* Tue Jan 19 2010 ms@suse.de
- v3.94
- fixed baselibs setup for 64bit image builds
- fixed split grub setup for install CD/Stick
- fixed split section parsing, remove trailing slash if no
  information follows
* Mon Jan 18 2010 ms@suse.de
- use -F for mke2fs calls
* Mon Jan 18 2010 ms@suse.de
- don't let xsltproc write into fixed /tmp location (bnc #571558)
- prevent USB device scan for pxe boot images (bnc #570961)
* Mon Jan 18 2010 ms@suse.de
- added config function to disable Ctrl-Alt-Del in inittab
* Fri Jan 15 2010 ms@suse.de
- added bug number
* Fri Jan 15 2010 ms@suse.de
- allow AOEROOT to contain the read-write device
* Fri Jan 15 2010 ms@suse.de
- v3.93
- moved package deletion into own function and adapt
  the examples. remove --noscripts for deleting packages
  this could cause files to stay in the system which has
  a bad impact core utilities like mkinitrd. If for example
  busybox is uninstalled without calling the postscript
  the mkinitrd setup links will stay as broken links and
  cause mkinitrd to stop working (bnc #570948)
* Thu Jan 14 2010 ms@suse.de
- update docs
* Thu Jan 14 2010 ms@suse.de
- v3.92
- fixed typo in getPXEDeployTimeout()
- forbid / to be specified in lvmvolumes (bnc #570398)
- allow absolute size value for lvm volumes (bnc #570396)
* Wed Jan 13 2010 adrian@suse.de
- fix writing of RELEASE line in content file
* Wed Jan 13 2010 ug@taylor.suse.de
- more KIWIURL::quote() fixes (bnc #561855)
* Wed Jan 13 2010 ms@suse.de
- create /srv/tftpboot/pxelinux.cfg/default only if not exist
* Wed Jan 13 2010 ms@suse.de
- rebuild docs
* Wed Jan 13 2010 ms@suse.de
- don't set disk cmdline parameter for pxe local grub setup
* Tue Jan 12 2010 cwh@suse.de
- Added autobuild script for generationg s390 cd kernel
* Tue Jan 12 2010 ms@suse.de
- fixed clicfs usage in combination with pxe image type
* Tue Jan 12 2010 cwh@suse.de
- Fixed s390 boot
* Mon Jan 11 2010 ms@suse.de
- partially reverted last patch
- fixed md5 file creation for clicfs images
* Mon Jan 11 2010 ms@suse.de
- v3.91
- fixed md5 file creation for clicfs images when used with PXE
- fixed validateSize() to take care for zblocks
* Mon Jan 11 2010 ms@suse.de
- added first version of report html creation
- again fixed KIWIURL::quote(). perl file checks doesn't
  allow quoted items (bnc #561855)
* Mon Jan 11 2010 coolo@suse.de
- do not error out - there are architectures without gfxboot.cfg
  (basically all but pcs)
* Sat Jan  9 2010 ms@suse.de
- fixed use of uninitialized value (bnc #569191)
* Fri Jan  8 2010 ms@suse.de
- v3.90
- changed default type to oem for migration result
* Fri Jan  8 2010 ms@suse.de
- fixed handling of oem-reboot request. preinit needs to run
  before this request is processed (bnc #563864)
* Fri Jan  8 2010 ms@suse.de
- migration: allow skipping parts of the process
* Fri Jan  8 2010 ms@suse.de
- fixed quoting when importing kernel cmdline (bnc #536309)
* Thu Jan  7 2010 ms@suse.de
- migration: added modified files tree
* Thu Jan  7 2010 ms@suse.de
- fixed percentage counter
* Thu Jan  7 2010 ms@suse.de
- migration: added modified files information
* Thu Jan  7 2010 ms@suse.de
- migration: fixed xml creation
* Thu Jan  7 2010 ms@suse.de
- migration: added a todo
* Thu Jan  7 2010 ms@suse.de
- migration performance fixes
* Thu Jan  7 2010 ms@suse.de
- added udevPending() to waitFor* functions (bnc #547862)
* Wed Jan  6 2010 ms@suse.de
- migration: fixed version detection
* Tue Jan  5 2010 ms@suse.de
- fixed cache creation
* Tue Jan  5 2010 ms@suse.de
- migration:
  * added cache file
  * some performance tweaks
* Tue Jan  5 2010 ms@suse.de
- migration: fixed path setup
* Tue Jan  5 2010 ms@suse.de
- fixed option setup for rpm -Va
* Tue Jan  5 2010 ms@suse.de
- migration: create overlay root tree as hard linked list
* Tue Jan  5 2010 ms@suse.de
- some work on the migration front [still WIP]:
  * changed to report -> perform system, fixed solvable
    creation and provide better information about package
    and pattern conflicts. Changed system to use the zypper
    defined repos and product information for the migration
* Mon Jan  4 2010 ms@suse.de
- fixed use of quiet variable
* Mon Jan  4 2010 ms@suse.de
- use default inode count for lvmparts (bnc #567580)
* Mon Jan  4 2010 ms@suse.de
- v3.89
- fixed dirPath() function, related to (bnc #561855)
- fixed KIWIURL::quote() for special '$' char (bnc #561855)
* Mon Dec 21 2009 cwh@suse.de
- fixed usage of string relational operator in numerical context
* Fri Dec 18 2009 adrian@suse.de
- sync more parameters for the EFI case
* Fri Dec 18 2009 adrian@suse.de
- limit volume id's to 32bytes or genisoimage aborts
* Thu Dec 17 2009 cwh@suse.de
- fixed efi boot
* Thu Dec 17 2009 ms@suse.de
- v3.88
- removed adaptec-firmware from SLED boot images. The package
  does not exist on SLED (bnc #562224)
* Wed Dec 16 2009 ms@suse.de
- v3.87
- added support for plaintext passwords
* Tue Dec 15 2009 ms@suse.de
- fixed user cancel exception text (bnc #557100)
* Tue Dec 15 2009 ms@suse.de
- v3.86
- call scripts in C env for LC_ALL and LANG (bnc #558693)
- fixed handling of dir:// and file:// (bnc #561855)
- bind mount /var/run/dbus into chroot (bnc #519764)
* Mon Dec 14 2009 ms@suse.de
- added parted to oemboot
* Mon Dec 14 2009 ms@suse.de
- update kiwi-tools
* Mon Dec 14 2009 ms@suse.de
- update kiwi-tools
* Mon Dec 14 2009 ms@suse.de
- fixed password salt creation
* Mon Dec 14 2009 ms@suse.de
- added kiwi-tools
* Mon Dec 14 2009 ms@suse.de
- clean packs
* Mon Dec 14 2009 ms@suse.de
- updated kiwi-tools packages
* Mon Dec 14 2009 ms@suse.de
- fixed dump progress window
* Mon Dec 14 2009 mbarringer@suse.de
- Removing cross-platform support from the Qt imagewriter
- Adding native Windows imagewriter
* Fri Dec 11 2009 ms@suse.de
- update dcounter in kiwi-tools. Adding the option -l which allows
  to use dcounter in progress dialogs (dialog program)
* Fri Dec 11 2009 ms@suse.de
- show disk size value in MB and only if > 0 (bnc #562190)
- put install progress information into dialog (bnc #562185)
- track restored files in percentage (bnc #562188)
* Fri Dec 11 2009 cwh@suse.de
- changed mkisofs parameters in KIWICollect.pm the way similar like autobuild did before
- fixed mkisofs parameters for ia64
- added ppc support to KIWIIsoLinux (KIWIIsoLinux-AppleFileMapping.txt is part of it)
- added KIWIIsoLinux-AppleFileMapping.txt to spec file
* Fri Dec 11 2009 ms@suse.de
- added adaptec-firmware to iso/net and oemboot (bnc #562224)
* Thu Dec 10 2009 ms@suse.de
- use blowfish extension for password creation (bnc #562105)
* Thu Dec 10 2009 ms@suse.de
- fixed storage of lvmgroup inside KIWIBoot object
* Thu Dec 10 2009 ms@suse.de
- fixed boot label setup for installstick and installcd modus
* Thu Dec 10 2009 ms@suse.de
- fixed condition for calling vgchange -an
* Wed Dec  9 2009 ms@suse.de
- fixed install stick creation
* Wed Dec  9 2009 adrian@suse.de
- fix repomd creation code
* Wed Dec  9 2009 adrian@suse.de
- fix compare operator
* Wed Dec  9 2009 ms@suse.de
- moved repartition functions to KIWILinuxRC
* Wed Dec  9 2009 ms@suse.de
- fixed home device fstab entry, uses disk by id now
* Wed Dec  9 2009 ug@taylor.suse.de
- implementation of hybridpersistent key (bnc #557100)
* Wed Dec  9 2009 ms@suse.de
- v3.85
- fixed user/group setup for multiple users (bnc #561749)
* Wed Dec  9 2009 ms@suse.de
- added information about repo solvable creation
- fixed solvable creation if only one URL is used
* Tue Dec  8 2009 ms@suse.de
- improved solvable caching code and added functions to
  KIWISatSolver module for extracting SaT informations about
  dependency and queueing problems
* Tue Dec  8 2009 ms@suse.de
- adapt perl code to last changes in satsolver plugin
* Tue Dec  8 2009 ms@suse.de
- fixed satsolver usage, pool_setarch is required for correct
  solving results. Also prune_best_arch_name_version() is now
  used instead of prune_to_best_arch
* Tue Dec  8 2009 adrian@suse.de
- drop the entire support for NO_ISO, since it is legacy and is not used anymore.
* Tue Dec  8 2009 adrian@suse.de
- ups, if statement should be in the opposite way around
* Mon Dec  7 2009 ms@suse.de
- v3.84
- fix syntax error when calling warning log function
- backport content meta data generation out of product files from
  release packages
* Mon Dec  7 2009 adrian@suse.de
- Support content file creation via data from selected release packages
  and their specs inside of .prod file.
* Thu Dec  3 2009 ms@suse.de
- v3.83
- added busybox for to netboot descriptions and changed
  compressed tftp download to busybox tftp because only this
  implementations allows to work with pipes (bnc #559830)
- removed 10.3 support
* Thu Dec  3 2009 ms@suse.de
- fixed spec file provides/obsoletes
* Thu Dec  3 2009 ms@suse.de
- dos2unix xsdDocHtml.css
* Thu Dec  3 2009 ms@suse.de
- fixed boot device activation
* Thu Dec  3 2009 adrian@scherben.(none)
- move kiwi installation source plugins from novell forge.
  These plugins are needed to create product medias for openSUSE 11.1 and later.
  The 11.0 plugin has been dropped, since it never was in a working state.
* Wed Dec  2 2009 ms@suse.de
- added support for custom LVM group name. Default is kiwiVG
- fixed LVM based recovery workflow. the recovery needs to know
  about the separate boot partition. Additionally the recovery
  partition must be a separate partition outside LVM
* Wed Dec  2 2009 adrian@scherben.(none)
- fix logging, not warnings for progress reporting.
* Tue Dec  1 2009 adrian@scherben.(none)
- fail if a plugin dir is configured, but does not exist
* Mon Nov 30 2009 ms@suse.de
- added options --fs-max-mount-count and --fs-check-interval
  as well as the XML type attribute fsnocheck which deactivates
  the filesystem check at all.
* Mon Nov 30 2009 ms@suse.de
- fixed root device setup for xenboot in EC2 (bnc #559143)
* Mon Nov 30 2009 ms@suse.de
- removed kernel-ec2-extra from xenboot,  not needed (bnc #559106)
* Mon Nov 30 2009 ms@suse.de
- v3.82
- fixed size setup which was ignored due to last fix (bnc #559098)
* Thu Nov 26 2009 ms@suse.de
- v3.81
- call images.sh / config.sh scripts in POSIX env (bnc #558693)
- fixed invalid link setup in createImageLiveCD() (bnc #558666)
- fixed size / inode calcuation due to wrong unit (bnc #555688)
* Thu Nov 26 2009 adrian@scherben.(none)
- fix call of warning method in KIWILog
* Wed Nov 25 2009 ms@suse.de
- fixed setup of xencons when building Xen domU images (bnc #557791)
* Wed Nov 25 2009 ms@suse.de
- fixed revision information in kiwi --version info
- fixed Makefile clean target
* Tue Nov 24 2009 ms@suse.de
- v3.80
- fixed root tree creation build inconsistencies due to missing
  libraries at the beginning of the root tree creation. Any glibc
  linked program uses /etc/nsswitch.conf and from there requires
  /lib(64)/libnss* libraries to do user/group to id resolution.
  If the operation happens chrooted, the libs needs to be there.
  The fix will install the glibc package which provides these
  libraries in a $root/baselibs directory first and moves them
  to $root. After that process the package manager is again called
  to install the bootstrap listed packages follewed by the rest
  of the specified packages (bnc #536256)
* Mon Nov 23 2009 ms@suse.de
- v3.79
- fixed clicfs boot by preventing root filesystem checks via
  ROOTFS_FSCK="0", also don't use run-init for clic (bnc #557661)
* Thu Nov 19 2009 ms@suse.de
- v3.78
- fixed umount calls before init is called. Due to this
  fix the df information after login should be correct
* Wed Nov 18 2009 ms@suse.de
- added openSUSE-11.2 target for migration (bnc #555724)
* Wed Nov 18 2009 ms@suse.de
- v3.77
- fixed search for gfxboot file du to changes in the
  gfxboot-devel package for 11.2 (bnc #556130)
* Tue Nov 17 2009 ms@suse.de
- added LVM feature to allow parts of the filesystem
  in a separate volume. The setup of volumes happens
  in the new <lvmvolumes> section
* Mon Nov 16 2009 ms@suse.de
- update XML to 3.8
* Mon Nov 16 2009 ms@suse.de
- v3.76
- don't require preinit to call init (bnc #521456)
* Thu Nov 12 2009 ms@suse.de
- remove pivot root calls (old code) and changed preinit
  handling to let preinit run like init. If preinit runs the
  kernel already knows the system image root as / and preinit
  always ends with exec init (bnc #521456)
* Wed Nov 11 2009 ms@suse.de
- fixed exit code evaluation in Dialog function. The value of the
  evaluated exit code was undefined because it depended on which
  subshell finished first. The solution is to prevent parameter
  subshells when building the dialog parameterlist (bnc #547864)
* Mon Nov  9 2009 ms@suse.de
- v3.75
- fixed spec file for s390 architecture
* Fri Nov  6 2009 ms@suse.de
- fixed sysconfig/kernel setup for old mkinitrd (bnc #547571)
* Fri Nov  6 2009 ms@suse.de
- really removed windowmanager files
* Fri Nov  6 2009 ms@suse.de
- really remove inittab files from examples
* Fri Nov  6 2009 ms@suse.de
- fixed xslt processing. The possible change to the XML
  file is now written to /tmp to avoid writing into read-only
  filesystem (bnc #552617)
* Fri Nov  6 2009 ms@suse.de
- removing displaymanager overlay files and use the baseUpdateSysConfig()
  function instead
* Fri Nov  6 2009 ms@suse.de
- removing inittab overlay files and use baseSetRunlevel() instead
* Thu Nov  5 2009 adrian@scherben.(none)
- Another place what broke the mkisofs sort file
* Thu Nov  5 2009 adrian@scherben.(none)
- Fix sort file for mkisofs, fixes boot on crappy BIOSes.
* Thu Nov  5 2009 ms@suse.de
- added support for timezone in JeOS
- changed suseActivateDefaultServices() to activate services
  only without calling the post scripts of installed RPM's
* Wed Nov  4 2009 ms@suse.de
- added missing usb host controller module (ohci) to all
  boot image descriptions except vmxboot which doesn't need it
* Tue Nov  3 2009 ms@suse.de
- added Patches from Robert Schweikert
  * added suse-min-gnome example image description
* Tue Nov  3 2009 ms@suse.de
- removed 10.3 examples
* Tue Nov  3 2009 ms@suse.de
- added Patches from Robert Schweikert
  * change deploy section to pxedeploy section and update schemaversion
    from 3.7 to 3.8 via xsl stylesheet
* Tue Nov  3 2009 ms@suse.de
- v3.75
- added Patches from Robert Schweikert
  * new function baseSetRunlevel to allow setup of runlevel in inittab
* Tue Nov  3 2009 ms@suse.de
- added ieee1394 firewire modules to support liveCD on
  firewire DVD drive (bnc #479020)
* Mon Nov  2 2009 mantel@suse.de
- only basic version of vim is installed; we disable syntax highlighting
  in order to avoid irritating error message on vim startup.
* Wed Oct 28 2009 ms@suse.de
- OEM recover/repair
  * make sure passwd/shadow and group files will be preserved
  * make sure RPM database will be preserved
* Wed Oct 28 2009 adrian@scherben.(none)
- use true/false instead of yes/no to harmonize with rest of kiwi
* Wed Oct 28 2009 adrian@scherben.(none)
- use yes/no in REPO_ONLY to harmonize with MULTIPLE_MEDIA
* Wed Oct 28 2009 adrian@scherben.(none)
- remove not used KIWI_COLLECT_TERMINAL_LOG enviroment variable, we use the --logfile switch since 11.1
* Wed Oct 28 2009 adrian@scherben.(none)
- cleanup log states (lots of Warning -> Information) and drop obsolete code.
* Tue Oct 27 2009 ms@suse.de
- fixed string comparison
* Tue Oct 27 2009 ms@suse.de
- kiwi-instsource changes done by coolo@novell.com
  * fix 32bit debuginfos
* Tue Oct 27 2009 ms@suse.de
- offer only languages for selection which are part of the
  initrd. The <locale> element defines which locales and
  translations are part of the initrd. If only one language
  is available no selection dialog will be opened
* Tue Oct 27 2009 coolo@suse.de
- fix 32bit debuginfos
* Tue Oct 27 2009 ms@suse.de
- kiwi-instsource changes done by coolo@novell.com
  * fixed logging
  * fixed several uninitialized variables
  * fixed debuginfo handling
* Mon Oct 26 2009 coolo@suse.de
- add all debuginfo packages
* Mon Oct 26 2009 coolo@suse.de
- little cleanup
* Mon Oct 26 2009 coolo@suse.de
- have defaults for product variables
* Mon Oct 26 2009 coolo@suse.de
- more fixes for logging
* Mon Oct 26 2009 coolo@suse.de
- one less unintialized variable
* Mon Oct 26 2009 coolo@suse.de
- more cleanup in the logging of products
* Mon Oct 26 2009 coolo@suse.de
- trying to fix logging
* Mon Oct 26 2009 ms@suse.de
- added missing config.sh script to strip down locale information
* Mon Oct 26 2009 ms@suse.de
- added bug ID
* Mon Oct 26 2009 ms@suse.de
- don't call ldconfig when loading KIWILinuxRC functions
* Mon Oct 26 2009 ms@suse.de
- better changelog entry
* Fri Oct 23 2009 ms@suse.de
- set splash to verbose if there is a systemException (bnc #547821)
- check for block device when retrieving MBR ID (bnc #547821)
* Fri Oct 23 2009 ms@suse.de
- added DOBACKUP variable to easily switch on/off the
  backup creation in recovery mode (bnc #546057)
* Thu Oct 22 2009 ms@suse.de
- recovery mode (bnc #546057):
  * throw reboot exception if backup files can't be created
  * create backup files for files in recovery.tar.gz only
* Wed Oct 21 2009 ms@suse.de
- use cmp to compare files first before diffing them. Prevent
  second find call for backup files. This increases the recovery
  performance in repair mode. Additionally write backup diffs
  to /tmp/backup (bnc #546057)
* Tue Oct 20 2009 ms@suse.de
- added support for lang and keytable in cmdline. Support is
  only available with the gfxboot code from >= 11.2 (bnc #547915)
- changed fbiterm return code evaluation. Echo the return code
  from the last instead of relying to the exit code of the
  fbiterm terminal (bnc #547864)
* Mon Oct 19 2009 ms@suse.de
- search .backup files in home and etc only (bnc #546057)
* Fri Oct 16 2009 mbarringer@suse.de
- Add changelog message to kiwi.changes
* Fri Oct 16 2009 mbarringer@suse.de
- Fixing bug 547143 - kiwi imagewriter needs .iso filetype filter too
* Wed Oct 14 2009 ms@suse.de
- don't remove libgcc_s from initrd. It's required for
  programs which uses pthread_cancel()
* Wed Oct 14 2009 ms@suse.de
- prevent automatic CD eject on kiwi install. If the tray is
  blocked (some servers hide their drives behind doors) the boot
  CD/DVD with the OEM image ends up back in the machine. Therefore
  we open a popup window asking to user to remove the install
  media before continuing
* Tue Oct 13 2009 ms@suse.de
- added udevPending call in waitForUSBDeviceScan() to make
  sure the device nodes are created if we leave the function
* Mon Oct 12 2009 ms@suse.de
- fixed clicfs usage for vmx,oem and usbboot. Needs the same
  boot partition like the DM squash setup uses
- fixed clicfs mount on bootvm creation
* Mon Oct 12 2009 ms@suse.de
- fixed error log switch in Echo function
* Mon Oct 12 2009 ms@suse.de
- fixed hwclock and timezone setup (bnc #546096)
- fixed 11.2 JeOS template, no kernel-*-base anymore
* Thu Oct  8 2009 ms@suse.de
- deactivate backup MBR at 0x800 (bnc #539505)
* Thu Oct  8 2009 ms@suse.de
- leave time message in kiwi.log file
* Thu Oct  8 2009 ms@suse.de
- update schema documentation
* Thu Oct  8 2009 ms@suse.de
- fixed setup of doc exclusion for zypper (bnc #544874)
- added boot timer for kiwi boot images like the kernel does
* Thu Oct  8 2009 ms@suse.de
- added kiwi-rpmlintrc filter for boot translations
- fixed css file encoding in documentation
- update kiwi-tools in sle11 repo
* Thu Oct  8 2009 ms@suse.de
- added boot timer for kiwi boot images like the kernel does
* Wed Oct  7 2009 ms@suse.de
- improved umount code for auto mount of removable storage
  devices. The function umountDevice() takes over the task
  of umounting all filesystems associated with the given
  device
- use searchBIOSBootDevice for usbboot instead of USBStickDevice
  since we have the unique MBR ID in place this is the better
  method to search for the boot device
* Wed Oct  7 2009 ms@suse.de
- create backup files for /etc and /home only in Recovery mode
  This is done to reduce the runtime the recovery process takes
* Tue Oct  6 2009 ms@suse.de
- fixed race condition in waitForStorageDevice()
- deactivate automatic filesystem check for clicfs based
  livesystems
* Tue Oct  6 2009 ms@suse.de
- Add cancel/reboot menu item in recovery bootloader configuration.
  This will help avoid accidental recovery invocation, which could
  be a potential issue. The cancel/reboot item is now the default
  selection, and the delay is now 30 seconds giving the user more
  time to contemplate their restoration options (bnc #544420)
* Mon Oct  5 2009 ms@suse.de
- fixed old X11R6 lib/lib64 path
* Mon Oct  5 2009 ms@suse.de
- again fixed stripUnusedLibs()
* Mon Oct  5 2009 ms@suse.de
- moved destination path check to function where it is needed
* Mon Oct  5 2009 ms@suse.de
- fixed race condition in setupRecoveryArchive() when
  creating the tar archive
- fixed fbiterm support for SLE10
- fixed baseStripUnusedLibs
* Mon Oct  5 2009 ms@suse.de
- added and improved official JeOS templates to the kiwi git
  source tree. The official templates used by the SDK product
  and the SuSE Studio online service are now provided via the
  kiwi package kiwi-templates (bnc #521970)
* Mon Oct  5 2009 ms@suse.de
- fixed OEM bool option handling
* Mon Oct  5 2009 ms@suse.de
- fixed detection of USB install media
* Mon Oct  5 2009 ms@suse.de
- added import attribute in <profile> section to allow
  default imports if not profile was set on the commandline
* Fri Oct  2 2009 ms@suse.de
- fixed handling of profiled preferences sections
* Fri Oct  2 2009 ms@suse.de
- fixed bool value evaluation in KIWIXML.pm::get*()
- added suseImportBuildKey() helper function used in JeOS
  templates (bnc #521970)
* Thu Oct  1 2009 ms@suse.de
- added support for <oem-recoveryID>, default ID=83 (bnc #543118)
- reload MBR in restore mode, also recreate swap and home
  systems if defined in restored fstab (bnc #542648)
* Thu Oct  1 2009 ms@suse.de
- fixed stick detection if multiple sticks are plugged in
  stickFound variable was set too early, thanks to Axel Theilmann
- use bc for more exact progress calculation
* Thu Oct  1 2009 ms@suse.de
- clear screen after install confirmation
* Wed Sep 30 2009 ms@suse.de
- oemboot: re-install grub bootloader into partition if the
  partition contains a bootloader signature already (bnc #543123)
- added backup diff in recovery mode. This will add a file~
  diff file for each file changed according to the recovery
  contents.
* Tue Sep 29 2009 ms@suse.de
- improved restore feature which also restores the filesystem
  before restoring files (bnc #542648)
* Mon Sep 28 2009 ms@suse.de
- fixed typos and mistakes in the documentation, Thanks to
  Robert who found them
* Thu Sep 24 2009 ms@suse.de
- limit language selection to the installed locales (bnc #539398)
  * de_DE.utf8
  * en_US.utf8
  * ru_RU.utf8
  * zh_CN.utf8
  * zh_TW.utf8
* Thu Sep 24 2009 ms@suse.de
- added language translations (ar,tr,uk) (bnc #539398)
* Wed Sep 23 2009 ms@suse.de
- added language translations (bnc #539398)
* Wed Sep 23 2009 ms@suse.de
- evaluate languages set by <locale> in the suseGFXBoot code.
  This will result in grub displaying the selected languages
* Tue Sep 22 2009 ms@suse.de
- added i18n support for dialog buttons too
* Mon Sep 21 2009 ms@suse.de
- fixed %%1 evaluation in getText
* Mon Sep 21 2009 ms@suse.de
- fixed LANG and locale use
* Mon Sep 21 2009 ms@suse.de
- added OEM restore mode (bnc #539390)
- evaluate kiwikernelmodule variable from cmdline also in
  modules.order mode where loading is done by udev (bnc #525345)
- don't remove libblkid1 from initrd (bnc #505580)
- remove reserved blocks in any case when mounting
  clic by calling tune2fs -m 0 (bnc #505580)
* Sun Sep 20 2009 ms@suse.de
- preserve ownership if xsltproc changes the xml file
* Fri Sep 18 2009 ms@suse.de
- added pot template for translations (bnc #539398)
* Thu Sep 17 2009 ms@suse.de
- added fbiterm to oemboot boot images. This allows to display
  wide screen characters on the framebuffer console and therefore
  enabled kiwi's dialog windows to be multilingual (bnc #539398)
- fixed baseStripLocales() function
* Wed Sep 16 2009 ms@suse.de
- fixed MBR flag setup (bnc #539505)
* Wed Sep 16 2009 ms@suse.de
- fixed bool value evaluation for oem-recovery
* Wed Sep 16 2009 ms@suse.de
- added backup MBR to 0x800 if --grub-chainload is in use
  also added FDST flag to 0x190 for preload setup. We need
  to take care for that value if other preloads requires
  something similar it should be an option (bnc #539505)
* Tue Sep 15 2009 ms@suse.de
- added cross-directory-hard-link filter
* Tue Sep 15 2009 ms@suse.de
- update xsl stylesheets
* Tue Sep 15 2009 ms@suse.de
- fixed types in oem examples
* Tue Sep 15 2009 ms@suse.de
- changed to schema version 3.7, add xsl stylesheet which
  automatically changes to the bool values true/false
  * allow ensconce as packagemanager type
  * fixed bool content for rpm-check-signatures
* Mon Sep 14 2009 ms@suse.de
- fixed bool content for rpm-check-signatures
* Mon Sep 14 2009 ms@suse.de
- allow ensconce as packagemanager type
- fixed bool content for rpm-check-signatures
- fixed inode calculation, needs integer result
* Sat Sep 12 2009 ms@suse.de
- link files to create live ISO in createImageLiveCD()
  instead of moving them (bnc #412689)
- do kiwi test mounts with readonly option (bnc #538355)
- use option -J -f to call genisoimage (bnc #538390)
* Fri Sep 11 2009 ms@suse.de
- disabled check for removable flag in USBStickDevice()
  function (bnc #535113)
* Fri Sep 11 2009 ms@suse.de
- allow cmdline line overwrites only if the variable
  ALLOW_CMDLINE_OVERWRITE=yes is set in config.<MAC> or
  config.default. By default no overwrites are allowed
  which should add an acceptable level of
  security (bnc #536309)
* Thu Sep  3 2009 ms@suse.de
- allow NBDROOT to be set via kernel cmdline (bnc #536309)
* Thu Sep  3 2009 ms@suse.de
- fixed satplugin getInstallList() function, did not allocate
  enough space to hold the package size. This causes the buffer
  overflow inside the binding. Also added the flags
-D_FORTIFY_SOURCE=2 -fstack-protector to build the same
  binding binary as if kiwi is build inside the BS. Also
  fixed the spec file and removed the versioned requires of
  satsolver-tools (bnc #532894)
* Wed Sep  2 2009 ms@suse.de
- fixed writeXML
* Wed Sep  2 2009 ms@suse.de
- added encoding information to all templates
- added log information about temporary XML changes
  for all modes of kiwi, removed the used xml output
  file
* Tue Sep  1 2009 ms@suse.de
- fixed virtual disk creation with clicfs involved
* Tue Sep  1 2009 ms@suse.de
- added option --grub-chainload which allows the virtual
  disk based images to chainload grub from partition one.
  This is required for some preload processes (bnc #529850)
- changed filesystem detection by using blkid instead
  of a raw dump + file call. Related to (bnc #529850)
- disabled partition table re-write for hybrid ISO's
  also see the comment in KIWIIsoLinux.pm
* Fri Aug 28 2009 ms@suse.de
- fixed partition size check which failed if oem-systemsize
  was set but the disk was smaller than the configured size
* Thu Aug 27 2009 ms@suse.de
- added release tag to sattools_version
* Wed Aug 26 2009 ms@suse.de
- added support for parted in oem repartition code
* Wed Aug 26 2009 ms@suse.de
- removed check for luks mapping in functions which are
  surely not called if the luks extension is used
* Tue Aug 25 2009 ms@suse.de
- fixed grep call, only return code is of interest
* Tue Aug 25 2009 ms@suse.de
- support new syslinux >= 3.82 format (bnc #530255)
- added function dn to support linux device node name
  convention: Converts from partition name to disk name (bnc #529580)
* Tue Aug 25 2009 ms@suse.de
- fixed bootloader title setup if multiple kernels are installed
- restructured oem repartition code to allow use of parted.
  parted does not allow to create custom partition id's they
  are the result of a sequence of subsequently created partitions.
  parted implementation will follow soon
- allow only bool (true/false) content for the oem-*
  boolean attributes
* Fri Aug 21 2009 ms@suse.de
- remove kernel-.*-base from all boot image descriptions
  for suse-11.2. They don't exist anymore
* Thu Aug 20 2009 ms@suse.de
- fixed spec file
* Thu Aug 20 2009 ms@suse.de
- fixed boot default size setup (bnc #532371)
- fixed KIWIBoot::getStorageSize function, use blockdev
- fixed dialog input by calling setctsid before dialog
* Wed Aug 19 2009 ms@suse.de
- fixed usb stick size check (bnc #532371)
* Wed Aug 19 2009 ms@suse.de
- removed duplicate creation of read/write filesystem
* Tue Aug 18 2009 ms@suse.de
- changed title for install media to "Install/Restore ..."
* Mon Aug 17 2009 ms@suse.de
- added support for language selection in displayEULA function.
  The function now uses the same file names according to the
  licenses.tgz file. If no language specific license file could
  be found the function defaults to license.txt and if that file
  also doesn't exist it defaults to EULA.txt (bnc #530497)
* Fri Aug 14 2009 ms@suse.de
- fixed main::mount() method, setup of umountStack was wrong
  now using mount destination for umount not source
* Fri Aug 14 2009 ms@suse.de
- fixed isohybrid created partition table to be DOS compatible
  This means the first partition starts at sector 64
* Fri Aug 14 2009 ms@suse.de
- update documentation, add information about LVM and
  repository priorities, differences between smart and zypper
* Thu Aug 13 2009 ms@suse.de
- fixed typo
* Thu Aug 13 2009 ms@suse.de
- convert schema css to unix file format
* Thu Aug 13 2009 ms@suse.de
- update schema documentation
* Thu Aug 13 2009 ms@suse.de
- provided new kiwi-tools for sles11 without pigz
* Thu Aug 13 2009 ms@suse.de
- removed pigz from kiwi-tools, it's packaged and
  maintained by Alexander Graf <agraf@suse.de> now
* Thu Aug 13 2009 ms@suse.de
- make rpm-force content a boolean value
* Wed Aug 12 2009 ms@suse.de
- fixed waitForStorageDevice() check
* Wed Aug 12 2009 ms@suse.de
- fixed fsck call for clicfs mount
* Wed Aug 12 2009 ms@suse.de
- run fsck and resize2fs only on first boot of a clic mount
- don't wait for storage device if it's a loop
* Wed Aug 12 2009 ms@suse.de
- fixed VMFindSystem function in xenboot (bnc #530200)
* Tue Aug 11 2009 ms@suse.de
- v3.74
- use resize2fs -M if possible ( >= v1.41 )
* Tue Aug 11 2009 ms@suse.de
- fixed bool value in documentation
* Tue Aug 11 2009 ms@suse.de
- fixed foreign addPackage and addArchive calls, make sure
  the package/archive is added to the bootstrap section not
  to the image section as we can't guarantee that a
  type="image" section exists
- run tagmedia at last
* Tue Aug 11 2009 ms@suse.de
- better text for used xml file
* Tue Aug 11 2009 ms@suse.de
- v3.73
- removed -extra kernel packages for 11.2, don't exist anymore
- added desktop kernel profile too boot images for 11.2
* Tue Aug 11 2009 ms@suse.de
- fixed getSize function to calculate required inode count
  for the subsequent mkfs ext2/3/4 call (bnc #528839)
* Mon Aug 10 2009 ms@suse.de
- added ddn function and replace all occurrences of
  a=$disk"number" with a=$(ddn $disk number) (bnc #529580)
* Mon Aug 10 2009 ms@suse.de
- added checkmedia KIWIIsoLinux constructor parameter
* Sun Aug  9 2009 adrian@scherben.(none)
- check for existens of README.BETA file
* Sun Aug  9 2009 adrian@scherben.(none)
  * Activate ISO creation for product medias by default.
  * Add check for medias intended to be a ftp tree only (no iso)
  * Do not ignore random errors anymore, but fail !
  * cleanup of some return values, still way more to do
* Fri Aug  7 2009 ms@suse.de
- v3.71
- added --select packages for the --info option
* Fri Aug  7 2009 ms@suse.de
- fixed loop between CDMount and searchBIOSBootDevice
  happening in oem ISO install mode
* Fri Aug  7 2009 ms@suse.de
- added dialog based progress information when restoring
  the recovery archive files (bnc #510041)
* Fri Aug  7 2009 ms@suse.de
- fixed evaluation of MKCLICFS_COMPRESSION (bnc #528743)
* Thu Aug  6 2009 ms@suse.de
- clear screen after dialog window disappears (bnc #510041)
* Thu Aug  6 2009 ms@suse.de
- v3.70
- fixed HAVE_USB check, usbcore is no longer a module
- added edd module to be present in isoboot
* Wed Aug  5 2009 ms@suse.de
- fixed OEM_SYSTEMSIZE evaluation for standard and luks repart
* Wed Aug  5 2009 ms@suse.de
- allow OEM_SYSMTEMSIZE evaluation for OEMRepartLuks
* Wed Aug  5 2009 ms@suse.de
- v3.69
- changed oem-repart to allow oem-systemsize even if no home and
  no swap partition was requested. by default the entire disk space
  is used but if a oem-systemsize is set this value will be used
  and therefore allows to have some space left on the disk
- fixed loop cleanup
* Wed Aug  5 2009 ms@suse.de
- wait for process to finish when sending int signal (bnc #525986)
* Tue Aug  4 2009 ms@suse.de
- use dmsetup remove instead of kpartx -d
* Tue Aug  4 2009 ms@suse.de
- add a sleep of one second between kpartx -d and losetup -d
* Tue Aug  4 2009 ms@suse.de
- send signal again after 5 seconds, if the process still exists
* Tue Aug  4 2009 ms@suse.de
- re-added clicfs ignore-cow-errors option
* Tue Aug  4 2009 ms@suse.de
- add a sleep of one second between kpartx -d and losetup -d
- wait for process to finish when sending interrupt signal (bnc #525986)
- added support for hybrid ISO's. This feature exists with
  openSUSE 11.2 or later. In order to use it add the attribute
  hybrid="true" to your iso type line. If you use the iso on
  a read/write medium the isoboot code will search for a 0x83
  partition used for writing OS data (bnc #496505)
* Mon Aug  3 2009 ms@suse.de
- added mediacheck feature for hybrid iso
- use partition not disk to mount hybrid
* Mon Aug  3 2009 ms@suse.de
- v3.68
- added support for hybrid ISO's. This feature exists with
  openSUSE 11.2 or later. In order to use it add the attribute
  hybrid="true" to your iso type line.
* Fri Jul 31 2009 ms@suse.de
- fixed typo
* Fri Jul 31 2009 ms@suse.de
- use blockdev to check partition and disk size (bnc #527016)
* Fri Jul 31 2009 ms@suse.de
- v3.67
- use #!/usr/bin/env vmware in .vmx config file
* Wed Jul 29 2009 ms@suse.de
- fixed file finder for relative paths in createImageSplit
* Wed Jul 29 2009 ms@suse.de
- fixed code box dimensions
* Wed Jul 29 2009 ms@suse.de
- fixed solvable creation for migrate, also add the
  option --report-packlist. Updated docu chapter about
  migration
* Wed Jul 29 2009 ms@suse.de
- deactivate mbr id check on oem install (bnc #525682)
* Wed Jul 29 2009 ms@suse.de
- v3.66
- update ec2 documentation, fixed public ari/aki table
* Mon Jul 27 2009 ms@suse.de
- update documentation
* Mon Jul 27 2009 ms@suse.de
- fixed build
* Mon Jul 27 2009 ms@suse.de
- fixed build
* Mon Jul 27 2009 ms@suse.de
- fixed build
* Mon Jul 27 2009 ms@suse.de
- added suse-11.2-JeOS template
* Mon Jul 27 2009 ms@suse.de
- removed obsolte tools/cdtool/suse-isolinux
- fixed isoboot: added gfxboot.com if it exists
* Mon Jul 27 2009 ms@suse.de
- leave libncursesw inside the initrd for dialog use
* Fri Jul 24 2009 ms@suse.de
- v3.65
- added waitForUSBDeviceScan() function and wait only
  if usbcore module could be loaded
* Thu Jul 23 2009 ms@suse.de
- added cciss module to be part of the oem initrd
* Thu Jul 23 2009 ms@suse.de
- fixed dumpkeys call in KIWIManager
* Mon Jul 20 2009 ms@suse.de
- added displayEULA function (bnc #522985)
* Thu Jul 16 2009 ms@suse.de
- added opensuseProduct in JeOS templates (bnc #522217)
* Thu Jul 16 2009 ms@suse.de
- v3.64
- fixed xenbridge network setup if bridge name is set to
  an empty string (bnc #515404)
* Wed Jul 15 2009 ms@suse.de
- fixed satplugin due to satsolver api changes (bnc #521968)
* Wed Jul 15 2009 ms@suse.de
- fixed JeOS SLE10 template
* Wed Jul 15 2009 ms@suse.de
- openssl-certs does not exist on SLE10 changed to openssl
* Tue Jul 14 2009 ms@suse.de
- added openssl-certs to bootstrap section of SLE JeOS and
  boot image templates to allow use of SLE update repositories
* Tue Jul 14 2009 ms@suse.de
- added openssl-certs to bootstrap section of SLE JeOS
  templates to allow use of SLE update repositories
* Tue Jul 14 2009 ms@suse.de
- fixed liveCD isolinux entry selection (bnc #521338)
- removed required lib* packages from delete sections
- be verbose when removing files from the initrd
* Tue Jul 14 2009 ms@suse.de
- added suseSetupProduct function (bnc #520268)
* Mon Jul 13 2009 ms@suse.de
- set hal lock for mapped luks device
- added support for luks extension for iso image type (bnc #505782)
* Mon Jul 13 2009 ms@suse.de
- added support for luks extension for xen image type (bnc #505782)
* Mon Jul 13 2009 ms@suse.de
- added support for luks extension for usb image type (bnc #505782)
* Mon Jul 13 2009 ms@suse.de
- added comments for luks boot setup
* Mon Jul 13 2009 ms@suse.de
- fixed ram only netboot image download (bnc #519055)
* Thu Jul  9 2009 ms@suse.de
- v3.63
- make luks password dialog more user friendly
- update schema documentation
* Wed Jul  8 2009 ms@suse.de
- added check for packages really on media when using
  fallback KIWIPattern resolver (bnc #517506)
* Wed Jul  8 2009 ms@suse.de
- fixed luksboot link
* Wed Jul  8 2009 ms@suse.de
- fixed bootloader setup for luks mode
- fixed default split file
* Tue Jul  7 2009 ms@suse.de
- added support for luks extension for oem image type
- fixed CD eject in oem CD/DVD install mode
* Mon Jul  6 2009 ms@suse.de
- fixed block comment
* Sun Jul  5 2009 ms@suse.de
- v3.62
- fixed combined mount with luks encoded read-write part
* Sun Jul  5 2009 ms@suse.de
- fixed combined mount with luks encoded read-write part
* Fri Jul  3 2009 ms@suse.de
- added basic support for LUKS extension for vmx image type
  with compressed root filesystem.
* Thu Jul  2 2009 ms@suse.de
- use --passwordbox instead of --inputbox to ask for the luks passphrase
* Thu Jul  2 2009 ms@suse.de
- added basic support for LUKS extension for vmx image type
* Wed Jul  1 2009 ms@suse.de
- v3.61
- prepared KIWIImage to work with luks extension. This is not
  a complete implementation so far, just a first start (bnc #505782)
- fixed inclusion of custom tar archives if the image
  description provides only a bootstrap section like the
  isoboot data does
* Wed Jun 24 2009 ms@suse.de
- allow inclusion of custom tar archives with new <archive>
  element. This can be used to include custom branding without
  special branding packages. This can also be used to include
  any kind of data without the need for a package (bnc #515573)
* Wed Jun 24 2009 ms@suse.de
- the inode issue comes back to haunt us yet again.  The last go
  around actually made things *worse* for things like vmdk that
  allocate large disks, since 2x the number of files is probably
  much smaller than the 'automatic' calculation used for a disk of
  that size. The attached patch fixes this by removing the
--fs-numinodes option (which is useless, IMHO) and replaces it
  with --fs-inoderatio.  Kiwi will assume 16k for inode ratio if
  not otherwise specified. We use the ratio to determine the number
  of inodes, unless it is a smaller value than num_files*2.
* Tue Jun 23 2009 ms@suse.de
- fixed typo
* Tue Jun 23 2009 ms@suse.de
- more virtio modules
* Tue Jun 23 2009 ms@suse.de
- update docs, --list-profiles moved to --info ... --select profiles
* Tue Jun 23 2009 ms@suse.de
- added virtio kernel modules to boot iamges (bnc #515543)
* Tue Jun 23 2009 ms@suse.de
- improved support for obtaining XML information (bnc #513093)
* Mon Jun 22 2009 ms@suse.de
- don't remove mkfs/fsck links, just a cleanup fix
* Mon Jun 22 2009 ms@suse.de
- v3.60
- don't remove libx*, 11.2 hwinfo is linked against libx86emu
* Fri Jun 19 2009 ms@suse.de
- v3.59
- fixed journal parameter handling in setupEXT2
* Fri Jun 19 2009 ms@suse.de
- fixed clone to search in default image path if source
  is specified as relative path
* Fri Jun 19 2009 ms@suse.de
- fixed checkType function if flags and filesystem attributes
  are used together. Using these attributes together in one
  type is redundant and therefore not correct but it should
  not lead to an error (bnc #514412)
- removed useless setValidateRepositoryType method
- add support for xml file logging. This allows to keep
  track on the temporary changes kiwi makes in the XML
  description caused by for example commandline options
* Fri Jun 19 2009 ms@suse.de
- fixed clean target
* Fri Jun 19 2009 ms@suse.de
- fixed clean target
* Thu Jun 18 2009 ms@suse.de
- combine manual pages and kiwi cookbook into one
* Wed Jun 17 2009 pschinagl@altair.suse.de
- updated documentation files
* Wed Jun 17 2009 pschinagl@altair.suse.de
- adding man pages to kiwi.pdf using joinPDF
* Wed Jun 17 2009 pschinagl@altair.suse.de
- Create pdfs from the man pages and append it to the kiwi.pdf
* Wed Jun 17 2009 pschinagl@altair.suse.de
- Changed refentrytitle to filename
* Wed Jun 17 2009 ms@suse.de
- fixed clicfs mount for pxe type (bnc #513826)
* Wed Jun 17 2009 pschinagl@altair.suse.de
- New chapter appendix as intropage for the man-pages
* Wed Jun 17 2009 pschinagl@altair.suse.de
- Added chapter appendix
* Wed Jun 17 2009 pschinagl@altair.suse.de
- set tocdepth to 2 to show new subsections and added an appendix chapter
* Wed Jun 17 2009 pschinagl@altair.suse.de
- Added subsections for the elements of config.xml
* Tue Jun 16 2009 ms@suse.de
- v3.58
- added -persist option when calling nbd-client (bnc #513112
* Wed Jun 10 2009 ms@suse.de
- fixed test case
* Wed Jun 10 2009 ms@suse.de
- fixed kernel/initrd links in setupSUSEInitrd (bnc #507261)
* Wed Jun 10 2009 ms@suse.de
- fixed use of mke2fs options
* Wed Jun 10 2009 ms@suse.de
- fixed SLE11 template iso type
* Wed Jun 10 2009 ms@suse.de
- fixed setRepository function so that it does not
  overwrite repositories marked with status="fixed"
* Wed Jun 10 2009 ms@suse.de
- call searchBIOSBootDevice only on initial deployment
  if the kiwi initrd is still in place for a subsequent boot
  use the root variable from the kernel commandline to find
  the boot disk, related to (bnc #507261)
* Tue Jun  9 2009 ms@suse.de
- added list of available patterns for --list-xmlinfo
* Tue Jun  9 2009 ms@suse.de
- added getSolfile method to be able to access the
  cached satsolver index file
* Tue Jun  9 2009 ms@suse.de
- fixed url list update when --add-repo is used
* Tue Jun  9 2009 ms@suse.de
- fixed kiwi --list-xmlinfo if repo doesn't exist
* Tue Jun  9 2009 ms@suse.de
- fixed typo
* Tue Jun  9 2009 ms@suse.de
- v3.57
- added support for ext4 filesystem, adapt 11.2 examples
- adapt 11.2 boot images for ext4
* Mon Jun  8 2009 ms@suse.de
- fixed dom0 Xen setup
* Fri Jun  5 2009 ms@suse.de
- v3.56
- fixed missing xen bootprofile in vmx and oem (bnc #510276)
- added ec2 bootkernel profile for vmx,oem,xen (bnc #510276)
* Thu Jun  4 2009 ms@suse.de
- fixed call of xsl stylesheet in kiwi.pl
* Thu Jun  4 2009 ms@suse.de
- default to "no" when the recovery dialog is displayed
* Wed Jun  3 2009 ms@suse.de
- moved schemeversion to schemaversion (bnc #509107)
* Tue Jun  2 2009 ms@suse.de
- moved <compressed> element into the <type> section
  added xsl stylesheet for transformation from scheme
  version 2.4 -> 3.5 according to this change. Always
  compress cpio images (bnc #509107)
* Tue Jun  2 2009 ms@suse.de
- fixed checkmedia reboot to happen immediately (bnc #509061)
- fixed checkmedia message (bnc #509060)
* Tue Jun  2 2009 matt@linux-871k.site
- Use O_LARGEFILE on the output open call as well
* Tue Jun  2 2009 matt@linux-871k.site
- Use O_LARGEFILE when opening an image in imagewriter
* Mon Jun  1 2009 ms@suse.de
- fixed documentation for bool value use (bnc #508614)
* Sun May 31 2009 ms@suse.de
- v3.55
- allow use of zypper iso:// URL type in kiwi (bnc #498437)
* Fri May 29 2009 mbarringer@suse.de
- Give the user more feedback when the imagewriter cannot open a file.
* Thu May 28 2009 ms@suse.de
- check for iso tool in KIWIIsoLinux.pm (bnc #478991)
- removed redundand relocateCatalog code, use the one
  from KIWIIsoLinux only
* Thu May 28 2009 ms@suse.de
- added kiwi --clone mode (bnc #505554)
* Wed May 27 2009 ms@suse.de
- v3.54
- added fix catalog function to KIWIIsoLinux.pm (bnc #478991)
- set inode count for system partition only, even if
  it has been specified via --fs-maxinodes (bnc #495135)
- fixed OEM recovery, set OEM_RECOVERY to the root device
  not the recovery device (bnc #503653)
* Tue May 26 2009 ms@suse.de
- fixed oem format="iso" install mode (bnc #506983)
- use dialog for asking questions (bnc #503653)
* Mon May 25 2009 ms@suse.de
- added resize_inode feature to filesystem before resizing.
  This will reserve space so the block group descriptor
  table may grow in the future (bnc #498683)
* Mon May 25 2009 ms@suse.de
- fixed clicfs mount, regression from my nfs fix
* Fri May 22 2009 ms@suse.de
- don't reserve blocks for clicfs without cow (bnc #505580)
* Fri May 22 2009 ms@suse.de
- reset IFS to standard value in CDDevice (bnc #505943)
* Fri May 22 2009 ms@suse.de
- added relocation function to KIWIIsoLinux module
* Fri May 22 2009 ms@suse.de
- rewrote KIWIIsoLinux.pm to allow bit/tri arch boot media
  the code has not been tested for efi or ikr due to lack of
  such machines (bnc #478991)
* Fri May 22 2009 ms@suse.de
- fixed typo in volid assignment
* Tue May 19 2009 ms@suse.de
- fixed/changed clicfs over NFS use. When using a clicfs
  image it's required that the clicfs filesystem is mounted
  on the server and the container (fsdata.ext3) is exported
  to the client. In that way it's consistent with all other
  filesystem types
* Tue May 19 2009 ms@suse.de
- set default volid for CD/DVD kiwi install media
* Tue May 19 2009 ms@suse.de
- fixed volid setup in case of format=iso setup (bnc #500501)
* Tue May 19 2009 ms@suse.de
- fixed typo
* Tue May 19 2009 ms@suse.de
- fixed volid setup in case of spaces (bnc #500501)
* Tue May 19 2009 ms@suse.de
- fixed doc hint for boot-theme
* Tue May 19 2009 ms@suse.de
- update documentation for bootinclude/bootdelete and boot-theme
  setup
- implement <boot-theme> setup
* Mon May 18 2009 ms@suse.de
- v3.52
- fixed clicfs mount over AOE,NBD (bnc #504652)
- allow inclusion of boot image packages specified inside
  the system image description. This feature is used to setup
  branding packages which needs to be installed as part of
  the boot image (initrd) (bnc #497888)
* Fri May 15 2009 ms@suse.de
- v3.51
- set keytable to us in template files (bnc #504275)
- fixed live iso examples (bnc #504283)
* Wed May 13 2009 ms@suse.de
- fixed group setup with correct group id (bnc #503117)
* Wed May 13 2009 ms@suse.de
- added bugid for spec file fix
- copy hidden files to home in oemboot code
* Wed May 13 2009 ms@suse.de
- fixed spec file
* Tue May 12 2009 ms@suse.de
- indentation fix
* Tue May 12 2009 ms@suse.de
- make use of new clicfs options for persistent writes
* Tue May 12 2009 ms@suse.de
- fixed spec file requirement for mkisofs on sle10
* Tue May 12 2009 adrian@scherben.(none)
- ensure that images.sh and config-cdroot.sh have execute permissions as well.
* Tue May 12 2009 adrian@scherben.(none)
- ensure that config.sh can get executed, even when it comes without execute permissions
* Fri May  8 2009 ms@suse.de
- added optional volid setup for iso's (bnc #500501)
- update scheme documentation from oXygen
* Thu May  7 2009 ms@suse.de
- don't set config file when calling modprobe in
  suseStripKernel function
- use 70%% of RAM for clicfs
* Thu May  7 2009 ms@suse.de
- validate MKCLICFS_COMPRESSION if set
- fixed tool hash for flags="clic"
- added free RAM value for clicfs mount instead of
  fixed size of 470M
* Wed May  6 2009 ms@suse.de
- fixed sap media changer call (bnc #486758)
- added more clic fixes, still not finished (bnc #497172)
- set inode count for system partition only (bnc #495135)
- fixed satsolver setup
* Tue May  5 2009 ms@suse.de
- 3.50
- added bash quotation function (bnc #500537)
* Tue May  5 2009 ms@suse.de
- more clicfs fixes
- fixed quotation of home and groups for user setup (bnc #500537)
- fixed system reboot if kiwi initrd is still in place
* Tue May  5 2009 ms@suse.de
- v3.49
- added clic fixes from coolo (bnc #497172)
- fixed quotation of realname for user setup (bnc #500537)
- fixed activateBootPartition code (bnc #500454)
* Tue May  5 2009 ms@suse.de
- fixed quotation of realname for user setup (bnc #500537)
- update documentation
* Mon May  4 2009 ms@suse.de
- allow setting up vga for iso images too (bnc #480336)
* Mon May  4 2009 ms@suse.de
- need eval to pass options to the mount call
* Mon May  4 2009 ms@suse.de
- detect if it is required to pass -t iso9660 (bnc #498497)
* Mon May  4 2009 ms@suse.de
- fixed permissions on recovery (bnc #489909)
* Mon May  4 2009 ms@suse.de
- added support for clicfs for suse >= 11.2 (bnc #497172)
  * ** not fully implemented and tested yet ***
- don't run path generation for iso:// and file:// paths
  if zypper is used (bnc #498437)
* Wed Apr 29 2009 ms@suse.de
- fixed initrd cpio if xen type is requested (bnc #399230)
* Wed Apr 29 2009 ms@suse.de
- fixed template xorg.conf for 64 bit
* Mon Apr 27 2009 ms@suse.de
- v3.47
- added kernel parameter nombridcheck (bnc #498371)
- remove boot/grub/mbrid file from installed system
  at first deployment to avoid conflicts on reboot
- set boot flag after repartitioning the device
- exclude install source device from being used as
  SAP data storage device
* Fri Apr 24 2009 ms@suse.de
- fixed format image creation for split type (bnc #497882)
- use -x option when copying system tree to avoid copying
  still mounted filesystems like proc for example (bnc #497984)
* Fri Apr 24 2009 ms@suse.de
- v3.46
- pass -t iso9660 when mounting CD/DVD devices. It's a kernel
  bug that slows down the bandwidth if not passing that value
  but the workaround is rock solid :) (bnc #493201)
* Thu Apr 23 2009 ms@suse.de
- prevent usb and storage modules from beeing loaded
  directly
* Thu Apr 23 2009 ms@suse.de
- don't reboot the system after OEMInstall, simply proceed
* Thu Apr 23 2009 ms@suse.de
- fixed kiwi_revision content in .profile
- fixed LVM repartition code if more than one VG exist
* Wed Apr 22 2009 ms@suse.de
- deacticate the bios 0x80 check it's not safe enough
- allow non interactive installation procedure in
  oem-sap-install mode. In case of multiple disks the smallest
  one is used for the system (bnc #486758)
* Wed Apr 22 2009 ms@suse.de
- activate volume groups before calling mkinitrd
* Wed Apr 22 2009 ms@suse.de
- restrict packagemanager names to smart and zypper
* Wed Apr 22 2009 ms@suse.de
- fixed filesystem detection if root is on LVM
* Wed Apr 22 2009 ms@suse.de
- fixed fstab setup of sapdata volume
* Wed Apr 22 2009 ms@suse.de
- added ovftool patch required for tech. preview
* Wed Apr 22 2009 ms@suse.de
- fixed bootpartition id for install image creation
* Wed Apr 22 2009 ms@suse.de
- v3.44
- fixed size of boot image partition when creating an
  install image of type: virtual disk
* Tue Apr 21 2009 ms@suse.de
- added missing entries in sysconfig/bootloader (bnc #495909)
* Tue Apr 21 2009 ms@suse.de
- let udev load modules if modules.order is provided by
  the kernel (bnc #493201)
* Mon Apr 20 2009 ms@suse.de
- added bool content type instead of text for
  rpm-excludedocs (bnc #496382)
* Mon Apr 20 2009 ms@suse.de
- fixed identifyFileSystem call
* Mon Apr 20 2009 ms@suse.de
- make sure DHCPHADDR is an uppercase value (bnc #495557)
- fixed probeFileSystem to take care if the first 512byte
  contains a bootloader (bnc #493489)
- fixed multicast activation/deactivation (bnc #356974)
- also check for include link to use --dereference when
  copying the overlay tree (bnc #490128)
* Mon Apr 20 2009 ms@suse.de
- fixed recovery device setup (bnc #493878)
* Tue Apr  7 2009 adrian@scherben.(none)
- fix mkpath calls for current perl
* Mon Apr  6 2009 ms@suse.de
- removed cromfs doesn't exist in 11.2
* Fri Apr  3 2009 ms@suse.de
- fixed SAP data VG creation
* Fri Apr  3 2009 ms@suse.de
- fixed SAP data storage setup if there is already a VG
* Fri Apr  3 2009 ms@suse.de
- fixed SAP storage check and data storage setup
* Fri Apr  3 2009 ms@suse.de
- v3.41
- fixed URL quoting when passing credentials (bnc #491475)
* Thu Apr  2 2009 ms@suse.de
- doc revision update
* Thu Apr  2 2009 ms@suse.de
- fixed xen config creation for bootprofile=xen and image type vmx
* Wed Apr  1 2009 ms@suse.de
- update man pages (variable names)
- leave gawk for oem images
* Tue Mar 31 2009 ms@suse.de
- fixed IFS setup for SAP functions
* Tue Mar 31 2009 ms@suse.de
- fixed typo
* Tue Mar 31 2009 ms@suse.de
- v3.40
- update manual pages. Patch by Peter Schinagl <peters@suse.de>
- added functions to run X inside preinit (bnc #486758)
* Tue Mar 31 2009 ms@suse.de
- added SAPDataStorageSetup function (bnc #486758)
* Mon Mar 30 2009 ms@suse.de
- added check functions SAPMemCheck, SAPCPUCheck
  and SAPStorageCheck. They apply if the oem-sap-install
  attribute is set for OEM images (bnc #486758)
* Mon Mar 30 2009 ms@suse.de
- leave libcom_err in isoboot
* Mon Mar 30 2009 ms@suse.de
- v3.39
- added a xendomain attribute in config.xml to be able to
  distinguish whether a virtual disk image should be a Xen
  dom0 host system or a Xen domU guest system. If no domain
  is set a dom0 image will be created
- added xenServer function to check if we run a Xen host
  or guest system. The bootloader setup is different for
  dom0 or domU. Adapt setupBootLoader* functions
- allow filesystem resizing to be used in isoboot
* Fri Mar 27 2009 ms@suse.de
- fixed xencons setup for lilo and syslinux
* Fri Mar 27 2009 ms@suse.de
- added support for virtual disk images as Xen guest. This
  means you can specify <type ..bootprofile="xen">vmx|oem</type>
  and the resulting virtual disk image can boot as Xen guest
  system. Patch by James Willcox <james@ximian.com>
* Fri Mar 27 2009 ms@suse.de
- v3.38
- added root fstab entry for compressed rootfs (bnc #486017)
- fixed console setup when booting into a Xen guest
* Thu Mar 26 2009 ms@suse.de
- really allow oem-reboot to take effect in recovery mode (bnc #487887)
* Thu Mar 26 2009 ms@suse.de
- v3.37
- added squashfs requirement for suse version > 10.1
- fixed solvable creation for repos without compressed
  meta data (packages and .pat file)
* Wed Mar 25 2009 ms@suse.de
- fixed build
* Wed Mar 25 2009 ms@suse.de
- v3.36
- allow oem-reboot to take effect in recovery mode (bnc #487887)
- improved the --list-xmlinfo option which now also prints
  information about the repositories used for the image
  and it will print out the install size in kB by using
  the satsolver. Users can so check how much space is
  required to build the root tree of the image
* Wed Mar 25 2009 ms@suse.de
- added compuled man pages
* Wed Mar 25 2009 ms@suse.de
- add --dest-dir check when --build runs
- fixed checkType function for iso tool check
- include xml man page source to git
- update template descriptions
* Tue Mar 24 2009 ms@suse.de
- add --dest-dir check when --build runs
- update template descriptions
* Mon Mar 23 2009 mbarringer@suse.de
- Checking in change allowing "-m" option to maximize the imagewriter window
* Mon Mar 23 2009 ms@suse.de
- removed KIWICollect_local.pm and also the --instsource-local
  option from the code base. This module is no longer maintained
  and all code related to this path went into KIWICollect.pm
* Mon Mar 23 2009 ms@suse.de
- better changelog entry for last zypper repo prio fix
* Mon Mar 23 2009 ms@suse.de
- fixed build, KIWICollect_local has been removed
* Mon Mar 23 2009 adrian@scherben.(none)
- obsolete second version of instsource module
* Mon Mar 23 2009 ms@suse.de
- v3.35
- added support for repo priority for zypper
* Mon Mar 23 2009 adrian@scherben.(none)
- add support for repository priorities with zypper
* Mon Mar 23 2009 adrian@scherben.(none)
- add support for priority ordering of repositories
* Fri Mar 20 2009 ms@suse.de
- fixed documentation changed wording from exten(d|t) to
  unpacked and package image
* Thu Mar 19 2009 ms@suse.de
- really fixed this path handling in upgrade mode
* Thu Mar 19 2009 ms@suse.de
- again fixed build script
* Thu Mar 19 2009 ms@suse.de
- fixed build tools
* Thu Mar 19 2009 ms@suse.de
- added suse-SLE10-JeOS template
* Thu Mar 19 2009 ms@suse.de
- v3.34
- fixed ignore element validation
- added suse-SLE10-JeOS template
* Tue Mar 17 2009 mbarringer@suse.de
- Trying to commit the MacOS port again
* Tue Mar 17 2009 mbarringer@suse.de
- Last commit failed for some reason
* Tue Mar 17 2009 mbarringer@suse.de
- Finished the MacOS X port
* Tue Mar 17 2009 ms@suse.de
- added support for arch attribute in pattern names
* Tue Mar 17 2009 ms@suse.de
- adapt ppc netboot descriptions
* Tue Mar 17 2009 ms@suse.de
- v3.33
- removed support for cromfs; dead and unmaintained fs
- added bootkernel attribute which allows to select a kernel
  profile defined in the boot image description
* Mon Mar 16 2009 ms@suse.de
- v3.32
- changed netboot descriptions >= 11.1 to provide diskless
  kernel profiles named diskless-kdefault and diskless-kpae.
  The standard diskless profile will no longer include a
  kernel
* Mon Mar 16 2009 ms@suse.de
- fixed oemboot workflow for dmsquash setup
* Mon Mar 16 2009 ms@suse.de
- fixed oemboot workflow for dmsquash setup
* Mon Mar 16 2009 ms@suse.de
- v3.31
- fixed broken CD/DVD mount path in isoboot workflow
- fixed vmxboot workflow for dmsquash setup
- fixed oemboot workflow for dmsquash setup
- fixed usbboot workflow for dmsquash setup
* Thu Mar 12 2009 ms@suse.de
- v3.30
- added warning message before installing system (bnc #484793)
* Thu Mar 12 2009 ms@suse.de
- v3.29
- added cdrkit-cdrtools-compat required for kiwi-desc-oemboot
- added experimental support for dmsquash filesystem type which is
  a squashfs filesystem containing an ext3 filesystem. The mount of
  the data happens via a device-mapper snapshot and allows
  copy-on-write access (bnc #483444)
- fixed install image size calculation in case of a compressed
  image. gzip -l was used but we ran into the >4GB bug mentioned
  in the gzip manpage (bnc #484247)
* Tue Mar 10 2009 ms@suse.de
- v3.28
- added crc-t10dif kernel module for 11.2 boot
- added x-bit to vmware .vmx file generated by kiwi
- don't use arch specific glibc in boot images
- don't specify cracklib but remove all possibly
  installed versions in boot images
* Mon Mar  9 2009 ms@suse.de
- fixed build helper tools according to svn -> git switch
